/***
*ap.h - Database adjustment parameter declarations
*
*$Id: ap.h 6.119 2007/09/18 17:18:30 hickcha Exp $
*
*   SPSD/M Copyright (c) 1987-1989, Minister of Regional Industrial Expansion.
*   All rights reserved.  Use, reproduction, or disclosure of this work,
*   as well as publication of results derived from this work, are subject
*   to the conditions specified in the SPSD/M License Agreement.
*
*Purpose:
*   This file declares the parameter structure, associated macro symbols,
*   and function prototypes associated with database adjustment.
*
*Revisions:
* +-----+----------+---------------------------------------------------------+
* | Who |   Date   | Description                                             |
* +-----+----------+---------------------------------------------------------+
* | CH  | 07/07/31 | Added EDUCADJFLAG, EDUCMPQ, EDUCMROC                    |
* | CH  | 07/06/08 | Added GFGSTIDX                                          |
* | CH  | 07/06/06 | Added GFPURPRC GFSELPRC                                 |
* | CH  | 07/02/12 | Removed DNINCFLAG                                       |
* | LP  | 05/09/23 | Removed GFUSECOM                                        |
* | CH  | 05/09/12 | Deleted variables idfdsft and iddeppch                  |
* | LP  | 05/09/12 | Added GFUSECOM                                          |
* | BBM | 05/07/12 | Added GFCLERGY                                          |
* | BBM | 05/01/11 | Added APRSFILE                                          |
* | LP  | 04/11/08 | Added APRVER                                            |
* | CH  | 04/03/22 | added GFNCALP and GFNCALN                               |
* | LP  | 04/03/16 | fixed typos                                             |
* | CH  | 04/03/09 | added EXPADJ                                            |
* | CH  | 04/02/09 | changed labels                                          |
* | CH  | 03/12/29 | added fxrepr                                            |
* | CH  | 03/11/17 | Added for 10.0: alimo homexp anncon                     |
* | CH  | 03/10/17 | Added for 10.0: intstu cgtc deppch iinvrd               |
* |     |          | Dropped for 10.0: scfoas scfuib scfctc scfptc scfftc    |
* |     |          |                   noth iint scfint ioinv scfcqp itogv   |
* |     |          |                   inogv ivetp iscfsa foravg             |
* | LP  | 02/07/23 | Removed IMPINTOPT - Interest imputation method          |
* | BBM | 02/06/12 | Add before or after tax LICO option: PTFAT parameter    |
* | BBM | 01/06/20 | Dropped GFINTPL/GFMORTI/GFHMKT/GFHMORT for version 9.0  |
* | BBM | 01/04/19 | Added GFCGLESS for version 9.0                          |
* | BBM | 01/04/19 | removed GFHOSSPO GFHOSSLF GFVENCAP for version 9.0      |
* | CH  | 00/05/08 | removed GFFDFATC                                        |
* | LP  | 99/06/28 | add IEMPADJ, IEMPBRK and IEMPBRKMAX (inc. adj. factors) |
* | CH  | 99/06/09 | drop GFFSITC, add GFSCFCQP GFSCFINT GFSCFSA             |
* | CH  | 99/06/07 | Label changes                                           |
* | BBM | 99/05/17 | Update definition of PTF parameter                      |
* | BBM | 99/02/11 | Update for Version 7.0                                  |
* | EGA | 98/06/22 | CTFAMSNA by region                                      |
* | BBM | 97/08/19 | drop EDXPMBY                                            |
* | BBM | 97/05/27 | Drop GFROYREB, GFROYTC, GFSTKCCF, GFSASKTI, GFRECSSP    |
* | BBM | 97/05/27 | Drop GFSTKSAV, GFHRENO                                  |
* | SFG | 97/05/26 | add CTCQPOPT parameter                                  |
* | BBM | 92/09/11 | remove GFEDUC growth parm (ideduc dropped for ideducm)  |
* | BBM | 92/06/26 | add PURB PURC PURR parameters (to replace UER)          |
* | BBM | 92/06/25 | drop MEDALLBY MEDANFBY UER parameter                    |
* | SFG | 92/02/27 | add CTCFGAS parameter                                   |
* | SFG | 92/02/19 | add CTCFALC, CTCFTOB, CTFAMSNA parameters               |
* | SFG | 92/02/04 | add back sex margin for GFIEMP                          |
* | SFG | 92/01/28 | add province margin to all GF's                         |
* | SFG | 92/01/28 | remove sex margin from GFIEMP                           |
* | SFG | 90/12/03 | disable res. inv. dummy (RESHVALRAT & RESRENTRAT)       |
* | SFG | 90/10/05 | Add provincial dimension to GFFMX                       |
* | SFG | 89/12/07 | Create DNINCFLAG                                        |
* | --- | 89/10/13 | Release 4.0                                             |
* |     |          |                                                         |
* +-----+----------+---------------------------------------------------------+
*
*Dependencies:
*   #include <stdio.h>   Required for definition of FILE
*   #include "spsm.h"    Required for manifest constants and macros
*   #include "vsu.h"     Required by 'vs.h'
*   #include "vs.h"      Required for age() prototype
*   #include "pm.h"      Required for apin(), apd() prototypes
*   #include "apu.h"     Required for declaration of 'apu' substructure
*   #include "ap.h"
*
*****************************************************************************/



/* ==================== MANIFEST CONSTANTS ================================ */

/**
* UAGESIZE determines the amount of space, in bytes, to be reserved
* for the user control structure (identified by 'apu' and declared in apu.h).
* The difference between UAGESIZE and the actual size of the user database
* adjustment structure (a substructure of the A structure declared below) is
* filled by a compile-time filler array of char's.
**/

#define UAGESIZE 1601

/* define array bounds */

#define PTFMAX   7   /* maximum of number of rows in PTF table */
#define	IEMPBRKMAX   9   /* maximum number of rows in IEMPBRK table */
#define	EDUCMPQMAX   12   /* maximum number of rows in EDUCMPQMAX table */
#define	EDUCMROCMAX   12   /* maximum number of rows in EDUCMROCMAX table */


/* ==================== STRUCTURE DECLARATION MACROS ====================== */

#define S_AP   struct AP_
#define P_AP   S_AP *



/* ==================== STRUCTURE DECLARATIONS ============================ */

/**
* The structure identified by the letters 'ap' holds parameter values
* used to adjust individual SPSD variables.  Values for these parameters
* are contained in files with the '.apr' extension.
**/

typedef struct AP_ {

	/*	2.2 Database Adjustment Parameters */

	char APRDESC[LABSIZE+1];   /* Description of database adjustment parameter file */
	char APRVER[HDRSIZE+1];    /* SPSD/M Release Version [string]          */
	char APRSFILE[PATHSIZE+1]; /* Starting Adjustment parameter file [string] */
	int    PROVMAP[NUMREG]; /* Provincial remapping [prov] */ 
	int    IMPUIBOPT;    /* Imputation method, UI [1=none 2=rank] */
	int    IMPSAOPT;     /* Imputation method, SA [1=none 2=rank] */
	int    IMPCQPOPT;    /* Imputation method, CQP [1=none 2=rank] */
	int    KEEPNEGEXP;   /* Retain negative expenditures in SHS */
	NUMBER CTTXRM[NUMCOM][NUMREG]; /* Base year commodity tax removal factor [com x prov] */ 
	NUMBER CTCFALC[NUMREG]; /* SHS reporting error adjustment: Alcohol [prov] */ 
	NUMBER CTCFTOB[NUMREG]; /* SHS reporting error adjustment: Tobacco [prov] */ 
	NUMBER CTCFGAS[NUMREG]; /* SHS reporting error adjustment: Gasoline [prov] */ 
	NUMBER CTFAMSNA[NUMCOM][NUMREG]; /* SHS->SNA conceptual conversion factor [com] */ 

	/*	2.2.1 Dollar Denominated Parameters */

	NUMBER EARNMIN;      /* Earnings threshold to be an earner */
	NUMBER PTF[PTFMAX][NUMURB];  /* Low income cut-off Before Tax [size, urban] */
	NUMBER PTFAT[PTFMAX][NUMURB];  /* Low income cut-off After Tax [size, urban] */
	int    RRSPIFLAG;    /* RRSP increment activation flag              */
	NUMBER RRSPEMIN;     /* Minimum (rpp+rrsp) for increment if rpp>0 */
	NUMBER RRSPEMAX;     /* Maximum (rpp+rrsp) for increment if rpp>0 */
	NUMBER RRSPEINC;     /* Increment to rrsp if conditions & rpp>0    */
	NUMBER RRSPSMIN;     /* Minimum (rrsp) for increment if rpp=0     */
	NUMBER RRSPSMAX;     /* Maximum (rrsp) for increment if rpp=0     */
	NUMBER RRSPSINC;     /* Increment to rrsp if conditions & rpp=0   */
	int    EDUCADJFLAG;    /* Adjust education months activation flag */
	NUMBER EDUCMPQ[EDUCMPQMAX][EDUCAGE];     /* Distribution of months in school by age for Quebec */
	NUMBER EDUCMROC[EDUCMROCMAX][EDUCAGE];     /* Distribution of months in school by age for provinces other than Quebec */

	/*	2.2.2 Database Adjustment Factors */

	/*	2.2.3 UI Growth Parameters */

	NUMBER UIBASEYRMAX;      /* Maximum insurable earnings for base year   */
	NUMBER UITARGYRMAX;      /* Maximum insurable earnings for target year */
	NUMBER PURB[NUMREG];     /* Base year unemployment rate [prov] */
	NUMBER PURC[NUMREG];     /* Current year unemployment rate [prov] */
	NUMBER PURR[NUMREG];     /* Ratio current:base unemployment rate [prov] */

	/*	2.2.4 Income and Deduction Items */

	NUMBER GFADDDED[NUMREG];     /* Growth Factor: Additional deductions from net income (256) */
	NUMBER GFALEXP[NUMREG];      /* Growth Factor: Other allowable employment expenses (229) */
	NUMBER GFCAPGEX[NUMREG];     /* Growth Factor: Capital gains exemptions (254)*/
	NUMBER GFCARRY[NUMREG];      /* Growth Factor: Carrying charges (221) */
	NUMBER GFCCET[NUMREG];       /* Growth Factor: Child care expenses associated with child */
	NUMBER GFCCETT[NUMREG];      /* Growth Factor: Child care expenses (Limit A, Form T778)  */
	NUMBER GFCGLESS[NUMREG];     /* Growth Factor: TCG Less Cap Gains Ded on Cap Prop Gifts  */
	NUMBER GFCGTC[NUMREG];       /* Growth Factor: Caregivers tax credit (315)  */
	NUMBER GFCHARIT[NUMREG];     /* Growth Factor: Charitable donations (340)  */
	NUMBER GFCLERGY[NUMREG];     /* Growth Factor: Clergy residential deduction */
	NUMBER GFCLOSS[NUMREG];      /* Growth Factor: Allowable other years capital loss (253) */
	NUMBER GFCPPL65[NUMREG];     /* Growth Factor: CPP for age < 65 */
	NUMBER GFCPP65[NUMREG];      /* Growth Factor: CPP for age 65 */
	NUMBER GFCPP66[NUMREG];      /* Growth Factor: CPP for age 66 */
	NUMBER GFCPP67[NUMREG];      /* Growth Factor: CPP for age 67 */
	NUMBER GFCPP68[NUMREG];      /* Growth Factor: CPP for age 68 */
	NUMBER GFCPP69[NUMREG];      /* Growth Factor: CPP for age 69 */
	NUMBER GFCPP70[NUMREG];      /* Growth Factor: CPP for age 70 */
	NUMBER GFCPP71[NUMREG];      /* Growth Factor: CPP for age 71 */
	NUMBER GFCPP72[NUMREG];      /* Growth Factor: CPP for age 72 */
	NUMBER GFCPP73[NUMREG];      /* Growth Factor: CPP for age 73 */
	NUMBER GFCPP74[NUMREG];      /* Growth Factor: CPP for age 74 */
	NUMBER GFCPP75[NUMREG];      /* Growth Factor: CPP for age 75 */
	NUMBER GFCPPG75[NUMREG];     /* Growth Factor: CPP for age > 75 */
	NUMBER GFDALIMO[NUMREG];     /* Growth Factor: Alimony paid (220)  */
	NUMBER GFDISOTH[NUMREG];     /* Growth Factor: Disability amount for dependants (318) */
	NUMBER GFDISSLF[NUMREG];     /* Growth Factor: Disability amount for self (316) */
	NUMBER GFDUES[NUMREG];       /* Growth Factor: Union and professional dues (212) */
	NUMBER GFEMPLO[NUMREG];      /* Growth Factor: Employee home relocation loan dedn (248) */
	NUMBER GFEXPLOR[NUMREG];     /* Growth Factor: Exploration and development expenses (224) */
	NUMBER GFFORINC[NUMREG];     /* Growth Factor: Net foreign income (508) */
	NUMBER GFFORTX[NUMREG];      /* Growth Factor: Foreign tax paid (507) */
	NUMBER GFGIFTS[NUMREG];      /* Growth Factor: Gifts to Canada/provinces/culture (342) */
	NUMBER GFGSTREB[NUMREG];      /* Growth Factor: GST rebate (457) */
	NUMBER GFHOMSTU[NUMREG];     /* Growth Factor: College residence/resident homeowner assistance (558) */
	NUMBER GFIALIMO[NUMREG];     /* Growth Factor: Alimony Income */
	NUMBER GFICAPG[NUMREG];      /* Growth Factor: Capital gains (actual) (127 * 1.5) */
	NUMBER GFIDIV[NUMREG];       /* Growth Factor: Dividend income (actual) (120 / 1.5) */
	NUMBER GFIEMP[NUMREG][2];    /* Growth Factor: Employment income [province,sex] */
	NUMBER GFILOSS[NUMREG];      /* Growth Factor: Business investment losses (217) */
	NUMBER GFINTSTU[NUMREG];     /* Growth Factor: Interest paid on student loans (319) */
	NUMBER GFIINVND[NUMREG];     /* Growth Factor: Investment income (excluding dividend) */
	NUMBER GFIPENS[NUMREG];      /* Growth Factor: Pension income (115) */
	NUMBER GFISA[NUMREG];        /* Growth Factor: Social assistance income */
	NUMBER GFISEFM[NUMREG];      /* Growth Factor: Self-employed income - farming */
	NUMBER GFISENF[NUMREG];      /* Growth Factor: Self-employed income - non-farming */
	NUMBER GFITC[NUMREG];        /* Growth Factor: Federal investment tax credits (412) */
	NUMBER GFITOTH[NUMREG];      /* Growth Factor: Other non-government income (taxable) */
	NUMBER GFITRRSP[NUMREG];     /* Growth Factor: Taxable RRSP withdrawals */
	NUMBER GFIWORKC[NUMREG];     /* Growth Factor: Worker's compensation */
	NUMBER GFLABTXG[NUMREG];     /* Growth Factor: Labour funds tax credit (414) */
	NUMBER GFMEDGRO[NUMREG];     /* Growth Factor: Medical expenses, gross (330) */
	NUMBER GFMINCAR[NUMREG];     /* Growth Factor: Minimum tax carryover (504) */
	NUMBER GFMOVEXP[NUMREG];     /* Growth Factor: Imputed moving expenses (219) */
	NUMBER GFMSCHPD[NUMREG];     /* Growth Factor: Manitoba school taxes paid */
	NUMBER GFNCLOS[NUMREG];      /* Growth Factor: Allowable other years non-capital loss (252) */
	NUMBER GFNORTH[NUMREG];      /* Growth Factor: Northern deductions (255) */
	NUMBER GFOTHDED[NUMREG];     /* Growth Factor: Other deductions from total income (232) */
	NUMBER GFOTHPE[NUMREG];      /* Growth Factor: Other dependant exemptions (305) */
	NUMBER GFPARTLO[NUMREG];     /* Growth Factor: Limited partnership losses (251) */
 	NUMBER GFPOLCON[NUMREG];     /* Growth Factor: Federal political contributions (409) */
	NUMBER GFPROPTX[NUMREG];     /* Growth Factor: Net property taxes paid (556) */
	NUMBER GFPRVFTC[NUMREG];     /* Growth Factor: Provincial foreign tax credit (Form T2036) */
	NUMBER GFPRVPOL[NUMREG];     /* Growth Factor: Provincial political contributions (565) */
	NUMBER GFRENTPD[NUMREG];     /* Growth Factor: Total rental payments (555) */
	NUMBER GFRPP[NUMREG];        /* Growth Factor: Registered pension plan contributions (207) */
	NUMBER GFRRSP[NUMREG];       /* Growth Factor: RRSP contributions (208) */
	NUMBER GFSAPRED[NUMREG];     /* Growth Factor: Predicted benefits from Social Assistance */
	NUMBER GFSTKDED[NUMREG];     /* Growth Factor: Stock option deduction (249) */
	NUMBER GFTUITN[NUMREG];      /* Growth Factor: Tuition fees (320) */
	NUMBER GFUIPRED[NUMREG];     /* Growth Factor: Predicted benefits from UI */
	NUMBER IEMPADJ[IEMPBRKMAX][NUMREG];    /* Adjustment Factor: Employment income [employment income breaks,province] */
	NUMBER IEMPBRK[IEMPBRKMAX];    /* Adjustment Factor: Income breaks for income adjustment[employment income breaks] */


	/*	2.2.5 SHS Expenditure Items */

	NUMBER EXPADJ[NUMREG];        /* Adjustment Factor: All expenditure adjustment */
	NUMBER GFFMX[NUMCOM][NUMREG]; /* Adjustment Factor: consumer expenditure categories [commodity] */
	NUMBER GFRECOM[NUMREG];       /* Adjustment Factor: Real estate commissions */
	NUMBER GFIPAC[NUMREG];        /* Adjustment Factor: Life insurance premiums and annuity contributions */ 
	NUMBER GFGVPEN[NUMREG];       /* Adjustment Factor: Government pension plan contributions */ 
	NUMBER GFPVPEN[NUMREG];       /* Adjustment Factor: Private pension plan contributions */
	NUMBER GFCQP[NUMREG];         /* Adjustment Factor: CPP/QPP contributions */
	NUMBER GFUIC[NUMREG];         /* Adjustment Factor: UI contributions */
	NUMBER GFINTAX[NUMREG];       /* Adjustment Factor: Income taxes */
	NUMBER GFPRTAX[NUMREG];       /* Adjustment Factor: Property tax */
	NUMBER GFTPTAX[NUMREG];       /* Adjustment Factor: Transfer of property taxes */
	NUMBER GFRFEES[NUMREG];       /* Adjustment Factor: Registration and license fees */
	NUMBER GFNES[NUMREG];         /* Adjustment Factor: Not elsewhere stated */
	NUMBER GFNCALN[NUMREG];       /* Adjustment Factor: Negative change in assets and liabilities */
	NUMBER GFNCALP[NUMREG];       /* Adjustment Factor: Positive change in assets and liabilities */
	NUMBER GFRRSPT[NUMREG];       /* Adjustment Factor: Total RRSP contributions (SHS) */
	NUMBER GFFABD[NUMREG];        /* Adjustment Factor: Account balancing difference */
	NUMBER GFFOMR[NUMREG];        /* Adjustment Factor: Other money receipts */
	NUMBER GFALIMO[NUMREG];       /* Adjustment Factor: Alimony and child support */
	NUMBER GFHOMEXP[NUMREG];      /* Adjustment Factor: Expenses associated with princ residence */
	NUMBER GFANNCON[NUMREG];      /* Adjustment Factor: Annuity contracts and transfers to RRIFs */
	NUMBER GFREPR[NUMREG];        /* Adjustment Factor: Repairs paid */
	NUMBER GFSELPRC[NUMREG];      /* Adjustment Factor: Selling price of home */
	NUMBER GFPURPRC[NUMREG];      /* Adjustment Factor: Purchase price of home */
	NUMBER GFGSTIDX[NUMREG][2];   /* Adjustment Factor: GST on housing index [province][tenure] */

	int UERrows;     /* number of rows in UER (fixed at NUMURB) */
	int PTFrows;     /* number of rows in PTF (fixed at NUMURB) */
	int NUMCOMrows;  /* number of rows for commodity dimension parms with E_FIXL */
	int NUMREGrows;  /* number of rows for region dimension parms with E_FIXL */
	int IEMPBRKrows;  /* number of rows for employment income break points  */ 
	int EDUCMPQrows;  /* number of rows education adjustment parameters  */ 
	int EDUCMROCrows;  /* number of rows education adjustment parameters  */ 

	S_UA UA;          /* User database adjustment parameters (see apu.h) [struct] */
	char APfill[UAGESIZE-sizeof(UA_)]; /* Filler to keep AP fixed in size [array] */


} AP_;



/* ==================== GLOBAL VARIABLE DECLARATIONS ====================== */

/**
* The global structure 'AP' holds parameter values used to adjust the SPSD.
* 'AP' is defined and initialised in 'global.c' .
**/

extern S_AP AP;


/**
* AGENAME is the global database adjustment identifier used to document which
* data adjustment algorithms were used in a run.
* It is defined and initialised in 'adju.c' .
**/

extern char AGENAME[IDSIZE+1];



/* ==================== FUNCTION PROTOTYPES =============================== */

#ifdef P_hh    /* declare prototypes taking hhld or sub-structures */
	extern  void adj(P_hh hhld);
#endif

#ifdef P_pc
	extern  void apin(P_pc pap, FILE *fp, FILE *fpcom);
	extern  void apd(P_pc pap);
#endif

extern  int  apc(void);
