/***
*mp.h - Tax/transfer parameter declarations
*
*$Id: mp.h 6.339 2007/09/18 17:18:30 hickcha Exp $
*
*   SPSD/M Copyright (c) 1987-1988, Minister of Supply and Services.
*   All rights reserved.  Use, reproduction, or disclosure of this work,
*   as well as publication of results derived from this work, are subject
*   to the conditions specified in the SPSD/M License Agreement.
*
*Purpose:
*   This file declares the parameter structure, associated macro symbols,
*   and function prototypes associated with tax/transfer parameters.
*
*Revisions:
* +-----+----------+---------------------------------------------------------+
* | Who |   Date   | Description                                             |
* +-----+----------+---------------------------------------------------------+
* | CH  | 07/07/30 | Added MAMTFTCFLG and CAMTFTCFLG                         |
* | CH  | 07/07/30 | Added QTUITRFFLG                                        |
* | CH  | 07/07/23 | Added CTPNEW and CTFNEW                                 |
* | LP  | 07/07/20 | Added 2 flags to CCE - QCCEEIFLG and QCCEEITST          |
* | CH  | 07/07/17 | Added QCMPOPT QPSXMINC QTPCFLG QESSNEEDS QLAXOLDDEP     |
* | LP  | 07/07/08 | Added Manitoba Child Benefit parameters (MCBFLAG +)     |
* | LP  | 07/07/05 | Added NL Senior Benefit parameters for senior couples   |
* | CH  | 07/06/25 | Added CTFGSTHOUSE                                       |
* | LP  | 07/06/04 | Added Ontario Child Benefit parameters                  |
* | LP  | 07/04/24 | Added non-refundable child tax credit - CTCAMTPC        |
* | LP  | 07/04/24 | Relabeled previous child tax credit parms as refundable |
* | LP  | 07/04/04 | Added Working Income Tax Benefit (WITB) - ref. credit   |
* | LP  | 07/02/23 | Changed Ont/Alt clawback parm, add clawback for cal year|
* | CH  | 07/02/22 | Added AHCIPINCFLG and CMSPINCFLAG                       |
* | CH  | 07/02/22 | Added PENSPLTINCR and QPENSPLTINCR                      |
* | CH  | 07/02/19 | Added CTCAPTOBFLG, CTTOBMAX, removed CTDFLAG CT[FP]TOT  |
* | LP  | 07/02/15 | Added OHPFLAG, ACHIPFLG, CMSPFLAG, prov health prem flgs|
* | LP  | 07/02/13 | Removed QDTCWCA, use revised QPSXM for all years/program|
* | LP  | 07/02/12 | Added QSTRMAGE, minimum age flag for Q. Sales Tax Credit|
* | CH  | 07/02/06 | Added pension income splitting                          |
* | LP  | 07/02/02 | Deleted QAMTINCRT, added QAMTCAPR                       |
* | LP  | 07/01/25 | Deleted CLERGYRD - not required, clergy always deducted |
* | LP  | 07/01/22 | Added 'eligible' to all large corporation dividend parm |
* | LP  | 07/01/22 | Removed provincial UCCB in income test flags - _UCCBITF |
* | LP  | 07/01/22 | Added AMTDIVLC - AMT Dividend Rate for eligible dividend|
* | LP  | 07/01/15 | Remove VUCCBTC, add PYCTCAPM, PYCTCPI, VYCTCAPM, VYCTCPI|
* | LP  | 07/01/12 | Removed parameter QHSCDIR, QDIVRAT - no longer needed   |
* | LP  | 06/12/27 | Removed MTCINCFL - unnecessary given net income changes |
* | LP  | 06/07/18 | Added back UIEFFLAG, UIRGERATE and UILFERATE            |
* | LP  | 06/07/07 | Added CSUPCR - BC supplementary tax credit for 2000 and |
* |     |          | added CPTCREF - BC political tax credit refundable flag |
* | LP  | 06/07/04 | Added Ont. Home Electricity Relief Program - OHEATFLG+  |
* | LP  | 06/07/04 | Added CSTCKID - BC sales tax credit amount for kids     |
* | LP  | 06/06/27 | Removed UILFERATE, UIRGERATE, UIEFFFLAG - no longer used|		 
* | LP  | 06/06/14 | Removed OASTBPI - OAS tax back completely phased in 91  |
* | LP  | 06/06/13 | Added prev. yr's parms for Alta Sen. Ben. for calendar  |
* | LP  | 06/06/12 | Added Phase in rates for AFETC and Fed Child Tax Benefit|
* | LP  | 06/06/09 | Removed provincial AXPI series, QCCEA1,2,3 not required |
* | LP  | 06/06/08 | Added Sask Sales Tax Credit parms for calendar year calc|
* | LP  | 06/06/07 | Added provincial flags to remove UCCB from income tests |
* | LP  | 06/06/05 | Added previous years' parms for GST credit for calendar |
* | LP  | 06/05/25 | Added UCCBFLAG & UCCBAMT universal child care benefit   |
* | LP  | 06/05/23 | Added previous years' parms for federal child benefit   |
* |     |          | to enable proper calendar year calculations             |
* | LP  | 06/05/15 | Added large corp. dividend parms for gross up and tax   |
* |     |          | credits, federally and provincially                     |
* | LP  | 06/05/11 | Added Canada Employment Credit EMPTXC                   |
* | CH  | 06/05/11 | Added ONCBSFT Ontario flow through of sa claw           |
* | LP  | 06/05/08 | Added MEDRTD refundable medical expense income turndown |
* | LP  | 06/05/05 | Added textbook tax credit TEXTPMFT and TEXTPMPT         |
* | LP  | 06/05/05 | Deleted CCEALIM                                         |
* | LP  | 06/04/20 | Added MCMINAGE - Man. cost of living credit min. age    |
* | LP  | 06/01/23 | Added SASKTECA - Sask. temporary energy cost allowance  |
* | CH  | 06/01/19 | Added QPIPEADJ, deleted QPIPEARN                        |
* | LP  | 06/01/19 | Changed QPIPBMTR label                                  |
* | LP  | 06/01/17 | Added SACLAWOPT to imsaclaw for incl in total/disp inc  |
* | LP  | 06/01/13 | Fixed labels for provincial AMT options (shorter labels)|
* | CH  | 06/01/04 | Deleted QPIPSEES                                        |
* | LP  | 05/12/28 | Removed ORDOPT & OMTY - pre 1991 parms for Ont tax red  |
* | LP  | 05/12/20 | Added Quebec Parental Insurance Plan parameters         |
* | CH  | 05/12/11 | Changed Labels                                          |
* | LP  | 05/12/01 | Removed CTFOEN & CTFMFG - pre 91 parameters deleted     |
* | LP  | 05/11/29 | Shortened label - QFATCOPT, too long to add all options |
* | LP  | 05/11/23 | Added NS rebate for elec VHEATERB, removed VHEATFRR     |
* | LP  | 05/11/17 | Removed pre 1991 UI parameters and QSTROPT              |
* | LP  | 05/11/14 | Added N.B. Home Heating Oil Benefit program (BHEAT..)   |
* | LP  | 05/10/25 | Added income test to NFLD home heating fuel rebate      |
* | LP  | 05/10/21 | Add Fed. Energy Cost Benefit, FECBFLAG,FECBGIS,FECBNCBS |
* | CH  | 05/09/12 | Deleted CHATPROP                                        |
* | LP  | 05/07/08 | Added back SA clawback parameters (SACLAWFLAG, etc.)    |
* | LP  | 05/05/30 | Added QRNCGFLG, QRNCGTC refund natural caregivers tx crd|
* | LP  | 05/05/26 | Added OSTCNIBC - income turndown for senior couples     |
* | LP  | 05/05/16 | Added AHCIPSPI - Health premium seniors exempt phase-in |
* | LP  | 05/05/11 | Added new deduction for workers (QEMPDEDP and QEMPDEDM) |
* | SFG | 05/05/10 | Removed second argument to mpd, Ampd                    |
* | LP  | 05/05/09 | Added BC low inc. tax reduction CLITR, CLITRTD, CLITRRR |
* | LP  | 05/05/06 | Added VHEATFLG + VHEAT series N.S. home-heating rebate  |
* | LP  | 05/04/19 | Added AFETCAPC enhanced ben. by # kids, Removed AFETCBPC|
* | LP  | 05/04/15 | Added BXMEXT, MXMEXT, EMXMEXT, MXMTEXT, EMXMTEXT        |
* | BM  | 05/01/11 | Added MPRSFILE                                          |
* | BM  | 04/11/09 | Added MPRVER                                            |
* | LP  | 04/07/20 | Added Alta Health Care Insurance Plan (health premium)  |
* | LP  | 04/07/15 | Added B.C. Medical Service Plan (MSP) Premium (CMSP + ) |
* | LP  | 04/07/14 | Added QAMTSTTC - spouse transfer tax credit flag for AMT|
* | LP  | 04/07/09 | Added Nfld. Low Income Tax Reduction - NLITR series     |
* | LP  | 04/06/22 | Added Sask. Child Benefit Single Parent Amount - SCBSPA |
* | LP  | 04/06/18 | Added Child Assistance - QCAFLAG + others and new non-  |
* |     |          | ref dep cred (QDTCWCA, QDTCNCA1, QDTCNCA2 and QDTCSPA)  |
* | LP  | 04/06/09 | Added Work Premium Refundable Credit - QWPFLAG + others |
* | LP  | 04/06/04 | Added Ont. Health Premium - OHPBASE and OHPPI (phase in)|
* | LP  | 04/06/02 | Added OFTCOPT - foreign tax credit application option   |
* | LP  | 04/06/02 | Added OSPSMAX - Ont. prop/sales tax credit senior max   |
* | LP  | 04/05/27 | Added NMBNSEXT, NMBNSEPI - Nfld MBNS newborn extra ben  |
* | LP  | 04/05/13 | Added QSTSCA - Que. Single Tax System Complementary Amt.|
* | LP  | 04/03/16 | fixed typos                                             |
* | LP  | 04/03/09 | Added ASBSAB, ASBSABRR supplemental accommodation benef.|
* | LP  | 04/02/23 | Removed Social Assistance Clawback parameters           |
* | LP  | 04/02/20 | Removed ALTAWP and Sask. Employ. Supplement parameters  |
* | LP  | 04/02/11 | Added QREPFAMI QHSSFLSS QHSSFUIR QHSSFALM QHSSFCAR      |
* |     |          | QNORFAMI QTRSAFAM QTRWCFAM                              |
* | CH  | 04/02/09 | Label changes                                           |
* | LP  | 04/01/06 | Removed provincial CGTC take ups and income turn downs  |
* | LP  | 03/12/22 | Added prov. non-ref medical tax credit _MEDALL & _MEDANF|
* | LP  | 03/12/19 | Added CCEPTFLG - part time student cce eligibility flag |
* | LP  | 03/12/19 | Added CHATPROP - gifts of depreciable property flag     |
* | LP  | 03/12/18 | Added QODISTC - infirm dependents 18 and over tax credit|
* | LP  | 03/12/18 | Added ODISTC - infirm dependents (18+) tax credit       |
* | LP  | 03/12/08 | Added infirm dependents max tax credit amounts (_ODISTC)|
* | LP  | 03/12/08 | Added QHPTCOPT - Que. housing parent tax credit option  |
* | LP  | 03/11/17 | Added ACGTCOPT, CCGTCOPT, MCGTCOPT, SCGTCOPT, OCGTCOPT, |
* |     |          |   BCGTCOPT, VCGTCOPT, PCGTCOPT, NCGTCOPT, CGTCOPT       |
* | LP  | 03/11/17 | Added INTSLFLG - Fed. stud loan interest tax credit flag|
* | LP  | 03/11/17 | Added QINTSLTC - Que. stud loan interest tax credit flag|
* | LP  | 03/11/13 | Added AEDXPMPT, CEDXPMPT, MEDXPMPT, SEDXPMPT, OEDXPMPT, |
* |     |          |   BEDXPMPT, VEDXPMPT, PEDXPMPT, NEDXPMPT, EDXPMPT       |
* | CH  | 03/11/04 | Deleted FORAVGFLAG                                      |
* | CH  | 03/05/30 | New and changed SA clawback parms                       |
* | CH  | 03/05/22 | Added Extra QSTR                                        |
* | CH  | 03/05/16 | NS Taxpayer refund program implemented                  |
* | CH  | 03/05/16 | Added NHEATSAFLG                                        |
* | CH  | 02/06/26 | Decreased UPRMSIZE                                      |
* | CH  | 02/06/25 | Increased UPRMSIZE                                      |
* | LP  | 02/06/21 | Added OCCSEXT one time $100 payment to OCCS families    |
* | LP  | 02/06/17 | Added Nfld Mother-Baby Nutrition Supp. (NMBNS & NMBNSPI)|
* | LP  | 02/05/17 | Added social assistance/NCBS clawback parameters        |
* | LP  | 02/04/30 | Added QSFDED, QSFTXCR, QSFMED and QNORTHDED             |
* | LP  | 01/07/18 | Removed NTCMAX                                          |
* | LP  | 01/07/10 | Added take ups for SES and EI Contribution refund       |
* | LP  | 01/06/22 | Added Sask. Employ Supplementary benefit for under 13   |
* | BBM | 01/06/20 | Drop NTCMAX OHIRF OHT VHOSPR VHOSPRM VHOT VHOTM  (no GB)| 
* | CH  | 01/06/12 | Changed EI code to incorporate 9.0 database variables   | 
* | LP  | 01/06/12 | Added OPTCFLAG- political cont tx cred. refundable flag |
* | LP  | 01/06/11 | Added NLVCMAX and NLVCRT labour sponsored venture cap.  |
* | LP  | 01/05/31 | Added N.B. Low-Income Tax Reduction parameters          |
* | LP  | 01/05/16 | Added new Quebec Alternative Minimum Tax parameters     |
* |     |          |   and removed QCAPRAT                                   |
* | LP  | 01/05/09 | Added new Federal Alternative Minimum Tax parameters    |
* | LP  | 01/05/09 | Added new Provincial Alternative Minimum Tax parameters |
* | BBM | 01/04/19 | Removed OHCMAX,VHOSPMAX,CVCMAX (no vars imputed in 9.0) |
* | LP  | 01/04/10 | Added SPTC, SPTCBEN Sask political contrib. tax credit  |
* | LP  | 01/04/05 | Added NBSBSPA NB seniors' benefit SPA eligibility flag  |
* | LP  | 01/04/03 | Added BC, Alta. & Sask. Home Heating Assistance Rebates |
* | LP  | 01/04/02 | Added NHEATFLG & NHEATREB NFLD Home Heating Fuel Rebate |
* | CH  | 01/03/16 | Increased number of rows of QCCETCR                     |
* | LP  | 01/03/05 | Removed Federal Senior's Benefit parameters             |
* | LP  | 01/03/05 | Added NSCI2 & NSF2 Newfoundland surtax 2nd level, rate  |
* | CH  | 00/12/19 | Family supplement additions                             |                                          
* | LP  | 00/11/16 | Removed QDEPNIFG flag for SA, etc in net income flag    |
* | LP  | 00/11/16 | Added QSPBFLAG, QSADED, QNFSDED (social benefits flags) |
* | CH  | 00/10/24 | Added CPP deduction for the self-employed               |
* | CH  | 00/10/24 | Added UIEIREPOPT                                        |                                          
* | CH  | 00/10/24 | Removed medical expense supplement turndown             |
* | CH  | 00/10/24 | Added relief for heating expenses                       |
* | LP  | 00/10/18 | Added QFAMNETI (family net income concempt for credits) |
* | LP  | 00/06/05 | Added GSTCTUNC - GST credit take up by # eligible kids  |                                          
* | LP  | 00/06/01 | Added CPP Contribution Take ups by age range and income |                                          
* | CH  | 00/05/24 | Added ALEXDEDFLG                                        |                                          
* | LP  | 00/05/16 | Added MTRNIOS Man. tax reduction net income offset      |
* | CH  | 00/05/15 | Added MHMASOPT                                          |
* | CH  | 00/05/12 | Removed FDFATCFLAG                                      |
* | CH  | 00/05/12 | Added taxpayer dividend                                 |
* | LP  | 00/05/09 | Added OCGIRFLG, OCAPGIR Ont Capital Gains Inclusion rate|
* | LP  | 00/05/03 | Added OCWISSP max annual benefit for single parents     |
* | CH  | 00/05/01 | Added flag for type and modified training               |                                          
* | LP  | 00/04/17 | Added NS direct assistance for families with kids flag  |
* | LP  | 00/04/11 | Added Quebec CPP/QPP contrib. on self-employed income   |
* | CH  | 00/04/10 | Added GSTAXM                                            |
* | CH  | 00/04/10 | Added Sask refundable sales tax credit                  |
* | CH  | 00/04/07 | Added Sask child and senior tax credits                 |
* | CH  | 00/04/06 | Added QFATC QNB phase out                               |
* | CH  | 00/04/06 | Added more Quebec family allowance tax credit parms     |
* | LP  | 00/04/06 | Added QSFSMXI for simplified tax form work sheet        |
* | LP  | 00/04/03 | Added QGIFTL1 QGFTCR QGIFTHCR                           |
* | CH  | 00/03/30 | Added QCBCFLG                                           |
* | CH  | 00/03/29 | Added BC family bonus parameters                        |
* | LP  | 00/03/23 | Added flag QEEXPDED emp. exp. deduction or reduce tot in|
* | LP  | 00/03/21 | Added Quebec refundable tax credit for medical expenses |
* | CH  | 00/03/21 | Added PEI income tax reduction                          |
* | LP  | 00/03/17 | Added Nova Scotia child benefit family income phase out |
* | LP  | 00/03/17 | Added Nfld child benefit program                        |
* | CH  | 00/03/01 | Added provincial tax on taxable income                  |
* | SFG | 99/12/09 | Change fa->famod and sa->samod                          |
* | CH  | 99/07/30 | Changed labels for OCWISRR OCWISTD                      |
* | CH  | 99/05/28 | Added QAMTXSTKFLG                                       |
* | CH  | 99/05/25 | Added Alberta flat tax                                  |
* | LP  | 99/05/25 | Add B.C. Earned Income Benefit                          |
* | LP  | 99/05/25 | Add BC Family Bonus Flag for program changes BCFBIFS    |
* | LP  | 99/05/25 | Add NFLD Low Income Senior's Benefit                    |
* | EGA | 99/05/25 | UITARGET and SATARGET by prov                           |                       
* | CH  | 99/04/21 | Added Quebec combined age, living alone and retirement  |
* |     |          |   and modified Simplified Low Income parameters         |
* | EGA | 99/05/21 | Redefine UIEITKP                                        |
* | CH  | 99/04/20 | Add NS child benefit                                    |
* | CH  | 99/04/16 | Add GSTASPFLAG                                          |
* | CH  | 99/04/15 | Add BXMPI                                               |
* | CH  | 99/03/26 | Add GSTREBFLAG                                          |
* | EGA | 99/03/25 | Add SAPFLAG, SATARGET, UITARGET                         |
* | CH  | 99/03/23 | Dropped LABTXCFLAG                                      |
* | CH  | 99/03/22 | Added Federal and provincial labour sponsored tax credit|
* | CH  | 99/03/09 | Added Man school tax assistance parameters              |
* | BBM | 99/03/09 | Add UIMAXPARWKS for parental benefits                   |
* | BBM | 99/02/99 | Drop FSITCFLAG, XII2FLAG: id variables no longer exist  |
* | TCB | 98/06/01 | MP, MP_BAS, MP_VAR declared extern                      |
* | CH  | 98/05/22 | Added N.S. Pharmacare VPHOPT VPHTDC                     |
* | EGA | 98/05/21 | UIEITKP                                                 |
* | BBM | 98/05/11 | Add OCWISFLG, OCWISTD, OCWISRR parameters(Ont Child WIS)|
* | BBM | 98/05/11 | Add GISPTDFLAG parameter                                |
* | EGA | 98/05/04 | Minor correction                                        |
* | CH  | 98/05/01 | added SASK emp. supp. phase in                          |
* | CH  | 98/05/01 | added SASK child benefit and employment supplement      |
* | EGA | 98/04/22 | Minor correctio  to Que max to gifts to crowns          |
* | EGA | 98/04/21 | Added Que max to gifts to crowns                        |
* | CH  | 98/04/08 | Added NB Low-income Seniors' Benefit                    |
* | EGA | 98/04/07 | Quebec Antipoverty Fund (QAPFFLG, QAPFRAT)              |
* | CH  | 98/04/07 | Added Federal Surtax Tax Reduction FSURTRMX,RR,RL       |
* | CH  | 98/04/06 | RRSP/RPP not included in Alternative minimum tax (AMTRP)|
* | EGA | 98/04/06 | Supplement for young kids in large families in QFATC    |
* | CH  | 98/04/03 | Added MANLTMAX                                          |
* | EGA | 98/04/02 | Quebec Low income credit: QLICRFLG, QLICR and			 |
* |     |          | Family credit reform: QFAMFLG, QFAMRAT                  |
* | CH  | 98/04/01 | Added FORAVGFLAG FDFATCFLAG                             |
* | EGA | 98/03/27 | mod. of Quebec political contribution: QPCOPT, QPCTR    |
* | EGA | 98/03/24 | add CGTC,CGTCTD,CGTCFLAG,CGTCTC,CGTCTK                  |
* | EGA | 98/03/09 | add QDUESOPT, QFATCSUP, QFATCSUP,QFATCMIN,QFATCMNK,   	 |
* |     |          | QFATCMXK, QFATCSRR, QFATCMRR, QFATD4K, QFATD4KI,        |
* |     |          | QTUIOPT, QAMTXFLG, QAMTXREF, QCAPAMTX, QDIVRAT, QCAPRAT,|
* |     |          | QAMTX, QAMTTX                                           |
* | EGA | 98/03/09 | delete QFATC1-3, QFATCM1-3,QFAMTC,QFAMTD1-3,QFABTD1-3   |
* |     |          | QMAXTAX, QFATCRR1-4 						             |
* | CH  | 98/03/09 | added CCESYNG CCESOLD                                   |
* | CH  | 98/02/26 | deleted CCEOPT                                          |
* | EGA | 98/02/18 | add QFATC1-3, QFATCM1-3,QFAMTC,QFAMTD1-3,QFABTD1-3      |
* |     |          | QMAXTAX, QFATCRR1-4, QFATCTK, QFATCOPT                  |
* | EGA | 98/02/12 | add QMEDOPT                                             |
* | EGA | 98/02/11 | add QYPRR, QYPTD, QYPPI                                 |
* | CH  | 98/02/05 | added ASBSSOPT                                          |
* | EGA | 98/02/11 | add QAXRR, QAXTD, QAXPI, QLAXRR, QLAXTD, QLAXPI         |
* | EGA | 98/02/05 | QHPTCTC AND QHPTCTK                                     |
* | CH  | 98/02/05 | add ASBNOASS ASBNOASM ASBEMP ASBRR, removed ASBTD ASBMAR|
* | CH  | 98/02/03 | added NS Direct Assistance flag VDASFLAG and renamed var|
* | CH  | 98/02/03 | added NS Direct Assistance VDASB VDACB VDASI VDACI      |
* | CH  | 98/01/22 | added Fed. Refundable medical expense supplement        |
* | EGA | 97/12/17 | QHPTC AND QHPTCFLG                                      |
* | EGA | 97/12/09 | QFAMDED for 1991 and after                              |
* | EGA | 97/12/09 | QCRDFLG for 1993 and after exclusion of social contrib. |
* | EGA | 97/10/15 | rename QSTFTYP3 and 4 to QSTRFTP3 and 4                 |
* | BBM | 97/10/15 | added Ont. Refundable child care tax credit parms       |
* | EGA | 97/10/10 | Add QUE newborn random ranking increase                 |
* | CH  | 97/10/09 | Add NFLD sales tax credit activation flag               |
* | BBM | 97/10/08 | Add MTCINCFL parameter                                  |
* | BBM | 97/10/07 | Implement B.C. Family Bonus parameters                  |
* | CH  | 97/10/07 | Add FSTCREF                                             |
* | CH  | 97/10/02 | Add UIEIFSRR UIEIFSRL                                   |
* | CH  | 97/10/01 | Add NFLD sales tax credit parameters                    |
* | CH  | 97/10/01 | Add NBCBPI                                              |
* | BBM | 97/09/29 | Add Suite of parameters for NB child tax benefits       |
* | CH  | 97/09/15 | add FCBEMX                                              |        
* | BBM | 97/09/12 | Alberta Family Employment Tax Credit Parameters         |
* | EGA | 97/09/12 | add QSTROPT, QSTRFTYP3, QSTRFTYP4                       |
* | EGA | 97/09/11 | add QSTRXXX variables                                   |
* | CH  | 97/09/11 | add FCBERR1, FCBERR2, FCBERR3                           |        
* | CH  | 97/09/10 | add MANLTCF                                             |        
* | EGA | 97/09/10 | add QEMPLOFLAG QNORTHFLAG QCAPFLAG QPARTLOFLAG          |        
* | BBM | 97/09/08 | Add VHOTM VHOSPRM for Nova Scotia HOSP changes 1994 ->  |
* | CH  | 97/08/21 | Removed SBST SBCT SBOT SBSPAT SBESPAT SBTURFLAG         |
* | CH  | 97/08/13 | Added UIFSHERMIN                                        |
* | CH  | 97/06/18 | Removed UIWBP5, UIWBP5R and their -MAX and -ROWS par.'s |
* | BBM | 97/05/27 | Drop STKCCFFLAG,RECSSPFLAG,VSTKMAX                      |
* | CH  | 97/04/03 | Add Newer EI parameters							     |
* | CH  | 97/03/04 | Add FCBEIE FCBEIS1 FCBEIS2 FCBEIS3 parameters           |
* | ER  | 96/10/04 | ADD OEHT Parameters                                     |
* | ER  | 96/09/24 | Add CCE full-time student flag (CCESFLAG)               |
* | ER  | 96/09/10 | Add Sask. Deficit Surtax Reduction Amount (SDSRA)       |
* | ER  | 96/09/09 | Add NFLD surtax parameters (NSCI,NSF)                   |
* | BBM | 96/08/28 | Add parameter to net clawback from OAS (NETOASFLAG)     |
* | BBM | 96/05/09 | Add Suite of parameters for Seniors Benefit             |
* | BBM | 96/04/16 | Add New parameters for ccea old kid age limit CCEAOAGE  |
* | BBM | 95/12/08 | Add New EI parameters                                   |
* | BBM | 95/06/21 | Add Nova Scotia Tax Reduction parameters(Begins in 1994)|
* | BBM | 95/05/19 | Add Nova Scotia Pharmacare program parameters           |
* | BBM | 95/04/25 | Change parameter labels which contain variable names    |
* | BBM | 94/10/05 | Add Quebec refundable child care expense credit parms   |
* | BBM | 94/09/29 | Add quebec net income / tax credit option parameters    |
* | BBM | 94/09/29 | Add quebec tax reduction parameters                     |
* | BBM | 94/09/29 | Add quebec health services tax parameters               |
* | BBM | 94/09/28 | Add quebec surtax parameters QHSF QHSF2 QHSCI QHSCI2    |
* | BBM | 94/09/26 | remove NPTCFLAG - don't need to protect with flag	     |
* | RSE | 94/04/07 | add Alberta seniors benefit for 1994 and beyond         |
* | GJC | 94/04/05 | add 1994 UI reform parms                                |
* | GJC | 94/03/20 | add parms for nova scotia two-tier surtax               |
* | RSE | 94/03/16 | add Newfoundland political contribution tax credit 1993+|                       |
* | GJC | 94/03/09 | eliminate MP.FCBNCC from structure                      |
* | RSE | 94/02/24 | reduce age amount as in 94 budget                       |
* | RSE | 94/02/22 | add Alberta and Quebec child benefit parameters         |
* | RSE | 94/02/07 | add refundable sales tax in 93 budget                   |
* | RSE | 94/02/04 | add the renter reduction flag                           |
* | GJC | 94/01/17 | remove MP.PUPST and MP.CTPUGAS change dim of CTPGAS     |
* | GJC | 93/04/16 | add sask defict surtax parameter                        |
* | GJC | 93/04/01 | remove MP.CAPGAL and MP.CAPGEFLR                        |
* | GJC | 93/03/08 | add duration factors for ui modeling                    |
* | GJC | 93/02/25 | add second tier parms for the bc surtax                 |
* | GJC | 93/02/17 | add database variable activation flags                  |
* | GJC | 93/02/17 | add capital gains effective annual effective an limit rt|
* | GJC | 93/01/20 | provinciaise SAFS                                       |
* | GJC | 93/01/19 | add ont surtax variables                                |
* | BBM | 93/01/12 | Add Ont. Tax Cr. income definition flag OTCIFLAG        |
* | BBM | 93/01/12 | Add Ont. seniors Tax Cr. parms OSPOCM OSSTCP OSTCNIBA   |
* | BBM | 92/09/02 | Del Sask family tc parms SFTCFLAG SFTCPC SFTCTD SFTCRR  |
* | BBM | 92/07/15 | Add new Quebec Tax parameters QMEDALL QMEDANF           |
* | BBM | 92/07/15 | Add BC Tax credit parameters                            |
* | BBM | 92/07/14 | Add CTC fudge parameters CTCTUR CTCINC                  |
* | BBM | 92/07/07 | Add prov political credit parms(ns/nb/pei/que/ont/alt/bc|
* | BBM | 92/07/07 | Add Federal child benefits parameters                   |
* | BBM | 92/07/07 | Add Flag to turn off provincial FA configurations       |
* | BBM | 92/07/02 | Add Manitoba Property Tax credit parameters             |
* | BBM | 92/07/02 | Add Manitoba Cost of living Tax credit parameters       |
* | BBM | 92/06/30 | Add Manitoba political tax credit parameters            |
* | BBM | 92/06/22 | Add Manitoba reform surtax and tax reduction parameters |
* | BBM | 92/06/21 | Fed political tax credit model based on total donations |
* | SFG | 92/02/07 | ctupst -> ctpupst; ctugas -> ctpugas; also CTUPST,CTUGAS|
* | SFG | 92/02/06 | Delete CTPICT; add CTUPST, CTUGAS               |
* | BBM | 91/07/10 | Added SFTCFLAG SFTCPC SFTCTD SFTCRR-Sask fam tax credit |
* | BBM | 91/07/05 | Added BSCI BSF - New Brunswick surtax                   |
* | BBM | 91/07/05 | Added CSDC - BC surtax dependant tax credit             |
* | BBM | 91/07/05 | Changed order/labels of Quebec FA parms                 |
* | BBM | 91/06/27 | Changed order of Ontario provincial tax parameters      |
* | BBM | 91/06/27 | added VSCI VSF                                          |
* | BBM | 91/06/27 | added OTRBPA OTRDCA OTRDDA OTRFP                        |
* | SFG | 90/08/26 | added QFARFLAG QFTRFLAG QCTCFLAG QRTRFLAG QCXMOPT QFTRA2|
* | SFG | 90/08/26 | added QCTCDEPA                                          |
* | SFG | 90/07/31 | Changed order of commodity tax parameters               |
* | SFG | 90/03/02 | inactivated NEARPARM to free up near memory congestion  |
* | --- | 89/10/13 | Release 4.0                                             |
* |     |          |                                                         |
* +-----+----------+---------------------------------------------------------+
*
*Dependencies:
*   #include "spsm.h"    Required for manifest constants and macros
*   #include "pm.h"      Required for mpd1(), mpd2() prototypes
*   #include "vsu.h"     Required by vs.h
*   #include "vs.h"      Required for prototypes with 'hhld' argument
*   #include "mpu.h"     Required for 'mpu' substructure definition
*   #include "mp.h"
*
*****************************************************************************/


/* ==================== MANIFEST CONSTANTS ================================ */


/**
* UPRMSIZE determines the amount of space, in bytes, to be reserved
* for the user tax/transfer parameter structure (identified by 'UM' and
* declared in mpu.h). The difference between UPRMSIZE and the actual size
* of the user tax/transfer parameter structure (a substructure of the
* MP structure declared below) is filled by a compile-time filler array
* of char's.
**/

#define UPRMSIZE 6402


/* define array bounds */

#define UIRMHRMAX  17   /* maximum of number of rows in UIREGHRMIN table   */
#define UIFSHEMAX  17   /* maximum of number of rows in UIFSHERMIN table   */
#define UIEIRMAX   10	/* maximum of number of rows in UIEIRATE table     */
#define UIEIBRPMAX 10	/* maximum of number of rows in UIEIBRP table      */
#define UIEWKRMAX  43   /* number of rows in UIEWK matrix                  */
#define UIEWKCMAX  12   /* number of cols in UIEWK matrix                  */
#define UIEIDIVMAX 11   /* maximum of number of rows in UIEIDIV table      */
#define QFFSLMAX    5   /* maximum of number of rows in QFFSL table        */
#define QFPSLMAX    5   /* maximum of number of rows in QFPSL table        */
#define QAAFAMAX    5   /* maximum of number of rows in QAAFA table        */
#define QNBFARMAX   4   /* number of rows[children] in QNBFA table         */
#define QNBFACMAX   5   /* number of cols[ages] in QNBFA table             */
#define FTXMAX     15   /* maximum of number of rows in FTX table          */
#define QTXMAX     30   /* maximum of number of rows in QTX table          */
#define QHSCMAX    10   /* maximum of number of rows in QHSC table         */
#define QCCETCRMAX 60   /* maximum of number of rows in QQCCETCR           */
#define GISSTMAX    8   /* maximum of number of elements in GISST table    */
#define GISCTMAX    8   /* maximum of number of elements in GISCT table    */
#define GISOTMAX    8   /* maximum of number of elements in GISOT table    */
#define SPATMAX     8   /* maximum of number of elements in SPAT  table    */
#define ESPATMAX    8   /* maximum of number of elements in ESPAT table    */
#define FPTCMAX     4   /* maximum of number of rows in FPTC table         */
#define VPTCMAX     4   /* maximum of number of rows in VPTC table         */
#define BPTCMAX     4   /* maximum of number of rows in BPTC table         */
#define PPTCMAX     4   /* maximum of number of rows in PPTC table         */
#define OPTCMAX     4   /* maximum of number of rows in OPTC table         */
#define OCWISRRMAX  4   /* maximum of number of rows in OCWISRR table      */
#define OCWISRRPMAX 4   /* maximum of number of rows in OCWISRRP table     */
#define NPTCMAX     4   /* maximum of number of rows in NPTC table         */
#define MPTCMAX     4   /* maximum of number of rows in MPTC table         */
#define SPTCMAX     4   /* maximum of number of rows in SPTC table         */
#define APTCMAX     4   /* maximum of number of rows in APTC table         */
#define CPTCTMAX    4   /* maximum of number of rows in CPTCT table        */
#define CTCTURMAX   8   /* maximum of number of elements in CTCTUR table   */
#define CRTRTMAX   10   /* maximum of number of elements in CRTRT table    */
#define CMSPMAX     3   /* maximum of number of elements in CMSP table     */
#define CMSPRATEMAX 6   /* maximum of number of elements in CMSPRATE table */
#define ASBRRMAX    6   /* maximum of number of elements in ASBRR vector   */
#define ASBNOASMAX  6   /* maximum of number of elements in ASBNOAS vector */
#define ASBRRPMAX   6   /* maximum of number of elements in ASBRRP vector   */
#define ASBNOASPMAX 6   /* maximum of number of elements in ASBNOASP vector */
#define QFATCTKMAX 10   /* maximum of number of elements in QFATCTK table  */
#define QFATCMXKMAX 10  /* maximum of number of elements in QFATCMX table  */
#define QFATCMNKMAX 10  /* maximum of number of elements in QFATCMN table  */
#define QFATCSRRMAX 10  /* maximum of number of elements in QFATCSRR table  */
#define QFATCMRRMAX 10  /* maximum of number of elements in QFATCMRR table  */
#define QFATCK6CMAX   7   /* number of columns[children<6] in QFATCK6 table         */
#define QFATCK6RMAX   30   /* number of rows[children] in QFATCK6 table         */
#define QPCTRMAX   10   /* maximum of number of elements in QPCTR table  */
#define SCBRR1MAX  9    /* maximum of number of elements in SCBRR1 vector */
#define SCBRR2MAX  9    /* maximum of number of elements in SCBRR2 vector */
#define UIEITKPMAX 96   /* maximum of number of elements in UIEITKP table */
#define UITARGETMAX 10   /* maximum of number of elements in UIEITKP table */
#define SATARGETMAX 10   /* maximum of number of elements in SATARGET table */
#define NPTXMAX     15   /* maximum of number of rows in NPTX table          */
#define PPTXMAX     15   /* maximum of number of rows in PPTX table          */
#define VPTXMAX     15   /* maximum of number of rows in VPTX table          */
#define BPTXMAX     15   /* maximum of number of rows in BPTX table          */
#define OPTXMAX     15   /* maximum of number of rows in OPTX table          */
#define MPTXMAX     15   /* maximum of number of rows in MPTX table          */
#define SPTXMAX     15   /* maximum of number of rows in SPTX table          */
#define APTXMAX     15   /* maximum of number of rows in APTX table          */
#define CPTXMAX     15   /* maximum of number of rows in CPTX table          */
#define CPPLT60MAX 10   /* maximum of number of rows in CPPLT60 table       */
#define CPP60T64MAX 10   /* maximum of number of rows in CPP60T64 table       */
#define CPPGT64MAX 10   /* maximum of number of rows in CPPGT64 table       */
#define GSTCTUNCMAX    5    /* maximum of number of rows in GSTCTUNC table       */
#define UIEIFS1MAX    30    /* maximum of number of rows in UIEIFS1 table       */
#define UIEIFS2MAX    30    /* maximum of number of rows in UIEIFS2 table       */
#define UIEIFS3MAX    30    /* maximum of number of rows in UIEIFS3 table       */
#define UIEIFSTOPUPMAX    30    /* maximum of number of rows in UIEIFSTOPUP table       */
#define UIEIFSYNGMAX    30    /* maximum of number of rows in UIEIFSYNG table       */
#define OHPBASEMAX     15   /* maximum of number of rows in OHPBASE table          */
#define QWPEIPIMAX     4    /* maximum of number of rows in QWPEIPI table          */
#define QWPMAXMAX      4    /* maximum of number of rows in QWPMAX table           */
#define QWPCRMAX       4    /* maximum of number of rows in QWPCR table            */
#define QWPTDMAX       4    /* maximum of number of rows in QWPTD table            */
#define QCAMAXMAX      4    /* maximum of number of rows in QCAMAX table           */
#define QCAMINMAX      4    /* maximum of number of rows in QCAMIN table           */
#define AHCIPITMAX     6    /* maximum of number of rows in AHCIPIT table          */
#define AHCIPSSBMAX    6    /* maximum of number of elements in AHCIPSSB table     */
#define AHCIPFSBMAX    6    /* maximum of number of elements in AHCIPFSB table     */
#define AFETCAPCMAX    4    /* maximum of number of rows in AFETCAPC table         */
#define MCLAWPCTCMAX   9   /* maximum of number of columns [kids<=age limit] in MCLAWPCT table */
#define MCLAWPCTRMAX   11   /* maximum of number of rows [kids] in MCLAWPCT table */
#define MCLAWPCTPCMAX   9   /* maximum of number of columns [kids<=age limit] in MCLAWPCTP table */
#define MCLAWPCTPRMAX   11   /* maximum of number of rows [kids] in MCLAWPCTP table */
#define NUMPERMAX   6   /* maximum of number of elements in ASHELTER vector */
#define BHEATBENMAX     4   /* maximum of number of rows in BHEATBEN table          */
#define QPIPEADJMAX     15   /* maximum of number of rows in QPIPEADJMAX table          */

/* the following are the values assumed by the deduction/credit switches */

#define EXEM   1
#define TXCR   2


/**
* The following define the indexes 
* of the UIEWK array.
**/

#define UIEWKR1   10  /* weeks employment for first row of UIEWK array */
#define UIEWKC1  6.0  /* unemployment rate for first column of UIEWK array */
#define UIEIHWCF  35  /* Conversion factor for rows of UIEWK array under the EI system */


/* ==================== MACRO DEFINITIONS ================================= */

/* NEARPARM determines if the global parameter structure is near or not */

/*#define NEARPARM NEAR*/
#define NEARPARM 



/* ==================== STRUCTURE DECLARATION MACROS ====================== */

#define S_MP   struct MP_
#define P_MP   S_MP *



/* ==================== STRUCTURE DECLARATIONS ============================ */

/**
* The structure identified by the letters 'mp' holds parameter values
* used to specify numbers associated with the tax/transfer system.
* Values for these parameters are contained in files with the '.mpr'
* extension.  Some of the structure members are not specified by the
* user, but are instead obtained by calculation from other parameters.
**/

typedef struct MP_ {


	/* Variant Description */

	char MPRDESC[LABSIZE+1];   /* Description of tax/transfer parameter file */
	char MPRVER[HDRSIZE+1];    /* SPSD/M Release Version */
	char MPRSFILE[LABSIZE+1]; /* Starting tax/transfer parameter file */
	int   TARGETYEAR;         /* Year of analysis */

	/* Database variable activation flags */

	int GSTREBFLAG;		/* Database variable(gstreb) activation flag */

	/* Government Transfers and Personal Income Taxes */


	/*     Government Transfers */


	/*          Unemployment Insurance */

	int UIFLAG;          /* UI/EI Activation flag (UI and EI)*/
	NUMBER UIERNMAX;     /* Maximum insurable earnings (UI and EI)*/
	NUMBER UIMINPCT;     /* Exemption limit (percent of maximum insurable earnings) (UI only)*/
	NUMBER UIPF;         /* UI contribution rate on earnings (UI and EI)*/
	NUMBER UIEIREF;      /* EI contribution refund cut-in (EI only)*/
	NUMBER UIEIREFTK;    /* EI contribution refund take up*/

	/*               Minimum Weeks for Qualification */

	int UIREGMINWK;   /* Minimum weeks to qualify for regular benefits (UI only)*/
	int UIMATMINWK;   /* Minimum weeks to qualify for maternity benefits  (UI only)*/
	int UISICMINWK;   /* Minimum weeks to qualify for sickness benefits  (UI only)*/
	int UIFSHMINWK;   /* Minimum weeks to qualify for fishing benefits (UI only)*/

	/*               Minimum Hours for Qualification */
	NUMBER UIREGHRMIN[UIRMHRMAX][LKP_COLS];  /* Min. hours to qualify for reg. benefits [unempl. rate] (EI only)*/
	int UIMATHRMIN;   /* Minimum hours to qualify for maternity benefits (EI only)*/
	int UISICHRMIN;   /* Minimum hours to qualify for sickness benefits (EI only)*/
	NUMBER UIFSHERMIN[UIFSHEMAX][LKP_COLS];  /* Min. earnings to qualify for fish. benefits [unempl. rate] (EI only)*/
    int UINEREHRMIN;  /* Minimum hours to qualify for new entrant or re-entrant (EI only)*/
    int UIEINEREFLG;  /* Flag to check for hours for new entrants and re-entrants (EI only)*/

	/*               Basic Parameters */

	int UIWAITWKS;       /* Minimum waiting period all claims (UI and EI)*/
	int  UIDEPOPT;       /* UI dependency option [1=normal, 2=Feb'94] (UI only)*/
	int  UIEIOPT;        /* UI Employment Insurance reform option [1=UI, 2=EI Dec'95]*/
	NUMBER UIREGWKFCT;   /* UI regular benefit weeks adjustment factor (UI and EI)*/	 
	NUMBER UITRNWKFCT;   /* UI training benefit weeks adjustment factor (UI and EI)*/
	NUMBER UITRNBNFCT;   /* UI training benefit per week adjustment factor (EI and EI)*/
	NUMBER UIOTHWKFCT;   /* UI other benefits weeks adjustment factor (UI and EI)*/
	NUMBER UIOTHBNFCT;   /* UI other benefits per week adjustment factor (EI and EI)*/
	int  UIEIYRS;        /* Number of years of previous EI benefits calculated (EI only)*/
    int  UIEIDIVFLG;     /* EI minimum divisor flag (EI only)*/
    NUMBER UIEIDIV[UIEIDIVMAX][LKP_COLS]; /* EI minimum divisor [uer][divisor] (EI only)*/
    NUMBER UIEITKP[UIEITKPMAX];          /* UI EI takeup rate [index] : index based on prov, sex, age, weeks */
	NUMBER UITARGET[UITARGETMAX];    /* UI/EI target for the number of cases (UI and EI)*/
	NUMBER UIEIMTYPFLG;   /* Flag to model main benefit type (UI and EI)*/

	/*               Benefit Duration */
	int  UIMAXMATWKS;     /* Maximum number of weeks - maternity (UI and EI)*/
	int  UIEXTMATWKS;     /* Additional weeks for maternity - behavioural response (UI and EI)*/
	int  UIMAXSICWKS;     /* Maximum number of weeks - sickness (UI and EI)*/
	int  UIMAXFSHWKS;     /* Maximum number of weeks - fishing (UI and EI)*/
	int  UIMAXPARWKS;     /* Maximum number of weeks - parental (UI and EI)*/
	int  UIMAXDUR;        /* Maximum duration of a UI claim (UI and EI)*/
	char UIEWK[UIEWKRMAX][UIEWKCMAX]; /* Entitlement (weeks) [wkwrk, uer] (UI and EI)*/

	/*               Benefit Rates */

	NUMBER UIBASRATE;   /* Benefit rate for basic phase (UI only)*/
	NUMBER UIENSRATE;   /* Enhanced rate for basic phase (UI only)*/
	NUMBER UIENSRTCO;   /* Enhanced rate cutoff (UI only)*/
	NUMBER UILFERATE;   /* Benefit rate for labour force extended phase (UI only)*/
	NUMBER UIRGERATE;   /* Benefit rate for regional extended phase (UI only)*/
	NUMBER UIEIRATE[UIEIRMAX][LKP_COLS]; /* Benefit rate under EI reform [Past Wks ben][Rate] (EI only)*/

	/*               Option Activation */

	int UIENTFLAG;  /* Basic entrance requirements flag (UI and EI)*/
	int UIBASFLAG;  /* Basic phase calculation flag (UI and EI)*/
	int UIEFFFLAG;  /* Observed effective weekly benefit rate flag (UI and EI)*/

	/*               Family supplement */
	int  UIEIFSFLG;      /* UI EI calculate family supplement flag (EI only)*/
	int  UIEIFSOPT;      /* UI EI calculate family supplement option (EI only)*/
	int  UIEIFIFLG;      /* EI intensity rule exemption for family supplement receivers (EI only)*/
	NUMBER UIEIFSRR;     /* UI EI family supplement reduction rate (EI only)*/
	NUMBER UIEIFSRL;     /* UI EI family supplement reduction level(EI only) */
	NUMBER UIEIMFSP;     /* EI Maximum family supplement percent of earnings (EI only)*/
	NUMBER UIEIFS1[UIEIFS1MAX][LKP_COLS]; /* Max fam supplement 1 child (EI only)*/
	NUMBER UIEIFS2[UIEIFS2MAX][LKP_COLS]; /* Max fam supplement 2 children (EI only)*/
	NUMBER UIEIFS3[UIEIFS3MAX][LKP_COLS]; /* Max fam supplement 3+ children (EI only)*/
	NUMBER UIEIFSTOPUP[UIEIFSTOPUPMAX][LKP_COLS]; /* Max fam supplement top up for more than 3 kids (EI only)*/
	NUMBER UIEIFSYNG[UIEIFSYNGMAX][LKP_COLS]; /* Max fam supplement top up for young children (EI only)*/

	/*               Repayment (through tax system) */

	NUMBER UIBAF;        /* UI benefit recovery base amount factor (UI and EI)*/
	NUMBER UIBAFNR;      /* UI EI benefit recovery base amount factor for non-repeaters (EI only)*/
	NUMBER UIBRP;        /* UI benefit recovery portion (UI only) */
	NUMBER UIEIRPR;        /* UI EI benefit clawback rate (EI only)*/
	NUMBER UIEIBRP[UIEIBRPMAX][LKP_COLS]; /* Maximum clawback under EI reform [Past Wks ben][Rate] (EI only)*/
	int UIEINRT;         /* UI EI Non repeater level for higher clawback turndown (EI only)*/
	int UIEIREPOPT;      /* EI Benefit repayment option (1=repeaters have higher rate,2=one rate)(EI only)*/

	/*          Quebec Parental Insurance Program    */

	int QPIPFLAG;        /* Quebec parental insurance plan activation flag */
	NUMBER QPIPTU;       /* Quebec parental insurance plan option take up  */
	int QPIPSMTW;        /* Quebec parental insurance plan maximum maternity weeks - special plan */
	int QPIPSPRW;        /* Quebec parental insurance plan maximum parental weeks - special plan */
	NUMBER QPIPSPRR;     /* Quebec parental insurance plan parental benefit rate - special plan */
	NUMBER QPIPSMTR;     /* Quebec parental insurance plan maternity benefit rate - special plan */
	int QPIPSPTW;        /* Quebec parental insurance plan maximum paternity weeks - special plan */
	NUMBER QPIPSPTR;     /* Quebec parental insurance plan paternity benefit rate - special plan */
	int QPIPBMTW;        /* Quebec parental insurance plan maximum maternity weeks - basic plan */
	int QPIPBPRW1;       /* Quebec parental insurance plan maximum parental initial weeks - basic plan */
	NUMBER QPIPBPRR1;    /* Quebec parental insurance plan parental initial weeks benefit rate - basic plan */
	NUMBER QPIPBMTR;     /* Quebec parental insurance plan maternity weeks benefit rate - basic plan */
	int QPIPBPRW2;       /* Quebec parental insurance plan maximum parental additional weeks - basic plan */
	NUMBER QPIPBPRR2;    /* Quebec parental insurance plan parental additional weeks benefit rate - basic plan */
	int QPIPBPTW;        /* Quebec parental insurance plan maximum paternity weeks - basic plan */
	NUMBER QPIPBPTR;     /* Quebec parental insurance plan paternity benefit rate - basic plan */
	NUMBER QPIPEMAX;     /* Quebec parental insurance plan maximum insurable earnings */
	NUMBER QPIPEMIN;     /* Quebec parental insurance plan minimum insurable earnings */
	NUMBER QUIPF;        /* Quebec EI contribution rate */
	NUMBER QPIPF;        /* Quebec parental insurance plan contribution rate for paid workers */
	NUMBER QPIPFSE;      /* Quebec parental insurance plan contribution rate for self-employed */
	NUMBER QPIPEADJ[QPIPEADJMAX][LKP_COLS];     /* Quebec parental insurance plan earnings adjustment */

	/*          Family Allowance */

	int FAFLAG;       /* Family allowance flag */
	int PFACFLAG;     /* Use provincial configuration flag */

	/*               All Provinces Except Alberta and Quebec */

	NUMBER STDFA;        /* Standard federal family allowance per child */

	/*               Alberta */

	NUMBER AFAC1;        /* Alberta FA benefit per child aged 0 - 6 */
	NUMBER AFAC2;        /* Alberta FA benefit per child aged 7 - 11 */
	NUMBER AFAC3;        /* Alberta FA benefit per child aged 12- 15 */
	NUMBER AFAC4;        /* Alberta FA benefit per child aged 16- 17 */
	NUMBER ACBC1;        /* Alberta Child benefit per child aged 0 - 6 */
	NUMBER ACBC2;        /* Alberta Child benefit per child aged 7 - 11 */
	NUMBER ACBC3;        /* Alberta Child benefit per child aged 12- 15 */
	NUMBER ACBC4;        /* Alberta Child benefit per child aged 16- 17 */
	NUMBER ACBC1P;       /* Alberta Child benefit per child aged 0 - 6 for 1st half of year */
	NUMBER ACBC2P;       /* Alberta Child benefit per child aged 7 - 11 for 1st half of year */
	NUMBER ACBC3P;       /* Alberta Child benefit per child aged 12- 15 for 1st half of year */
	NUMBER ACBC4P;       /* Alberta Child benefit per child aged 16- 17 for 1st half of year */

	/*                Quebec */

	NUMBER QFFSL[QFFSLMAX][LKP_COLS]; /* Federal family allowance: Quebec Configuration[parity,$] */
	NUMBER QFS;          /* Federal supplement per child 12-17 in Quebec configuration */
	NUMBER QFPSL[QFPSLMAX][LKP_COLS]; /* Quebec provincial family allowance [parity,$] */
	int QAAFAFLAG;      /* Availability Allowance: Supplement to Quebec FA */
	NUMBER QAAFA[QAAFAMAX][LKP_COLS]; /* Quebec availability allowance (supplement) [parity,$] */
	int QNBFAFLAG;                       /* Quebec newborn family allowance flag */
	int QNBRFLAG;                       /* Quebec newborn family random increase of child rank */
	NUMBER QNBFA[QNBFARMAX][QNBFACMAX];  /* Quebec newborn family allowance [parity,age] */
	int QNBPOFLAG;                       /* Quebec newborn family allowance phase out flag */
	int QNBPOYR;                       /* Quebec newborn family allowance phase out year */
	NUMBER QNBPOPYR;        /* Quebec newborn family allowance phase-out year proportion */
	int QCBCFLG;         /* Quebec Child benefit flag for Quebec calculation methodology */
	NUMBER QCBC1;        /* Quebec Child benefit for 1st child */
	NUMBER QCBC2;        /* Quebec Child benefit for 2nd child */
	NUMBER QCBC3;        /* Quebec Child benefit for 3rd child */
	NUMBER QCBCS;        /* Quebec Child benefit supplement child aged 12- 17 */
	int QCBCFLGP;         /* Quebec Child benefit flag for Quebec calculation methodology for 1st half of year */
	NUMBER QCBC1P;        /* Quebec Child benefit for 1st child for 1st half of year */
	NUMBER QCBC2P;        /* Quebec Child benefit for 2nd child for 1st half of year */
	NUMBER QCBC3P;        /* Quebec Child benefit for 3rd child for 1st half of year */
	NUMBER QCBCSP;        /* Quebec Child benefit supplement child aged 12- 17 for 1st half of year */

	/*               Repayment (through tax system) */

	NUMBER FATBPI;       /* Family allowance take-back phase in */
	NUMBER FATD;         /* Family allowance turndown income */
	NUMBER FARR;         /* Family allowance repayment rate */

	/*          Old Age Security (OAS) */

	int OASFLAG;      /* Old age security flag */
	NUMBER BOAS;         /* Basic OAS */

	/*               Repayment (through tax system) */

	int NETOASFLG;       /* Net the clawback from Old Age Security */
	NUMBER OASTD;        /* OAS turndown income */
	NUMBER OASRR;        /* OAS reduction rate */

	/*          Guaranteed Income Supplement */

	int GISFLAG;         /* Federal GIS/SPA/ESPA flag */
	int GISOASFLAG;      /* 1984 GIS top-up to OAS residence shortfall flag */
	NUMBER BGISS;        /* Basic GIS - single */
	NUMBER BGISM;        /* Basic GIS - married */
	NUMBER BESPA;        /* Basic GIS portion of extended SPA */
	NUMBER PYINC;        /* Deflator to calculate previous year income */
	NUMBER PYINCP;       /* Deflator to calculate income from 2 years prior */
	NUMBER GISRLS;       /* Basic GIS reduction level: single pensioners */
	NUMBER GISRLM;       /* Basic GIS reduction level: married pensioners */
	NUMBER SPARL;        /* SPA reduction point: one married/ widowed */
	NUMBER GISRRS;       /* Basic GIS reduction rate: single pensioners */
	NUMBER GISRRM;       /* Basic GIS reduction rate: married pensioners */
	NUMBER SPAOASRR;     /* OAS portion of SPA taxback rate */


	/*               Take-up Rates */

	int GISTURFLAG;                   /* GIS take-up flag: apply 5 take-up tables       */
	NUMBER GISST[GISSTMAX][LKP_COLS]; /* GIS take-up rate: single pensioner by benefit level [benefit,rate] */
	NUMBER GISCT[GISCTMAX][LKP_COLS]; /* GIS take-up rate: pensioner couple by benefit level [benefit,rate] */
	NUMBER GISOT[GISOTMAX][LKP_COLS]; /* GIS take-up rate: one pensioner couple by benefit level [benefit,rate] */
	NUMBER SPAT[SPATMAX][LKP_COLS];   /* SPA take-up rate by benefit level [benefit,rate] */
	NUMBER ESPAT[ESPATMAX][LKP_COLS]; /* Extended SPA take-up rate by benefit level [benefit,rate] */

					 
	/*          Provincial Elderly Programs */

	int GISTFLAG;     /* Provincial GIS top-up flag */

	/*               Newfoundland */

	NUMBER NFSBBAS;     /* NFLD Low-Income Seniors' Benefit base amount */
	NUMBER NFSBTD;      /* NFLD Low-Income Seniors' Benefit turndown */
	NUMBER NFSBRR;      /* NFLD Low-Income Seniors' Benefit reduction rate */
	NUMBER NFSBCBAS;    /* NFLD Low-Income Seniors' Benefit base amount for senior couples */
	NUMBER NFSBCTD;     /* NFLD Low-Income Seniors' Benefit turndown for senior couples */
	NUMBER NFSBCRR;     /* NFLD Low-Income Seniors' Benefit reduction rate for senior couples */

	/*               Nova Scotia */

	NUMBER NSMAX;        /* Nova Scotia maximum GIS supplement level */
	NUMBER NS23;         /* Nova Scotia GIS supplement for 2/3 GIS */
	NUMBER NS13;         /* Nova Scotia GIS supplement for 1/3 GIS */
	NUMBER NSLT13;       /* Nova Scotia GIS supplement for less than 1/3 GIS */

	/*               New Brunswick */

	NUMBER NBSB;        /* New Brunswick Low-Income Seniors' Benefit */
	int NBSBSPA;        /* N.B. Low-Income Seniors' Benefit - SPA eligibility */

	/*               Ontario */

	NUMBER ONTS;         /* Ontario GIS supplement: single pensioners */
	NUMBER ONTC;         /* Ontario GIS supplement: married pensioners */
	NUMBER ONTSTG;       /* Ontario sales tax grant for seniors            */
	NUMBER ONTPTG;       /* Ontario property tax grant for seniors         */
	NUMBER ONTFPTG;      /* Ontario property tax grant (fraction of rent)  */

	/*               Manitoba */

	NUMBER MANS;         /* Manitoba GIS supplement: single pensioners */
	NUMBER MANC;         /* Manitoba GIS supplement: married pensioners */
	NUMBER MANSNPF;      /* Manitoba GIS supplement reduction point: single */
	NUMBER MANCNPF;      /* Manitoba GIS supplement reduction point: married */

	/*               Saskatchewan */

	NUMBER SASKS;        /* Saskatchewan GIS supplement: single pensioners */
	NUMBER SASKC;        /* Saskatchewan GIS supplement: married pensioners */
	NUMBER SASKMINS;     /* Saskatchewan GIS supplement minimum benefits: single */
	NUMBER SASKMINC;     /* Saskatchewan GIS supplement minimum benefits: married */
	NUMBER SASKRR1;      /* Saskatchewan GIS supplement reduction rate: regular */
	NUMBER SASKRR2;      /* Saskatchewan GIS supplement reduction rate: 1 GIS */
	NUMBER SASKRR3;      /* Saskatchewan GIS supplement reduction rate: SPA */
	NUMBER SASKTECA;     /* Saskatchewan GIS supplement temporary energy cost allowance */

	/*               Alberta */

    NUMBER ALTAMIN;      /* Alberta GIS supplement minimum annual benefit */
	NUMBER ALTASC;       /* Alberta GIS supplement maximum annual benefit */
	NUMBER ASBBASIC;     /* Alberta seniors benefit annual basic benefit */
	int ALTASOPT;        /* Alberta seniors option [1=GIST,2=new seniors benefit 1994] */
	NUMBER ASBSS;        /* Alberta seniors benefit senior spouse supplement */
	NUMBER ASBNSS;       /* Alberta seniors benefit non-senior spouse supplement */
	NUMBER ASBRENT;      /* Alberta seniors benefit renter supplement */
	NUMBER ASBNOAS[ASBNOASMAX]; /* Alberta seniors benefit reduction if no OAS [senior type] */
	NUMBER ASBEMP;       /* Alberta seniors benefit employment inclusion rate */
	NUMBER ASBRR[ASBRRMAX];  /* Alberta seniors benefit reduction rate [senior type] */
	int ASBSSOPT;        /* Alberta seniors benefit 1 senior couple option [1=model separately,2=model as senior couples] */
	NUMBER ASBSAB;       /* Alberta seniors benefit supplemental accommodation benefit */
	NUMBER ASBSABRR;     /* Alberta seniors benefit supplemental accommodation reduction rate */

	int ASBCYFLG;        /* Alberta seniors benefit calendar year calculation flag */
	NUMBER ASBBASICP;     /* Alberta seniors benefit annual basic benefit for 1st half of year */
	NUMBER ASBSSP;        /* Alberta seniors benefit senior spouse supplement for 1st half of year */
	NUMBER ASBNSSP;       /* Alberta seniors benefit non-senior spouse supplement for 1st half of year */
	NUMBER ASBRENTP;      /* Alberta seniors benefit renter supplement for 1st half of year */
	NUMBER ASBNOASP[ASBNOASPMAX]; /* Alberta seniors benefit reduction if no OAS for 1st half of year [senior type] */
	NUMBER ASBEMPP;       /* Alberta seniors benefit employment inclusion rate for 1st half of year */
	NUMBER ASBRRP[ASBRRPMAX];  /* Alberta seniors benefit reduction rate for 1st half of year [senior type] */
	int ASBSSOPTP;        /* Alberta seniors benefit 1 senior couple option for 1st half of year */
	NUMBER ASBSABP;       /* Alberta seniors benefit supplemental accommodation benefit for 1st half of year */
	NUMBER ASBSABRRP;    /* Alberta seniors benefit supplemental accommodation reduction rate for 1st half of year */
	NUMBER ASBBOASP;     /* Alberta seniors benefit Basic OAS from previous year */

	/*               British Columbia */

	NUMBER BCS;          /* British Columbia GIS supplement: single pensioners */
	NUMBER BCC;          /* British Columbia GIS supplement: married pensioners */

	/*          Federal Sales Tax Credit */

	NUMBER FSTCF;        /* Federal sales tax credit amount for filer */
	NUMBER FSTCS;        /* Federal sales tax credit amount for spouse */
	NUMBER FSTCC;        /* Federal sales tax credit amount for dependant */
	NUMBER FSTCL;        /* Federal sales tax credit reduction level */
	NUMBER FSTCR;        /* Federal sales tax credit reduction rate */
	int GSTFLAG;         /* GST credit activation flag */
	NUMBER GSTAC;        /* GST additional credit amount */
	NUMBER GSTAR;        /* GST additional credit rate of net income */
	NUMBER GSTAXM;       /* GST additional credit exemption */
	int GSTASPFLAG;      /* Maximum GST additional credit for single parents flag */
	NUMBER GSTCTUNC[GSTCTUNCMAX][LKP_COLS];       /* GST credit take up by number of children */
	

	/*          Federal Sales Tax Credit for the calendar year */

	int GSTCYFLG;        /* GST credit calendar year calculation activation flag */
	NUMBER FSTCFP;       /* Federal sales tax credit amount for filer for 1st half of year */
	NUMBER FSTCSP;       /* Federal sales tax credit amount for spouse for 1st half of year */
	NUMBER FSTCCP;       /* Federal sales tax credit amount for dependant for 1st half of year */
	NUMBER FSTCLP;       /* Federal sales tax credit reduction level for 1st half of year */
	NUMBER FSTCRP;       /* Federal sales tax credit reduction rate for 1st half of year */
	NUMBER GSTACP;       /* GST additional credit amount for 1st half of year */
	NUMBER GSTARP;       /* GST additional credit rate of net income for 1st half of year  */
	NUMBER GSTAXMP;      /* GST additional credit exemption for 1st half of year */
	int GSTASPFLAGP;     /* Maximum GST additional credit for single parents flag for 1st half of year */

	/*          Federal Refundable Child Tax Credit */

	int CTCOPT;          /* Refundable Child tax credit option */
	NUMBER CTCPC;        /* Refundable Child tax credit per child */
	NUMBER CTCTD;        /* Family income refundable child tax credit turndown */
	NUMBER CTCRR;        /* Refundable Child tax credit reduction rate */
	int    CTCREF;       /* Refundable CTC post-reform rules flag                     */
	NUMBER CTCSUP;       /* Refundable CTC young child supplement                     */
	NUMBER CTCERF;       /* Refundable CTC child care expense reduction fraction */
	NUMBER CTCTUR[CTCTURMAX][LKP_COLS]; /* Refundable CTC take up rate table [benefit,rate] */
	NUMBER CTCINC;       /* Refundable CTC family income scaling factor */
										    
	/*          Federal Family Benefits Program */

	NUMBER FCBBAS;       /* Basic child benefit (per child) */
	NUMBER FCBYNG;       /* Supplement for children under age 7*/
	NUMBER FCBYNGR;      /* Child care expense reduction rate */
	int FCBUCCB;         /* Flag for Supplement for children age 6 */
	NUMBER FCBLRG;       /* Supplement for 3rd and subsequent kids */
	NUMBER FCBTD;        /* Federal child benefits family income turndown */
	NUMBER FCBRR;        /* Multi-children family income reduction rate */
	NUMBER FCBRRS;       /* Single-child family income reduction rate */
	NUMBER FCBEIS;       /* Child benefits earned income supplement */
	NUMBER FCBESR;       /* Child benefits earned income supplement rate */
	NUMBER FCBERR;       /* Child benefits earning supplement reduction rate */
	NUMBER FCBERR1;      /* WIS/NCBS reduction rate for families with 1 child */
	NUMBER FCBERR2;      /* WIS/NCBS reduction rate for families with 2 children */
	NUMBER FCBERR3;      /* WIS/NCBS reduction rate for families with 3+ children */
	NUMBER FCBECI;       /* Child benefits earning supplement cut-in level */
	NUMBER FCBEMX;       /* Earnings where WIS phase-in is at maximum */
	NUMBER FCBETD;       /* WIS/NCBS turndown level*/
	int FCBEIE;          /* Flag for WIS dependent on number of children*/
	NUMBER FCBEIS1;      /* WIS/NCBS for first child */
	NUMBER FCBEIS2;      /* WIS/NCBS for second child */
	NUMBER FCBEIS3;      /* WIS/NCBS for each additional child */
	NUMBER FCBPI;        /* Federal Child Tax Benefit phase-in rate*/

	int FCBENCAL;        /* Calculate child benefits for calendar year flag */
	NUMBER FCBBASP;      /* Basic child benefit (per child) for 1st half of year */
	NUMBER FCBYNGP;      /* Supplement for children under age 7 for 1st half of year */
	NUMBER FCBYNGRP;     /* Child care expense reduction rate for 1st half of year */
	int FCBUCCBP;        /* Flag for Supplement for children age 6 for 1st half of year */
	NUMBER FCBLRGP;      /* Supplement for 3rd and subsequent kids for 1st half of year */
	NUMBER FCBTDP;       /* Federal child benefits family income turndown for 1st half of year */
	NUMBER FCBRRP;       /* Multi-children family income reduction rate for 1st half of year */
	NUMBER FCBRRSP;      /* Single-child family income reduction rate for 1st half of year */
	NUMBER FCBEISP;      /* Child benefits earned income supplement for 1st half of year */
	NUMBER FCBESRP;      /* Child benefits earned income supplement rate for 1st half of year */
	NUMBER FCBERRP;      /* Child benefits earning supplement reduction rate for 1st half of year */
	NUMBER FCBERR1P;     /* WIS/NCBS reduction rate for families with 1 child for 1st half of year */
	NUMBER FCBERR2P;     /* WIS/NCBS reduction rate for families with 2 children for 1st half of year */
	NUMBER FCBERR3P;     /* WIS/NCBS reduction rate for families with 3+ children for 1st half of year */
	NUMBER FCBECIP;      /* Child benefits earning supplement cut-in level for 1st half of year */
	NUMBER FCBEMXP;      /* Earnings where WIS phase-in is at maximum for 1st half of year */
	NUMBER FCBETDP;      /* WIS/NCBS turndown level for 1st half of year */
	int FCBEIEP;         /* Flag for WIS dependent on number of children for 1st half of year*/
	NUMBER FCBEIS1P;     /* WIS/NCBS for first child for 1st half of year */
	NUMBER FCBEIS2P;     /* WIS/NCBS for second child for 1st half of year */
	NUMBER FCBEIS3P;     /* WIS/NCBS for each additional child for 1st half of year */
	NUMBER FCBPIP;       /* Federal Child Tax Benefit phase-in rate for 2nd half of year */

	/*          Universal Child Care Benefit       */
	int    UCCBFLAG;      /* Universal child care benefit activation flag */
	NUMBER UCCBAMT;       /* Universal child care benefit amount for each child < 6 */


	/*          Provincial Family Benefits Program */
	/*          Newfoundland and Labrador Child Benefit Program */
	int    NCBFLG;        /* Newfoundland child benefit activation flag */
	NUMBER NCB1;          /* Nfld. child benefit for first child */
	NUMBER NCB2;          /* Nfld. child benefit for second child */
	NUMBER NCB3;          /* Nfld. child benefit for third child */
	NUMBER NCB4;          /* Nfld. child benefit for 4th and subsequent child */
	NUMBER NCBTD;         /* Nfld. child benefit family income turndown */
	NUMBER NCBPO;         /* Nfld. child benefit family income phase out */
	NUMBER NMBNS;         /* Nfld. Mother-Baby Nutrition Supplement */
	NUMBER NMBNSEXT;      /* Nfld. Mother-Baby Nutrition Supplement newborn extra benefit */
	NUMBER NCB1P;         /* Nfld. child benefit for first child for 1st half of year */
	NUMBER NCB2P;         /* Nfld. child benefit for second child for 1st half of year */
	NUMBER NCB3P;         /* Nfld. child benefit for third child for 1st half of year */
	NUMBER NCB4P;         /* Nfld. child benefit for 4th and subsequent child for 1st half of year */
	NUMBER NCBTDP;        /* Nfld. child benefit family income turndown for 1st half of year */
	NUMBER NCBPOP;        /* Nfld. child benefit family income phase out for 1st half of year */
	NUMBER NMBNSP;        /* Nfld. Mother-Baby Nutrition Supplement for 1st half of year */
	NUMBER NMBNSEXTP;     /* Nfld. Mother-Baby Nutrition Supplement newborn extra benefit for 1st half of year */

	/*          New Brunswick child tax benefit Program */

	int    NBCTBFLG;      /* NB child benefit activation flag */
	NUMBER NBCBBAS;       /* NB Basic child benefit (per child) */
	NUMBER NBCBTD;        /* NB child benefits family income turndown */
	NUMBER NBCBRR;        /* NB Multi-children family income reduction rate */
	NUMBER NBCBRRS;       /* NB Single-child family income reduction rate */
	NUMBER NBCBEIS;       /* NB Child benefits earned income supplement */
	NUMBER NBCBESR;       /* NB Child benefits earned income supplement rate */
	NUMBER NBCBERR;       /* NB Child benefits earning supplement reduction rate */
	NUMBER NBCBECI;       /* NB Child benefits earning supplement cut-in level */
	NUMBER NBCBETD;       /* NB Child benefits earning supplement turndown level*/
	NUMBER NBCBPI;        /* NB Child benefits phase-in rate*/
	NUMBER NBCBBASP;      /* NB Basic child benefit (per child) for 1st half of year */
	NUMBER NBCBTDP;       /* NB child benefits family income turndown for 1st half of year */
	NUMBER NBCBRRP;       /* NB Multi-children family income reduction rate for 1st half of year */
	NUMBER NBCBRRSP;      /* NB Single-child family income reduction rate for 1st half of year */
	NUMBER NBCBEISP;      /* NB Child benefits earned income supplement for 1st half of year */
	NUMBER NBCBESRP;      /* NB Child benefits earned income supplement rate for 1st half of year */
	NUMBER NBCBERRP;      /* NB Child benefits earning supplement reduction rate for 1st half of year */
	NUMBER NBCBECIP;      /* NB Child benefits earning supplement cut-in level for 1st half of year */
	NUMBER NBCBETDP;      /* NB Child benefits earning supplement turndown level for 1st half of year */
	NUMBER NBCBPI1P;      /* NB Child benefits phase-in rate for 1st half of year */
	NUMBER NBCBPI2P;      /* NB Child benefits phase-in rate for 2nd half of year */

	/*          Nova Scotia child tax benefit Program */

	int    VCBFLG;      /* NS child benefit activation flag */
	NUMBER    VCBTD;      /* NS child benefit turndown */
	NUMBER    VCBBAS1;    /* NS child benefit for first child */
	NUMBER    VCBBAS2;    /* NS child benefit for second child */
	NUMBER    VCBBAS3;    /* NS child benefit for third or additional child */
	NUMBER    VCBPO;      /* NS child benefit family income phase out */
	NUMBER    VCBTDP;     /* NS child benefit turndown for 1st half of year */
	NUMBER    VCBBAS1P;   /* NS child benefit for first child for 1st half of year */
	NUMBER    VCBBAS2P;   /* NS child benefit for second child for 1st half of year */
	NUMBER    VCBBAS3P;   /* NS child benefit for third or additional child for 1st half of year */
	NUMBER    VCBPOP;     /* NS child benefit family income phase out for 1st half of year */

	/*          Ontario Child Benefit */
	int OCBFLAG;        /* Ontario Child Benefit activation flag */
	NUMBER OCBAMT;      /* Ontario Child Benefit amount per child */
	NUMBER OCBTD;       /* Ontario Child Benefit family income turndown */
	NUMBER OCBRR;       /* Ontario Child Benefit reduction rate */
	NUMBER OCBMIN;      /* Ontario Child Benefit minimum benefit */

	NUMBER OCBAMTP;     /* Ontario Child Benefit amount per child for 1st half of year */
	NUMBER OCBTDP;      /* Ontario Child Benefit family income turndown for 1st half of year */
	NUMBER OCBRRP;      /* Ontario Child Benefit reduction rate for 1st half of year */
	NUMBER OCBPIP;      /* Ontario Child Benefit flag for 1st half of year */

	/*          Ontario Refundable Child Care Expenses Tax Credit */

	int OCCEAFLG;        /* Ont. Child Care Expense Credit activation flag */
	NUMBER OCCEAYNG;		/* Ont. Child Care Expense Credit allowance per child */
	NUMBER OCCEAPCT;		/* Ont. Child Care Expense Credit qualifying percentage */
	NUMBER OCCEATD;		/* Ont. Child Care Expense Credit family income turndown */
	NUMBER OCCEARR;		/* Ont. Child Care Expense Credit benefit reduction rate */
	int OCWISFLG;		/* Ont. Child Care Working Income Supplement activation flag */
	NUMBER OCWISTD;		/*	Ont. Child Care Working Income Supplement minimum earnings */
	NUMBER OCWISSP;		/*	Ont. Child Care Working Income Supplement maximum benefit for single parents */
	NUMBER OCWISRR[OCWISRRMAX][LKP_COLS]; /* Ont. Child Care Working Income Supplement Rate [children][rr]*/	
	NUMBER OCCSEXT;		/* Ont. Child Care Supplement One-time payment of extra benefit */
	int OCCSOCB;        /* Ont. Child Care Supplement reduced by Ontario Child Benefit flag */	
	int OCCSPOYR;           /* Ont. Child Care Working Income Supplement phase out year */
	NUMBER OCCSPOPYR;       /* Ont. Child Care Supplement phase out year proportion born pre July */

	NUMBER OCCEAYNGP;		/* Ont. Child Care Expense Credit allowance per child for 1st half of year */
	NUMBER OCCEAPCTP;		/* Ont. Child Care Expense Credit qualifying percentage for 1st half of year */
	NUMBER OCCEATDP;		/* Ont. Child Care Expense Credit family income turndown for 1st half of year */
	NUMBER OCCEARRP;		/* Ont. Child Care Expense Credit benefit reduction rate for 1st half of year */
	int OCWISFLGP;		/* Ont. Child Care Working Income Supplement activation flag for 1st half of year */
	NUMBER OCWISTDP;		/*	Ont. Child Care Working Income Supplement minimum earnings for 1st half of year */
	NUMBER OCWISSPP;		/*	Ont. Child Care Working Income Supplement maximum benefit for single parents for 1st half of year */
	NUMBER OCWISRRP[OCWISRRPMAX][LKP_COLS]; /* Ont. Child Care Working Income Supplement Rate [children][rr] for 1st half of year */	

	/*          Manitoba child benefit program */

	int    MCBFLAG;       /* Manitoba child benefit activation flag */
	NUMBER    MCBTD;      /* Manitoba child benefit turndown */
	NUMBER    MCBAMT;     /* Manitoba child benefit amount per child */
	NUMBER    MCBPO;      /* Manitoba child benefit phase out */
	NUMBER    MCBMINE;    /* Manitoba child benefit minimum earnings threshold */
	NUMBER 	  MCBEIR;     /* Manitoba Child benefit earned income phase-in rate */

	/*          Saskatchewan child benefit programs */

	int SCBFLG;        /* Sask Child Benefit activation flag */
	NUMBER SCB1;		/* Sask Child Benefit max for 1st child */
	NUMBER SCB2;		/* Sask Child Benefit max for 2nd child */
	NUMBER SCB3;		/* Sask Child Benefit max for 3rd and additional child */
	NUMBER SCBTD1;		/* Sask Child Benefit 1st turndown */
	NUMBER SCBTD2;		/* Sask Child Benefit 2nd turndown */
	NUMBER SCBRR1[SCBRR1MAX];  /* Sask Child Benefit 1st reduction rate [number of kids] */
	NUMBER SCBRR2[SCBRR2MAX];  /* Sask Child Benefit 2nd reduction rate [number of kids] */
	NUMBER SCBSPA;		/* Sask Child Benefit Single Parent Amount  */

	NUMBER SCB1P;		/* Sask Child Benefit max for 1st child for 1st half of year */
	NUMBER SCB2P;		/* Sask Child Benefit max for 2nd child for 1st half of year */
	NUMBER SCB3P;		/* Sask Child Benefit max for 3rd and additional child for 1st half of year */
	NUMBER SCBTD1P;		/* Sask Child Benefit 1st turndown for 1st half of year */
	NUMBER SCBTD2P;		/* Sask Child Benefit 2nd turndown for 1st half of year */
	NUMBER SCBRR1P[SCBRR1MAX];  /* Sask Child Benefit 1st reduction rate [number of kids] for 1st half of year */
	NUMBER SCBRR2P[SCBRR2MAX];  /* Sask Child Benefit 2nd reduction rate [number of kids] for 1st half of year */
	NUMBER SCBSPAP;		/* Sask Child Benefit Single Parent Amount for 1st half of year */


	/*   B.C. Family Bonus Program */

	int    BCFBFLAG;      /* Activate B.C. Family Bonus Program */
	NUMBER BCFBBAS;       /* B.C. Family Bonus amount per child */
	NUMBER BCFBTD;        /* B.C. Family Bonus Turndown */
	NUMBER BCFBRRS;       /* B.C. Family Bonus single child reduction rate */
	NUMBER BCFBRR;        /* B.C. Family Bonus multiple child reduction rate */
	int    BCFBIFS;       /* Activate B.C. Family Bonus to include Federal NCS */
	NUMBER BCFBNCS1;	  /* B.C. Family Bonus National Child Supplement for first child */
	NUMBER BCFBNCS2;      /* B.C. Family Bonus National Child Supplement for second child */
	NUMBER BCFBNCS3;      /* B.C. Family Bonus National Child Supplement for each additional child */
	NUMBER BCFBNCSRR1;    /* B.C. Family Bonus NCS reduction rate for families with 1 child */
	NUMBER BCFBNCSRR2;    /* B.C. Family Bonus NCS reduction rate for families with 2 children */
	NUMBER BCFBNCSRR3;    /* B.C. Family Bonus NCS reduction rate for families with 3+ children */
	NUMBER BCFBNCSTD;     /* B.C. Family Bonus National Child Supplement Turndown  */
	int    BCEIBFLG;      /* Activate B.C. Earned Income Benefit Program */
	NUMBER BCBEIS1;	      /* B.C. Earned Income Benefit for first child */
	NUMBER BCBEIS2;       /* B.C. Earned Income Benefit for	second child */
	NUMBER BCBEIS3;       /* B.C. Earned Income Benefit for each additional child */
	NUMBER BCBERR1;       /* B.C. EIB reduction rate for families with 1 child */
	NUMBER BCBERR2;       /* B.C. EIB reduction rate for families with 2 children */
	NUMBER BCBERR3;       /* B.C. EIB reduction rate for families with 3+ children */
	NUMBER BCBEMX;        /* B.C. Earned Income Benefit Income Reduction  */
	NUMBER BCEIBPI;       /* B.C. Earned Income Benefit Income Phase In   */
	NUMBER BCBEITD;       /* B.C. Earned Income Benefit Turndown  */

	NUMBER BCFBBASP;       /* B.C. Family Bonus amount per child for 1st half of year */
	NUMBER BCFBTDP;        /* B.C. Family Bonus Turndown for 1st half of year */
	NUMBER BCFBRRSP;       /* B.C. Family Bonus single child reduction rate for 1st half of year */
	NUMBER BCFBRRP;        /* B.C. Family Bonus multiple child reduction rate for 1st half of year */
	int    BCFBIFSP;       /* Activate B.C. Family Bonus to include Federal NCS for 1st half of year */
	NUMBER BCFBNCS1P;	  /* B.C. Family Bonus National Child Supplement for first child for 1st half of year */
	NUMBER BCFBNCS2P;      /* B.C. Family Bonus National Child Supplement for second child for 1st half of year */
	NUMBER BCFBNCS3P;      /* B.C. Family Bonus National Child Supplement for each additional child for 1st half of year */
	NUMBER BCFBNCSRR1P;    /* B.C. Family Bonus NCS reduction rate for families with 1 child for 1st half of year */
	NUMBER BCFBNCSRR2P;    /* B.C. Family Bonus NCS reduction rate for families with 2 children for 1st half of year */
	NUMBER BCFBNCSRR3P;    /* B.C. Family Bonus NCS reduction rate for families with 3+ children for 1st half of year */
	NUMBER BCFBNCSTDP;     /* B.C. Family Bonus National Child Supplement Turndown for 1st half of year  */
	int    BCEIBFLGP;      /* Activate B.C. Earned Income Benefit Program for 1st half of year */
	NUMBER BCBEIS1P;	      /* B.C. Earned Income Benefit for first child for 1st half of year */
	NUMBER BCBEIS2P;       /* B.C. Earned Income Benefit for	second child for 1st half of year */
	NUMBER BCBEIS3P;       /* B.C. Earned Income Benefit for each additional child for 1st half of year */
	NUMBER BCBERR1P;       /* B.C. EIB reduction rate for families with 1 child for 1st half of year */
	NUMBER BCBERR2P;       /* B.C. EIB reduction rate for families with 2 children for 1st half of year */
	NUMBER BCBERR3P;       /* B.C. EIB reduction rate for families with 3+ children for 1st half of year */
	NUMBER BCBEMXP;        /* B.C. Earned Income Benefit Income Reduction for 1st half of year  */
	NUMBER BCEIBPIP;       /* B.C. Earned Income Benefit Income Phase In for 1st half of year  */
	NUMBER BCBEITDP;       /* B.C. Earned Income Benefit Turndown for 1st half of year  */

	/*          Social Assistance Parameters */

	int SAFLAG;      /* Social assistance flag */
	int SAPFLAG;     /* Social assistance predicted value flag */
	int SAELDOPT;    /* SA for elderly calculation method [1=~SA,2=GIST->~SA,3=diff] */
	NUMBER SAFS[NUMREG];  /* Federal share of social assistance [prov] */
	NUMBER SFAOUT;   /* Proportion of social assistance to eliminate */
	NUMBER SATARGET[SATARGETMAX];    /* Social assistance target for predicted SA */
	int SACLAWFLAG;     /* Social assistance NCBS clawback flag */
	int SACLAWPR[NUMREG];    /* Social assistance clawback flag [prov] */
	int SACLAWOPT;      /* Social assistance NCBS clawback include in tax/income flag */
	NUMBER NCLAWSA1;    /* Newfoundland social assistance clawback amount for first child */
	NUMBER NCLAWSA2;    /* Newfoundland social assistance clawback amount for each additional child */
	NUMBER PNCBSFT;    /* P.E.I. social assistance NCBS flow-through amount per child */
	NUMBER QNCBSFT1;    /* Quebec social assistance NCBS flow-through amount for first child */
	NUMBER QNCBSFT2;    /* Quebec social assistance NCBS flow-through amount for second child */
	NUMBER QNCBSFT3;    /* Quebec social assistance NCBS flow-through amount for third (or more) child */
	NUMBER ONCBSFT1;    /* Ontario social assistance NCBS flow-through amount for first child */
	NUMBER ONCBSFT2;    /* Ontario social assistance NCBS flow-through amount for second child */
	NUMBER ONCBSFT3;    /* Ontario social assistance NCBS flow-through amount for third (or more) child */
	NUMBER MCLAWSA6;     /* Manitoba Social assistance NCBS clawback for children 6 and under */
	NUMBER MCLAWSA12;     /* Manitoba Social assistance NCBS clawback for children 12 and under  */
	NUMBER MCLAWPCT[MCLAWPCTRMAX][MCLAWPCTCMAX];   /* Manitoba SA Clawback percentage kids over flow through age in families [#kids][#kids<age] */
	NUMBER ANCBSFT1;    /* Alberta social assistance NCBS flow-through amount for first child */
	NUMBER ANCBSFT2;    /* Alberta social assistance NCBS flow-through amount for second child */
	NUMBER ANCBSFT3;    /* Alberta social assistance NCBS flow-through amount for third (or more) child */
	int ASHELTFLG;      /* Alberta Shelter Increase under NCBS clawback flag */
	NUMBER ASHELTER[NUMPERMAX];    /* Alberta Shelter Increase by number of persons in household */

	/*          Social Assistance Clawback Parameters for the calendar year */

	NUMBER NCLAWSA1P;    /* Newfoundland SA clawback amount for first child for 1st half of year */
	NUMBER NCLAWSA2P;    /* Newfoundland SA clawback amount for each additional child for 1st half of year */
	NUMBER PNCBSFTP;    /* P.E.I. SA NCBS flow-through amount per child for 1st half of year */
	NUMBER QNCBSFT1P;    /* Quebec SA NCBS flow-through amount for first child for 1st half of year */
	NUMBER QNCBSFT2P;    /* Quebec SA NCBS flow-through amount for second child for 1st half of year */
	NUMBER QNCBSFT3P;    /* Quebec SA NCBS flow-through amount for third (or more) child for 1st half of year */
	NUMBER ONCBSFT1P;    /* Ontario SA NCBS flow-through amount for first child for 1st half of year */
	NUMBER ONCBSFT2P;    /* Ontario SA NCBS flow-through amount for second child for 1st half of year */
	NUMBER ONCBSFT3P;    /* Ontario SA NCBS flow-through amount for third (or more) child for 1st half of year */
	NUMBER MCLAWSA6P;     /* Manitoba SA NCBS clawback for children 6 and under for 1st half of year */
	NUMBER MCLAWSA12P;     /* Manitoba SA NCBS clawback for children 12 and under for 1st half of year */
	NUMBER MCLAWPCTP[MCLAWPCTPRMAX][MCLAWPCTPCMAX];   /* Manitoba SA Clawback percentage kids over flow through age for 1st half of year [#kids][#kids<age] */
	NUMBER ANCBSFT1P;    /* Alberta SA NCBS flow-through amount for first child for 1st half of year */
	NUMBER ANCBSFT2P;    /* Alberta SA NCBS flow-through amount for second child for 1st half of year */
	NUMBER ANCBSFT3P;    /* Alberta SA NCBS flow-through amount for third (or more) child for 1st half of year */
	int ASHELTFLGP;      /* Alberta Shelter Increase under NCBS clawback flag for 1st half of year */
	NUMBER ASHELTERP[NUMPERMAX];    /* Alberta Shelter Increase by number of persons in household for 1st half of year */
	/*          Federal Refundable Medical Expense Supplement */

	NUMBER MEDREMIN;  /* Minimum earnings for refundable medical expense supplement */
	NUMBER MEDRRATE;  /* Proportion of expenses allowed for medical expense supplement */
	NUMBER MEDRMAX;   /* Maximum expenses allowed for medical expense supplement */
	NUMBER MEDRRR;    /* Reduction rate for the medical expense supplement */
	NUMBER MEDRTD;    /* Refundable medical expense supplement income turndown */

	/*          Federal Refundable Working Income Tax Benefit  */
	int WITBFLAG;     /* Working Income Tax Benefit activation flag  */
	NUMBER WITBSNG;   /* Working Income Tax Benefit amount for singles */
	NUMBER WITBFAM;   /* Working Income Tax Benefit amount for couples/single parents */
	NUMBER WITBFPO;   /* WITB Family Net Income Phase-out Threshold */
	NUMBER WITBSPO;   /* WITB Single Net Income Phase-out Threshold */
	NUMBER WITBMINE;  /* Working Income Tax Benefit Minimum Earnings Threshold */
	NUMBER WITBPIR;   /* Working Income Tax Benefit Phase in Rate */
	NUMBER WITBRR;    /* Working Income Tax Benefit Reduction Rate */
	NUMBER WITBSMINE;  /* WITB Supplement for Disabilities Minimum Earnings Threshold */
	NUMBER WITBSAMT;   /* WITB Supplement for Disabilities Amount */
	NUMBER WITBSPIR;   /* WITB Supplement for Disabilities Phase in Rate */
	NUMBER WITBSRR;    /* WITB Supplement for Disabilities Reduction Rate */
	NUMBER WITBSFPO;   /* WITB Supplement for Disabilities Family Net Income Phase-out Threshold */
	NUMBER WITBSSPO;   /* WITB Supplement for Disabilities Single Net Income Phase-out Threshold */

	/*          Federal relief for heating expenses */

	int HEATRLFLG;     /* Federal relief for heating expenses activation flag */
	NUMBER HEATSNG;    /* Federal relief for heating expenses for singles */
	NUMBER HEATFAM;    /* Federal relief for heating expenses for families */
	int FECBFLAG;      /* Federal Energy Cost Benefit activation flag */
	NUMBER FECBGIS;    /* Federal Energy Cost Benefit for GIS recipients */
	NUMBER FECBNCBS;   /* Federal Energy Cost Benefit for NCBS recipients */


	/*          Provincial relief for heating expenses  */

	/*          Newfoundland and Labrador Home Heating Fuel Rebate  */

	int NHEATFLG;      /* Newfoundland home heating fuel rebate activation flag */
	NUMBER NHEATREB;   /* Newfoundland home heating fuel rebate amount */
	int NHEATSAFLG;    /* Newfoundland home heating fuel rebate - SA recipients eligible */
	int NHEATINC;      /* Newfoundland home heating fuel rebate - income test flag */
	NUMBER NHEATTD;    /* Newfoundland home heating fuel rebate family income turndown */
	NUMBER NHEATPO;    /* Newfoundland home heating fuel rebate family income phase out */
	NUMBER NHEATMIN;   /* Newfoundland home heating fuel rebate minimum */
	NUMBER NHEATRR;    /* Newfoundland home heating fuel rebate reduction rate */

	/* 			Nova Scotia Home Heating Assistance Rebate     */

	int VHEATFLG;      /* Nova Scotia Home Heating Assistance Rebate activation flag */
	NUMBER VHEATREB;   /* Nova Scotia home heating fuel rebate amount for oil */
	NUMBER VHEATERB;   /* Nova Scotia home heating fuel rebate amount for electricity */
	NUMBER VHEATSTD;   /* Nova Scotia home heating fuel rebate income turndown for singles */
	NUMBER VHEATFTD;   /* Nova Scotia home heating fuel rebate income turndown for families */
	NUMBER VHEATTU;    /* Nova Scotia home heating fuel rebate take up  */

	/* 			New Brunswick Home Heating Oil Benefit     */

	int BHEATFLG;      /* New Brunswick Home Heating Oil Benefit activation flag */
	NUMBER BHEATBEN[BHEATBENMAX][LKP_COLS];   /* New Brunswick Home Heating Oil Benefit [income, benefit] */
	NUMBER BHEATPO;    /* New Brunswick Home Heating Oil Benefit family income phase out */
	int BHEATSA;       /* New Brunswick Home Heating Oil Benefit for SA recipients flag */

	/* 			Ontario Home Electricity Relief Program     */

	int OHEATFLG;      /* Ontario Home Electricity Relief activation flag */
	NUMBER OHEATSNG;   /* Ontario Home Electricity Relief amount for singles */
	NUMBER OHEATFAM;   /* Ontario Home Electricity Relief amount for families */
	NUMBER OHEATSTD;   /* Ontario Home Electricity Relief income turndown for singles */
	NUMBER OHEATFTD;   /* Ontario Home Electricity Relief income turndown for families */
	NUMBER OHEATMIN;   /* Ontario Home Electricity Relief minimum */
	NUMBER OHEATRR;    /* Ontario Home Electricity Relief reduction rate */

	/* 			Saskatchewan Home Heating Assistance Rebate     */

	int SHEATFLG;      /* Saskatchewan Home Heating Assistance Rebate activation flag */
	NUMBER SHEATSNG;   /* Saskatchewan Home Heating Assistance Rebate for singles */
	NUMBER SHEATFAM;   /* Saskatchewan Home Heating Assistance Rebate for families */

	/*          Alberta Energy Tax Refund             */

	int AHEATFLG;      /* Alberta Energy Tax Refund activation flag */
	NUMBER AHEATREB;   /* Alberta Energy Tax Refund amount */

	/* 			British Columbia Refundable Energy Credit     */

	int CHEATFLG;      /* British Columbia Refundable Energy Credit activation flag */
	NUMBER CHEATSNG;   /* British Columbia Refundable Energy Credit for singles */
	NUMBER CHEATFAM;   /* British Columbia Refundable Energy Credit for families */

		
	/*          Nova Scotia Direct Assistance Program */

	int VDAFLAG;     /* NS Direct assistance benefit flag */
	NUMBER VDASB;    /* NS Direct assistance benefit for singles */
	NUMBER VDACB;    /* NS Direct assistance benefit for couples */
	NUMBER VDASI;    /* NS Direct assistance maximum income for singles */
	NUMBER VDACI;    /* NS Direct assistance maximum income for couples */
	int VDAFWC;      /* NS Direct assistance benefit for families with children flag */

	/*          Nova Scotia Taxpayer Refund */
	int NSTXREFFLG;     /* NS Taxpayer refund  flag */
	NUMBER NSTXREFAMT;    /* NS Taxpayer refund amount */

	/*     Personal Taxes */


	/*          Calculation of Total Income */

	NUMBER CAPGIR;       /* Capital gains inclusion rate */
	NUMBER FDGUR;        /* Federal dividend gross-up rate */
	NUMBER FDGURLC;      /* Federal dividend gross-up rate from large (eligible) corporations */
	NUMBER DIVPLC;       /* Percentage of dividends from large (eligible) corporations */
	int SPLTPNSFLAG;     /* Flag to split pension income */
	NUMBER PENSPLTINCR;  /* Increment by which to split pension income */

	/*          Deductions from Total Income */

	int REPNETFLAG;     /* Social program repayments reduce net income flag */

	/*               Employment Expense Deduction */

	NUMBER ALEXPP;       /* Proportion of other allowable employment expenses to use as deduction */
	NUMBER FACTISENF;  /* Scale-up factor for non-farm self-employment income */

	/*               CPP/QPP Contributions */
	NUMBER CPPXM;        /* CPP/QPP exemptible earnings */
	NUMBER YMPE;         /* CPP/QPP maximum pensionable earnings */
	NUMBER SECF;         /* CPP/QPP contribution rate on self-employment earnings */
	NUMBER WSCF;         /* CPP/QPP contribution rate on employment earnings */
	NUMBER WSCM;         /* Ratio of self-employed to employed contribution fraction */
	NUMBER CPPLT60[CPPLT60MAX][LKP_COLS];       /* CPP/QPP Contributions Take up (under 60) by earnings with CPP income */
	NUMBER CPP60T64[CPP60T64MAX][LKP_COLS];       /* CPP/QPP Contributions Take up (60 - 64) by earnings with CPP income */
	NUMBER CPPGT64[CPPGT64MAX][LKP_COLS];       /* CPP/QPP Contributions Take up (over 64) by earnings with CPP income */
	int CPPSEDEDFLG;     /* CPP/QPP contribution deduction for self-employed earnings flag */
	NUMBER CPPSEDFRC;    /* CPP/QPP contribution deduction fraction for self-employed earnings */

	/*               Child Care Expense Deduction */

	int    CCEATFLG;     /* CCEA eligible->claimable transformation activation flag */
	NUMBER CCEATLL;      /* CCEA eligible->claimable lower limit           */
	NUMBER CCEATFR;      /* CCEA eligible->claimable fraction              */
	NUMBER CCEAYNG;      /* CCEA young child limit                         */
	NUMBER CCEAOLD;      /* CCEA old child limit                           */
	NUMBER CCEAEMPF;     /* CCEA fraction of employment income (Limit `B') */
	int    CCESFLAG;     /* CCE full-time student flag                     */
	int    CCEAOAGE;     /* CCEA Maximum eligible age for oldest child     */
	int    CCEROPT;      /* Child care expense deduction recipient [1=mother,2=lower income] */
	int    CCEZOPT;      /* CCE young kid optimization rules [1=use, 2=zero, 3=optimize] */
	NUMBER CCESYNG;      /* CCEA young child limit for full-time students  */
	NUMBER CCESOLD;      /* CCEA old child limit for full-time students    */
	int    CCEPTFLG;     /* CCE part-time student flag                     */

	/*               Basic Exemption / Tax Credit */

	NUMBER BXM;          /* Basic personal exemption/amount */
	NUMBER BXMEXT;       /* Basic personal amount extra top-up */
	NUMBER BXMS;         /* Basic personal exemption supplement */
	NUMBER BXMSRR;       /* Basic personal exemption supplement reduction rate */
	NUMBER BXMSPI;       /* Basic personal exemption supplement phase in */

	/*               Age Exemption / Tax Credit */

	NUMBER AXM;          /* Age amount */
	NUMBER AXTD;        /* Age amount net income turndown */
	NUMBER AXRR;        /* Age amount credit reduction rate */
	NUMBER AXPI;        /* Age amount phase in rate for 1994 and beyond*/




	/*               Married Exemption / Spouse Tax Credit */

	NUMBER MXM;          /* Married exemption/amount */
	NUMBER MXMT;         /* Married exemption/amount turndown level */
	NUMBER MXMEXT;       /* Married amount extra top-up */
	NUMBER MXMTEXT;      /* Married amount turndown level extra top-up */

	/*               Married Equivalent Exemption / Spouse Equivalent Tax Credit */

	NUMBER EMXM;         /* Married equivalent exemption/amount */
	NUMBER EMXMT;        /* Married equivalent exemption/amount turndown level */
	NUMBER EMXMEXT;      /* Married equivalent amount extra top-up */
	NUMBER EMXMTEXT;     /* Married equivalent amount turndown level extra top-up */

	/*               Exemption / Tax Credit for Dependent Children */

	NUMBER YCXM1;        /* Dependent child amount (1st child)    */
	NUMBER YCXM2;        /* Dependent child amount (2nd child)    */
	NUMBER YCXM3;        /* Dependent child amount (3rd ,etc.)    */
	NUMBER YCXMT;        /* Dependent child exemption/amount turndown level  */

	/*          Other Deductions from Net Income */


	/*               Pension Income Deduction / Tax Credit */

	NUMBER YPNDL;        /* Maximum pension income deduction/amount */

	/*               Charitable Donation Deduction / Tax Credit */

	NUMBER MEDANF;       /* Medical allowance lower limit net income fraction */
	NUMBER MEDALL;       /* Medical allowance maximum lower limit */
	NUMBER CHATNF;       /* Charitable donations maximum net income fraction */
	NUMBER CHATL1;       /* Charitable donations amount level 1 */
	NUMBER CHATR1;       /* Charitable donations tax credit rate 1 */
	NUMBER CHATR2;       /* Charitable donations tax credit rate 2 */

	/*               Disability Deduction / Tax Credit */

	NUMBER MAXDX;        /* Maximum disability deduction/amount */
	NUMBER ODISTC;       /* Maximum infirm dependent 18 or older tax credit */

	/*               Education Deduction / Tax Credit */

	NUMBER EDXPM;        /* Education amount per month of full-time studies */
	NUMBER EDXPMPT;      /* Education amount per month of part-time studies */
	NUMBER MAXET;        /* Maximum on transfer of education and tuition amount */
	int    EDDISPT;      /* Part time students with disabilities flag */

	/*               Textbook Tax Credit */

	NUMBER TEXTPMFT;     /* Textbook amount per month of full-time studies */
	NUMBER TEXTPMPT;     /* Textbook amount per month of part-time studies */

	/*               Interest on Student Loans Tax Credit */

	NUMBER INTSLFLG;     /* Interest on Student Loans Tax Credit Activation Flag */

	/* 				 Canada Employment Credit */

	NUMBER EMPTXC;      /* Canada Employment Credit */

	/*               Child Tax Credit */
	NUMBER CTCAMTPC;    /* Child Tax Credit amount per child */

	/*          Federal Taxes */


	/*               Basic Federal Tax */

	NUMBER FTX[FTXMAX][LKP_COLS]; /* Federal tax table [taxable income,basic federal tax] */
	NUMBER FNTCR;        /* Federal non-refundable tax credit rate */
	NUMBER FDTCR;        /* Federal dividend tax credit rate */
	NUMBER FDTCRLC;      /* Federal dividend tax credit rate from large (eligible) corporations */

	/*               Federal Surtax */

	NUMBER FSURL1;       /* Federal surtax level 1 */
	NUMBER FSURR1;       /* Federal surtax rate 1 */
	NUMBER FSURL2;       /* Federal surtax level 2 */
	NUMBER FSURR2;       /* Federal surtax rate 2 */
	NUMBER FSURTRMX;     /* Maximum federal surtax reduction */
	NUMBER FSURTRRL;     /* Federal surtax reduction reduction level */
	NUMBER FSURTRRR;     /* Federal surtax reduction reduction rate */

	/*               Federal Political Contribution Tax Credit */
	NUMBER FPTC[FPTCMAX][LKP_COLS]; /* Federal political contribution table [total donations,donation allowed] */
    NUMBER FPTCBEN;           /* Maximum federal political tax credit allowed*/
    
	/*               Federal Labour-sponsored Funds Tax Credit */
    NUMBER FLVCRT[NUMREG];    /* Percent of labour-sponsored funds cost allowed as credit [prov] */
    NUMBER FLVCMAX;           /* Maximum labour-sponsored funds tax credit allowed */

	/*               Federal Alternate Minimum Tax */

	NUMBER AMTEX;        /* Alternate minimum tax: exemption level */
	NUMBER AMTTX;        /* Alternate minimum tax rate */
	int    AMTRPFLG;        /* RRSP/RPP included in Alternate minimum tax (1=included) */
	int    AMTPRVDF[NUMREG];  /* Alternative minimum tax: prov. tax difference definition[prov] */
	NUMBER AMTSTK;       /* Alternative minimum tax: Stock Option Proportion */
	NUMBER AMTINCRT;     /* Alternative minimum tax: Inclusion Rate */
	NUMBER AMTDIV;       /* Alternative minimum tax: percentage of taxable dividends  */
	NUMBER AMTDIVLC;     /* Alternative minimum tax: percentage of eligible taxable dividends */
	NUMBER AMTFORTX;     /* Alternative minimum tax: Foreign Income Tax Rate */
	int    AMTNEGTI;     /* Alternative minimum tax: Allow Negative Taxable Income Flag */

	/*               Quebec Tax Abatement */

	NUMBER QTAP;         /* Quebec tax abatement proportion of basic federal tax */

	/*               Caregiver Tax Credit */

    NUMBER CGTC;        /* Caregiver Tax Credit */
	int    CGTCFLG;     /* Caregiver Tax Credit activation flag */
	int    CGTCOPT;     /* Caregiver Tax Credit option (1=max, 2=greenbook) */

	/*               Provincial Taxes */
	int IMSHTOPT;        /* Paid rent and property tax imputation option*/


	/*                    Newfoundland */

	NUMBER NPTF;         /* Newfoundland provincial tax fraction */
	NUMBER NSCI;         /* Newfoundland provincial tax above which surtax applies */
	NUMBER NSF;          /* Newfoundland provincial surtax rate */
	NUMBER NSCI2;        /* Newfoundland provincial surtax level 2 */
	NUMBER NSF2;         /* Newfoundland provincial surtax rate 2 */
	NUMBER NPTC[NPTCMAX][LKP_COLS]; /* Newfoundland political contribution table [total donations,donation allowed] */
    NUMBER NPTCBEN;      /* Maximum Newfoundland political tax credit allowed */
	NUMBER NLVCMAX;      /* Maximum NFLD labour-sponsored funds tax credit allowed */ 
	NUMBER NLVCRT; 		 /* Percent of NFLD labour-sponsored funds cost allowed as credit */
	int NSTCFLAG;        /* NFLD sales tax credit activation flag  */
	NUMBER NSTCA;        /* NFLD sales tax credit amount for adults */
    NUMBER NSTCC;        /* NFLD sales tax credit amount for children */
    NUMBER NSTCR;        /* NFLD sales tax credit reduction rate */
    NUMBER NSTCL;        /* NFLD sales tax credit reduction level */
	NUMBER NLITRS;       /* NFLD low income tax reduction single maximum  */
	NUMBER NLITRF;       /* NFLD low income tax reduction family maximum  */
	NUMBER NLITRSIT;     /* NFLD low income tax reduction single income threshold  */
	NUMBER NLITRFIT;     /* NFLD low income tax reduction family income threshold  */
	NUMBER NLITRRR;      /* NFLD low income tax reduction credit reduction rate  */
    /* tax on taxable income parameters */
	int    NTXFLG;       /* NFLD tax on taxable income activation flag */
	NUMBER NMXM;         /* NFLD married amount */
	NUMBER NMXMT;        /* NFLD married amount turndown level */
	NUMBER NEMXM;        /* NFLD equivalent to married amount */
	NUMBER NEMXMT;       /* NFLD equivalent to married turndown level */
	NUMBER NPNTCR;       /* NFLD provincial non-refundable tax credit rate */
	NUMBER NBXM;         /* NFLD Basic Personal Exemption/amount */
	NUMBER NAXM;         /* NFLD Age Amount */
	NUMBER NAXTD;        /* NFLD Age Amount net income turndown */
	NUMBER NAXRR;        /* NFLD Age Amount credit reduction rate */
	NUMBER NYPNDL;       /* NFLD Pension Income Deduction Amount */
	NUMBER NMEDANF;      /* NFLD Medical allowance lower limit net income fraction */
	NUMBER NMEDALL;      /* NFLD Medical allowance maximum lower limit */
	NUMBER NCHATL1;      /* NFLD Charitable Donations amount level 1 */
	NUMBER NCHATR1;      /* NFLD Charitable Donations tax credit rate 1 */
	NUMBER NCHATR2;      /* NFLD Charitable Donations tax credit rate 2 */
	NUMBER NMAXDX;       /* NFLD Maximum Disability deduction/amount */
	NUMBER NODISTC;      /* NFLD Maximum infirm dependent 18 or older tax credit */
	NUMBER NEDXPM;       /* NFLD Education Amount per month of full-time studies */
	NUMBER NEDXPMPT;     /* NFLD Education Amount per month of part-time studies */
	NUMBER NMAXET;       /* NFLD maximum on transfer of education and tuition amount */
	NUMBER NPTX[NPTXMAX][LKP_COLS]; /* NFLD tax table [taxable income,basic provincial tax] */
    NUMBER NCGTC;        /* NFLD Caregiver Tax Credit */
	int    NCGTCFLG;     /* NFLD Caregiver Tax Credit activation flag */
	int    NCGTCOPT;     /* NFLD Caregiver Tax Credit Option (1=max, 2=greenbook) */
	NUMBER NDTCR;        /* NFLD dividend tax credit rate */
	NUMBER NDTCRLC;      /* NFLD dividend tax credit rate from large (eligible) corporations */
	int    NAMTOPT;      /* NFLD alternative minimum tax option  */
	NUMBER NAMTTX;       /* NFLD amt rate as tax on adjusted income */
	NUMBER NAMTPCTF;     /* NFLD amt rate as pct of additional fed tax due to minimum tax */
	NUMBER NAMTPCTM;     /* NFLD amt rate as pct of federal minimum tax amount  */
	

	/*                    Prince Edward Island */

	NUMBER PPTF;         /* P.E.I. provincial tax fraction */
	NUMBER PSCI;         /* P.E.I. provincial tax above which surtax applies */
	NUMBER PSF;          /* P.E.I. provincial surtax rate */
	NUMBER PPTC[PPTCMAX][LKP_COLS]; /* P.E.I. political contribution table [total donations,donation allowed] */
    NUMBER PPTCBEN;        /* Maximum P.E.I. political tax credit allowed */
	NUMBER PLVCMAX;        /* Maximum P.E.I. labour-sponsored funds tax credit allowed */ 
	NUMBER PLVCRT; 		   /* Percent of P.E.I. labour-sponsored funds cost allowed as credit */
 	NUMBER PTRBAS; 		   /* Base PEI low income tax reduction */
	NUMBER PTRSP; 		   /* PEI low income tax reduction for spouse or equivalent-to-spouse */
	NUMBER PTRKID; 		   /* PEI low income tax reduction for dependent child */
	NUMBER PTRTD; 		   /* PEI low income tax reduction Turndown */
	NUMBER PTRRR; 		   /* PEI low income tax reduction Reduction Rate */
    /* tax on taxable income parameters */
	int    PTXFLG;       /* P.E.I. tax on taxable income activation flag */
	NUMBER PMXM;         /* P.E.I. married amount */
	NUMBER PMXMT;        /* P.E.I. married amount turndown level */
	NUMBER PEMXM;        /* P.E.I. equivalent to married amount */
	NUMBER PEMXMT;       /* P.E.I. equivalent to married turndown level */
	NUMBER PPNTCR;       /* P.E.I. provincial non-refundable tax credit rate */
	NUMBER PBXM;         /* P.E.I. Basic Personal Exemption/amount */
	NUMBER PAXM;         /* P.E.I. Age Amount */
	NUMBER PAXTD;        /* P.E.I. Age Amount net income turndown */
	NUMBER PAXRR;        /* P.E.I. Age Amount credit reduction rate */
	NUMBER PYPNDL;       /* P.E.I. Pension Income Deduction Amount */
	NUMBER PMEDANF;      /* P.E.I. Medical allowance lower limit net income fraction */
	NUMBER PMEDALL;      /* P.E.I. Medical allowance maximum lower limit */
	NUMBER PCHATL1;      /* P.E.I. Charitable Donations amount level 1 */
	NUMBER PCHATR1;      /* P.E.I. Charitable Donations tax credit rate 1 */
	NUMBER PCHATR2;      /* P.E.I. Charitable Donations tax credit rate 2 */
	NUMBER PMAXDX;       /* P.E.I. Maximum Disability deduction/amount */
	NUMBER PODISTC;      /* P.E.I. Maximum infirm dependent 18 or older tax credit */
	NUMBER PEDXPM;       /* P.E.I. Education Amount per month of full-time studies */
	NUMBER PEDXPMPT;     /* P.E.I. Education Amount per month of part-time studies */
	NUMBER PMAXET;       /* P.E.I. maximum on transfer of education and tuition amount */
	NUMBER PYCTCAPM;     /* P.E.I. Young Child Tax Credit Amount per Month */
	NUMBER PYCTCPI;      /* P.E.I. Young Child Tax Credit Phase in */
	NUMBER PPTX[PPTXMAX][LKP_COLS]; /* P.E.I. tax table [taxable income,basic provincial tax] */
    NUMBER PCGTC;        /* P.E.I. Caregiver Tax Credit */
	int    PCGTCFLG;     /* P.E.I. Caregiver Tax Credit activation flag */
	int    PCGTCOPT;     /* P.E.I. Caregiver Tax Credit Option (1=max, 2=greenbook) */
	NUMBER PDTCR;        /* P.E.I. dividend tax credit rate */
	NUMBER PDTCRLC;      /* P.E.I. dividend tax credit rate from large (eligible) corporations */
	int    PAMTOPT;      /* P.E.I. alternative minimum tax option  */
	NUMBER PAMTTX;       /* P.E.I. amt rate as tax on adjusted income */
	NUMBER PAMTPCTF;     /* P.E.I. amt rate as pct of additional fed tax due to minimum tax */
	NUMBER PAMTPCTM;     /* P.E.I. amt rate as pct of federal minimum tax amount */


	/*                    Nova Scotia */

	NUMBER VPTF;         /* Nova Scotia provincial tax fraction */
	NUMBER VSCI;         /* Nova Scotia provincial tax above which surtax applies */
	NUMBER VSCI2;        /* Nova Scotia provincial tax above which surtax applies (2nd level) */
	NUMBER VSF;          /* Nova Scotia provincial surtax rate */
	NUMBER VSF2;         /* Nova Scotia provincial surtax rate (2nd level) */
	NUMBER VPTC[VPTCMAX][LKP_COLS]; /* Nova Scotia political contribution table [total donations,donation allowed] */
   NUMBER VPTCBEN;        /* Maximum Nova Scotia political tax credit allowed */
	int VPHOPT;           /* Nova Scotia pharmacare premium option (1=GIS, 2=income) */
	NUMBER VPHPREM;       /* Nova Scotia pharmacare premium */
	NUMBER VPHTC;         /* Nova Scotia pharmacare refundable tax credit */
	NUMBER VPHTD;         /* Nova Scotia pharmacare tax credit turndown */
	NUMBER VPHTDC;        /* Nova Scotia pharmacare tax credit turndown for couples */
	NUMBER VPHRR;         /* Nova Scotia pharmacare tax credit reduction rate */
	NUMBER VTRBAS;			 /* Nova Scotia tax reduction basic amount */
	NUMBER VTRSP; 			 /* Nova Scotia tax reduction spouse amount */ 
	NUMBER VTREM;		 /* Nova Scotia tax reduction equivalent to spouse amount */
	NUMBER VTRKID;		 /* Nova Scotia tax reduction child amount */
	NUMBER VTRTD;  		 /* Nova Scotia tax reduction family income turndown */
	NUMBER VTRRR;		    /* Nova Scotia tax reduction family income reduction rate */
	NUMBER VLVCMAX;        /* Maximum N.S. labour-sponsored funds tax credit allowed */ 
	NUMBER VLVCRT; 		   /* Percent of N.S. labour-sponsored funds cost allowed as credit */
    /* tax on taxable income parameters */
	int    VTXFLG;       /* N.S. tax on taxable income activation flag */
	NUMBER VMXM;         /* N.S. married amount */
	NUMBER VMXMT;        /* N.S. married amount turndown level */
	NUMBER VEMXM;        /* N.S. equivalent to married amount */
	NUMBER VEMXMT;       /* N.S. equivalent to married turndown level */
	NUMBER VPNTCR;       /* N.S. provincial non-refundable tax credit rate */
	NUMBER VBXM;         /* N.S. Basic Personal Exemption/amount */
	NUMBER VAXM;         /* N.S. Age Amount */
	NUMBER VAXTD;        /* N.S. Age Amount net income turndown */
	NUMBER VAXRR;        /* N.S. Age Amount credit reduction rate */
	NUMBER VYPNDL;       /* N.S. Pension Income Deduction Amount */
	NUMBER VMEDANF;      /* N.S. Medical allowance lower limit net income fraction */
	NUMBER VMEDALL;      /* N.S. Medical allowance maximum lower limit */
	NUMBER VCHATL1;      /* N.S. Charitable Donations amount level 1 */
	NUMBER VCHATR1;      /* N.S. Charitable Donations tax credit rate 1 */
	NUMBER VCHATR2;      /* N.S. Charitable Donations tax credit rate 2 */
	NUMBER VMAXDX;       /* N.S. Maximum Disability deduction/amount */
	NUMBER VODISTC;      /* N.S. Maximum infirm dependent 18 or older tax credit */
	NUMBER VEDXPM;       /* N.S. Education Amount per month of full-time studies */
	NUMBER VEDXPMPT;     /* N.S. Education Amount per month of part-time studies */
	NUMBER VMAXET;       /* N.S. maximum on transfer of education and tuition amount */
	NUMBER VYCTCAPM;     /* N.S. Young Child Tax Credit Amount per Month */
	NUMBER VYCTCPI;      /* N.S. Young Child Tax Credit Phase in */
	NUMBER VPTX[VPTXMAX][LKP_COLS]; /* N.S. tax table [taxable income,basic provincial tax] */
    NUMBER VCGTC;        /* N.S. Caregiver Tax Credit */
	int    VCGTCFLG;     /* N.S. Caregiver Tax Credit activation flag */
	int    VCGTCOPT;     /* N.S. Caregiver Tax Credit Option (1=max, 2=greenbook) */
	NUMBER VDTCR;        /* N.S. dividend tax credit rate */
	NUMBER VDTCRLC;      /* N.S. dividend tax credit rate from large (eligible) corporations */
	int    VAMTOPT;      /* N.S. alternative minimum tax option  */
	NUMBER VAMTTX;       /* N.S. amt rate as tax on adjusted income */
	NUMBER VAMTPCTF;     /* N.S. amt rate as pct of additional fed tax due to minimum tax */
	NUMBER VAMTPCTM;     /* N.S. amt rate as pct of federal minimum tax amount */

	/*                    New Brunswick */

	NUMBER BPTF;         /* New Brunswick provincial tax fraction */
	NUMBER BSCI;         /* New Brunswick provincial tax above which surtax applies */
	NUMBER BSF;          /* New Brunswick provincial surtax rate */
	NUMBER BPTC[BPTCMAX][LKP_COLS]; /* New Brunsw. political contribution table [total donations,donation allowed] */
    NUMBER BPTCBEN;      /* Maximum New Brunswick political tax credit allowed */
	NUMBER BLVCMAX;      /* Maximum N.B. labour-sponsored funds tax credit allowed */ 
	NUMBER BLVCRT; 		 /* Percent of N.B. labour-sponsored funds cost allowed as credit */
 	NUMBER BTRBAS; 	     /* Base N.B. low income tax reduction */
	NUMBER BTRSP; 	     /* N.B. low income tax reduction for spouse or equivalent-to-spouse */
	NUMBER BTRTD; 	     /* N.B. low income tax reduction Turndown */
	NUMBER BTRRR; 	     /* N.B. low income tax reduction Reduction Rate */
    /* tax on taxable income parameters */
	int    BTXFLG;       /* N.B. tax on taxable income activation flag */
	NUMBER BMXM;         /* N.B. married amount */
	NUMBER BMXMT;        /* N.B. married amount turndown level */
	NUMBER BEMXM;        /* N.B. equivalent to married amount */
	NUMBER BEMXMT;       /* N.B. equivalent to married turndown level */
	NUMBER BPNTCR;       /* N.B. provincial non-refundable tax credit rate */
	NUMBER BBXM;         /* N.B. Basic Personal Exemption/amount */
	NUMBER BAXM;         /* N.B. Age Amount */
	NUMBER BAXTD;        /* N.B. Age Amount net income turndown */
	NUMBER BAXRR;        /* N.B. Age Amount credit reduction rate */
	NUMBER BYPNDL;       /* N.B. Pension Income Deduction Amount */
	NUMBER BMEDANF;      /* N.B. Medical allowance lower limit net income fraction */
	NUMBER BMEDALL;      /* N.B. Medical allowance maximum lower limit */
	NUMBER BCHATL1;      /* N.B. Charitable Donations amount level 1 */
	NUMBER BCHATR1;      /* N.B. Charitable Donations tax credit rate 1 */
	NUMBER BCHATR2;      /* N.B. Charitable Donations tax credit rate 2 */
	NUMBER BMAXDX;       /* N.B. Maximum Disability deduction/amount */
	NUMBER BODISTC;      /* N.B. Maximum infirm dependent 18 or older tax credit */
	NUMBER BEDXPM;       /* N.B. Education Amount per month of full-time studies */
	NUMBER BEDXPMPT;     /* N.B. Education Amount per month of part-time studies */
	NUMBER BMAXET;       /* N.B. maximum on transfer of education and tuition amount */
	NUMBER BPTX[BPTXMAX][LKP_COLS]; /* N.B. tax table [taxable income,basic provincial tax] */
    NUMBER BCGTC;        /* N.B. Caregiver Tax Credit */
	int    BCGTCFLG;     /* N.B. Caregiver Tax Credit activation flag */
	int    BCGTCOPT;     /* N.B. Caregiver Tax Credit Option (1=max, 2=greenbook) */
	NUMBER BDTCR;        /* N.B. dividend tax credit rate */
	NUMBER BDTCRLC;      /* N.B. dividend tax credit rate from large (eligible) corporations */
	int    BAMTOPT;      /* N.B. alternative minimum tax option  */
	NUMBER BAMTTX;       /* N.B. amt rate as tax on adjusted income */
	NUMBER BAMTPCTF;     /* N.B. amt rate as pct of additional fed tax due to minimum tax */
	NUMBER BAMTPCTM;     /* N.B. amt rate as pct of federal minimum tax amount */

	/*                    Quebec */

	int    QSPLTPNSFLAG; /* Quebec flag to split pension income */ 
	NUMBER QPENSPLTINCR;  /* Quebec increment by which to split pension income */
	int    QCRDFLG;      /* Quebec income credit flag [1=if social contribution are deducted] */
	NUMBER QNTCR;        /* Quebec nominal tax credit rate */
	NUMBER QCAPGIR;      /* Quebec capital gains inclusion rate */
	NUMBER QDGUR;        /* Quebec dividend gross-up rate */
	NUMBER QDGURLC;      /* Quebec dividend gross-up rate from large (eligible) corporations */
	NUMBER QALEXP;       /* Quebec proportion of other allowable employment expenses to use */
	NUMBER QEAMAX;       /* Quebec maximum employment allowance deduction */
	int    QFAIFLAG;     /* Quebec inclusion of federal family allowance in income flag */
	int    QSPBFLAG;     /* Quebec inclusion of social program benefits in income flag */
	int    QNORFAMI;	 /* Quebec Northern Deductions from Family Tax Credit Income flag */
	int    QTRSAFAM;	 /* Quebec Social Assistance Included in Family Tax Credit Income flag */
	int    QTRWCFAM;	 /* Quebec Workers Compensation Included in Family Tax Credit Income flag */
	int    QREPFAMI;     /* Quebec repayment of UI/OAS benefits deduct from income flag */
	NUMBER QEAP;         /* Proportion of earnings for Quebec employment allowance deduction */
	NUMBER QFAMDED;      /* Quebec Family related deduction on income in refundable credits */
	int QREPNETFG;       /* Social program repayments reduce Quebec net income flag */
	int    QSADED;       /* Quebec deduction of social assistance benefits from net income flag */
	int    QNFSDED;      /* Quebec deduction of net federal supplements (SPA and GIS) from net income flag */
	int QCPPOPT;         /* Quebec CPP/QPP contribution deduction/credit option [1=deduction,2=credit] */
	int QUICOPT;         /* Quebec UI contributions deduction/credit option [1=deduction,2=credit] */
	NUMBER QCCEAYNG;     /* Quebec CCEA young child limit */
	NUMBER QCCEAOLD;     /* Quebec CCEA old child limit */
	NUMBER QCCETCR[QCCETCRMAX][LKP_COLS]; /* Refundable CCE credit rate [net income, % cce claimable] */
	int    QCCEEIFLG;     /* Quebec Refundable CCE EI Benefits in Earned Income flag */
	int    QCCEEITST;     /* Quebec Refundable CCE Earned Income Test flag */
	int    QCCEOPT;      /* Quebec CCE calculation option [1=deduction,2=refundable credit] */
	int    QHSCFLAG;     /* Quebec Health Services Fund Contribution calculation flag */
	NUMBER QHSC[QHSCMAX][LKP_COLS]; /* Quebec Health Services Fund Contribution table */
	int    QHSOASFG;	 /* Quebec Health Services Fund Contribution OAS Deduction flag */
	int    QHSSFLSS;	 /* Quebec Health Services Fund Contrib. Allowable Losses Deduction flag */
	int    QHSSFALM;	 /* Quebec Health Services Fund Contrib. Alimony Paid Deduction flag */
	int    QHSSFUIR;	 /* Quebec Health Services Fund Contrib. UI/EI Repayment Deduction flag */
	int    QHSSFCAR;	 /* Quebec Health Services Fund Contrib. Carrying Charges Deduction flag */
	NUMBER QBXM;         /* Quebec basic personal exemption/amount */
	NUMBER QAXM;         /* Quebec age exemption/amount */
	NUMBER QAXRR;        /* Quebec age exemption reduction rate */
	NUMBER QAXTD;        /* Quebec age exemption income turn down */
	NUMBER QAXPI;        /* Quebec age exemption reduction phase in */
	NUMBER QMXM;         /* Quebec married exemption/amount */
	NUMBER QLAXM;        /* Quebec living alone exemption/amount */
	NUMBER QLAXRR;       /* Quebec living alone reduction rate */
	NUMBER QLAXTD;       /* Quebec living alone turn down */
	NUMBER QLAXPI;       /* Quebec living alone phase-in */
	NUMBER QLAXOLDDEP;   /* Quebec living alone amount if all dependents 18 or over */
	NUMBER QPSXM;        /* Quebec post-secondary exemption/amount */
	NUMBER QPSXMINC;     /* Quebec income ratio for post-secondary exemption/amount */
	NUMBER QLPXM;        /* Quebec lone parent exemption/amount */
	NUMBER QYCXM1;       /* Quebec dependent child #1 amount */
	NUMBER QYCXM2;       /* Quebec dependent child #2 amount */
	NUMBER QODISTC;      /* Quebec infirm dependent amount (18 and over) */
	NUMBER QYPDL;        /* Quebec deduction limit for pension income */
	NUMBER QYPRR;        /* Quebec deduction reduction rate for pension income */
	NUMBER QYPTD;        /* Quebec deduction turn down for pension income */
	NUMBER QYPPI;        /* Quebec deduction phase-in for pension income */
	NUMBER QCHATNF;      /* Quebec charitable donations maximum % net income */
	int    QGIFTFLG;	 /* Quebec max to gifts to Federal/Province/Crown activation flag */ 
	int    QGIFTOPT;	 /* Quebec gifts as tax credit */ 
	NUMBER QMAXDX;       /* Quebec maximum disability deduction/amount */
	NUMBER QEMPDEDP;     /* Quebec earned income deduction percent of income */
	NUMBER QEMPDEDM;     /* Quebec earned income deduction for workers maximum */
	NUMBER QTX[QTXMAX][LKP_COLS]; /* Quebec income tax table [taxable income,basic provincial tax] */
	int    QTROPT;       /* Quebec Tax Reduction calculation option 1=universal 2=income tested */
	NUMBER QTRP;         /* Quebec tax Reduction proportion */
	NUMBER QTRBE;		 /* Quebec Tax Reduction Breakeven */
	NUMBER QDTCR;        /* Quebec dividend tax credit rate */
	NUMBER QDTCRLC;      /* Quebec dividend tax credit rate from large (eligible) corporations */
	int    QFTRFLAG;     /* Quebec family tax reduction activation flag */
	NUMBER QEIA1;        /* Quebec eligible income family type #1 */
	NUMBER QEIA2;        /* Quebec eligible income family type #2 */
	NUMBER QEIA3;        /* Quebec eligible income family type #3 */
	NUMBER QEIA4;        /* Quebec eligible income family type #4 */
	NUMBER QEIA5;        /* Quebec eligible income family type #5 */
	NUMBER QEIAA;        /* Quebec eligible income aged amount */
	NUMBER QESSNEEDS;    /* Quebec essential needs for transfer of parental contributions */
	NUMBER QFTRA1;       /* Quebec family tax reduction family type #1 */
	NUMBER QFTRA2;       /* Quebec family tax reduction family type #2 */
	NUMBER QFTRA3;       /* Quebec family tax reduction family type #3 */
	NUMBER QFTRA4;       /* Quebec family tax reduction family type #4 */
	NUMBER QFTRRR;       /* Quebec family tax reduction reduction rate */
	int    QRTRFLAG;     /* Quebec real estate rebate activation flag  */
	NUMBER QPTRMTP;      /* Quebec property tax minimum tax per person */
	NUMBER QPTRMTR;      /* Quebec property tax maximum tax for reduction */
	NUMBER QPTRTF;       /* Quebec property tax fraction */
	NUMBER QPTRRR;       /* Quebec property tax rebate reduction rate */
	NUMBER QPTRGISB;     /* Quebec property tax rebate GIS bonus */
	NUMBER QSTRRR;       /* Quebec sales tax rebate reduction rate */
	int    QSTRMAGE;     /* Quebec sales tax rebate minimum age flag  */
	NUMBER QSTRFTP3;     /* Quebec sales tax rebate family type 3 credit */
	NUMBER QSTRFTP4;     /* Quebec sales tax rebate family type 4 credit */
	NUMBER QSTRCHILD;    /* Quebec sales tax rebate children dependent credit */
	NUMBER QSTRBCRD;     /* Quebec sales tax rebate base credit */
	NUMBER QSTREXT;       /* Quebec sales tax rebate extra amount */
	int    QSTRFLAG;     /* Quebec sales tax rebate activation flag */
	NUMBER QPTC;         /* Quebec political contribution table [total donations,donation allowed] */
	NUMBER QPTCBEN;      /* Maximum Quebec political tax credit allowed */
	NUMBER QMEDANF;      /* Quebec medical allowance lower limit net income fraction */
	NUMBER QMEDALL;      /* Quebec medical allowance maximum lower limit */
	NUMBER QHSCI;        /* Quebec surtax first cut-in level */
	NUMBER QHSCI2;       /* Quebec surtax second cut-in level */
	NUMBER QHSF;         /* Quebec surtax first level rate */
	NUMBER QHSF2;        /* Quebec surtax second level rate */
    NUMBER QHPTC;        /* Quebec Housing Parent Tax Credit */
	int    QHPTCFLG;     /* Quebec Housing Parent Tax Credit activation flag */
	int    QHPTCOPT;     /* Quebec Housing Parent Tax Credit Calculation option */
    int    QMEDOPT;      /* Quebec Medical Tax Credit option      */
    int    QDUESOPT;    /* Quebec Dues Tax Credit option      */
    int    QFATCOPT;    /* Quebec Family Allowance Tax Credit Option  */
    NUMBER QFATCSUP;     /* Quebec Family Allowance Tax Credit Supplement for single parent */
	NUMBER QFATCMIN;     /* QFATC minimum benefit paid */
	NUMBER QFATCK6[QFATCK6RMAX][QFATCK6CMAX];   /* QFATC Supplement for kids under 6 in large families [#kids][#kids<6]*/
	NUMBER QFATCTK[QFATCTKMAX][LKP_COLS];   /* QFATC Take-up rates by total income */
	NUMBER QFATCMXK[QFATCMXKMAX][LKP_COLS]; /* QFATC Maximum benefits by kid rank */
	NUMBER QFATCMNK[QFATCMNKMAX][LKP_COLS]; /* QFATC Minimum benefits by kid rank */
	NUMBER QFATCSRR[QFATCSRRMAX][LKP_COLS]; /* QFATC turn down income levels and reduction rate for single parent*/
	NUMBER QFATCMRR[QFATCMRRMAX][LKP_COLS]; /* QFATC turn down income levels and reduction rate for married parents*/
	NUMBER QFATD4K;     /* QFATC turn down income for 4 children and more */
	NUMBER QFATD4KI;    /* QFATC turn down income increase by child for 4 children and more */
	NUMBER QFATCHIRR;     /* QFATC High income reduction rate */
	NUMBER QFATCHITD;     /* QFATC High income turndown */
	int QFATCK6YR;     /* QFATC Supplement for kids under 6 phase out year */
	NUMBER    QFATCK6PYR;                       /* QFATC supplement for kids under 6 phase out year proportion */
	int    QTUIOPT;                       /* Quebec tuition tax credit option */
	int    QTUITRFFLG;                     /* Quebec flag to allow transfer of tuition tax credit to parents */
	int    QAMTXFLG;                       /* Quebec alternative minimum tax, QAMTX, activation flag */
	NUMBER QAMTXREF;                       /* Quebec alternative minimum tax 1995 reform indicator (flag) */
    NUMBER QCAPAMTX;                       /* QAMTX taxable capital ratio */
	NUMBER QAMTX;                          /* QAMTX exemption level */
	NUMBER QAMTTX;                         /* QAMTX tax rate */
	int    QAMTXSTKFLG;                    /* QAMTX stock option deduction inclusion (1=stk can be deducted) */
	int    QAMTNEGTI;                      /* Quebec Alternative Minimum Tax Allow Negative Taxable Income */
	int    QAMTCBX;                        /* Quebec Alternative Minimum Tax Calculate Basic Exemption */
	int    QAMTRPFLG;                      /* RRSP/RPP included in Quebec Alternative Minimum Tax (1=include) */
	int    QAMTRITC;                       /* Quebec Alternative Minimum Tax Retirement Income Credit Deduction */
	NUMBER QAMTDIV;                        /* Quebec Alternative Minimum Tax Taxable Dividend Limit */
	NUMBER QAMTCAPR;                       /* Quebec Alternative Minimum Tax Capital inclusion rate */
	int    QAMTSTTC;                       /* Quebec Alternative Minimum Tax Spouse Transfer of Tax Credits Flag */
	NUMBER QPCTR[QPCTRMAX][LKP_COLS];      /* Quebec political contribution tax rates */
	int    QPCOPT;                         /* Quebec political contribution option */
    int    QSFOPT;                         /* Quebec Simplified Form Option (1=general 2=simplified 3=optimized)*/
	NUMBER QSFTC;                          /* Quebec Simplified Form tax credit */
    int    QSFDISFLAG;                     /* Quebec Simplified Form Disability tax credit inclusion flag */
    int    QFAMFLG;                        /* Quebec family income deduction activation flag*/
	NUMBER QFAMRAT;                        /* Quebec family income rate */
    int    QAPFFLG;                        /* Quebec anti-poverty fund activation flag*/
	NUMBER QAPFRAT;                        /* Quebec anti-poverty fund rate */
	NUMBER QLVCMAX;                        /* Maximum Quebec labour-sponsored funds tax credit allowed */ 
	NUMBER QLVCRT; 		                   /* Percent of Quebec labour-sponsored funds cost allowed as credit */
    int    QCALRFLG;                       /* Quebec combined age, living alone retirement credit*/
	int    QMRTCFLG;                       /* Quebec refundable tax credits for medical expenses activation flag */
	NUMBER QMEDRMIN; 					   /* Minimum earnings for Quebec refundable tax credit for medical expenses */
	NUMBER QMEDRATE;                       /* Proportion of expenses allowed for refundable tax credit for medical expenses */
	NUMBER QMEDRMAX;                       /* Maximum expenses allowed for Que. refundable tax credit for medical expenses */
	NUMBER QMEDRTD;                        /* Turndown level for Que. refundable tax credit for medical expenses */
	NUMBER QMEDRRR;                        /* Reduction rate for the Que. refundable tax credit for medical expenses */
	int    QMEDINC;                        /* Income definition for Que. refundable tax credit for medical expenses */	
	int    QEEXPDED;                       /* Quebec employment expenses deduction application flag */
	int    QGIFTHCR;                       /* Quebec higher tax credit on large gifts activation flag */
	NUMBER QGIFTL1;                        /* Quebec minimum gift limit subject to higher credit rate */
	NUMBER QGFTCR;                         /* Quebec credit rate for gifts over upper limit */
	NUMBER QSFSMXI;                        /* Quebec simplified form spouse maximum income for work sheet */
	int    QITSFSEW;                       /* Quebec improved tax system for self-employed worker activation flag */
	NUMBER QITSSEF;                        /* Quebec percentage of self-employ CPP/QPP contributions to convert to deduction */
	int    QFAMNETI;                       /* Quebec family allowance tax credit net income concept flag */
	int    QSFDED;                         /* Quebec Simplified Form - additional deductions for net income calculation flag */
	int    QSFTXCR;                        /* Quebec Simplified Form - transfer unused credits to spouse under either tax system */
	int    QSFMEDFLAG;                     /* Quebec Simplified Form medical expense tax credit inclusion flag */
	int    QNORTHDED;                      /* Quebec northern deductions - 0=for taxable income, 1=for net income */
	int    QINTSLTC;                       /* Quebec student loan interest tax credit flag */
	NUMBER QSTSCA;                         /* Quebec Single Tax System Complementary Amount */
	int    QCAFLAG;                        /* Quebec Child Assistance refundable tax credit flag */
	NUMBER QCAMAX[QCAMAXMAX];              /* Quebec Child Assistance Maximum [number of children] */
	NUMBER QCAMIN[QCAMINMAX];              /* Quebec Child Assistance Minimum [number of children] */
	NUMBER QCATDC;                         /* Quebec Child Assistance Income Turndown for couples */
	NUMBER QCATDS;                         /* Quebec Child Assistance Income Turndown for single parents */
	NUMBER QCASPMAX;                       /* Quebec Child Assistance Maximum Single Parent additional credit */
	NUMBER QCASPMIN;                       /* Quebec Child Assistance Minimum Single Parent additional credit */
	NUMBER QCARR;                          /* Quebec Child Assistance Reduction Rate */
	NUMBER QDTCNCA1;                       /* Quebec Dependent Tax Credit Amount for first dependent without child assistance */
	NUMBER QDTCNCA2;                       /* Quebec Dependent Tax Credit Amount for other dependents without child assistance */
	NUMBER QDTCSPA;                        /* Quebec Dependent Tax Credit Single Parent Amount (no child assistance) */
	int    QWPFLAG;                        /* Quebec Work Premium refundable tax credit flag */
	NUMBER QWPEIPI[QWPEIPIMAX];            /* Quebec Work Premium Employment Income Phase In [family type] */ 
	NUMBER QWPMAX[QWPMAXMAX];              /* Quebec Work Premium Maximum [family type] */
	NUMBER QWPTD[QWPTDMAX];                /* Quebec Work Premium Income Turndown [family type] */
	NUMBER QWPCR[QWPCRMAX];                /* Quebec Work Premium Credit Rate [family type] */
	NUMBER QWPRR;                          /* Quebec Work Premium Reduction Rate */
    NUMBER QRNCGTC;                        /* Quebec Natural Caregivers Tax Credit */
	int    QRNCGFLG;                       /* Quebec Natural Caregivers Tax Credit activation flag */
	int    QTPCFLG;                        /* Quebec transfer of recognized parental contribution to education activation flag */
	int    QCMPOPT;                        /* Quebec Complementary Credit option */

   	/*                    Ontario */

	NUMBER OPTF;         /* Ontario provincial tax fraction */
	NUMBER OTRBPA;       /* Ontario tax reduction basic personal amount */
	NUMBER OTRDCA;       /* Ontario tax reduction dependant child amount */
	NUMBER OTRDDA;       /* Ontario tax reduction disabled dependant amount */
	NUMBER OTRFP;        /* Ontario tax reduction personal amount multiplier */
	NUMBER OTRF;         /* Ontario tax reduction Ontario tax multiplier */
	int    OFTCOPT;      /* Ontario foreign tax credit application option */
	NUMBER OSSML;        /* Ontario surtax first cut-in level */
	NUMBER OSSML2;       /* Ontario surtax second cut-in level */
	NUMBER OSSMR;        /* Ontario surtax first level rate */
	NUMBER OSSMR2;       /* Ontario surtax second level rate */
	int    OPTCFLAG;     /*	Ontario political contribution refundable tax credit flag */
	NUMBER OPTC[OPTCMAX][LKP_COLS]; /* Ontario political contribution table [total donations,donation allowed] */
    NUMBER OPTCBEN;      /* Maximum Ontario political tax credit allowed */
	NUMBER OTCNIBA;      /*	Ontario tax credit net income base amount */
	NUMBER OSTCNIBA;     /*	Ontario seniors tax credit net income base amount */
	NUMBER OSTCNIBC;     /*	Ontario seniors tax credit net income base amount for couples */
	int    OSTCFLAG;     /*	Ontario seniors tax credit claimed flag */
	NUMBER OPRIR;        /* Ontario property tax credit rental inclusion rate */
	NUMBER OPCRA;        /* Ontario property tax college residence amount */
	NUMBER OPOCM;        /* Ontario property tax maximum occupancy cost */
	NUMBER OSPOCM;       /* Ontario seniors property tax maximum occupancy cost */
	NUMBER OPOCAR;       /* Ontario property tax percent of occupancy cost */
	NUMBER OSTCB;        /* Ontario sales tax credit basic credit */
	NUMBER OSTCS;        /* Ontario sales tax credit spouse credit */
	NUMBER OSTCD;        /* Ontario sales tax credit dependant credit */
	NUMBER OSTCP;        /* Ontario sales tax credit percent of income */
	NUMBER OSSTCP;       /* Ontario seniors sales tax credit percent of income */
	NUMBER OPSMAX;       /* Ontario property/sales tax credit maximum */
	NUMBER OSPSMAX;      /* Ontario seniors property/sales tax credit maximum */
	int    OEHTFLAG;     /* OEHT - Ontario Employer Health Tax Flag */
	NUMBER OEHTEX;       /* OEHT - Exemption */
	NUMBER OEHTTD1;      /* OEHT - Turndown 1 */
	NUMBER OEHTTD2;      /* OEHT - Turndown 2 */
	NUMBER OEHTRR1;      /* OEHT - Rate 1 */
	NUMBER OEHTRR2;      /* OEHT - Rate 2 */
	NUMBER OEHTRR3;      /* OEHT - Rate 3 */
	NUMBER OEHTDRR;      /* OEHT - Income Tax Deduction Rate */
	NUMBER OLVCMAX;      /* Maximum Ont. labour-sponsored funds tax credit allowed */ 
	NUMBER OLVCRT; 		 /* Percent of Ont. labour-sponsored funds cost allowed as credit */
	NUMBER OPYTAX; 		 /* Estimate of previous year's Ontario taxes */
	NUMBER OTXDVMIN;     /* Minimum taxpayer dividend for people with non-zero taxes */
	NUMBER OTXDVMAX; 	 /* Maximum taxpayer dividend */
	int    OHPFLAG;      /* Ontario Health Premium activation flag */
	NUMBER OHPBASE[OHPBASEMAX][LKP_COLS]; /* Ontario Health Premium table [taxable income,premium] */
	NUMBER OHPPI;        /* Ontario Health Premium program phase in  */
    /* tax on taxable income parameters */
	int    OTXFLG;       /* Ont. tax on taxable income activation flag */
	NUMBER OMXM;         /* Ont. married amount */
	NUMBER OMXMT;        /* Ont. married amount turndown level */
	NUMBER OEMXM;        /* Ont. equivalent to married amount */
	NUMBER OEMXMT;       /* Ont. equivalent to married turndown level */
	NUMBER OPNTCR;       /* Ont. provincial non-refundable tax credit rate */
	NUMBER OBXM;         /* Ont. Basic Personal Exemption/amount */
	NUMBER OAXM;         /* Ont. Age Amount */
	NUMBER OAXTD;        /* Ont. Age Amount net income turndown */
	NUMBER OAXRR;        /* Ont. Age Amount credit reduction rate */
	NUMBER OYPNDL;       /* Ont. Pension Income Deduction Amount */
	NUMBER OMEDANF;      /* Ont. Medical allowance lower limit net income fraction */
	NUMBER OMEDALL;      /* Ont. Medical allowance maximum lower limit */
	NUMBER OCHATL1;      /* Ont. Charitable Donations amount level 1 */
	NUMBER OCHATR1;      /* Ont. Charitable Donations tax credit rate 1 */
	NUMBER OCHATR2;      /* Ont. Charitable Donations tax credit rate 2 */
	NUMBER OMAXDX;       /* Ont. Maximum Disability deduction/amount */
	NUMBER OODISTC;      /* Ont. Maximum infirm dependent 18 or older tax credit */
	NUMBER OEDXPM;       /* Ont. Education Amount per month of full-time studies */
	NUMBER OEDXPMPT;     /* Ont. Education Amount per month of part-time studies */
	NUMBER OMAXET;       /* Ont. maximum on transfer of education and tuition amount */
	NUMBER OPTX[OPTXMAX][LKP_COLS]; /* Ont. tax table [taxable income,basic provincial tax] */
    NUMBER OCGTC;        /* Ont. Caregiver Tax Credit */
	int    OCGTCFLG;     /* Ont. Caregiver Tax Credit activation flag */
	int    OCGTCOPT;     /* Ont. Caregiver Tax Credit Option (1=max, 2=greenbook) */
	NUMBER ODTCR;        /* Ont. dividend tax credit rate */
	NUMBER ODTCRLC;      /* Ont. dividend tax credit rate from large (eligible) corporations */
	int    OAMTOPT;      /* Ont. alternative minimum tax option  */
	NUMBER OAMTTX;       /* Ont. amt rate as tax on adjusted income */
	NUMBER OAMTPCTF;     /* Ont. amt rate as pct of additional fed tax due to minimum tax */
	NUMBER OAMTPCTM;     /* Ont. amt rate as pct of federal minimum tax amount */
	int    OCGIRFLG;     /* Ont. Capital Gains Inclusion Rate Activation Flag */
	NUMBER OCAPGIR;      /* Ont. Capital Gains Inclusion Rate */

	/*                    Manitoba */

	NUMBER MPTF;         /* Manitoba provincial tax fraction */
	NUMBER MNITR;        /* Manitoba net income tax rate */
	/* 1988 and after Manitoba Tax Reduction/Surtax  */
	NUMBER MRBXM;          /* Manitoba tax reduction basic credit */
	NUMBER MRMXM;          /* Manitoba tax reduction married credit */
	NUMBER MREMXM;         /* Manitoba tax reduction married equivalent credit */
	NUMBER MRAXM;          /* Manitoba tax reduction age credit */
	NUMBER MRSAXM;         /* Manitoba tax reduction spouse age credit */
	NUMBER MRDISEX;        /* Manitoba tax reduction disability credit */
	NUMBER MRODISEX;       /* Manitoba tax reduction old disabled dependant credit */
	NUMBER MRYCXM;         /* Manitoba tax reduction young dependants credit */
	NUMBER MTRNIOS;        /* Manitoba tax reduction net income offset */
	NUMBER MSBXM;          /* Manitoba surtax basic credit */
	NUMBER MSMXM;          /* Manitoba surtax married credit */
	NUMBER MSEMXM;         /* Manitoba surtax married equivalent credit */
	NUMBER MSAXM;          /* Manitoba surtax age credit */
	NUMBER MSSAXM;         /* Manitoba surtax spouse age credit */
	NUMBER MSDISEX;        /* Manitoba surtax disability credit */
	NUMBER MSODISEX;       /* Manitoba surtax old disabled dependant credit */
	NUMBER MSYCXM;         /* Manitoba surtax young dependants credit */

	/* Manitoba Cost of living Tax Credit */
	NUMBER MCBXM;          /* Manitoba cost-of-living basic credit */
	NUMBER MCMXM;          /* Manitoba cost-of-living married credit */
	NUMBER MCEMXM;         /* Manitoba cost-of-living married equivalent credit */
	NUMBER MCAXM;          /* Manitoba cost-of-living age credit */
	NUMBER MCSAXM;         /* Manitoba cost-of-living spouse age credit */
	NUMBER MCDISEX;        /* Manitoba cost-of-living disability credit */
	NUMBER MCSDISEX;       /* Manitoba cost-of-living spouse disabled credit */
	NUMBER MCODISEX;       /* Manitoba cost-of-living old disabled dependant credit */
	NUMBER MCYCXM;         /* Manitoba cost-of-living young dependants credit */
	NUMBER MCFINCRR;       /* Manitoba cost-of-living family income reduction rate */
	NUMBER MCMINAGE;       /* Manitoba cost-of-living tax credit minimum age */

	/* Manitoba Property Tax Credit */
	NUMBER MPRIR;          /* Manitoba property tax credit rental inclusion rate */
	NUMBER MPBXM;          /* Manitoba property tax credit basic credit */
	NUMBER MPAXM;          /* Manitoba property tax credit senior citizen credit */
	NUMBER MPFINCRR;       /* Manitoba property tax credit family income reduction rate */
	NUMBER MPMINC;         /* Manitoba property tax credit minimum credit */
	NUMBER MPMNTH;         /* Manitoba property tax minimum threshold */
	int MHMASOPT;          /* Manitoba homeowner assistance option (1=Model 2=database) */
	int MSCHFLAG;          /* Manitoba school tax assistance activation flag */
	NUMBER MSCHAGE;        /* Manitoba school tax minimum age */
	NUMBER MSCHMNTH;       /* Manitoba school tax minimum threshold */
	NUMBER MSCHTD;         /* Manitoba school tax turndown */
	NUMBER MSCHRND;        /* Manitoba school tax assistance rounding unit */
	NUMBER MSCHBXM;        /* Manitoba school tax basic amount */
	NUMBER MSCHRR;         /* Manitoba school tax reduction rate */

	/* Manitoba Political Contribution Tax Credit */
	NUMBER MPTC[MPTCMAX][LKP_COLS]; /* Manitoba political contribution table [total donations,donation allowed] */
   NUMBER MPTCBEN;        /* Maximum Manitoba political tax credit allowed */

   /* Manitoba Learning tax credit */
   NUMBER MANLTCF;        /* Manitoba learning tax credit factor */
   NUMBER MANLTMAX;       /* Manitoba learning tax credit maximum amount per student */

   /* Manitoba Labour sponsored funds tax credit */
	NUMBER MLVCMAX;        /* Maximum Man. labour-sponsored funds tax credit allowed */ 
	NUMBER MLVCRT; 		   /* Percent of Man. labour-sponsored funds cost allowed as credit */

    /* tax on taxable income parameters */
	int    MTXFLG;       /* Man. tax on taxable income activation flag */
	NUMBER MMXM;         /* Man. married amount */
	NUMBER MMXMT;        /* Man. married amount turndown level */
	NUMBER MEMXM;        /* Man. equivalent to married amount */
	NUMBER MEMXMT;       /* Man. equivalent to married turndown level */
	NUMBER MPNTCR;       /* Man. provincial non-refundable tax credit rate */
	NUMBER MBXM;         /* Man. Basic Personal Exemption/amount */
	NUMBER MAXM;         /* Man. Age Amount */
	NUMBER MAXTD;        /* Man. Age Amount net income turndown */
	NUMBER MAXRR;        /* Man. Age Amount credit reduction rate */
	NUMBER MYPNDL;       /* Man. Pension Income Deduction Amount */
	NUMBER MMEDANF;      /* Man. Medical allowance lower limit net income fraction */
	NUMBER MMEDALL;      /* Man. Medical allowance maximum lower limit */
	NUMBER MCHATL1;      /* Man. Charitable Donations amount level 1 */
	NUMBER MCHATR1;      /* Man. Charitable Donations tax credit rate 1 */
	NUMBER MCHATR2;      /* Man. Charitable Donations tax credit rate 2 */
	NUMBER MMAXDX;       /* Man. Maximum Disability deduction/amount */
	NUMBER MODISTC;      /* Man. Maximum infirm dependent 18 or older tax credit */
	NUMBER MEDXPM;       /* Man. Education Amount per month of full-time studies */
	NUMBER MEDXPMPT;     /* Man. Education Amount per month of part-time studies */
	NUMBER MMAXET;       /* Man. maximum on transfer of education and tuition amount */
	NUMBER MPTX[MPTXMAX][LKP_COLS]; /* Man. tax table [taxable income,basic provincial tax] */
    NUMBER MCGTC;        /* Man. Caregiver Tax Credit */
	int    MCGTCFLG;     /* Man. Caregiver Tax Credit activation flag */
	int    MCGTCOPT;     /* Man. Caregiver Tax Credit Option (1=max, 2=greenbook) */
	NUMBER MDTCR;        /* Man. dividend tax credit rate */
	NUMBER MDTCRLC;      /* Man. dividend tax credit rate from large (eligible) corporations */
	int    MAMTOPT;      /* Man. alternative minimum tax option  */
	NUMBER MAMTTX;       /* Man. amt rate as tax on adjusted income */
	NUMBER MAMTPCTF;     /* Man. amt rate as pct of additional fed tax due to minimum tax */
	NUMBER MAMTPCTM;     /* Man. amt rate as pct of federal minimum tax amount */
	int MAMTFTCFLG;   /* Man. amt flag for provincial foreign tax credit  */

	/*                    Saskatchewan */

    NUMBER SDSRA;        /* Saskatchewan deficit surtax reduction rate */
	NUMBER SPTF;         /* Saskatchewan provincial tax fraction */
	NUMBER SFTAX;        /* Saskatchewan provincial flat surtax rate on net income */
	NUMBER SDSF;         /* Saskatchewan provincial deficit surtax fraction */
	NUMBER SSF;          /* Saskatchewan provincial high income surtax fraction */
	NUMBER SSCI;         /* Saskatchewan surtax cut-in */
	NUMBER STRBR;        /* Saskatchewan basic provincial tax reduction */
	NUMBER SSTR;         /* Saskatchewan spousal & married equivalent tax reduction */
	NUMBER STRCL;        /* Saskatchewan child tax reduction limit */
	NUMBER STRPC;        /* Saskatchewan tax reduction per child */
	NUMBER STRSC;        /* Saskatchewan tax reduction for senior citizens */
	NUMBER STRRR;        /* Saskatchewan tax reduction reduction rate */
	NUMBER STRBA;        /* Saskatchewan tax reduction base amount */
	NUMBER SPTC[SPTCMAX][LKP_COLS]; /* Saskatchewan political contribution table [total donations,donation allowed] */
    NUMBER SPTCBEN;       /* Maximum Saskatchewan political tax credit allowed */
	NUMBER SLVCMAX;      /* Maximum Sask. labour-sponsored funds tax credit allowed */ 
	NUMBER SLVCRT; 		 /* Percent of Sask. labour-sponsored funds cost allowed as credit */
	int    SSTCFLAG;     /* Sask. sales tax credit activation flag */
	NUMBER SSTCBAS; 	 /* Sask. sales tax credit base amount */
	NUMBER SSTCBASTD; 	 /* Sask. sales tax credit base amount turndown */
	NUMBER SSTCSP; 	     /* Sask. sales tax credit spousal amount */
	NUMBER SSTCSPTD; 	 /* Sask. sales tax credit spousal amount turndown */
	NUMBER SSTCKID; 	 /* Sask. sales tax credit child amount */
	NUMBER SSTC1KIDTD; 	 /* Sask. sales tax credit child amount turndown if only 1 child */
	NUMBER SSTC2KIDTD; 	 /* Sask. sales tax credit child amount turndown if more than 1 child */
	NUMBER SSTCRR; 	     /* Sask. sales tax credit reduction rate */
	NUMBER SSTCBASPIR; 	 /* Sask. sales tax credit base amount phase in rate */
	NUMBER SSTCPI; 	     /* Sask. sales tax credit phase in  */
	NUMBER SSTCBASP; 	 /* Sask. sales tax credit base amount for 1st half of year */
	NUMBER SSTCBASTDP; 	 /* Sask. sales tax credit base amount turndown for 1st half of year */
	NUMBER SSTCSPP;	     /* Sask. sales tax credit spousal amount for 1st half of year */
	NUMBER SSTCSPTDP; 	 /* Sask. sales tax credit spousal amount turndown for 1st half of year */
	NUMBER SSTCKIDP; 	 /* Sask. sales tax credit child amount for 1st half of year*/
	NUMBER SSTC1KIDTDP;	 /* Sask. sales tax credit child amount turndown if only 1 child for 1st half of year */
	NUMBER SSTC2KIDTDP;	 /* Sask. sales tax credit child amount turndown if more than 1 child for 1st half of year */
	NUMBER SSTCRRP;	     /* Sask. sales tax credit reduction rate for 1st half of year */
	NUMBER SSTCBASPIRP;	 /* Sask. sales tax credit base amount phase in rate for 1st half of year */
	NUMBER SSTCPI1P;	     /* Sask. sales tax credit phase in for 1st half of year */
	NUMBER SSTCPI2P;	     /* Sask. sales tax credit phase in for 2nd half of year */
    /* tax on taxable income parameters */
	int    STXFLG;       /* Sask. tax on taxable income activation flag */
	NUMBER SMXM;         /* Sask. married amount */
	NUMBER SMXMT;        /* Sask. married amount turndown level */
	NUMBER SEMXM;        /* Sask. equivalent to married amount */
	NUMBER SEMXMT;       /* Sask. equivalent to married turndown level */
	NUMBER SPNTCR;       /* Sask. provincial non-refundable tax credit rate */
	NUMBER SBXM;         /* Sask. Basic Personal Exemption/amount */
	NUMBER SAXM;         /* Sask. Age Amount */
	NUMBER SAXTD;        /* Sask. Age Amount net income turndown */
	NUMBER SAXRR;        /* Sask. Age Amount credit reduction rate */
	NUMBER SYPNDL;       /* Sask. Pension Income Deduction Amount */
	NUMBER SMEDANF;      /* Sask. Medical allowance lower limit net income fraction */
	NUMBER SMEDALL;      /* Sask. Medical allowance maximum lower limit */
	NUMBER SCHATL1;      /* Sask. Charitable Donations amount level 1 */
	NUMBER SCHATR1;      /* Sask. Charitable Donations tax credit rate 1 */
	NUMBER SCHATR2;      /* Sask. Charitable Donations tax credit rate 2 */
	NUMBER SMAXDX;       /* Sask. Maximum Disability deduction/amount */
	NUMBER SODISTC;      /* Sask. Maximum infirm dependent 18 or older tax credit */
	NUMBER SEDXPM;       /* Sask. Education Amount per month of full-time studies */
	NUMBER SEDXPMPT;     /* Sask. Education Amount per month of part-time studies */
	NUMBER SMAXET;       /* Sask. maximum on transfer of education and tuition amount */
	NUMBER SPTX[SPTXMAX][LKP_COLS]; /* Sask. tax table [taxable income,basic provincial tax] */
    NUMBER SCGTC;        /* Sask. Caregiver Tax Credit */
	int    SCGTCFLG;     /* Sask. Caregiver Tax Credit activation flag */
	int    SCGTCOPT;     /* Sask. Caregiver Tax Credit Option (1=max, 2=greenbook) */
	NUMBER SDTCR;        /* Sask. dividend tax credit rate */
	NUMBER SDTCRLC;      /* Sask. dividend tax credit rate from large (eligible) corporations  */
	int    SAMTOPT;      /* Sask. alternative minimum tax option  */
	NUMBER SAMTTX;       /* Sask. amt rate as tax on adjusted income */
	NUMBER SAMTPCTF;     /* Sask. amt rate as pct of additional fed tax due to minimum tax */
	NUMBER SAMTPCTM;     /* Sask. amt rate as pct of federal minimum tax amount */
	NUMBER SCNTC;     /* Sask. non-refundable child tax credit amt per child */
	NUMBER SSSTC;     /* Sask. senior supplement tax credit */


	/*                    Alberta */

	NUMBER APTF;         /* Alberta provincial tax fraction */
	NUMBER ASCI;         /* Alberta surtax cut-in */
	NUMBER ASF;          /* Alberta surtax fraction */
	NUMBER AFTAX;        /* Alberta flat surtax rate on taxable income */
	NUMBER ATRBC;        /* Alberta tax reduction basic claim */
	NUMBER ATRF;         /* Alberta tax reduction fraction */
	NUMBER APTC[APTCMAX][LKP_COLS]; /* Alberta political contribution table [total donations,donation allowed] */
    NUMBER APTCBEN;       /* Maximum Alberta political tax credit allowed */
    int AFETCFLAG;        /* Alberta Family Employment Tax Credit Activation Flag */
    NUMBER AFETCAPC[AFETCAPCMAX];  /* Alberta Family Employment Tax Credit Amount Per Child [number of children] */
    NUMBER AFETCNC;       /* Alberta Family Employment Tax Credit Maximum Number of Children */
    NUMBER AFETCCI;       /* Alberta Family Employment Tax Credit Benefit Cut-in Level */
    NUMBER AFETCBR;       /* Alberta Family Employment Tax Credit Benefit Rate */
    NUMBER AFETCTD;       /* Alberta Family Employment Tax Credit Turndown Level */
    NUMBER AFETCRR;       /* Alberta Family Employment Tax Credit Reduction Rate */
    NUMBER AFETCPI;	     /* Alberta Family Employment Tax Credit phase in */
    NUMBER AFETCAPCP[AFETCAPCMAX];  /* Alberta Family Employment Tax Credit Amount Per Child for 1st half of year */
    NUMBER AFETCNCP;      /* Alberta Family Employment Tax Credit Maximum Number of Children for 1st half of year */
    NUMBER AFETCCIP;      /* Alberta Family Employment Tax Credit Benefit Cut-in Level for 1st half of year */
    NUMBER AFETCBRP;      /* Alberta Family Employment Tax Credit Benefit Rate for 1st half of year */
    NUMBER AFETCTDP;      /* Alberta Family Employment Tax Credit Turndown Level for 1st half of year */
    NUMBER AFETCRRP;      /* Alberta Family Employment Tax Credit Reduction Rate for 1st half of year */
    NUMBER AFETCPIP;	     /* Alberta Family Employment Tax Credit phase in for 2nd half of year */
	int    AHCIPFLG;      /* Alberta Health Care Insurance Plan activation flag */
    NUMBER AHCIPS;        /* Alberta Health Care Insurance Plan Single Premium */
    NUMBER AHCIPF;        /* Alberta Health Care Insurance Plan Family Premium */
	int    AHCIPINCFLG;   /* Alberta Health Care Insurance Plan flag to give to highest earner */
    NUMBER AHCIPSR;       /* Alberta Health Care Insurance Plan Subsidy Rate */
    int    AHCIPSOPT;     /* Alberta Health Care Insurance Plan Subsidy option (1=table, 2=flat rate) */
    NUMBER AHCIPIT[AHCIPITMAX];  /* Alberta Health Care Insurance Plan Income Threshold [family type] */
    NUMBER AHCIPSSB[AHCIPSSBMAX][LKP_COLS];  /* Alberta Health Care Insurance Plan Single Subsidy Table  */
    NUMBER AHCIPFSB[AHCIPFSBMAX][LKP_COLS];  /* Alberta Health Care Insurance Plan Family Subsidy Table  */
    NUMBER AHCIPSPI;       /* Alberta Health Care Insurance Plan Senior Exemption Phase In */
    NUMBER ARESREB;        /* Alberta Resource Rebate Amount */

    /* tax on taxable income parameters */
	int    ATXFLG;       /* Alta tax on taxable income activation flag */
	NUMBER AMXM;         /* Alta married amount */
	NUMBER AMXMT;        /* Alta married amount turndown level */
	NUMBER AEMXM;        /* Alta equivalent to married amount */
	NUMBER AEMXMT;       /* Alta equivalent to married turndown level */
	NUMBER APNTCR;       /* Alta provincial non-refundable tax credit rate */
	NUMBER ABXM;         /* Alta Basic Personal Exemption/amount */
	NUMBER AAXM;         /* Alta Age Amount */
	NUMBER AAXTD;        /* Alta Age Amount net income turndown */
	NUMBER AAXRR;        /* Alta Age Amount credit reduction rate */
	NUMBER AYPNDL;       /* Alta Pension Income Deduction Amount */
	NUMBER AMEDANF;      /* Alta Medical allowance lower limit net income fraction */
	NUMBER AMEDALL;      /* Alta Medical allowance maximum lower limit */
	NUMBER ACHATL1;      /* Alta Charitable Donations amount level 1 */
	NUMBER ACHATR1;      /* Alta Charitable Donations tax credit rate 1 */
	NUMBER ACHATR2;      /* Alta Charitable Donations tax credit rate 2 */
	NUMBER AMAXDX;       /* Alta Maximum Disability deduction/amount */
	NUMBER AODISTC;      /* Alta Maximum infirm dependent 18 or older tax credit */
	NUMBER AEDXPM;       /* Alta Education Amount per month of full-time studies */
	NUMBER AEDXPMPT;     /* Alta Education Amount per month of part-time studies */
	NUMBER AMAXET;       /* Alta maximum on transfer of education and tuition amount */
	NUMBER APTX[APTXMAX][LKP_COLS]; /* Alta tax table [taxable income,basic provincial tax] */
    NUMBER ACGTC;        /* Alta Caregiver Tax Credit */
	int    ACGTCFLG;     /* Alta Caregiver Tax Credit activation flag */
	int    ACGTCOPT;     /* Alta Caregiver Tax Credit Option (1=max, 2=greenbook) */
	NUMBER ADTCR;        /* Alta dividend tax credit rate */
	NUMBER ADTCRLC;      /* Alta dividend tax credit rate from large (eligible) corporations */
	int    AAMTOPT;      /* Alta alternative minimum tax option  */
	NUMBER AAMTTX;       /* Alta amt rate as tax on adjusted income */
	NUMBER AAMTPCTF;     /* Alta amt rate as pct of additional fed tax due to minimum tax */
	NUMBER AAMTPCTM;     /* Alta amt rate as pct of federal minimum tax amount  */

	/*                    British Columbia */

	NUMBER CPTF;         /* British Columbia provincial tax fraction */
	NUMBER CSCI;         /* British Columbia surtax first cut-in level */
	NUMBER CSCI2;        /* British Columbia surtax second cut-in level */
	NUMBER CSF;          /* British Columbia surtax first level rate */
	NUMBER CSF2;         /* British Columbia surtax second level rate */
	NUMBER CSDC;         /* British Columbia provincial surtax dependant credit */
	NUMBER CPTCT[CPTCTMAX][LKP_COLS]; /* B.C. political contribution table [total donations,donation allowed] */
   NUMBER CPTCBEN;      /* Maximum B.C. political tax credit allowed */
	int CPTCREF;        /* British Columbia political tax credit refundable flag	*/
	NUMBER CRTRP;        /* British Columbia renter tax reduction proportion of rent allowed */
	NUMBER CRTRB;        /* British Columbia renter tax reduction basic credit */
	NUMBER CRTRS;        /* British Columbia renter tax reduction credit for spouse */
	NUMBER CRTRD;        /* British Columbia renter tax reduction credit for other dependants */
	NUMBER CRTRPN;       /* British Columbia renter tax reduction proportion of net income */
	NUMBER CRTRT[CRTRTMAX][LKP_COLS]; /* B.C. renter tax reduction base amount turndown [dependants, amount] */
	int CRFLAG;          /* British Columbia rental reduction flag */
	NUMBER CSUPCR;        /* British Columbia supplemental tax credit */
	int CSTCFLAG;        /* British Columbia sales tax credit flag	*/
	NUMBER CSTHINC;      /* British Columbia family head income threshold (stc) */
	NUMBER CSTSINC;      /* British Columbia spousal income threshold top-up (stc) */
	NUMBER CSTKINC;      /* British Columbia kid income threshold top-up (stc) */
	NUMBER CSTCR;        /* British Columbia stc reduction rate */
	NUMBER CSTC;         /* British Columbia stc amount */
	NUMBER CSTCKID;      /* British Columbia stc amount for children */
	NUMBER CLITR;        /* B.C. Low Income Tax Reduction Credit */
	NUMBER CLITRTD;      /* B.C. Low Income Tax Reduction Credit net income turndown */
	NUMBER CLITRRR;      /* B.C. Low Income Tax Reduction Credit reduction rate */
	NUMBER CLVCMAX;      /* Maximum B.C. labour-sponsored funds tax credit allowed */ 
	NUMBER CLVCRT; 		 /* Percent of B.C. labour-sponsored funds cost allowed as credit */
	int    CMSPFLAG;     /* B.C. Medical Services Plan activation flag */
	NUMBER CMSP[CMSPMAX][LKP_COLS]; /* B.C. Medical Services Plan Premium [family size, amount] */
	int    CMSPINCFLAG;     /* B.C. Medical Services Plan flag to give to highest earner  */
	NUMBER CMSPRATE[CMSPRATEMAX][LKP_COLS]; /* B.C. Medical Services Plan Subsidy Rate [income, rate] */
	NUMBER CMSPSDED;     /* B.C. Medical Services Plan Spouse Deduction */ 
	NUMBER CMSPADED;     /* B.C. Medical Services Plan Age 65+ Deduction */ 
	NUMBER CMSPCDED;     /* B.C. Medical Services Plan Child Deduction */ 
	NUMBER CMSPDDED;     /* B.C. Medical Services Plan Disability Deduction */ 
    /* tax on taxable income parameters */
	int    CTXFLG;       /* B.C. tax on taxable income activation flag */
	NUMBER CMXM;         /* B.C. married amount */
	NUMBER CMXMT;        /* B.C. married amount turndown level */
	NUMBER CEMXM;        /* B.C. equivalent to married amount */
	NUMBER CEMXMT;       /* B.C. equivalent to married turndown level */
	NUMBER CPNTCR;       /* B.C. provincial non-refundable tax credit rate */
	NUMBER CBXM;         /* B.C. Basic Personal Exemption/amount */
	NUMBER CAXM;         /* B.C. Age Amount */
	NUMBER CAXTD;        /* B.C. Age Amount net income turndown */
	NUMBER CAXRR;        /* B.C. Age Amount credit reduction rate */
	NUMBER CYPNDL;       /* B.C. Pension Income Deduction Amount */
	NUMBER CMEDANF;      /* B.C. Medical allowance lower limit net income fraction */
	NUMBER CMEDALL;      /* B.C. Medical allowance maximum lower limit */
	NUMBER CCHATL1;      /* B.C. Charitable Donations amount level 1 */
	NUMBER CCHATR1;      /* B.C. Charitable Donations tax credit rate 1 */
	NUMBER CCHATR2;      /* B.C. Charitable Donations tax credit rate 2 */
	NUMBER CMAXDX;       /* B.C. Maximum Disability deduction/amount */
	NUMBER CODISTC;      /* B.C. Maximum infirm dependent 18 or older tax credit */
	NUMBER CEDXPM;       /* B.C. Education Amount per month of full-time studies */
	NUMBER CEDXPMPT;     /* B.C. Education Amount per month of part-time studies */
	NUMBER CMAXET;       /* B.C. maximum on transfer of education and tuition amount */
	NUMBER CPTX[CPTXMAX][LKP_COLS]; /* B.C. tax table [taxable income,basic provincial tax] */
    NUMBER CCGTC;        /* B.C. Caregiver Tax Credit */
	int    CCGTCFLG;     /* B.C. Caregiver Tax Credit activation flag */
	int    CCGTCOPT;     /* B.C. Caregiver Tax Credit Option (1=max, 2=greenbook) */
	NUMBER CDTCR;        /* B.C. dividend tax credit rate */
	NUMBER CDTCRLC;      /* B.C. dividend tax credit rate from large (eligible) corporations */
	int    CAMTOPT;      /* B.C. alternative minimum tax option  */
	NUMBER CAMTTX;       /* B.C. amt rate as tax on adjusted income */
	NUMBER CAMTPCTF;     /* B.C. amt rate as pct of additional fed tax due to minimum tax */
	NUMBER CAMTPCTM;     /* B.C. amt rate as pct of federal minimum tax amount */
	int CAMTFTCFLG;   /* B.C. amt flag for provincial foreign tax credit  */

	/*               Commodity Taxes */

	int CTFLAG;    /* Commodity tax activation flag */
	int CTOPT;     /* Commodity tax calculation method [1=SHS,2=SPSM] */
	NUMBER CTFCID[NUMCOM];            /* Federal custom import duties [com] */
	NUMBER CTFEXD[NUMCOM];            /* Federal excise duties [com] */
	NUMBER CTFEXT[NUMCOM];            /* Federal excise taxes [com] */
	NUMBER CTFGST[NUMCOM];            /* Federal GST [com] */
	NUMBER CTFNEW[NUMCOM];            /* New federal commodity tax [com] */
	NUMBER CTPLGL[NUMREG];            /* Provincial liquor gallonage tax [prov] */
	NUMBER CTPPLQ[NUMREG];            /* Provincial profits on liquor commissions [prov] */
	NUMBER CTPGAS[NUMCOM][NUMREG];    /* Provincial gasoline tax [com x prov] */
	NUMBER CTPAMU[NUMREG];            /* Provincial amusement tax [prov] */
	NUMBER CTPTOB[NUMREG];            /* Provincial tobacco tax [prov] */
	NUMBER CTPRST[NUMCOM][NUMREG];    /* Provincial retail sales tax [com x prov] */
	NUMBER CTPNEW[NUMCOM][NUMREG];    /* New provincial commodity tax [com x prov] */
	NUMBER CTLPROP;                   /* Local property taxes */
	NUMBER CTNES;                     /* Expenditures NES */
	NUMBER CTSAVE;                    /* All positive savings */
	int CTCAPTOBFLG;    			  /* Flag to cap tobacco expenditures */
	NUMBER CTTOBMAX;                  /* Maximum value of tobacco expenditures */
	NUMBER CTFGSTHOUSE[NUMREG][2];    /* Gst on housing to be allocated [prov][tenure]*/

	/* array limits */
	int UIRMHRrows;           /* number of rows in UIREGHRMIN           */
	int UIFSHErows;           /* number of rows in UIFSHERMIN           */
	int UIEWKrows;            /* number of rows in UIEWK                */
	int UIEIRrows;            /* number of rows in UIEIRATE             */
	int UIEIBRProws;          /* number of rows in UIEIBRP              */
	int UIEIDIVrows;          /* number of rows in UIEIDIV              */
	int QFFSLrows;            /* number of rows in QFFSL                */
	int QFPSLrows;            /* number of rows in QFPSL                */
	int QAAFArows;            /* number of rows in QAAFA                */
	int QNBFArows;            /* number of rows in QNBFA                */
	int QCCETCRrows;          /* number of rows in QCCETCR              */
	int GISSTrows;            /* number of rows in GISST table          */
	int GISCTrows;            /* number of rows in GISCT table          */
	int GISOTrows;    /* number of rows in GISOT table          */
	int SPATrows;             /* number of rows in SPAT  table          */
	int ESPATrows;            /* number of rows in ESPAT table          */
	int FPTCrows;             /* number of rows in FPTC                 */
	int VPTCrows;             /* number of rows in VPTC                 */
	int BPTCrows;             /* number of rows in BPTC                 */
	int PPTCrows;             /* number of rows in PPTC                 */
	int OPTCrows;             /* number of rows in OPTC                 */
	int OCWISRRrows;          /* number of rows in OCWISRR              */
	int OCWISRRProws;         /* number of rows in OCWISRRP             */
	int NPTCrows;             /* number of rows in NPTC                 */
	int MPTCrows;             /* number of rows in MPTC                 */
	int SPTCrows;             /* number of rows in SPTC                 */
	int APTCrows;             /* number of rows in APTC                 */
	int CPTCTrows;            /* number of rows in CPTCT                */       
	int CTCTURrows;           /* number of rows in CTCTUR               */
	int FTXrows;              /* number of rows in FTX                  */
	int QTXrows;              /* number of rows in QTX                  */
    int QHSCrows;             /* number of rows in QHSC                 */
	int CRTRTrows;            /* number of rows in CTCTUR               */
	int CMSProws;             /* number of rows in CMSP                 */
	int CMSPRATErows;         /* number of rows in CMSPRATE             */
	int CTNUMCOM;    /* number of rows for commodity dimension parms    */
	int CTNUMREG;    /* number of rows in region dimension parms        */
	int ASBRRrows;            /* number of rows in ASBRR                */
	int ASBNOASrows;          /* number of rows in ASBNOAS              */
	int ASBRRProws;           /* number of rows in ASBRRP               */
	int ASBNOASProws;         /* number of rows in ASBNOASP             */
	int QHPTCTKrows;		  /* number of rows in QHPTCTK              */
	int CGTCTKrows;		  	  /* number of rows in CGTCTK               */
	int NCGTCTKrows;		  /* number of rows in NCGTCTK               */
	int PCGTCTKrows;		  /* number of rows in PCGTCTK               */
	int VCGTCTKrows;		  /* number of rows in VCGTCTK               */
	int BCGTCTKrows;		  /* number of rows in BCGTCTK               */
	int OCGTCTKrows;		  /* number of rows in OCGTCTK               */
	int MCGTCTKrows;		  /* number of rows in MCGTCTK               */
	int SCGTCTKrows;		  /* number of rows in SCGTCTK               */
	int ACGTCTKrows;		  /* number of rows in ACGTCTK               */
	int CCGTCTKrows;		  /* number of rows in CCGTCTK               */
	int QHPTCTCrows;		  /* number of rows in QHPTCTC              */
	int CGTCTCrows;		      /* number of rows in CGTCTC               */
	int NCGTCTCrows;		  /* number of rows in NCGTCTC               */
	int PCGTCTCrows;		  /* number of rows in PCGTCTC               */
	int VCGTCTCrows;		  /* number of rows in VCGTCTC               */
	int BCGTCTCrows;		  /* number of rows in BCGTCTC               */
	int OCGTCTCrows;		  /* number of rows in OCGTCTC               */
	int MCGTCTCrows;		  /* number of rows in MCGTCTC               */
	int SCGTCTCrows;		  /* number of rows in SCGTCTC               */
	int ACGTCTCrows;		  /* number of rows in ACGTCTC               */
	int CCGTCTCrows;		  /* number of rows in CCGTCTC               */
	int QFATCK6rows;		  /* number of rows in QFATCK6              */
	int QFATCTKrows;		  /* number of rows in QFATCTK              */
	int QFATCMXKrows;		  /* number of rows in QFATCMXK             */
	int QFATCMNKrows;		  /* number of rows in QFATCMNK             */
	int QFATCSRRrows;		  /* number of rows in QFATCSRR             */
	int QFATCMRRrows;		  /* number of rows in QFATCMRR             */
	int QPCTRrows;		      /* number of rows in QPCTR                */
	int SCBRR1rows;		      /* number of rows in SCBRR1               */
	int SCBRR2rows;		      /* number of rows in SCBRR2               */
    int UIEITKProws;          /* number of rows in UIEITKP              */
    int UITARGETrows;         /* number of rows in UITARGET             */
    int SATARGETrows;         /* number of rows in SATARGET             */
	int NPTXrows;              /* number of rows in NPTX                  */
	int PPTXrows;              /* number of rows in PPTX                  */
	int VPTXrows;              /* number of rows in VPTX                  */
	int BPTXrows;              /* number of rows in BPTX                  */
	int OPTXrows;              /* number of rows in OPTX                  */
	int MPTXrows;              /* number of rows in MPTX                  */
	int SPTXrows;              /* number of rows in SPTX                  */
	int APTXrows;              /* number of rows in APTX                  */
	int CPTXrows;              /* number of rows in CPTX                  */
	int CPPLT60rows;          /* number of rows in CPPLT60              */
	int CPP60T64rows;          /* number of rows in CPP60T64              */
	int CPPGT64rows;          /* number of rows in CPPGT64              */
	int GSTCTUNCrows;          /* number of rows in GSTCTUNC              */
	int UIEIFS1rows;          /* number of rows in UIEIFS1              */
	int UIEIFS2rows;          /* number of rows in UIEIFS2              */
	int UIEIFS3rows;          /* number of rows in UIEIFS3              */
	int UIEIFSTOPUProws;          /* number of rows in UIEIFSTOPUP              */
	int UIEIFSYNGrows;          /* number of rows in UIEIFSYNG              */
	int OHPBASErows;           /* number of rows in OHPBASE              */
	int QWPEIPIrows;           /* number of rows in QWPEIPI              */
	int QWPMAXrows;            /* number of rows in QWPMAX               */
	int QWPTDrows;             /* number of rows in QWPTD                */
	int QWPCRrows;             /* number of rows in QWPCR                */
	int QCAMAXrows;            /* number of rows in QCAMAX               */
	int QCAMINrows;            /* number of rows in QCAMIN               */
	int AHCIPITrows;           /* number of rows in AHCIPIT              */
	int AHCIPSSBrows;          /* number of rows in AHCIPSSB             */
	int AHCIPFSBrows;          /* number of rows in AHCIPFSB             */
	int AFETCAPCrows;          /* number of rows in AFETCAPC             */
	int MCLAWPCTrows;		  /* number of rows in MCLAWPCT              */
	int MCLAWPCTProws;		  /* number of rows in MCLAWPCTP              */
	int NUMPERrows;           /* number of rows in ASHELTER              */
	int BHEATBENrows;          /* number of rows in BHEATBEN             */
	int QPIPEADJrows;          /* number of rows in QPIPEADJ             */

	/* Derived Parameters */
	NUMBER UIBRA;        /* UI repayment base amount (UI and EI)*/
	NUMBER UIBRANR;      /* EI repayment base amount for non-repeaters (EI only)*/
	NUMBER GISBE1;       /* Breakeven for GIS one pensioner couple */
	NUMBER GISBE2;       /* Breakeven for GIS/SPA couple */
	NUMBER SPAXO;        /* Benefit Cross-over GIS/SPA vs GIS one pensioner couple */



	/**
	* The following items include the user-defined tax/transfer parameter
	* structure and a filler array which expands the size up to UPRMSIZE.
	**/

	S_UM UM;          /* user algorithm parameters (see mpu.h) [struct]      */
	char MPfill[UPRMSIZE-sizeof(UM_)]; /* filler to keep MP fixed in size [array] */


} _MP;



/* ==================== GLOBAL VARIABLE DECLARATIONS ====================== */


/**
* The global structure 'MP' holds parameter values used by tax/transfer
* calculation routines.
* 'MP' is defined and initialised in 'global.c' .
**/

/*global*/ extern S_MP NEARPARM MP;


/**
* The global structure 'MP_BAS' holds parameter values used to calculate
* variables for the 'Base' simulation.
* 'MP_BAS' is defined and initialised in 'global.c' .
**/

/*global*/ extern S_MP FAR MP_BAS;


/**
* The global structure 'MP_VAR' holds parameter values used to calculate
* variables for the 'Variant' simulation.
* 'MP_VAR' is defined and initialised in 'global.c' .
**/

/*global*/ extern S_MP FAR MP_VAR;


/**
* The following global strings serve to identify the version of each
* tax/transfer module in the 'standard' algorithm.  They are combined
* to form the ALGDESC informational control parameter.
**/

extern char FAR Stxcalc[];
extern char FAR Stxccea[];
extern char FAR Stxctc[];
extern char FAR Sctmod[];
extern char FAR Scall[];
extern char FAR Sdrv[];
extern char FAR Sfamod[];
extern char FAR Stxfstc[];
extern char FAR Sgis[];
extern char FAR Sgist[];
extern char FAR Stxhstr[];
extern char FAR Stxinet[];
extern char FAR Stxitax[];
extern char FAR Smemo1[];
extern char FAR Smemo2[];
extern char FAR Soas[];
extern char FAR Stxhhexp[];
extern char FAR Stxprov[];
extern char FAR Stxnfld[];
extern char FAR Stxpei[];
extern char FAR Stxns[];
extern char FAR Stxnb[];
extern char FAR Stxque[];
extern char FAR Stxont[];
extern char FAR Stxman[];
extern char FAR Stxsask[];
extern char FAR Stxalta[];
extern char FAR Stxbc[];
extern char FAR Stxqccea[];
extern char FAR Stxqhstr[];
extern char FAR Stxqinet[];
extern char FAR Stxqitax[];
extern char FAR Stxqcalc[];
extern char FAR Ssamod[];
extern char FAR Sui[];
extern char FAR Sdem[];
extern char FAR Sgai[];
extern char FAR Smpc[];
extern char FAR Smpd[];
extern char FAR Scceopt[];


/* ==================== FUNCTION PROTOTYPES =============================== */

#ifdef P_hh    /* declare prototypes taking hhld or sub-structures */
	extern  void txcalc(P_hh hhld);
	extern  void txccea(P_hh hhld);
	extern  void txctc(P_hh hhld);
	extern  void ctmod(P_hh hhld);
	extern  void call(P_hh hhld);
	extern  void drv(P_hh hhld);
	extern  void famod(P_hh hhld);
	extern  void txfstc(P_hh hhld);
	extern  void gis(P_hh hhld);
	extern  void gist(P_hh hhld);
	extern  void txhstr(P_hh hhld);
	extern  void txinet(P_hh hhld);
	extern  void txitax(P_hh hhld);
	extern  void memo1(P_hh hhld);
	extern  void memo2(P_hh hhld);
	extern  void oas(P_hh hhld);
	extern  void txhhexp(P_hh hhld);
	extern  void txprov(P_hh hhld);
	extern  void txnfld(P_hh hhld);
	extern  void txpei(P_hh hhld);
	extern  void txns(P_hh hhld);
	extern  void txnb(P_hh hhld);
	extern  void txque(P_hh hhld);
	extern  void txont(P_hh hhld);
	extern  void txman(P_hh hhld);
	extern  void txsask(P_hh hhld);
	extern  void txalta(P_hh hhld);
	extern  void txbc(P_hh hhld);
	extern  void txqccea(P_hh hhld);
	extern  void txqhstr(P_hh hhld);
	extern  void txqinet(P_hh hhld);
	extern  void txqitax(P_hh hhld);
	extern  void txqcalc(P_hh hhld);
	extern  void samod(P_hh hhld);
	extern  void ui(P_hh hhld);
	extern  void dem(P_hh hhld);
	extern  void gai(P_hh hhld);
	extern  void cceopt(P_hh hhld, void (* drv)(P_hh));
	extern  void classu(P_hh hhld);
#endif

#ifdef P_pc
	extern  void mpd(P_pc pcp);
	extern  void mpd1(P_pc pcp);
	extern  void mpd2(P_pc pcp);
	extern  void mpd3(P_pc pcp);
	extern  void mpd4(P_pc pcp);
#endif

extern  int mpc(void);
