/***
*spsm.h - SPSM common manifest constants and macros
*
*$Id: spsm.h 6.117 2007/09/18 17:18:31 hickcha Exp $
*
*   SPSD/M Copyright (c) 1987-1989, Minister of Regional Industrial Expansion.
*   All rights reserved.  Use, reproduction, or disclosure of this work,
*   as well as publication of results derived from this work, are subject
*   to the conditions specified in the SPSD/M License Agreement.
*
*Purpose:
*   This header file is included by every source code module in SPSM
*   immediately after any standard C library include files.
*   It contains definitions of commonly used constants, as well as macros
*   whose correct operation require that the definitions be respected
*   across all source code modules, in all directories.  A function
*   prototype for the 'quit' function is also provided.  This function
*   is called in various modules as a controlled exit for fatal error
*   conditions.
*
*Revisions:
* +-----+----------+---------------------------------------------------------+
* | Who |   Date   | Description                                             |
* +-----+----------+---------------------------------------------------------+
* | CH  | 07/07/31 | Added EDUCAGE                                           |
* | CH  | 07/03/33 | Update Copyright/VERSION number for release 15.0        |
* | CH  | 07/02/09 | Update Copyright/VERSION number for release 14.2        |
* | CH  | 07/01/04 | Update Copyright to 2007                                |
* | SFG | 06/12/12 | Increased maximum path size from 127 to 255             |
* | SFG | 06/12/12 | Removed unused obsolete manifest constant FILESIZE      |
* | LP  | 06/10/25 | Update Copyright/VERSION number for release 15.0        |
* | CH  | 06/07/25 | Update Copyright/VERSION number for release 14.2        |
* | LP  | 05/09/12 | Update Copyright/VERSION number for release 14.0        |
* | BBM | 04/10/19 | Update Copyright/VERSION number for release 11.0        |
* | BBM | 04/10/19 | Update Copyright/VERSION number for release 10.2        |
* | BBM | 04/05/07 | Update Copyright/VERSION number for release 10.1        |
* | CH  | 03/11/04 | Corrected VERSION                                       |
* | CH  | 03/10/17 | Update Copyright/VERSION number for release 10.0        |
* | CH  | 03/08/06 | Update Copyright/VERSION number for release 9.3         |
* | CH  | 03/07/17 | Update Copyright and increased PATHSIZE                 |
* | BBM | 02/09/11 | Update Copyright/VERSION number for release 9.2         |
* | BBM | 01/11/05 | Update Copyright/VERSION number for release 9.1         |
* | BBM | 01/04/18 | Update Copyright/VERSION number for release 9.0         |
* | EGA | 00/11/02 | STRSIZE increased from 3000 to 5000                     |
* | BBM | 00/06/09 | Update Copyright/VERSION number for release 8.1         |
* | BBM | 00/06/09 | Update Copyright/VERSION number for release 8.0         |
* | BBM | 99/08/24 | Update Copyright notice to 1999 for release 7.0         |
* | EGA | 99/05/20 | Adjust Max number of persons to SCF max in 1995: 12     |
* | EGA | 99/05/12 | Max number of persons from 9 to 25                      |
* | BBM | 99/02/05 | Update NUMCOM to 48 from 40 for release 7.0             |
* | SFG | 99/02/05 | Update VERSION to 7.00                                  |
* | SFG | 98/05/15 | Update VERSION to 6.10                                  |
* | SFG | 98/05/14 | enlarge file buffer size for WIN32, decrease for MS-DOS |
* | SFG | 98/04/22 | Have 32-bit version use double precision                |
* | SFG | 98/02/17 | Add manifest constants for copyright notice             |
* | SFG | 95/05/06 | Update VERSION to 6.00                                  |
* | SFG | 93/09/20 | Update VERSION to 5.20                                  |
* | SFG | 93/01/19 | Update VERSION to 5.00                                  |
* | SFG | 92/08/26 | removed EX, CL, and related constants and code          |
* | SFG | 92/05/01 | MAXPERS & MAXFAM back to 9                              |
* | SFG | 92/04/24 | MAXPERS & MAXFAM to 15                                  |
* | SFG | 92/04/24 | Update VERSION to 5.00                                  |
* | SFG | 91/12/05 | Update VERSION to 4.21                                  |
* | --- | 89/10/13 | Release 4.0                                             |
* |     |          |                                                         |
* +-----+----------+---------------------------------------------------------+
*
*Dependencies:
*   #include "spsm.h"
*
*****************************************************************************/



/* ==================== MANIFEST CONSTANTS AND MACRO DEFINITIONS ========== */

/**
* The following macros, if used, are specified in the command which
* invokes the C compiler.  They are documented here for completeness.
* In all cases, the value to which the macro is set is irrelevant - what
* counts is whether the macro is defined or not.
*
* _MSC_VER    Microsoft C compiler is being used
* LC          Lattice C compiler is being used
* M_I86       Target machine is iAPX (Intel family) - defined by cl command
* I370        Target machine is IBM mainframe
* DEBUG       DEBUG macros are expanded
* NTRACE      Function traceback facilities are de-activated
* MSCOVL      Activate pragmas to control overlays under _MSC_VER
*
* When MSCOVL is defined, pragmas to control overlays are activated.
* The activated pragmas (protected by #ifdef MSCOVL) are only recognized
* by the Microsoft C compiler, and allow the creation of an overlay
* structure in which different functions within a single module can
* be allocated to different overlays.  This results in considerable
* memory savings for the SPSM without any significant execution time
* penalty.
*
**/


/* The following indicates relevant predefined macros for Microsoft C
 * compilers.
 *
 *
 *   _MSDOS       always      C700, MSVC
 *   _MSC_VER     always      C700, MSVC, MSVCNT
 *   _WIN32       always      MSVCNT
 *   _M_IX86      always      MSVCNT (except other machine targets?)
 *   _M_I86       always      C700, MSVC
 *   _M_I8086     sometimes   C700, MSVC
 *   _M_I286      sometimes   C700, MSVC
 *   _M_I386      sometimes   C700, MSVC
 *   _WINDOWS     sometimes   C700, MSVC
 *
 */

/* generalize from _M_I86 to _M_IX86 for C700 and MSVC compilers */
#if defined(M_I8086)
#define _M_IX86 000
#elif defined(M_I286)
#define _M_IX86 200
#elif defined(M_I386)
#define _M_IX86 300
#endif

/* activate overlay compilation for _MSDOS console target */
#if defined(_MSDOS) && !defined(_WINDOWS)
#define MSCOVL
#endif

#define VERSION 1500     /* SPSD/M software version identifier */
#define COPYRIGHT_ENGLISH "Copyright (c) Minister of Industry 1984-2007"
#define COPYRIGHT_FRENCH  "Copyright (c) Ministre de l'Industrie 1984-2007"


/* define file buffer size depending on OS */

#if defined(_WIN32)
#define BUFSIZE 65536
#else
#define BUFSIZE 4096
#endif


/* define output device widths */

#define MAXWCON  79     /* limit on line length to console */
#define MAXWPRT 132     /* limit on line length to printer */


/* define limits for various arrays */

#define MAXPERS  25     /* maximum # of persons in a household             */
#define MAXFAM   25     /* maximum # of families in a household            */
#define NUMCOM   48     /* number of commodities (CTR arrays)              */
#define NUMREG   10     /* number of regions (provinces)                   */
#define NUMURB    5     /* number of urban size classes                    */
#define NUMFTYP   6     /* number of distinct standard family types        */
#define NUMRAND  20     /* number of independent random number streams     */
#define NUMEXT   23     /* number of extra user-created database variables */
#define EDUCAGE   3     /* number of ages for which education to be adjusted */


/* define identifiers used to specify family unit concepts */

#define NUMLEV    5     /* number of family/individual levels     */
#define INLEVEL   0     /* code to identify individual level      */
#define NFLEVEL   1     /* code to identify nuclear family level  */
#define CFLEVEL   2     /* code to identify census family level   */
#define EFLEVEL   3     /* code to identify economic family level */
#define HHLEVEL   4     /* code to identify household level       */
#define FLTLEVEL  5     /* code identifying floating level        */
#define SPLEVEL   6     /* code identifying spouse of person      */


/**
* Define limits for strings of various sorts.
* NB: The space required by the null terminator is NOT included
* in these constants, and must be accounted for when defining strings.
* Eg. char name[PATHSIZE+1];
**/

#define PATHSIZE    255      /* maximum path length                       */
#define STRSIZE   5000      /* maximum size of strings                   */
#define IDSIZE      20      /* maximum length of an identifier           */
#define LABSIZE     60      /* maximum length of labels of various sorts */
#define HDRSIZE     40      /* length of labels in file headers          */


#define LOGICAL int      /* type used to store true or false values       */
#define TRUE  1          /* manifest constants to make code more readable */
#define FALSE 0


/* codes used to denote status of an attempted operation */

#define OK    0
#define BAD   1


/**
* Macros used to implement the 'near' and 'far' storage modifier
* keywords and the 'cdecl' function calling convention in a portable manner
* for the Microsoft C compiler.  If compiling with the Microsoft C compiler,
* then NEAR expands to 'near', FAR expands to 'far', and CDECL expands to
* 'cdecl', otherwise these macros expand to nothing.
**/


#if defined(_WIN32)

#define CDECL _cdecl
#define NUMDOUBLE

#elif defined(_MSC_VER)

#define NEARDEF             /* if defined, then NEAR->near and FAR->far */
#define NEAR near
#define FAR far
#define CDECL cdecl
#define NUMFLOAT

#else

/* Unix was supported once upon a time */
#define NUMDOUBLE

#endif


#if !defined(NEAR)
#define NEAR
#endif
#if !defined(FAR)
#define FAR
#endif
#if !defined(CDECL)
#define CDECL
#endif



/**
* The NUMBER, NUMDOUBLE, and NUMFLOAT macros control whether the
* files which include spsm.h will use the float or double type to store
* floating point quantities.  Other header files also use these
* macros to generate appropriate code or appropriate types.  A number
* of widely used floating point constants are also defined.  Only one of
* NUMFLOAT or NUMDOUBLE should be defined.  Note that some
* structures will greatly increase in size if 'double' is used, perhaps
* necessitating a change in the use of 'near' memory.
**/


#ifdef NUMFLOAT               /* indicates that 'float' is being used  */
#define NUMBER float
#define ZERO (float) 0.0
#define HALF (float) 0.5
#define ONE (float) 1.0
#define THOUSAND (float) 1000.0
#define MILLION (float) 1000000.0
#endif

#ifdef NUMDOUBLE              /* indicates that 'double' is being used */
#define NUMBER double
#define ZERO 0.0
#define HALF 0.5
#define ONE 1.0
#define THOUSAND 1000.0
#define MILLION 1000000.0
#endif



/**
* Define constants used to classify C types.  These constants are
* used to record the type of data stored at a given memory location.
**/

#define C_CHR 0        /* code identifying 'char' */
#define C_INT 1        /* code identifying 'int' */
#define C_FLT 2        /* code identifying 'float' */
#define C_DBL 3        /* code identifying 'double' */
#ifdef NUMDOUBLE
#define C_NUM C_DBL    /* code identifying floating point number */
#else
#define C_NUM C_FLT
#endif
#define C_LNG 4        /* code identifying 'long' */
#define C_STR 5        /* code identifying null-terminated string (array) */
#define C_PSTR 6       /* code identifying null-terminated string (pointer) */


/* ==================== FUNCTION PROTOTYPES =============================== */

/* These prototypes are interface-independent but interface-callable functions
 * that are generally implemented in each executable.  In particular, the
 * calc_cleanup() function is called by the interface termination routines
 * such as intf_error() and must be supplied if these are used.
 */

extern  int  calc_start(int argc, char *argv[]);
extern  void calc_cancel(void);
extern  void calc_cleanup(void);


/* The following functions are interface-specific.  Console versions can be
 * found in defs/conintf.c and frontend/conspsm.c, while MFC windows
 * versions can be found in frontend/winspsm.cpp and associated header
 * files.
 */

void intf_log(char *msg);
void intf_message(char *msg, char *title);
void intf_exit(int retcode);
void intf_trace(void);
void intf_update(void);
