/***
*Adrv.cpp - Tax/transfer calculator
*
*$Id: Adrv.cpp 6.114 2007/09/18 17:22:08 hickcha Exp $
*
*   SPSD/M Copyright (c) 1987-1995, Minister of Industry.
*   All rights reserved.  Use, reproduction, or disclosure of this work,
*   as well as publication of results derived from this work, are subject
*   to the conditions specified in the SPSD/M License Agreement.
*
*Purpose:
*   This file contains the definition of the .c function.
*
*Revisions:
* +-----+----------+---------------------------------------------------------+
* | Who |   Date   | Description                                             |
* +-----+----------+---------------------------------------------------------+
* | CH  | 07/03/22 | change the STDNAME to reflect release 15.0              |
* | CH  | 06/07/25 | change the STDNAME to reflect release 14.2              |
* | LP  | 06/07/14 | change the STDNAME to reflect release 14.1              |
* | LP  | 05/12/13 | change the STDNAME for release 14.0 - update yrs 91-10  |
* | LP  | 05/09/12 | change the STDNAME to reflect release 14.0              |
* | BBM | 04/10/19 | change the STDNAME to reflect release 10.2              |
* | BBM | 04/05/07 | change the STDNAME to reflect release 10.1              |
* | LP  | 03/11/04 | update the STDNAME to reflect release 10.0 (now to 2009)|
* | CH  | 03/11/04 | change the STDNAME to reflect release 10.0              |
* | CH  | 03/08/06 | change the STDNAME to reflect release 9.3               |
* | BBM | 02/09/11 | change the STDNAME to reflect release 9.2               |
* | BBM | 01/08/29 | change the STDNAME to reflect release 9.1               |
* | BBM | 01/08/29 | change the STDNAME to reflect release 9.0               |
* | LP  | 01/04/05 | Switched txprov and txfstc so that provinces can use    |
* |     |          |    federal gst and heat rebate amounts                  |
* | LP  | 01/03/12 | Removed Seniors Benefit module (senben.cpp)             |
* | BBM | 01/01/26 | change the STDNAME to reflect release 8.2               |
* | BBM | 01/01/24 | change the STDNAME to reflect 2005                      |
* | BBM | 00/09/05 | change the STDNAME to reflect release 8.1               |
* | BBM | 00/06/08 | change the STDNAME to reflect release 8.0               |
* | CH  | 00/03/27 | Swithced txprov and txctc so that provinces can use     |
* |     |          |    federal ctb amounts                                  |
* | SFG | 99/12/09 | Change fa->famod and sa->samod                          |
* | BBM | 99/08/24 | change the STDNAME to reflect release 7.0               |
* | TCB | 98/05/28 | Renamed *.cpp, ANSI function headers                    |
* | BBM | 98/05/15 | change the STDNAME to reflect release 6.1               |
* | BBM | 98/03/05 | Move gist.c to just before sa.c so SAELDOPT 2 will work |
* | BBM | 97/08/19 | change the STDNAME to reflect release 6.0               |
* | SFG | 94/10/07 | change the STDNAME to reflect release 5.2               |
* | GJC | 93/03/31 | change the STDNAME tp reflect release 5.1               |
* | --- | 89/10/13 | Release 4.0                                             |
* |     |          |                                                         |
* +-----+----------+---------------------------------------------------------+
*
*Definitions:
*   Adrv     [global]  Tax/transfer calculator
*
*****************************************************************************/


/* ==================== C-RUNTIME LIBRARY INCLUDE FILES =================== */

#include <stdio.h>  /* definitions/declarations for standard I/O routines   */


/* ==================== SPSD/M INCLUDE FILES ============================== */

#include "spsm.h"   /* SPSM common manifest constants and macros            */
#include "sub.h"    /* Subroutine library declarations                      */
#include "vsu.h"    /* Household variable sub-structure (user's)            */
#include "vs.h"     /* Household variable structure and sub-structures      */
#include "mpu.h"    /* Tax/transfer parameter declarations (user's)         */
#include "mp.h"     /* Tax/transfer parameter declarations                  */


/* ==================== GLOBAL VARIABLE DEFINITIONS ======================= */

/*global*/ char ALTNAME[IDSIZE+1] = "Unnamed";

/* Give global string describing version of this module */

/*global*/ char FAR Tdrv[] = "Untitled"
#ifdef _MSC_VER
" [" __TIMESTAMP__ "]"
#endif
;


/* ==================== COMPILER PRAGMAS ================================== */

#ifdef MSCOVL

#endif


/* ==================== FUNCTION DEFINITIONS ============================== */


/*****************************************************************************
*Adrv - Tax/transfer calculator
*
*Synopsis:
*    void Adrv(            
*    P_hh hh              
*    )                    
*
*Description:
*
*Return Value:
*   None.
*
*Calls:
*   ui       Compute UI benefits
*   famod    Compute family allowance
*   oas      Compute OAS for elderly
*   dem      Compute new taxable demogrants
*   txinet   Compute net income
*   gis      Compute GIS/SPA for elderly
*   gist     Compute Provincial GIS top-ups for elderly
*   samod    Compute social assistance or guarantees
*   txitax   Compute taxable income
*   txhstr   Apply tax transfers between head and spouse
*   txcalc   Calculate federal income tax
*   txctc    Compute child tax credit
*   txfstc   Compute federal sales tax credit
*   txprov   Compute provincial taxes
*   gai      Compute new refundable credits or guarantees
*   memo1    Compute memo items for reporting
*   ctmod    Compute commodity taxes
*   memo2    Compute consumable income, etc.
*   cceopt   Multiple calls of tax/transfer calculator
*   classu   Compute user-defined reporting variables
*
*Called by:
*   call     Call tax/transfer calculator
*   cceopt   Multiple calls of tax/transfer calculator
*   pass2    recalculate UI with child benefits in place
*
*****************************************************************************/
void Adrv(
	register P_hh hh
)
{
	DEBUG_ON("Adrv");

	/* compute taxes & transfers for each household, */
	/* and memo items such as disposable income.     */

	ui(hh);          /* compute Unemployment Insurance benefit           */
	famod(hh);       /* compute family allowances                        */
	oas(hh);         /* compute old age security                         */
	dem(hh);         /* compute new demogrants                           */
	txinet(hh);      /* compute net income                               */
	gis(hh);         /* compute guaranteed income supplement for elderly */
	gist(hh);        /* compute provincial elderly top-ups               */
	samod(hh);       /* compute social assistance                        */
	txitax(hh);      /* compute taxable income                           */
	txhstr(hh);      /* compute child & spouse deductions                */
	txcalc(hh);      /* compute federal tax                              */
	txctc(hh);       /* compute child tax credit                         */
	txfstc(hh);      /* compute federal sales tax credit                 */
	txprov(hh);      /* compute provincial taxes and credits             */
	gai(hh);         /* compute new guarantees, refundable credits       */
	memo1(hh);       /* compute disposable income, etc.                  */
	ctmod(hh);       /* compute commodity taxes and allocate to persons  */
	memo2(hh);       /* compute consumable income, etc.                  */
	cceopt(hh, Adrv); /* zero CCE for young kids if optimal               */
	classu(hh);      /* compute user-defined reporting variables         */

	DEBUG_OFF("Adrv");
}

