/***
*Amemo1.cpp - Compute memo items for reporting
*
*$Id: Amemo1.cpp 6.132 2007/09/18 17:22:08 hickcha Exp $
*
*   SPSD/M Copyright (c) 1987-1995, Minister of Industry.
*   All rights reserved.  Use, reproduction, or disclosure of this work,
*   as well as publication of results derived from this work, are subject
*   to the conditions specified in the SPSD/M License Agreement.
*
*Purpose:
*   This file contains the definition of the .c function.
*
*Revisions:
* +-----+----------+---------------------------------------------------------+
* | Who |   Date   | Description                                             |
* +-----+----------+---------------------------------------------------------+
* | LP  | 07/07/08 | Added immcb (Manitoba Child Benefit) to impfp           |
* | LP  | 07/06/04 | Added imocb (Ontario Child Benefit) to impfp            |
* | LP  | 07/01/23 | Removed imninc - no income flag - no longer used        |
* | LP  | 06/12/12 | Moved imicnet and imictot to txinet, now used in code   |
* | LP  | 06/06/14 | Added imbcss (BC Senior Supp - SA prog) imicnet, imictot|
* | LP  | 06/05/30 | Added Universal Child Care Benefit imuccb to imftran    |
* | LP  | 06/05/24 | Moved idiworkc from imfoth to impoth (prov. other trans)|
* | CH  | 06/05/11 | Removed Alta shelter from impfp                         |
* | LP  | 06/01/17 | Added SACLAWOPT to imsaclaw for incl in total/disp inc  |
* | LP  | 05/12/16 | Added imqpipcbn to imptran, imqpipp to imptax           |
* | LP  | 05/11/09 | Added imictot, imicnet - tax form total and net income  |
* | LP  | 05/11/04 | Added Alberta Resource Rebate (imresreb) to impoth      |
* | LP  | 05/10/21 | Added Federal Energy Cost Benefit (imfecb) to imfoth    |
* | LP  | 05/10/20 | Added Alta shelter increase (imashelt) to impfp         |
* | LP  | 05/08/10 | Added imsaclaw (sa clawback) to imftax and immdisp      |
* | LP  | 04/08/03 | Added impoth to imptran                                 |
* | LP  | 04/06/04 | Added imphp (provincial health premiums) to imptax      |
* | LP  | 04/02/23 | Removed imashelt from impfp - removed ALTA sa top up    |
* | LP  | 04/02/20 | Removed imses from impfp - removed Sask. Emp. Supplement|
* | CH  | 03/10/17 | 10.0 changes: Deleted idivetp idinogv idinoth iditogv   |
* |     |          |                  replaced idiint + idioinv by idiinvrd  |
* | CH  | 03/05/16 | Added NS taxpayer refund                                |
* | LP  | 02/06/21 | Added Ont. Child Care Supp. one time extra ben. to impfp|
* | LP  | 02/06/17 | Added Nfld Mother-Baby Nutrition Supplement to impfp    |
* | LP  | 02/06/04 | Added Alta shelter increase (imashelt) to impfp         |
* | LP  | 01/04/05 | Added provincial relief for heating expenses to impoth  |
* | LP  | 01/02/28 | Removed Federal Seniors Benefit program                 |
* | CH  | 00/11/09 | Added relief for heating expenses to imfoth             |
* | CH  | 00/10/24 | Added relief for heating expenses                       |
* | LP  | 00/03/17 | Add imincb to impfp (NFLD child benefit)                |
* | LP  | 99/05/11 | Add imibceib to impfp (B.C. earned income benefit)      |
* | CH  | 99/04/22 | Add imnsc to impfp                                      |
* | BBM | 99/02/12 | Add idialimo to immoth (was in iditoth in V6)           |
* | BBM | 99/02/12 | Add idivetp and idiworkc to imfoth (were in idinogv V6) |
* | BBM | 99/02/11 | Drop idiroom from imminv computation - now in imiself   |
* | TCB | 98/05/28 | Renamed *.cpp, ANSI function headers                    |
* | CH  | 98/05/01 | Add imses imscb to impfp                                |
* | CH  | 98/02/26 | Add imiafetc to impfp                                   |
* | EGA | 98/02/18 | Quebec Family Allowance Tax Credit                      |
* | CH  | 98/02/05 | Add NS Direct Assistance to imptran                     |
* | BBM | 97/10/15 | Add Ont Refund. child care tax credit imoccea to impfp  |
* | BBM | 97/10/07 | Add BC Family Bonus to impfp                            |
* | BBM | 97/09/30 | Add NB Child Tax Benefit to impfp                       |
* | CCH | 97/08/21 | Added imigispa                                          |
* | BBM | 96/09/19 | Add Seniors Benefits to Accounting                      |
* | BBM | 94/10/06 | Add Quebec CCE refundable tax credit to accounting      |
* | GJC | 93/03/24 | Add self employed variable and new programs variable    |
* | GJC | 93/02/19 | Add funny "other" refunable credits to transfers        |
* | BBM | 92/07/07 | Add federal child benefits variable to accounting       |
* | --- | 89/10/13 | Release 4.0                                             |
* |     |          |                                                         |
* +-----+----------+---------------------------------------------------------+
*
*Definitions:
*   Amemo1   [global]  Compute memo items for reporting
*
*****************************************************************************/


/* ==================== C-RUNTIME LIBRARY INCLUDE FILES =================== */

#include <stdio.h>  /* definitions/declarations for standard I/O routines   */


/* ==================== SPSD/M INCLUDE FILES ============================== */

#include "spsm.h"   /* SPSM common manifest constants and macros            */
#include "sub.h"    /* Subroutine library declarations                      */
#include "vsu.h"    /* Household variable sub-structure (user's)            */
#include "vs.h"     /* Household variable structure and sub-structures      */
#include "mpu.h"    /* Tax/transfer parameter declarations (user's)         */
#include "mp.h"     /* Tax/transfer parameter declarations                  */


/* ==================== GLOBAL VARIABLE DEFINITIONS ======================= */

/* Give global string describing version of this module */

/*global*/ char FAR Tmemo1[] = "Untitled"
#ifdef _MSC_VER
" [" __TIMESTAMP__ "]"
#endif
;


/* ==================== COMPILER PRAGMAS ================================== */

#ifdef MSCOVL

#endif


/* ==================== FUNCTION DEFINITIONS ============================== */

/*****************************************************************************
*Amemo1 - Compute memo items for reporting
*
*Synopsis:
*    void Amemo1(          
*    P_hh hh              
*    )                    
*
*Description:
*
*Return Value:
*   None.
*
*Calls:
*   isneg    Is argument negative ?
*
*Structure Members:
*   MP.SACLAWOPT    (i)  Social assistance NCBS clawback include in tax/income flag
*   hh.hhnin        (i)  Number of individuals in household
*   hh.in           (i)  Individual data [array]
*   id.idialimo     (i)  Alimony income received
*   id.idicapg      (i)  Capital gains (actual)
*   id.idicqp       (i)  CPP/QPP income (114)
*   id.ididiv       (i)  Dividend income (actual)
*   id.idiemp       (i)  Wages & salaries
*   id.idiinvnd     (i)  Interest and other investment income
*   id.idipens      (i)  Pension income (115)
*   id.idisefm      (i)  Self-employed income - farming
*   id.idisenf      (i)  Self-employed income - non-farming
*   id.iditoth      (i)  Other taxable income (130)
*   id.idiworkc     (i)  Workers compensation benefits
*   im.imbft        (i)  Basic federal tax
*   im.imcqppc      (i)  CPP/QPP contributions
*   im.imctc        (i)  Child tax credit
*   im.imfcben      (i)  Total Federal Child Benefits
*   im.imfecb       (i)  Federal Energy Cost Benefit
*   im.imffa        (i)  Federal portion of family allowances
*   im.imfortc      (i)  Federal other refundable tax credits
*   im.imfsa        (i)  Federal social assistance
*   im.imfstc       (i)  Federal sales tax credit
*   im.imheatrl     (i)  Federal relief for heating expenses
*   im.imiafetc     (i)  Alberta Family Employment Tax Credit Benefits
*   im.imibceib     (i)  B.C. Earned Income Benefit
*   im.imibcfb      (i)  B.C. Family Bonus
*   im.imigis       (i)  GIS benefits
*   im.imigist      (i)  GIS provincial top-up
*   im.iminet       (i)  Net income
*   im.iminsda      (i)  NS Direct Assistance Program
*   im.imioas       (i)  OAS benefits
*   im.imiosa       (i)  Other SA or guarantees
*   im.imiotg       (i)  Other taxable demogrants
*   im.imispa       (i)  Spouse's allowance
*   im.imiuib       (i)  Unemployment Insurance/Employment Insurance benefits
*   im.immcb        (i)  Manitoba Child Benefit
*   im.imnbcben     (i)  Total NB child tax Benefits
*   im.imncb        (i)  Newfoundland Child Benefit
*   im.imnmbns      (i)  Newfoundland Mother-Baby Nutrition Supplement
*   im.imnscb       (i)  Nova Scotia Child Benefit
*   im.imnstxrf     (i)  Nova Scotia Taxpayer Refund
*   im.imocb        (i)  Ontario Child Benefit
*   im.imoccea      (i)  Ont. Child Care Exp. credit allowed (Family)
*   im.imoccext     (i)  Ont. Child Care Supplement one-time extra benefit
*   im.impfa        (i)  Provincial family allowance
*   im.impheatr     (i)  Provincial Home Heating Fuel/Energy Rebate
*   im.imphp        (i)  Provincial Health Premium
*   im.importc      (i)  Other refundable provincial tax credits
*   im.impsa        (i)  Provincial social assistance
*   im.imptc        (i)  Refundable provincial tax credits
*   im.imqaafa      (i)  Quebec Availability Allowance FA Supplement
*   im.imqfatc      (i)  Quebec Family Allowance Tax Credit
*   im.imqnbfa      (i)  Quebec newborn Allowance
*   im.imqpipcbn    (i)  Quebec parental insurance plan calendar year benefits
*   im.imqpipp      (i)  Quebec parental insurance plan premiums for paid workers
*   im.imqpippse    (i)  Quebec parental insurance plan premiums for self-employed
*   im.imqtar       (i)  Quebec tax abatement (refundable)
*   im.imrepay      (i)  Social Benefits Repayments
*   im.imresreb     (i)  Alberta Resource Rebate Amount
*   im.imsaclaw     (i)  Social Assistance NCB Clawback Amount
*   im.imscb        (i)  Saskatchewan Child Benefit
*   im.imtxf        (i)  Federal income tax payable
*   im.imtxp        (i)  Provincial income tax payable
*   im.imuccb       (i)  Universal Child Care Benefit amount
*   im.imuic        (i)  UIC contributions
*   im.imfoth       (io) Federal other government income
*   im.imftax       (io) Federal taxes
*   im.imftran      (io) Federal transfer income
*   im.imicqp       (io) CPP/QPP payable
*   im.immdisp      (io) Disposable income
*   im.immemp       (io) All employment income
*   im.imminv       (io) Investment income
*   im.immmkt       (io) Market income
*   im.immoth       (io) Other income
*   im.immtax       (io) All taxes
*   im.immtot       (io) Total income
*   im.immtran      (io) All transfer income
*   im.impfp        (io) Provincial family programs
*   im.impoth       (io) Provincial other government income
*   im.imptax       (io) Provincial taxes
*   im.imptran      (io) Provincial transfer income
*   im.imctcben     (o)  Federal child tax credit and child benefits
*   im.imfiler      (o)  Taxable filer status
*   im.imfnewpg     (o)  Federal new programs
*   im.imfothtr     (o)  Federal other trans income and ref. credits
*   im.imiemp       (o)  Wages and salaries
*   im.imigispa     (o)  GIS and spouse's allowance
*   im.imiself      (o)  Total self-employment income
*   im.immicons     (o)  Consumable income
*   im.impalltc     (o)  All refundable provincial tax credits
*
*Called by:
*   drv      Tax/transfer calculator
*
*****************************************************************************/
void Amemo1(
	P_hh hh
)
{
	register P_in in;

	register int ini;

	DEBUG_ON("Amemo1");

	/* process each person in household */
	for (ini=0, in=&hh->in[0]; ini<hh->hhnin; ini++, in++) {

		DEBUG5("%s age=%d, sex=%d, marst=%d, cfrh=%d\n",
		         in->id.idage, in->id.idsex, in->id.idmarst, in->id.idcfrh);

		/* initialize filer status */
		in->im.imfiler = 0;


		/* create filer (taxable) status for reporting             */
		/* an individual is considered a relevant filer if:        */
		/*    - a non-zero basic federal tax                       */
		/*    - eligible for child tax credit or sales tax credit  */
		/*    - eligible for provincial tax credits                */
		if (in->im.imbft >= ONE || in->im.imctc >= ONE || in->im.imfcben >= ONE
                        		|| in->im.imfstc >= ONE || in->im.imptc >= ONE
			                     || isneg(in->im.iminet)) {
			in->im.imfiler = 1;
			DEBUG1("%s individual is a relevant filer\n");
		}
		/* an individual is a taxable filer if either federal or   */
		/* provincial taxes payable are greater than 1             */
		if (in->im.imtxf >= ONE || in->im.imtxp >= ONE) {
			in->im.imfiler = 2;
			DEBUG1("%s individual is a taxable  filer\n");
		}
		DEBUG2("%s filer=%d\n", in->im.imfiler);

		in->im.imiemp	 = in->id.idiemp;
		in->im.imiself	 = in->id.idisenf + in->id.idisefm;
		in->im.imfoth   = in->im.imheatrl + in->im.imfecb;
		in->im.impoth   = in->id.idiworkc + in->im.impheatr + in->im.imresreb;
		in->im.imicqp   = in->id.idicqp;
		in->im.immemp   = in->id.idiemp + in->id.idisenf + in->id.idisefm;
		in->im.imminv   = in->id.idiinvnd + in->id.ididiv + in->id.idicapg;
		in->im.immoth   = in->id.idipens + in->id.iditoth + in->id.idialimo ;
		in->im.immmkt   = in->im.immemp + in->im.imminv + in->im.immoth;
		in->im.imftran  = in->im.imffa + in->im.imioas + in->im.imiotg + in->im.imigis + in->im.imispa  
		            + in->im.imctc + in->im.imfcben + in->im.imicqp + in->im.imfoth + in->im.imiuib
		            + in->im.imfstc + in->im.imqtar + in->im.imfsa + in->im.imiosa
						+ in->im.imfortc + in->im.imuccb ;
		in->im.imctcben = in->im.imctc + in->im.imfcben;
		in->im.imfothtr = in->im.imfoth + in->im.imfortc;
		in->im.imfnewpg = in->im.imiotg + in->im.imiosa;
		in->im.imigispa = in->im.imigis + in->im.imispa;
		in->im.impfp    = in->im.impfa + in->im.imqaafa + in->im.imqnbfa + in->im.imiafetc
						+ in->im.imnbcben + in->im.imibcfb + in->im.imoccea + in->im.imqfatc
						+ in->im.imscb + in->im.imnscb + in->im.imibceib
						+ in->im.imncb + in->im.imnmbns + in->im.imoccext + in->im.imocb
						+ in->im.immcb;
		in->im.imptran  = in->im.impfp + in->im.imigist + in->im.imptc + in->im.impsa
							 + in->im.importc + in->im.iminsda + in->im.imnstxrf + in->im.impoth
							 + in->im.imqpipcbn;
		in->im.impalltc = in->im.imptc + in->im.importc;
		in->im.immtran  = in->im.imptran + in->im.imftran;
		in->im.immtot   = in->im.immmkt + in->im.immtran;
		in->im.imftax   = in->im.imuic + in->im.imcqppc + in->im.imrepay + in->im.imtxf 
							+ (MP.SACLAWOPT?in->im.imsaclaw:ZERO);
		in->im.imptax   = in->im.imtxp + in->im.imphp + in->im.imqpipp + in->im.imqpippse;
		in->im.immtax   = in->im.imftax + in->im.imptax;

		in->im.immdisp  = in->im.immtot - in->im.immtax 
						  + (MP.SACLAWOPT?in->im.imsaclaw:ZERO);


		/* final icons value is determined in memo2 */
		in->im.immicons  = in->im.immdisp;

	}

	DEBUG_OFF("Amemo1");
}
