/***
*Atxbc.cpp - Compute provincial taxes for British Columbia
*
*$Id: Atxbc.cpp 6.127 2007/09/18 17:22:10 hickcha Exp $
*
*   SPSD/M Copyright (c) 1987-1995, Minister of Industry.
*   All rights reserved.  Use, reproduction, or disclosure of this work,
*   as well as publication of results derived from this work, are subject
*   to the conditions specified in the SPSD/M License Agreement.
*
*Purpose:
*   This file contains the definition of the .c function.
*
*Revisions:
* +-----+----------+---------------------------------------------------------+
* | Who |   Date   | Description                                             |
* +-----+----------+---------------------------------------------------------+
* | CH  | 07/07/30 | add flag so people with amt cannot have foreign tx credit |
* | LP  | 07/04/19 | Changed spouse cred transfer test from imicnet to imbpt |
* | CH  | 07/02/22 | Added CMSPINCFLAG                                       |
* | LP  | 07/02/15 | Added CMSPFLAG - B.C. Health Premium activation flag    |
* | LP  | 07/02/11 | Prov. pension credit now based on imipnst, not idipens  |
* | LP  | 07/01/23 | Removed imninc - no income flag - no longer used        |
* | LP  | 07/01/19 | Removed CUCCBITF-UCCB removed from income as per forms  |
* | LP  | 06/12/14 | Switched iminet to imicnet (income tax form concept)    |
* | LP  | 06/07/07 | Added CSUPCR - BC supplementary tax credit for 2000 and |
* |     |          | added CPTCREF - BC political tax credit refundable flag |
* | LP  | 06/07/04 | Added CSTCKID - BC sales tax credit amount for kids     |
* | LP  | 06/06/14 | Add imbcss (BC sen supp) to income tests (part of SA)   |
* | LP  | 06/06/13 | Add nneg to income tests that are reduced by imuccb     |
* | LP  | 06/06/09 | Removed phase-in parameters for BC family bonus         |
* | LP  | 06/06/09 | Removed CAXPI - no need for a phase-in for prov. age tc |
* | LP  | 06/06/07 | Added CUCCBITF - Flag to remove UCCB from income tests  |
* | LP  | 06/06/05 | Revised the application of PYINCP                       |
* | LP  | 06/05/26 | Added B.C. family bonus by calendar year code/parms     |
* | LP  | 06/05/15 | Added large corporation dividend tax credit rate CDTCRLC|
* | LP  | 05/11/03 | Revised p.t. educ. credit to allow disab students ft amt|
* | LP  | 05/05/09 | Added BC low inc. tax reduction CLITR, CLITRTD, CLITRRR |
* | LP  | 04/07/15 | Added B.C. Medical Service Plan (MSP) Premium (CMSP + ) |
* | LP  | 04/02/17 | Added idiworkc to income test for credits, family bonus |
* | LP  | 03/12/22 | Added CMEDALL and CMEDANF prov. non-ref medical exp cred|
* | LP  | 03/12/09 | Added impothpe, CODISTC infirm dep. (18+) tax credit    |
* | LP  | 03/11/17 | Added CCGTCOPT and revised caregiver credit calculation |
* | LP  | 03/11/17 | Added impintsl (provincial student loan interest credit)|
* |     |          | using the new database variable idintstu                |
* | LP  | 03/11/12 | Added ideducpm and AEDXPMPT - part-time months of educ. |
* | CH  | 03/10/17 | Deleted iddisab, replaced ideducm by ideducfm           |
* | LP  | 01/07/18 | Renamed impmincar to impminco                           |
* | LP  | 01/06/12 | Added impmincar - provincial minimum tax carryover cred.|
* | LP  | 01/05/09 | Added CAMTPCTM and added another option to CAMTOPT      |
* | BBM | 01/04/19 | Removed reference to idvencap (not on 9.0 dbase)        |
* | LP  | 01/03/07 | Added B.C. Home Heating Assistance Rebate               |
* | LP  | 01/03/07 | Removed CVCFLAG, CHCM and CPTC (pre 1988 parameters)    |
* | CH  | 00/10/24 | Added CPP deduction for the self-employed               |
* | CH  | 00/05/05 | Modified CGTC                                           |
* | CH  | 00/03/29 | Modified B.C. Family Bonus program                      |
* | CH  | 00/03/01 | Added provincial tax on taxable income                  |
* | LP  | 99/05/11 | Added B.C. Earned Income Benefit and changes to the     |
* |     |          |    B.C. Family Bonus Program to include federal WIS     |
* | CH  | 99/03/11 | Added labour-sponsored venture capital program and      |
* |     |          |    reordered modules                                    |
* | TCB | 98/05/28 | Renamed *.cpp, ANSI function headers                    |
* | CH  | 98/05/21 | Changed B.C Family Bonus Phase-in                       |
* | BBM | 97/10/07 | Implement B.C. Family Bonus                             |
* | RSE | 94/02/14 | changed sales tax credit to apply to nuclear families   |
* | RSE | 94/02/08 | add sales tax credit                                    |
* | RSE | 94/02/04 | put rent reduction flag in place                        |
* | GJC | 93/02/25 | add two-tiered surtax                                   |
* | BBM | 92/07/08 | Modeled provincial tax credits, drop reference to idptc |
* | SFG | 92/07/06 | Created                                                 |
* |     |          |                                                         |
* +-----+----------+---------------------------------------------------------+
*
*Definitions:
*   Atxbc    [global]  Compute provincial taxes for British Columbia
*
*****************************************************************************/


/* ==================== C-RUNTIME LIBRARY INCLUDE FILES =================== */

#include <stdio.h>  /* definitions/declarations for standard I/O routines   */


/* ==================== SPSD/M INCLUDE FILES ============================== */
/* #define DEBUG 1 */
#include "spsm.h"   /* SPSM common manifest constants and macros            */
#include "sub.h"    /* Subroutine library declarations                      */
#include "vsu.h"    /* Household variable sub-structure (user's)            */
#include "vs.h"     /* Household variable structure and sub-structures      */
#include "mpu.h"    /* Tax/transfer parameter declarations (user's)         */
#include "mp.h"     /* Tax/transfer parameter declarations                  */


/* ==================== GLOBAL VARIABLE DEFINITIONS ======================= */

/* Give global string describing version of this module */

/*global*/ char FAR Ttxbc[] = "Untitled"
#ifdef _MSC_VER
" [" __TIMESTAMP__ "]"
#endif
;




/* ==================== COMPILER PRAGMAS ================================== */

#ifdef MSCOVL

#endif


/* ==================== FUNCTION DEFINITIONS ============================== */


/*****************************************************************************
*Atxbc - Compute provincial taxes for British Columbia
*
*Synopsis:
*    void Atxbc(           
*    P_hh hh              
*    )                    
*
*Description:
*
*Return Value:
*   None.
*
*Calls:
*   nneg     Change negative numbers to zero
*   isnzero  Is argument non-zero ?
*   minn     Find the minimum of two numbers
*   lkup1    Table look-up with interpolation/extrapolation
*   txhhexp  Compute and pro-rate household taxes, rent, etc.
*   taxbak1  One level tax-back function
*   lkup2    Table look-up without interpolation
*
*Structure Members:
*   MP.BCBEIS1      (i)  B.C. Earned Income Benefit for first child
*   MP.BCBEIS1P     (i)  B.C. Earned Income Benefit for first child for 1st half of year
*   MP.BCBEIS2      (i)  B.C. Earned Income Benefit for second child
*   MP.BCBEIS2P     (i)  B.C. Earned Income Benefit for second child for 1st half of year
*   MP.BCBEIS3      (i)  B.C. Earned Income Benefit for each additional child
*   MP.BCBEIS3P     (i)  B.C. Earned Income Benefit for each additional child for 1st half of year
*   MP.BCBEITD      (i)  B.C. Earned Income Benefit Turndown
*   MP.BCBEITDP     (i)  B.C. Earned Income Benefit Turndown for 1st half of year
*   MP.BCBEMX       (i)  B.C. Earned Income Benefit Income Reduction
*   MP.BCBEMXP      (i)  B.C. Earned Income Benefit Income Reduction for 1st half of year
*   MP.BCBERR1      (i)  B.C. EIB reduction rate for families with 1 child
*   MP.BCBERR1P     (i)  B.C. EIB reduction rate for families with 1 child for 1st half of year
*   MP.BCBERR2      (i)  B.C. EIB reduction rate for families with 2 children
*   MP.BCBERR2P     (i)  B.C. EIB reduction rate for families with 2 children for 1st half of year
*   MP.BCBERR3      (i)  B.C. EIB reduction rate for families with 3+ children
*   MP.BCBERR3P     (i)  B.C. EIB reduction rate for families with 3+ children for 1st half of year
*   MP.BCEIBFLG     (i)  Activate B.C. Earned Income Benefit Program
*   MP.BCEIBFLGP    (i)  Activate B.C. Earned Income Benefit Program for 1st half of year
*   MP.BCEIBPI      (i)  B.C. Earned Income Benefit Income Phase In
*   MP.BCEIBPIP     (i)  B.C. Earned Income Benefit Income Phase In for 1st half of year
*   MP.BCFBBAS      (i)  B.C. Family Bonus amount per child
*   MP.BCFBBASP     (i)  B.C. Family Bonus amount per child for 1st half of year
*   MP.BCFBFLAG     (i)  Activate B.C. Family Bonus Program
*   MP.BCFBIFS      (i)  Activate B.C. Family Bonus to include Federal NCS
*   MP.BCFBIFSP     (i)  Activate B.C. Family Bonus to include Federal NCS for 1st half of year
*   MP.BCFBNCS1     (i)  B.C. Family Bonus National Child Supplement for first child
*   MP.BCFBNCS1P    (i)  B.C. Family Bonus National Child Supplement for first child for 1st half of year
*   MP.BCFBNCS2     (i)  B.C. Family Bonus National Child Supplement for second child
*   MP.BCFBNCS2P    (i)  B.C. Family Bonus National Child Supplement for second child for 1st half of year
*   MP.BCFBNCS3     (i)  B.C. Family Bonus National Child Supplement for each additional child
*   MP.BCFBNCS3P    (i)  B.C. Family Bonus National Child Supplement for each additional child for 1st half of year
*   MP.BCFBNCSRR1   (i)  B.C. Family Bonus NCS reduction rate for families with 1 child
*   MP.BCFBNCSRR1P  (i)  B.C. Family Bonus NCS reduction rate for families with 1 child for 1st half of year
*   MP.BCFBNCSRR2   (i)  B.C. Family Bonus NCS reduction rate for families with 2 children
*   MP.BCFBNCSRR2P  (i)  B.C. Family Bonus NCS reduction rate for families with 2 children for 1st half of year
*   MP.BCFBNCSRR3   (i)  B.C. Family Bonus NCS reduction rate for families with 3+ children
*   MP.BCFBNCSRR3P  (i)  B.C. Family Bonus NCS reduction rate for families with 3+ children for 1st half of year
*   MP.BCFBNCSTD    (i)  B.C. Family Bonus National Child Supplement Turndown
*   MP.BCFBNCSTDP   (i)  B.C. Family Bonus National Child Supplement Turndown for 1st half of year
*   MP.BCFBRR       (i)  B.C. Family Bonus multiple child reduction rate
*   MP.BCFBRRP      (i)  B.C. Family Bonus multiple child reduction rate for 1st half of year
*   MP.BCFBRRS      (i)  B.C. Family Bonus single child reduction rate
*   MP.BCFBRRSP     (i)  B.C. Family Bonus single child reduction rate for 1st half of year
*   MP.BCFBTD       (i)  B.C. Family Bonus Turndown
*   MP.BCFBTDP      (i)  B.C. Family Bonus Turndown for 1st half of year
*   MP.CAMTFTCFLG   (i)  B.C. amt flag for provincial foreign tax credit
*   MP.CAMTOPT      (i)  B.C. alternative minimum tax option
*   MP.CAMTPCTF     (i)  B.C. amt rate as pct of additional fed tax due to minimum tax
*   MP.CAMTPCTM     (i)  B.C. amt rate as pct of federal minimum tax amount
*   MP.CAMTTX       (i)  B.C. amt rate as tax on adjusted income
*   MP.CAXM         (i)  B.C. Age Amount
*   MP.CAXRR        (i)  B.C. Age Amount credit reduction rate
*   MP.CAXTD        (i)  B.C. Age Amount net income turndown
*   MP.CBXM         (i)  B.C. Basic Personal Exemption/amount
*   MP.CCGTC        (i)  B.C. Caregiver Tax Credit
*   MP.CCGTCFLG     (i)  B.C. Caregiver Tax Credit activation flag
*   MP.CCGTCOPT     (i)  B.C. Caregiver Tax Credit Option (1=max, 2=greenbook)
*   MP.CCHATL1      (i)  B.C. Charitable Donations amount level 1
*   MP.CCHATR1      (i)  B.C. Charitable Donations tax credit rate 1
*   MP.CCHATR2      (i)  B.C. Charitable Donations tax credit rate 2
*   MP.CDTCR        (i)  B.C. dividend tax credit rate
*   MP.CDTCRLC      (i)  B.C. dividend tax credit rate from large (eligible) corporations
*   MP.CEDXPM       (i)  B.C. Education Amount per month of full-time studies
*   MP.CEDXPMPT     (i)  B.C. Education Amount per month of part-time studies
*   MP.CEMXM        (i)  B.C. equivalent to married amount
*   MP.CEMXMT       (i)  B.C. equivalent to married turndown level
*   MP.CHEATFAM     (i)  British Columbia Refundable Energy Credit for families
*   MP.CHEATFLG     (i)  British Columbia Refundable Energy Credit activation flag
*   MP.CHEATSNG     (i)  British Columbia Refundable Energy Credit for singles
*   MP.CLITR        (i)  B.C. Low Income Tax Reduction Credit
*   MP.CLITRRR      (i)  B.C. Low Income Tax Reduction Credit reduction rate
*   MP.CLITRTD      (i)  B.C. Low Income Tax Reduction Credit net income turndown
*   MP.CLVCMAX      (i)  Maximum B.C. labour-sponsored funds tax credit allowed
*   MP.CLVCRT       (i)  Percent of B.C. labour-sponsored funds cost allowed as credit
*   MP.CMAXDX       (i)  B.C. Maximum Disability deduction/amount
*   MP.CMAXET       (i)  B.C. maximum on transfer of education and tuition amount
*   MP.CMEDALL      (i)  B.C. Medical allowance maximum lower limit
*   MP.CMEDANF      (i)  B.C. Medical allowance lower limit net income fraction
*   MP.CMSP         (i)  B.C. Medical Services Plan Premium [family size, amount]
*   MP.CMSPADED     (i)  B.C. Medical Services Plan Age 65+ Deduction
*   MP.CMSPCDED     (i)  B.C. Medical Services Plan Child Deduction
*   MP.CMSPDDED     (i)  B.C. Medical Services Plan Disability Deduction
*   MP.CMSPFLAG     (i)  B.C. Medical Services Plan activation flag
*   MP.CMSPINCFLAG  (i)  B.C. Medical Services Plan flag to give to highest earner
*   MP.CMSPRATE     (i)  B.C. Medical Services Plan Subsidy Rate [income, rate]
*   MP.CMSPRATErows (i)  number of rows in CMSPRATE
*   MP.CMSPSDED     (i)  B.C. Medical Services Plan Spouse Deduction
*   MP.CMSProws     (i)  number of rows in CMSP
*   MP.CMXM         (i)  B.C. married amount
*   MP.CMXMT        (i)  B.C. married amount turndown level
*   MP.CODISTC      (i)  B.C. Maximum infirm dependent 18 or older tax credit
*   MP.CPNTCR       (i)  B.C. provincial non-refundable tax credit rate
*   MP.CPTCBEN      (i)  Maximum B.C. political tax credit allowed
*   MP.CPTCREF      (i)  British Columbia political tax credit refundable flag
*   MP.CPTCT        (i)  B.C. political contribution table [total donations,donation allowed]
*   MP.CPTCTrows    (i)  number of rows in CPTCT
*   MP.CPTF         (i)  British Columbia provincial tax fraction
*   MP.CPTX         (i)  B.C. tax table [taxable income,basic provincial tax]
*   MP.CPTXrows     (i)  number of rows in CPTX
*   MP.CRFLAG       (i)  British Columbia rental reduction flag
*   MP.CRTRB        (i)  British Columbia renter tax reduction basic credit
*   MP.CRTRD        (i)  British Columbia renter tax reduction credit for other dependants
*   MP.CRTRP        (i)  British Columbia renter tax reduction proportion of rent allowed
*   MP.CRTRPN       (i)  British Columbia renter tax reduction proportion of net income
*   MP.CRTRS        (i)  British Columbia renter tax reduction credit for spouse
*   MP.CRTRT        (i)  B.C. renter tax reduction base amount turndown [dependants, amount]
*   MP.CRTRTrows    (i)  number of rows in CTCTUR
*   MP.CSCI         (i)  British Columbia surtax first cut-in level
*   MP.CSCI2        (i)  British Columbia surtax second cut-in level
*   MP.CSDC         (i)  British Columbia provincial surtax dependant credit
*   MP.CSF          (i)  British Columbia surtax first level rate
*   MP.CSF2         (i)  British Columbia surtax second level rate
*   MP.CSTC         (i)  British Columbia stc amount
*   MP.CSTCFLAG     (i)  British Columbia sales tax credit flag
*   MP.CSTCKID      (i)  British Columbia stc amount for children
*   MP.CSTCR        (i)  British Columbia stc reduction rate
*   MP.CSTHINC      (i)  British Columbia family head income threshold (stc)
*   MP.CSTKINC      (i)  British Columbia kid income threshold top-up (stc)
*   MP.CSTSINC      (i)  British Columbia spousal income threshold top-up (stc)
*   MP.CSUPCR       (i)  British Columbia supplemental tax credit
*   MP.CTCINC       (i)  Refundable CTC family income scaling factor
*   MP.CTXFLG       (i)  B.C. tax on taxable income activation flag
*   MP.CYPNDL       (i)  B.C. Pension Income Deduction Amount
*   MP.FCBENCAL     (i)  Calculate child benefits for calendar year flag
*   MP.HEATSNG      (i)  Federal relief for heating expenses for singles
*   MP.PYINC        (i)  Deflator to calculate previous year income
*   MP.PYINCP       (i)  Deflator to calculate income from 2 years prior
*   cf.cfin         (i)  First person in census family [pointer]
*   cf.cfinch       (i)  First child in census family [pointer]
*   cf.cfineld      (i)  Eldest person in census family [pointer]
*   cf.cfinspo      (i)  Spouse of eldest [pointer]
*   cf.cfnchild     (i)  Number of children (including 18+)
*   cf.cfnkids      (i)  Number of children in census family
*   cf.cfnpers      (i)  Number of persons in census family
*   cf.cfspoflg     (i)  Census family contains married couple
*   hh.cf           (i)  Census family data [array]
*   hh.hhncf        (i)  Number of census families in household
*   hh.hhnin        (i)  Number of individuals in household
*   hh.hhnnf        (i)  Number of nuclear families in household
*   hh.in           (i)  Individual data [array]
*   hh.nf           (i)  Nuclear family data [array]
*   id.idage        (i)  Age
*   id.idcf         (i)  Person's census family [pointer]
*   id.idcfrh       (i)  Relationship to census family head
*   id.idcgtc       (i)  Caregivers tax credit (database) (315)
*   id.iddisoth     (i)  Disability amount for dependants (318)
*   id.iddisslf     (i)  Disability amount for self (316)
*   id.ideducfm     (i)  Eligible full-time months of education
*   id.ideducpm     (i)  Eligible part-time months of education
*   id.idestat      (i)  Educational status
*   id.ididiv       (i)  Dividend income (actual)
*   id.idiemp       (i)  Wages & salaries
*   id.idinspo      (i)  Person's spouse [pointer]
*   id.idintstu     (i)  Interest paid on student loans (319)
*   id.idisefm      (i)  Self-employed income - farming
*   id.idisenf      (i)  Self-employed income - non-farming
*   id.idlabtxg     (i)  Gross Labour funds bought (413)
*   id.idmedgro     (i)  Medical expenses, gross (330)
*   id.idmincar     (i)  Minimum tax carryover (504)
*   id.idnf         (i)  Person's nuclear family [pointer]
*   id.idothpe      (i)  Amounts for Infirm Dependants (306)
*   id.idprvftc     (i)  Provincial foreign tax credit (Form T2036)
*   id.idprvpol     (i)  Provincial political contributions (565)
*   id.idsex        (i)  Sex
*   id.idspoflg     (i)  Person has spouse
*   id.idtuitn      (i)  Tuition fees (320)
*   im.imamtfg      (i)  Minimum tax flag
*   im.imamtinc     (i)  Net adjusted income used for minimum tax
*   im.imamtprv     (i)  Federal minimum tax concept used for provincial minimum tax
*   im.imbft        (i)  Basic federal tax
*   im.imccea       (i)  Child care expenses allowed
*   im.imchara      (i)  Allowable charitable donations and gifts (calculated)
*   im.imchclm      (i)  Number of dependent children claimed
*   im.imcppse      (i)  CPP contributions deduction for self-emp
*   im.imcqppc      (i)  CPP/QPP contributions
*   im.imdedfn      (i)  All deductions from net income
*   im.imdepni      (i)  Dependant's net income
*   im.imfcbene     (i)  Total Federal Child Benefit Supplement
*   im.imheatrl     (i)  Federal relief for heating expenses
*   im.imicnet      (i)  Net Income (line 236)
*   im.imildivt     (i)  Dividend income from large (eligible) corporations (taxable)
*   im.imipnst      (i)  Taxable pension income (after splitting)
*   im.imisdivt     (i)  Dividend income from small corporations (taxable)
*   im.imitax       (i)  Taxable income
*   im.immartxc     (i)  Married tax credit claimed
*   im.imminamt     (i)  Minimum Amount due to Federal Minimum Tax
*   im.imrentpd     (i)  Imputed rent paid
*   im.imuccb       (i)  Universal Child Care Benefit amount
*   im.imuic        (i)  UIC contributions
*   nf.nfineld      (i)  Eldest person in nuclear family [pointer]
*   nf.nfinspo      (i)  Spouse of eldest [pointer]
*   nf.nfnkids      (i)  Number of children in nuclear family
*   nf.nfspoflg     (i)  Nuclear family contains married couple
*   im.imbpt        (io) Basic provincial tax
*   im.imnptc       (io) Non-refundable provincial tax credits
*   im.impatxc      (io) Prov Age amount tax credit
*   im.impbtc       (io) Prov Basic amount
*   im.impcgtc      (io) Prov Caregiver Tax Credit Level
*   im.impchrtc     (io) Prov Charitable Donations tax credit
*   im.impcpptc     (io) Prov CPP/QPP contributions tax credit
*   im.impdistc     (io) Prov Disability tax credit
*   im.impdtxc      (io) Provincial dividend tax credit
*   im.impedtxc     (io) Prov Education tax credit
*   im.impintsl     (io) Provincial interest on student loans tax credit
*   im.implvctc     (io) Provincial labour-sponsored funds tax credit
*   im.impmartc     (io) Prov Married and Equivalent to Married tax credit
*   im.impmeda      (io) Prov Medical expenses allowed (computed)
*   im.impmedtc     (io) Prov Medical Expenses tax credit
*   im.impminco     (io) Prov Minimum tax carryover
*   im.impothpe     (io) Provincial infirm dependents 18 or older tax credit
*   im.imppentc     (io) Prov Pension Income tax credit
*   im.impptc       (io) Provincial Political Contrib Tax Credit
*   im.imprvtax     (io) Prov gross provincial tax
*   im.impsur       (io) Provincial surtax
*   im.imptaxcr     (io) Prov total tax credits
*   im.imptc        (io) Refundable provincial tax credits
*   im.imptr        (io) Provincial tax reduction
*   im.impttxct     (io) Prov total tax credits transferred
*   im.imptutxc     (io) Prov Tuition tax credit
*   im.impuictc     (io) Prov UI/EI contributions tax credit
*   im.imtxp        (io) Provincial income tax payable
*   im.imibceib     (o)  B.C. Earned Income Benefit
*   im.imibcfb      (o)  B.C. Family Bonus
*   im.impatxcr     (o)  Prov total tax credits applied
*   im.impctxct     (o)  Prov tax credits transferred from children
*   im.impheatr     (o)  Provincial Home Heating Fuel/Energy Rebate
*   im.imphp        (o)  Provincial Health Premium
*   im.impstxct     (o)  Prov tax credits transferred from spouse
*
*Called by:
*   txprov   Compute provincial taxes
*
*****************************************************************************/
void Atxbc(
    P_hh hh
)
{
    register P_in ineld;
    register P_in inspo;
    register int ini;
    register int nfi;
    register P_in in;
    register P_cf cf;    
    register P_nf nf;
    register int cfi;
    NUMBER rrinet=ZERO;     /* Census Family net income for rtr */
    NUMBER nrrinet=ZERO;    /* Census Family net income for rtr after reduction */
    NUMBER depred=ZERO;      /* base amount reduction for rtr */
    NUMBER rtrcred=ZERO;     /* applied credits to rtr */
    NUMBER nrtr=ZERO;        /* Net renters tax reduction */
    NUMBER trcr=ZERO;        /* tax reduction credits */
    NUMBER tr=ZERO;          /* tax reduction */
    NUMBER rtr=ZERO;         /* residual tax reduction for transfer */
    NUMBER poltcr = ZERO;    /* Political tax credit (raw) */
    NUMBER poltc = ZERO;     /* Political tax credit */
    NUMBER stcinet=ZERO;     /* Nuclear family net income for sales tax credit */
    NUMBER thrinc = ZERO;    /* Sales tax credit: income level for head */
    NUMBER bcstc  = ZERO;    /* Sales tax credit: level */
    NUMBER ninctx = ZERO;    /* net income tax after stc application */
    NUMBER famrent= ZERO;    /* rent paid by the entire CF */
    NUMBER nfinet = ZERO;    /* net income for taxback of Family Bonus */
    NUMBER nfiemp = ZERO;    /* net employment income for taxback of Earned Income Benefit */
    NUMBER nffben = ZERO;    /* federal benefit supplement */
    NUMBER bonus = ZERO;     /* B.C. Family Bonus */
    NUMBER bonus1 = ZERO;     /* B.C. Family Bonus */
    NUMBER bonus2 = ZERO;     /* B.C. Family Bonus */
    int csndep;              /* BC surtax-number of dependants */
    NUMBER lvctc = ZERO;   /* Labour-sponsored venture capital tax cred */
    NUMBER bceiben = ZERO;    /* B.C. Earned Income Benefit amount */
    NUMBER fbncs1 = ZERO;   /* Family Bonus National Child Supplement */
    NUMBER fbncsrr1 = ZERO;   /* Family Bonus National Child Supplement reduction */
    NUMBER bceibmax1 = ZERO;    /* B.C. Earned Income Benefit maximum amount */
    NUMBER bceiben1 = ZERO;    /* B.C. Earned Income Benefit amount */
    NUMBER bceibrr1 = ZERO;    /* B.C. Earned Income Benefit reduction rate */
    NUMBER fbncs2 = ZERO;   /* Family Bonus National Child Supplement */
    NUMBER fbncsrr2 = ZERO;   /* Family Bonus National Child Supplement reduction */
    NUMBER bceibmax2 = ZERO;    /* B.C. Earned Income Benefit maximum amount */
    NUMBER bceiben2 = ZERO;    /* B.C. Earned Income Benefit amount */
    NUMBER bceibrr2 = ZERO;    /* B.C. Earned Income Benefit reduction rate */
    NUMBER mineinc1 = ZERO;    /* minimum between earned income and turndown */
    NUMBER mineinc2 = ZERO;    /* minimum between earned income and turndown */
    NUMBER mspnkids = ZERO;   /* number of kids in family for MSP premium deduction */
    NUMBER mspndis = ZERO;    /* number of disabled in family for MSP premium deduction */
    NUMBER mspnpers = ZERO;   /* number of persons in family for MSP premium calculation */
    NUMBER mspprem = ZERO;    /* MSP premium calculation */
    NUMBER adjninc = ZERO;    /* MSP adjusted net income for MSP premium deduction */
    NUMBER ccexp = ZERO;      /* Child care expenses claimed for MSP premium deduction */
    NUMBER mspded = ZERO;     /* MSP premium deduction */
    NUMBER premrate = ZERO;   /* MSP premium rate after premium assistance */  
	NUMBER litr = ZERO;       /* B.C. low income tax reduction amount */
	NUMBER netinc = ZERO;     /* B.C. low income tax reduction net income */
	NUMBER bcsupc = ZERO;     /* B.C. supplemental tax credit */

    DEBUG_ON("Atxbc");

    /*******************************************************************
    *****  Calculations for tax on taxable income, 
    ********************************************************************/

    if (MP.CTXFLG) { 

       /* process each census family in household */
       for (cfi=0, cf=&hh->cf[0]; cfi<hh->hhncf; cfi++, cf++) {

          /* Do needed declarations/initialisations for each census family */
          NUMBER ctxcrt = ZERO;   /* total children's transferable credits  */
          NUMBER tfr1 = ZERO;     /* transfer type 1 */
          NUMBER tfr2 = ZERO;     /* tranfer type 2 */
          NUMBER txcrt = ZERO;    /* tax credits */
          NUMBER agered = ZERO;
          NUMBER adjamt = ZERO;	
		  NUMBER netinc = ZERO;

          NUMBER cemc   = ZERO;   /* value of equivalent to married tax credit */
          NUMBER cinet   = ZERO;   /* value of current child's income */
          NUMBER minet   = ZERO;   /* value of child's income for child with least income */
          NUMBER inetfg   = ZERO;   /* went through process once */

          /*******************************************************************
          *****  Calculation of married and equivalent to married tax credits
          ********************************************************************/
         
          /* calculate equivalent to married credit */
 
          /* process children in census family */
          for (ini=0, in=cf->cfinch; ini<cf->cfnchild; ini++, in++) {
             /* Filter condition (ineligible for EM credit)  */
             if (in->id.idage > 18) {
                continue;
             }
             cinet = in->im.imdepni;
             /* calculate EM credit if income is lower or if not done before */
             if (!cf->cfspoflg && (inetfg==ZERO || minet > cinet)) {
                inetfg=1;
                minet = cinet;
                cemc = MP.CPNTCR * nneg(MP.CEMXM - nneg(cinet - MP.CEMXMT));
             }
          }
          /* initialise pointers for head and spouse modelled variables */
          ineld = cf->cfineld;
          inspo = cf->cfinspo;     /* NB: is NULL if no spouse present */

          if (cf->cfspoflg) {
             DEBUG1("%s spouse present\n");
             /**
             * If the net income of the head is greater than the net
             * income of the spouse, the head gets the married
             * exemption 
             **/
             if (ineld->im.imicnet >= inspo->im.imicnet) {
                DEBUG1("%s head receives married tax credit\n");
                ineld->im.impmartc = MP.CPNTCR * nneg(MP.CMXM - nneg(inspo->im.imdepni - MP.CMXMT));
             }
             else {
                DEBUG1("%s spouse receives married tax credit\n");
                inspo->im.impmartc = MP.CPNTCR * nneg(MP.CMXM - nneg(ineld->im.imdepni - MP.CMXMT));
             }
          }
          else { /* no spouse present */
             ineld->im.impmartc = cemc;
          }
     
          /* note, we are already in a census family loop */
 
          /* process persons in census family */
          for (ini=0, in=cf->cfin;  ini<cf->cfnpers;  ini++, in++) {
             /*********************************************************
             *****  Calculation of non-family tax credits
             **********************************************************/

			 /* calculate caregivers tax credit */
			 if (MP.CCGTCFLG && isnzero(in->id.idcgtc)) {
				/* if AGCTGOPT == 1 then */
				/* apply the maximum amount if they have any caregivers amount */
				 if (MP.CCGTCOPT == 1) {
					in->im.impcgtc = MP.CCGTC * MP.CPNTCR;
				 }
				 else {   /* use the greenbook imputed amount */
				 	in->im.impcgtc = in->id.idcgtc * MP.CPNTCR;
				 }
				 DEBUG2("%s cgtc =%.2f\n", in->im.impcgtc);
			 }

             /* calculate cpp/qpp contributions tax credit  */
             in->im.impcpptc = (in->im.imcqppc - in->im.imcppse) * MP.CPNTCR;
             DEBUG2("%s cppctc =%.2f\n", in->im.impcpptc);

             /* calculate ui contributions tax credit  */
             in->im.impuictc = in->im.imuic * MP.CPNTCR;
             DEBUG2("%s uctc  =%.2f\n", in->im.impuictc);

             /* calculate tuition tax credit */
             if (isnzero(in->id.idtuitn)) {
                in->im.imptutxc = in->id.idtuitn * MP.CPNTCR;
                DEBUG2("%s tutxc  =%.2f\n", in->im.imptutxc);
             }

             /* calculate personal tax credit */
             in->im.impbtc = MP.CPNTCR * MP.CBXM;
                DEBUG2("%s btc    =%.2f\n", in->im.impbtc);

			 /*  Calculate the net income concept to match tax forms */
			 /*  This income is used in the age and medical tax credit income tests */

			 netinc = in->im.imicnet;

             /*  calculate age amount tax credit  */
             if (in->id.idage >= 65) {
                DEBUG1("%s age tax credit\n");
                agered = minn(MP.CAXM, MP.CAXRR * nneg(netinc - MP.CAXTD));
                adjamt = MP.CAXM - agered;
                in->im.impatxc = MP.CPNTCR * adjamt;
             }
             DEBUG2("%s atxc   =%.2f\n", in->im.impatxc);

             /* calculate prov pension income tax credit    */
             in->im.imppentc = MP.CPNTCR * minn(MP.CYPNDL, in->im.imipnst);
             DEBUG2("%s pentxc =%.2f\n", in->im.imppentc);
 
			 /* compute allowable medical expenses using the value on the database */
			 if (isnzero(in->id.idmedgro)) {
			 	in->im.impmeda = nneg(in->id.idmedgro -
			 		minn(MP.CMEDALL, MP.CMEDANF * netinc));
			  	DEBUG3("%s idmedgro= %.2f impmeda =%.2f\n",
			  		in->id.idmedgro, in->im.impmeda);
			 }

			 /* calculate medical expenses tax credit */
			 if (isnzero(in->im.impmeda)) {
			  	in->im.impmedtc = in->im.impmeda * MP.CPNTCR;
			   	DEBUG2("%s pmedtc =%.2f\n", in->im.impmedtc);
			 }

			 /* calculate amount for infirm dependents age 18 or older */
			 /*  if the filer has an amount for idothpe, then give max credit */

			 if (isnzero(in->id.idothpe)) {
   				in->im.impothpe = MP.CPNTCR * MP.CODISTC;
                DEBUG2("%s othpe =%.2f\n", in->im.impothpe);
			 }
		     
             /* calculate prov charitable donations tax credit */
             if (isnzero(in->im.imchara)) {
                in->im.impchrtc = (minn(MP.CCHATL1, in->im.imchara)  * MP.CCHATR1
                            + nneg(in->im.imchara - MP.CCHATL1) * MP.CCHATR2);
                DEBUG2("%s chartc =%.2f\n", in->im.impchrtc);
             }
 
             /* set prov disability tax credit for self to maximum    */
             if (isnzero(in->id.iddisslf)) {
                in->im.impdistc = MP.CPNTCR * MP.CMAXDX;
             }
             DEBUG2("%s disatc =%.2f\n", in->im.impdistc);

             /* set disability tax credit for other to maximum    */
             if (isnzero(in->id.iddisoth)) {
               in->im.impdistc += (MP.CPNTCR * MP.CMAXDX);
             }
             DEBUG2("%s disatc =%.2f\n", in->im.impdistc);

             /* calculate prov education allowance tax credit */
             if (isnzero(in->id.ideducfm)) {
                in->im.impedtxc = MP.CPNTCR * (in->id.ideducfm * MP.CEDXPM);
                DEBUG2("%s edtxc  =%.2f\n", in->im.impedtxc);
             }

			 /*  add in the tax credit amount associated with part-time studies */
			 if (isnzero(in->id.ideducpm)) {
				if (isnzero(in->id.iddisslf) && in->id.ideducfm == 0 ) {
				    /* give only part time students the full time credit
					   if they also have an amount for disability */
					in->im.impedtxc = MP.CPNTCR * (in->id.ideducpm * MP.CEDXPM);
				}
				else {  /* has some part and/or full time and not disabled */
					in->im.impedtxc += MP.CPNTCR * (in->id.ideducpm * MP.CEDXPMPT);
                	DEBUG2("%s edtxc  =%.2f\n", in->im.impedtxc);
				}
			 }

			 /* calculate the interest paid on student loans tax credit */
			 /*  new for version 10.0, apply the Greenbook value idintstu */
			 if (isnzero(in->id.idintstu)) {
				in->im.impintsl = MP.CPNTCR * in->id.idintstu;
				DEBUG2("%s intsl =%.2f\n", in->im.impintsl);
			 }

             /* calculate federal dividend tax credit */
             if (isnzero(in->id.ididiv)) {
                in->im.impdtxc = (in->im.imisdivt * MP.CDTCR)
                				+ (in->im.imildivt * MP.CDTCRLC);
                DEBUG2("%s fdtxc  =%.2f\n", in->im.impdtxc);
             }

			 /* calculate the British Columbia minimum tax carry-over tax credit */
			 if (isnzero(in->id.idmincar)) {
				if (MP.CAMTOPT == 2) {
				   /* Alternative minimum taxes are calculated, use CAMTPCTF, the
				   /*  amt rate as pct of additional fed tax due to minimum tax
				   /*  to calculte the minimum tax carry-over credit. */
				   in->im.impminco = in->id.idmincar * MP.CAMTPCTF;
				 }
				 else if (MP.CAMTOPT == 3) { 
						/* Alternative minimum taxes are calculated using CAMTTX. */
						in->im.impminco = in->id.idmincar * MP.CAMTTX;
					  }
				 else if (MP.CAMTOPT == 4) {
						/* Alternative minimum taxes are calculated using CAMTPCTM. */
						 in->im.impminco = in->id.idmincar * MP.CAMTPCTM;
				 }
				 DEBUG2("%s pminco =%.2f\n", in->im.impminco);
			 }
            
             /*********************************************************
             *****  Calculation of basic personal tax
             **********************************************************/
            
             /* calculate provincial tax before tax credits    */
             /* if alternative minimum tax , option 3 = tax structure on federal net adjusted income */
             if (in->im.imamtfg && MP.CAMTOPT == 3) {
                in->im.imprvtax = MP.CAMTTX * in->im.imamtinc;
             }
             else {
                in->im.imprvtax = (NUMBER) lkup1(MP.CPTX, MP.CPTXrows, in->im.imitax);
             }
             in->im.imbpt = in->im.imprvtax;

             /* census family children */
             if (in->id.idcfrh >= 2) {
                /* total non-transferable tax credits applicable to dependent */
                in->im.imptaxcr = in->im.impbtc      /* basic personal tax credit       */
                        + in->im.impatxc     /* age tax credit                  */
                        + in->im.impothpe    /* infirm dependents 18 and older tax credit */
                        + in->im.impchrtc   /* charitable donations tax credit */
                        + in->im.impcpptc   /* CPP contributions tax credit    */
                        + in->im.impmedtc   /* medical expenses tax credit     */
                        + in->im.imppentc   /* pension income tax credit       */
                        + in->im.impuictc    /* UI contributions tax credit     */
                        + in->im.impdtxc    /* provincial dividend tax credit     */
                        + in->im.impcgtc     /* caregiver tax credit                  */
                        + in->im.impminco    /* provincial minimum tax carryover credit */
						+ in->im.impintsl   /* provincial interest on student loans credit */
                        ;
                DEBUG2("%s child's  non-transferable tax credits=%.2f\n",
                        in->im.imtaxcr);
                in->im.impatxcr = ZERO;
                if (isnzero(in->im.imptaxcr)) {
                   /* if child's basic federal tax is more than transferable */
                   /* tax credits, apply total amount to reduce tax          */
                   if (in->im.imbpt > in->im.imptaxcr) {
                      in->im.impatxcr += in->im.imptaxcr;
                      in->im.imbpt -= in->im.imptaxcr;
                   }
                   else { /* in->im.imbpt <= in->im.imptaxcr */
                      in->im.impatxcr += in->im.imbpt;
                      in->im.imbpt = ZERO;
                   }
                   DEBUG3("%s child's bft    =%.2f, atxcrt=%.2f\n",
                         in->im.imbpt, in->im.impatxcr);
                }
                /* total transferable tax credits must be processed in 2 parts*/
                /* tfr2 contains the education allowance and tuition tax      */
                /*      credits which are subject to a maximum transferable   */
                /*      calculation dependent on the parameter MAXET          */
                /* tfr1 contains all other transferable tax credits           */
                tfr1 = in->im.impdistc;
                tfr2 = in->im.impedtxc + in->im.imptutxc;
                txcrt = tfr1 + tfr2;
                DEBUG2("%s child's  transferable tax credits    =%.2f\n", txcrt);
                in->im.imptaxcr += txcrt;
                if (isnzero(txcrt)) {
                   /* if child's basic federal tax is more than transferable */
                   /* tax credits, apply total amount to reduce tax          */
                   if (in->im.imbpt > txcrt) {
                      in->im.impatxcr += txcrt;
                      /* in->im.imttxcrt = 0.0  and no need to increase ctxcrt  */
                      in->im.imbpt -= txcrt;
                   }
                   else { /* txcrt >= in->im.imbpt */
                      /* the child has some tax credit left for a parent    */
                      /* reduce basic federal tax to zero and calculate     */
                      /* actual amount of transferable tax credits          */
                      in->im.impatxcr += in->im.imbpt;
                      in->im.imbpt = ZERO;
                      tfr2 = minn(MP.CPNTCR * MP.CMAXET,tfr2);
                      /* first calculate disability credit, then education amount */
  
                      tfr1 = nneg(tfr1  /* disability credit */
                              - nneg( (MP.CPNTCR * in->im.imitax)     /* taxable income * credit tax rate 
                                                                            to preserve idendity */
                                      - in->im.impbtc      /* basic personal tax credit       */
                                      - in->im.impatxc     /* age tax credit                  */
                                     /* next two credits equal zero for CF children */
                                     /*- in->im.immartxc      married tax credit */
                                     - in->im.impcpptc   /* CPP contributions tax credit    */
                                     - in->im.impuictc    /* UI contributions tax credit     */
                                     - in->im.imppentc));  /* pension income tax credit       */

                      tfr2 = nneg(tfr2  /* education and tuition */
                              - nneg( (MP.CPNTCR * in->im.imitax)     /* taxable income * credit tax rate 
                                                                         to preserve idendity */
                                    - in->im.impbtc      /* basic personal tax credit       */
                                    - in->im.impatxc     /* age tax credit                  */
                                    /* next two credits equal zero for CF children */
                                    /*- in->im.immartxc      married tax credit */
                                    - in->im.impcpptc   /* CPP contributions tax credit    */
                                    - in->im.impuictc    /* UI contributions tax credit     */
                                    - in->im.imppentc));  /* pension income tax credit       */

             
                      in->im.impttxct = tfr1+tfr2;
                      /* add extra to family ctxcrt */
                      ctxcrt += in->im.impttxct;
                      DEBUG2("%s ctxcrt = %.2f\n", ctxcrt);
                   }
                }
                DEBUG4("%s child's bft    =%.2f, atxcrt=%.2f, ttxcrt=%.2f\n",
                      in->im.imbpt, in->im.impatxcr, in->im.impttxct);
             }

             /* head or spouse of census family */
             if (in->id.idcfrh < 2) {
                /* total non-transferable tax credits applicable to parent */
                in->im.imptaxcr = in->im.impbtc      /* basic personal tax credit       */
                       + in->im.impothpe    /* infirm dependents 18 and older tax credit */
                       + in->im.impchrtc   /* charitable donations tax credit */
                       + in->im.impcpptc   /* CPP contributions tax credit    */
                       + in->im.impmartc   /* married tax credit              */
                       + in->im.impmedtc   /* medical expenses tax credit     */
                       + in->im.impuictc    /* UI contributions tax credit     */
                       + in->im.impdtxc    /* provincial dividend tax credit     */
					   + in->im.impminco   /* provincial minimum tax carryover credit */
					   + in->im.impintsl  /* provincial interest on student loans credit */
                       ;
                DEBUG2("%s parent's non-transferable tax credits=%.2f\n",
                     in->im.imptaxcr);
                in->im.impatxcr = ZERO;
                if (isnzero(in->im.imptaxcr)) {
                   /* if parent's basic federal tax is more than transferable */
                   /* tax credits, apply total amount to reduce tax          */
                   if (in->im.imbpt > in->im.imptaxcr) {
                      in->im.impatxcr += in->im.imptaxcr;
                      in->im.imbpt -= in->im.imptaxcr;
                   }
                   else { /* in->im.imbpt <= in->im.imptaxcr */
                      in->im.impatxcr += in->im.imbpt;
                      in->im.imbpt = ZERO;
                   }
                   DEBUG3("%s parent's bft   =%.2f, atxcrt=%.2f\n",
                         in->im.imbpt, in->im.impatxcr);
                }
                /* total transferable tax credits must be processed in 2 parts*/
                /* tfr2 contains the education allowance and tuition tax      */
                /*      credits which are subject to a maximum transferable   */
                /*      calculation dependent on the parameter MAXET          */
                /* tfr1 contains all other transferable tax credits           */
                tfr1 = in->im.impatxc   /* age tax credit                        */
                    + in->im.impdistc   /* disability tax credit                 */
                    + in->im.impcgtc    /* caregiver tax credit                  */
                    + in->im.imppentc   /* pension income tax credit             */
                    ;
                tfr2 = in->im.impedtxc + in->im.imptutxc;
                txcrt = tfr1 + tfr2;
                DEBUG2("%s parent's transferable tax credits    =%.2f\n", txcrt);
                in->im.imptaxcr += txcrt;
                if (isnzero(txcrt)) {
                   /* if basic federal tax is more than transferable         */
                   /* tax credits, apply total amount to reduce tax          */
                   if (in->im.imbpt > txcrt) {
                      in->im.impatxcr += txcrt;
                      /* in->im.impttxct = 0.0 */
                      in->im.imbpt -= txcrt;
                   }
                   else { /* txcrt >= in->im.imbpt */
                      /* the parent has some tax credits left for a         */
                      /* their spouse (if present) so reduce basic federal  */
                      /* tax to zero and calculate actual amount of         */
                      /* transferable tax credits                           */
                      in->im.impatxcr += in->im.imbpt;
                      in->im.imbpt = ZERO;
  
                      tfr2 = minn(MP.CPNTCR * MP.CMAXET, tfr2);
                       /* NB: use expanded net income (as on tax form) */
                      /* follows Schedule 2 */
                      in->im.impttxct = nneg(tfr1 + tfr2
                                         - MP.CPNTCR * nneg(in->im.imdepni -in->im.imdedfn - MP.CBXM -
                                                         (in->im.imcqppc - in->im.imcppse) - in->im.imuic));
   
                   }
                }
                DEBUG4("%s parent's bft   =%.2f, atxcrt=%.2f, ttxcrt=%.2f\n",
                    in->im.imbpt, in->im.impatxcr, in->im.impttxct);
             } /* end of head/spouse */
          } /* end of person in census family loop.  
              we are still in a census family loop */                           

          /* if there is a spouse in the family */
          if (cf->cfspoflg) {
             DEBUG1("%s spouse present\n");
 
             /* if provincial taxes owing of the elder is greater than the taxes   */
             /* owing of the spouse, the elder receives any tax credits  */
             /* not needed by the spouse and children                    */
             /* The impcgtc will be claimed by the person with the most taxes owing */
             if (ineld->im.imbpt >= inspo->im.imbpt) {
                txcrt = inspo->im.impttxct + ctxcrt;
                ineld->im.imptaxcr += txcrt;
                DEBUG2("%s elder receives transfered tax credits=%.2f\n", txcrt);
                ineld->im.impstxct = inspo->im.impttxct;
                ineld->im.impttxct = ZERO;
                ineld->im.impctxct = ctxcrt;
                if (isnzero(txcrt)) {
                   /* if basic federal tax is more than transfered           */
                   /* tax credits, apply total amount to reduce tax          */
                   if (ineld->im.imbpt > txcrt) {
                      ineld->im.impatxcr += txcrt;
                      ineld->im.imbpt -= txcrt;
                   }
                   else { /* txcrt >= ineld->im.imbpt */
                      ineld->im.impatxcr += ineld->im.imbpt;
                      ineld->im.imbpt = ZERO;
                   }     
                }
                DEBUG4("%s elder's bft  =%.2f, stxcrt=%.2f, ctxcrt=%.2f\n",
                    ineld->im.imbpt, ineld->im.imstxcrt, ineld->im.impctxct);
             }       
             else { /* spouse has greater income */
                txcrt = ineld->im.impttxct + ctxcrt;
                inspo->im.imptaxcr += txcrt;
                DEBUG2("%s spouse receives transfered tax credits=%.2f\n", txcrt);
                inspo->im.impstxct = ineld->im.impttxct;
                inspo->im.impttxct = ZERO;
                inspo->im.impctxct = ctxcrt;
                if (isnzero(txcrt)) {
                   /* if basic federal tax is more than transfered           */
                   /* tax credits, apply total amount to reduce tax          */
                   if (inspo->im.imbpt > txcrt) {
                      inspo->im.impatxcr += txcrt;
                      inspo->im.imbpt -= txcrt;
                   }
                   else { /* txcrt >= inspo->im.imbpt */
                      inspo->im.impatxcr += inspo->im.imbpt;
                      inspo->im.imbpt = ZERO;
                   }
                }
                DEBUG4("%s spouse's bft=%.2f, stxcrt=%.2f, ctxcrt=%.2f\n",
                  inspo->im.imbpt, inspo->im.impstxct, inspo->im.impctxct);
             }
          } 
          else { /* no spouse present */
             txcrt = ctxcrt;
             ineld->im.imptaxcr += txcrt;
             DEBUG2("%s elder (alone) receives transfered tax credits=%.2f\n", txcrt);
             ineld->im.impstxct = ZERO;
             ineld->im.impttxct = ZERO;
             ineld->im.impctxct = ctxcrt;
             if (isnzero(txcrt)) {
                /* if basic federal tax is more than transfered           */
                /* tax credits, apply total amount to reduce tax          */
                if (ineld->im.imbpt > txcrt) {
                   ineld->im.impatxcr += txcrt;
                   ineld->im.imbpt -= txcrt;
                }
                else { /* txcrt >= ineld->im.imbpt */
                   ineld->im.impatxcr += ineld->im.imbpt;
                   ineld->im.imbpt = ZERO;
                }
             }
             DEBUG4("%s elder's bft  =%.2f, stxcrt=%.2f, ctxcrt=%.2f\n",
                ineld->im.imbpt, ineld->im.impstxct, ineld->im.impctxct);
          }      
       } 
    } /* end of tax on taxable income calculation */


    /*******************************************************************
    *****  Calculate provincial taxes 
    ********************************************************************/

    /* call the function which performs the inputation of paid rent
    *  and property taxes to individuals in the hhld
    */
    txhhexp(hh);


    /* process each person in household */
    for (ini=0, in=&hh->in[0]; ini<hh->hhnin; ini++, in++) {
        DEBUG6("%s person %d: age=%d, sex=%d, marst=%d, cfrh=%d\n",
           ini, in->id.idage, in->id.idsex, in->id.idmarst, in->id.idcfrh);

        /* initialise spouse and census family pointer */
        cf=in->id.idcf;
        inspo=in->id.idinspo;

        /* initialise nuclear family pointer */
        nf=in->id.idnf;
      

        /* original tax as percentage of federal tax */
        if (!MP.CTXFLG) { /* basic provincial tax */
            in->im.imbpt = in->im.imbft * MP.CPTF;
            in->im.imtxp = in->im.imbpt;   /* initialise tax paid to BPT */
        }
        /* if CTXFLG is turned on, then it's the tax on taxable income
           the bpt has already been calculated in the census family loop */
        else {
            if (in->im.imamtfg && MP.CAMTOPT == 2) {
               /* minimum tax is equal to a percentage of the additional federal tax
                   attributable to the alternative minimum tax */
               in->im.imbpt += in->im.imamtprv * MP.CAMTPCTF;
            }
			else {
				if ( in->im.imamtfg && MP.CAMTOPT == 4 ) {
				  /* minimum tax is equal to a percentage of the federal minimum
				     amount attributable to the alternative minimum tax */
					in->im.imbpt = in->im.imminamt * MP.CAMTPCTM;
				}
			}
            in->im.imtxp = in->im.imbpt;   /* initialise tax paid to BPT */
        }

        /* calculate and apply provincial foreign tax credit */
        if (MP.CAMTFTCFLG && in->im.imamtfg) {
            /* When the flag is turned on, these people aren't eligible for the foreign tax credit */
        }
        else {
            /* Eligible for the foreign tax credit.  Note that people who have the 
               amt would have a different way of calculating the credit.  It is not 
               possible to do that in the SPSM */
            in->im.imnptc = minn(in->im.imtxp,in->id.idprvftc);
            in->im.imtxp -= in->im.imnptc;
        }

		/* British Columbia Tax Reduction Credit */

		litr = MP.CLITR;

		taxbak1( in->im.imicnet, MP.CLITRTD, &litr, MP.CLITRRR);
		in->im.imptr = minn(in->im.imtxp, litr);
        in->im.imnptc += in->im.imptr;
		in->im.imtxp -= in->im.imptr;
		
        /* calculate surtax */
        /* note: second tier effective in 1992 */
        /* find number of dependants */
        csndep = 0;
        if (isnzero(in->im.immartxc)) {
            csndep = 1;
        }
        csndep += (int) in->im.imchclm;

        /* compute surtax less reduction for dependents */
        in->im.impsur   = nneg(
                                ( MP.CSF * nneg(in->im.imtxp - MP.CSCI)
                                 + MP.CSF2 * nneg(in->im.imtxp - MP.CSCI2) )
                                 - (csndep * MP.CSDC)
                            );

        /* apply surtax */
        in->im.imtxp += in->im.impsur;

        DEBUG5("%s bc  taxes: bpt=%.2f sur=%.2f txf=%.2f txp=%.2f\n",
                 in->im.imbpt, in->im.impsur, in->im.imtxf, in->im.imtxp);

		/* British Columbia tax adjustments for 2000 only */
		/* Includes supplementary credits of $25.20 for basic, spouse and equivalent */
		bcsupc = MP.CSUPCR;
		if (isnzero(in->im.immartxc) ) {
			bcsupc += MP.CSUPCR;
		}
		/* taxes owing are reduced by the supplementary credits */
		/* and add to total non-refundable tax credits */
		bcsupc = minn(in->im.imtxp, bcsupc);
		in->im.imnptc += bcsupc;
		in->im.imtxp  -= bcsupc;


        /* Refundable British Columbia Venture Capital Tax Credit */
		/*------------------------------------------------------------*/
		/* This code was disabled for version 9.0 where the greenbook */
		/* variable (1997) was too small to be imputed                */
		/*------------------------------------------------------------*/
        /* DEBUG1("%s bc  ven: venture capital tax credit\n"); */
        /* in->im.imptc += minn(in->id.idvencap, MP.CVCMAX);   */
        /* DEBUG3("%s bc  ven: vencap=%.2f, CVCMAX=%.2f\n",	   */
        /* in->id.idvencap, MP.CVCMAX);						   */

        /* refundable sales tax credit: effective in 1993 and beyond */
        /* NOTE: This is done for nuclear families instead of census families */
        /*       since those 19 and over within the household are eligible */
            
        if (MP.CSTCFLAG) {
            DEBUG1("%s bc  stc: activated\n");

            /* assign the value of the credit to the nuclear family head */
            
            /* NOTE: since there is currently no variable defining nuclear */
            /*       family head, we must use the census family variables   */
            /*       combined with age to determine nuclear family head     */

            if (in->id.idcfrh==0 || ((in->id.idcfrh==2) && (in->id.idage>=19))) {
                DEBUG1("%s bc  stc: found cf head or kid age 19 or over\n");

                /* initialize the income threshold */
                thrinc = MP.CSTHINC ;
                bcstc  = MP.CSTC ;

                /* add spousal top-up */
                if (nf->nfspoflg) {
                    DEBUG1("%s bc  stc: spouse present\n");
                    thrinc += MP.CSTSINC;
                    bcstc  += MP.CSTC ;
                }

                /* add top-up for kids */
                if (nf->nfnkids>0) {
                    DEBUG1("%s bc  stc: kids present\n");
                    thrinc = thrinc + (MP.CSTKINC * nf->nfnkids);
                    bcstc  = bcstc + (MP.CSTCKID * nf->nfnkids) ;
                }
                /* now calculate net income based on the nuclear family */
                /* tax back credit at reduction rate CSTCR on stcinet */
                /* in excess of thrinc.                               */

                 /* calculate nuclear family net income */
                
                stcinet = nneg(in->im.imicnet - in->im.imuccb);

                if (nf->nfspoflg) {
                    stcinet += nneg(inspo->im.imicnet - inspo->im.imuccb) ;
                }

                DEBUG3("%s bc  stc: pre stc= %.2f thrinc= %.2f\n",
                         bcstc, thrinc);
                taxbak1(stcinet, thrinc, &bcstc, MP.CSTCR);
                DEBUG3("%s bc  stc: post stc= %.2f thrinc= %.2f\n",
                         bcstc, thrinc);

                /* first, reduce the income tax liability by the stc */
                /* if there is any stc left over, turn into a refundable credit */

				if (isnzero(bcstc)) {
					in->im.imptc = bcstc;
				}
            }
        }
        
        DEBUG5("%s BC  sum: bpt=%.2f, txp=%.2f, ptc=%.2f, nptc=%.2f\n",
            in->im.imbpt, in->im.imtxp, in->im.imptc, in->im.imnptc);


        /* political contribution tax credit */
      
        if (isnzero(in->id.idprvpol)) {
            DEBUG1("%s bc  pol: political contribution tax credit\n");
            poltcr = (NUMBER) lkup1(MP.CPTCT, MP.CPTCTrows, in->id.idprvpol);
            poltc  = minn(MP.CPTCBEN, poltcr);
           /* in->im.impptc = minn(poltc, in->im.imtxp);  */
            DEBUG4("%s bc  pol: idpolcon=%.2f poltcr=%.2f poltc=%.2f\n",
               in->id.idprvpol, poltcr, poltc);

			if (MP.CPTCREF) {   /* tax credit is refundable (up to 1999) */
				/* first have to apply the sales tax credit to taxes owing 
			   		and the remainder is used as a refundable credit */
				in->im.impptc = minn(poltcr, in->im.imtxp - in->im.imptc);
				in->im.imptc += in->im.impptc;
			}
			else {  /* credit is non-refundable (2000 onwards) */
				in->im.impptc = minn(poltcr, in->im.imtxp);
	            /* apply political contribution tax credit */
    	        in->im.imnptc += in->im.impptc;
        	    in->im.imtxp  -= in->im.impptc;
			}

            DEBUG3("%s bc  pol: idpolcon =%.2f impptc =%.2f\n",
               in->id.idprvpol, in->im.impptc);
        }

        /* BC labour-sponsored venture capital credit */
        /* note: This should also include the employee share ownership plan tax credit */
        if ( isnzero(in->id.idlabtxg) ) {
           lvctc = minn(MP.CLVCMAX, MP.CLVCRT * in->id.idlabtxg);
           in->im.implvctc = minn(lvctc, in->im.imtxp);
           in->im.imnptc += in->im.implvctc;
           in->im.imtxp  -= in->im.implvctc;
        }

        /* British Columbia RENTERS TAX REDUCTION */
        /*  was in place from 1989 to 1992 */

        if (MP.CRFLAG){

            /* first calculate the rent paid of the CF */

            if (in->id.idcfrh==0) {
                famrent = in->im.imrentpd;

                if (in->id.idspoflg) {
                    famrent += inspo->im.imrentpd;
                }
            }

            /* calculate the reduction for CF heads without a spouse */

            if (in->id.idcfrh==0 && isnzero(famrent) && !in->id.idspoflg ){
                /* calculate census family net income */
                rrinet = in->im.imicnet;

                /* calculate the "base amount " */
                depred = (NUMBER) lkup2(MP.CRTRT, MP.CRTRTrows,
                                       (NUMBER) cf->cfnpers);

                /* calculate the basic credit */
                trcr = MP.CRTRB + (cf->cfnkids * MP.CRTRD);

                nrrinet = nneg(rrinet - depred );
                rtrcred = minn(trcr, (in->im.imrentpd*MP.CRTRP));
                nrtr = nneg( rtrcred    - (nrrinet * MP.CRTRPN));

                /* Apply net renters tax reduction */
                tr = minn(in->im.imtxp, nrtr);
                in->im.imtxp -= tr;
                in->im.imptr += tr;

            }

            /* calculate the reduction for CF families with a spouse */
            /* we calc the reduction here of all CFs containing a spouse
                since we must know the spouses imtxp in order to apportion
                the reduction correctly */

            if (in->id.idcfrh==1 && isnzero(famrent)) {
            
                /* calculate census family net income */
                rrinet = in->im.imicnet + inspo->im.imicnet; 

                /* calculate the "base amount " */
                depred = (NUMBER) lkup2(MP.CRTRT, MP.CRTRTrows,
                                (NUMBER) cf->cfnpers);

                /* calculate the basic credit */
                trcr = MP.CRTRB + MP.CRTRS + (cf->cfnkids * MP.CRTRD);
                nrrinet = nneg(rrinet - depred );

                /* here use the spouses rent paid since the spouse*/
                /* is the head */
                rtrcred = minn(trcr, (inspo->im.imrentpd * MP.CRTRP) );
                nrtr = nneg( rtrcred    - (nrrinet * MP.CRTRPN) );


                /** Assign reduction to higher net income spouse and transfer  
                * any remaining tax reduction to the lower net income spouse 
                * if tax is greater than zero. */

                if (in->im.imicnet < inspo->im.imicnet) {
                    DEBUG1("%s bc  rtr: head netinc > spouse net inc\n");

                    tr  = minn(inspo->im.imtxp, nrtr);          /* head amount  */
                    rtr = minn(in->im.imtxp, (nrtr-tr) );    /* spouse amount */

                    inspo->im.imtxp -= tr;
                    inspo->im.imptr += tr;
                    in->im.imtxp -= rtr;
                    in->im.imptr += rtr;
                }
                else {
                    DEBUG1("%s bc  rtr: spouse netinc > head net inc\n");

                    tr  = minn(in->im.imtxp , nrtr);    /* spouse amount */
                    rtr = minn(inspo->im.imtxp , (nrtr-tr));  /* head amount */

                    in->im.imtxp -= tr;
                    in->im.imptr += tr;
                    inspo->im.imtxp -= rtr;
                    inspo->im.imptr += rtr;
                }
            }
        }

		/* British Columbia Home Heating Assistance Rebate */

		/* Give the one time rebate to recipients of the federal home heating rebate */

		if (MP.CHEATFLG) {
			/* check if this individual is to receive the federal rebate */
			if (isnzero(in->im.imheatrl)) {
				/* if this amount is equal to the individual amount, 
				   give the individual provincial top-up. */
				if ( in->im.imheatrl == MP.HEATSNG ) {
					in->im.impheatr = MP.CHEATSNG ;
				}
				else { /* federal amount must then be equal to family credit */
					/* give the individual the provincial family rebate top-up. */
					in->im.impheatr = MP.CHEATFAM ;
				}
			}
		}

    }

    /**
    * Calculate B.C. Family Bonus
    **/

    if (MP.BCFBFLAG==1 || MP.BCEIBFLG == 1) {
        DEBUG1("%s child benefit program in effect\n");

       /* process each nuclear family in household */
       for (nfi=0, nf=&hh->nf[0];  nfi<hh->hhnnf;  nfi++, nf++) {
            DEBUG4("%s cben: nf %d spoflg=%d, nkids=%d\n",
            nfi, nf->nfspoflg, nf->nfnkids);

          if (nf->nfnkids == 0) {
               DEBUG1("%s cben: skipping nuclear family with no `children'\n");
             continue;
          }

          /* Initialize local variables and head and spouse pointers */
          ineld = nf->nfineld;
          inspo = nf->nfinspo;

          /* Compute Family net income and family employment income */
          nfinet = MP.PYINC * nneg( ineld->im.imicnet - ineld->im.imuccb );
          nfiemp = MP.PYINC *
                    (ineld->id.idiemp + ineld->id.idisenf + ineld->id.idisefm );
          nffben = ineld->im.imfcbene;

          if (nf->nfspoflg) {
             nfinet += MP.PYINC * nneg(inspo->im.imicnet - inspo->im.imuccb );
             nffben += inspo->im.imfcbene;
             nfiemp += MP.PYINC *
                  (inspo->id.idiemp + inspo->id.idisenf + inspo->id.idisefm);
          }

          /* Scale incomes with user specified rates */
 
          nfinet = nfinet * MP.CTCINC;
          nfiemp = nfiemp * MP.CTCINC;

          /* Compute Family Bonus */
                
          /* initialize base benefit*/
          bonus2 = ZERO;
            
          /* Assign base amount which is dependent on number of kids */
          /* this amount is multiplied by a phase-in fraction */
          bonus2 = MP.BCFBBAS * nf->nfnkids;

          /***
          ** Tax Back basic benefits
          ** providing a different(reduced) tax rate for
          ** single children families
          ***/
          if (nf->nfnkids==1) {
             taxbak1(nfinet, MP.BCFBTD, &bonus2, MP.BCFBRRS);
          }
          else {
             taxbak1(nfinet, MP.BCFBTD, &bonus2, MP.BCFBRR);
          }
                                                                                
          /* calculate bonus as per Income Tax Regulation if after 1997 */
          /* this step is used to denote that the BC Family Bonus includes */
          /* the Federal Earnings Income Supplement in the calculation     */
        
          if (MP.BCFBIFS == 1) {
		     /* Compute Family Federal Child Earning Income Supplement amounts  
		        The regulations for the BC Family Bonus mimic the program options 
		        for the Federal Child Earning Income Supplement in the formula   
		        that calculates the B.C. Family Bonus.                           
                However, the parameters are not obliged to match the federal program
                and the provincial regulations are changed regularly */
  		 		
   		     fbncs2 =  (MP.BCFBNCS1) + (MP.BCFBNCS2 * minn(nneg(nf->nfnkids-1),1)) +
		               (MP.BCFBNCS3 * nneg(nf->nfnkids-2));
		     
		     /* the phase-out rate also depends on number of children, up to 3 */
             
             if (nf->nfnkids == 1) fbncsrr2 = MP.BCFBNCSRR1;
		        else if (nf->nfnkids == 2) fbncsrr2 = MP.BCFBNCSRR2;
		        else if (nf->nfnkids > 2) fbncsrr2 = MP.BCFBNCSRR3;

		     if (isnzero(fbncs2)) {
   		        taxbak1(nfinet, MP.BCFBNCSTD, &fbncs2, fbncsrr2);
		     }
             bonus2 -= fbncs2;
             bonus2 = nneg(bonus2);
          }

          /* calculate earned income benefit */        
          if (MP.BCEIBFLG==1) {

             /* calculate the amount of benefit depending on the number of eligible children */
             bceibmax2 =  (MP.BCBEIS1) + (MP.BCBEIS2 * minn(nneg(nf->nfnkids-1),1)) +
                   (MP.BCBEIS3 * nneg(nf->nfnkids-2));
            
             /* capture the minimum between the earned income and turndown */
            
             mineinc2 = minn(nfiemp, MP.BCBEMX);
            
             /*  calculate the earned income benefit as per formula in regulations */
            
             bceiben2 = bceibmax2 * ((mineinc2- MP.BCEIBPI)/
                       (MP.BCBEMX - MP.BCEIBPI));  
            
             bceiben2 = nneg(bceiben2);   
            
             if (nf->nfnkids == 1) bceibrr2 = MP.BCBERR1;
             else if (nf->nfnkids == 2) bceibrr2 = MP.BCBERR2;
             else if (nf->nfnkids > 2) bceibrr2 = MP.BCBERR3;

             if (isnzero(bceiben2)) {
                taxbak1(nfinet, MP.BCBEITD, &bceiben2, bceibrr2);
             }
          }

       	  /* Recalculate for the calendar year if FCBENCAL is activated */
		  if (MP.FCBENCAL) {

			  /* Adjust net income to represent the value for 2 years previous */
			  nfinet = (nfinet / MP.PYINC)  * MP.PYINCP;  
			  nfiemp = (nfiemp / MP.PYINC)  * MP.PYINCP;  
			  	
	          /* initialize base benefit*/
	          bonus1 = ZERO;
	            
	          /* Assign base amount which is dependent on number of kids */
	          /* this amount is multiplied by a phase-in fraction */
	          bonus1 = MP.BCFBBASP * nf->nfnkids;

	          /***
	          ** Tax Back basic benefits
	          ** providing a different(reduced) tax rate for
	          ** single children families
	          ***/
	          if (nf->nfnkids==1) {
	             taxbak1(nfinet, MP.BCFBTDP, &bonus1, MP.BCFBRRSP);
	          }
	          else {
	             taxbak1(nfinet, MP.BCFBTDP, &bonus1, MP.BCFBRRP);
	          }
	                                                                                
	          /* calculate bonus as per Income Tax Regulation if after 1997 */
	          /* this step is used to denote that the BC Family Bonus includes */
	          /* the Federal Earnings Income Supplement in the calculation     */
	        
	          if (MP.BCFBIFSP == 1) {
			     /* Compute Family Federal Child Earning Income Supplement amounts  
			        The regulations for the BC Family Bonus mimic the program options 
			        for the Federal Child Earning Income Supplement in the formula   
			        that calculates the B.C. Family Bonus.                           
	                However, the parameters are not obliged to match the federal program
	                and the provincial regulations are changed regularly */
	  		 		
	   		     fbncs1 =  (MP.BCFBNCS1P) + (MP.BCFBNCS2P * minn(nneg(nf->nfnkids-1),1)) +
			               (MP.BCFBNCS3P * nneg(nf->nfnkids-2));
			     
			     /* the phase-out rate also depends on number of children, up to 3 */
	             
	             if (nf->nfnkids == 1) fbncsrr1 = MP.BCFBNCSRR1P;
			        else if (nf->nfnkids == 2) fbncsrr1 = MP.BCFBNCSRR2P;
			        else if (nf->nfnkids > 2) fbncsrr1 = MP.BCFBNCSRR3P;

			     if (isnzero(fbncs1)) {
	   		        taxbak1(nfinet, MP.BCFBNCSTDP, &fbncs1, fbncsrr1);
			     }
	             bonus1 -= fbncs1;
	             bonus1 = nneg(bonus1);
  	          }

	          /* calculate earned income benefit */        
	          if (MP.BCEIBFLGP==1) {

	             /* calculate the amount of benefit depending on the number of eligible children */
	             bceibmax1 =  (MP.BCBEIS1P) + (MP.BCBEIS2P * minn(nneg(nf->nfnkids-1),1)) +
	                   (MP.BCBEIS3P * nneg(nf->nfnkids-2));
	            
	             /* capture the minimum between the earned income and turndown */
	            
	             mineinc1 = minn(nfiemp, MP.BCBEMXP);
	            
	             /*  calculate the earned income benefit as per formula in regulations */
	            
	             bceiben1 = bceibmax1 * ((mineinc1- MP.BCEIBPIP)/
	                       (MP.BCBEMXP - MP.BCEIBPIP));  
	            
	             bceiben1 = nneg(bceiben1);   
	            
	             if (nf->nfnkids == 1) bceibrr1 = MP.BCBERR1P;
	             else if (nf->nfnkids == 2) bceibrr1 = MP.BCBERR2P;
	             else if (nf->nfnkids > 2) bceibrr1 = MP.BCBERR3P;

	             if (isnzero(bceiben1)) {
	                taxbak1(nfinet, MP.BCBEITDP, &bceiben1, bceibrr1);
	             }
	          }
			  /* still in calculate for calendar year, take half of each calculation */
			  bceiben = (bceiben1/2) + (bceiben2/2);
			  bonus = (bonus1/2) + (bonus2/2);
		 
		  }
		  else {  /* use the july to june amounts for the entire year */
			  bceiben = bceiben2;
			  bonus = bonus2;
		  }

          /* assign BC Earned Income Benefit to mother if present */
          if (nf->nfspoflg && (inspo->id.idsex == FEMALE)) {
                DEBUG1("%s bceiben: spouse is the mother, gets Benefit\n");
                inspo->im.imibceib = bceiben;
				inspo->im.imibcfb = bonus ;
          }
          else {
                DEBUG1("%s bceiben: elder receives Earned Income Benefit\n");
                ineld->im.imibceib = bceiben;
				ineld->im.imibcfb = bonus ;

		  }
         
       }
    }

	/* B.C. Medical Services Plan */

	if (MP.CMSPFLAG) {
	    for (cfi=0, cf=&hh->cf[0]; cfi<hh->hhncf; cfi++, cf++) {
	            
	        ineld = cf->cfineld;
			inspo = cf->cfinspo;

			/* premium based on family size up to a maximum of 3 */
			mspnpers = minn(3, cf->cfnpers);
			mspprem = lkup2(MP.CMSP, MP.CMSProws, (NUMBER) mspnpers);
			
			/* Regular Premium Assistance 
			   Regular premium assistance offers subsidies ranging from 20 to 100 per cent,
			   based on an individual's net income (or a couple's combined net income)
			   for the previous year, less deductions for age, family size and disability.
			   If the resulting amount referred to as "adjusted net income" is $24,000 or less,
			   a subsidy is available.
			   The current adjusted net income thresholds are: 
			   $16,000 - 100 percent subsidy
			   $18,000 - 80 percent subsidy
			   $20,000 - 60 percent subsidy
			   $22,000 - 40 percent subsidy
			   $24,000 - 20 percent subsidy   	   */
			   
		   /*	   Determine adjusted net income for premium assistance */

			adjninc = ineld->im.imicnet* MP.PYINC;
			ccexp = ineld->im.imccea;

	        if (cf->cfspoflg) {
	           adjninc += inspo->im.imicnet * MP.PYINC;
			   ccexp += inspo->im.imccea;	
		    }
		   
		   /* Apply deductions allowed by the Medical Services Plan
		      May deduct an amount for spouse, senior, senior spouse,
		      children (less 1/2 of child care expenses claimed) and disability  */
		   mspded = 0;
		   if (cf->cfspoflg) {
		      mspded = MP.CMSPSDED;
			  if (inspo->id.idage > 64) {
				  mspded += MP.CMSPADED;
			  }
		   }
		   if (ineld->id.idage > 64) {
		   	  mspded += MP.CMSPADED;
		   }
		   
			/* Count the number of eligible children in the census family 
			   Eligibility - 18 or younger
			               - 19 to 24 and attending school or university full time. */

			mspnkids = 0;	
	        for (ini=0, in=cf->cfinch; ini<cf->cfnchild; ini++, in++) {
		    	if (in->id.idage < 19) {
				    mspnkids++;
				}
				else {   /* aged 19 to 24 */
					 if (in->id.idestat == 1 || in->id.idestat == 3) {
					 	mspnkids++;
					 }
				}
			}		 	 
		    
		   if (mspnkids >0) {
			  mspded += nneg((MP.CMSPCDED * mspnkids) - (0.5 * ccexp));
		   }
		   mspndis = 0;
		   if (ineld->id.iddisslf > 0) {
		       mspndis++;
		   }
		   if (cf->cfspoflg && inspo->id.iddisslf > 0) {
		       mspndis++;
		   }
		   if (ineld->id.iddisoth > 0 || (cf->cfspoflg && inspo->id.iddisoth > 0) ) {
		      mspndis++;
		   }
		   mspded += (mspndis * MP.CMSPDDED);
		   
		   adjninc = nneg(adjninc - mspded);
		   premrate = (NUMBER) lkup2(MP.CMSPRATE, MP.CMSPRATErows, (double) adjninc);
           /* If flag is on, give premium to sposue with the biggest income */
		   if (MP.CMSPINCFLAG && cf->cfspoflg && (inspo->im.imicnet > ineld->im.imicnet) ) {
              inspo->im.imphp = mspprem * nneg(1.0 - premrate);    	   
           }
           else {
              ineld->im.imphp = mspprem * nneg(1.0 - premrate);    	   
           }
	           		
		}
	}  
    DEBUG_OFF("Atxbc");
}
