/***
*Atxnfld.cpp - Compute provincial taxes for Newfoundland
*
*$Id: Atxnfld.cpp 6.123 2007/09/18 17:22:11 hickcha Exp $
*
*   SPSD/M Copyright (c) 1987-1995, Minister of Industry.
*   All rights reserved.  Use, reproduction, or disclosure of this work,
*   as well as publication of results derived from this work, are subject
*   to the conditions specified in the SPSD/M License Agreement.
*
*Purpose:
*   This file contains the definition of the .c function.
*
*Revisions:
* +-----+----------+---------------------------------------------------------+
* | Who |   Date   | Description                                             |
* +-----+----------+---------------------------------------------------------+
* | LP  | 07/04/19 | Changed spouse cred transfer test from imicnet to imbpt |
* | LP  | 07/02/11 | Prov. pension credit now based on imipnst, not idipens  |
* | LP  | 07/01/23 | Removed imninc - no income flag - no longer used        |
* | LP  | 07/01/19 | Removed NUCCBITF-UCCB removed from income as per forms  |
* | LP  | 06/12/13 | Switched iminet to imicnet (income tax form concept)    |
* | LP  | 06/06/20 | Allow the unused NFLD tax reduction transfer to spouse  |
* | LP  | 06/06/09 | Removed phase-in parameters for NFLD child benefit      |
* | LP  | 06/06/09 | Removed NAXPI - no need for a phase-in for prov. age tc |
* | LP  | 06/06/07 | Added NUCCBITF - Flag to remove UCCB from income tests  |
* | LP  | 06/06/05 | Revised the application of PYINCP                       |
* | LP  | 06/05/30 | Added Newfoundland Child Benefit for calendar year      |
* | LP  | 06/05/15 | Added large corporation dividend tax credit rate NDTCRLC|
* | LP  | 05/11/03 | Revised p.t. educ. credit to allow disab students ft amt|
* | LP  | 05/10/25 | Added income test to NFLD home heating fuel rebate      |
* | LP  | 04/07/09 | Added Nfld Low Income Tax Reduction - NLITR series.     |
* | LP  | 04/05/27 | Added NMBNSEXT - Mother Baby Nutrition Supplement Extra |
* |     |          | one time benefit and fixed income test and infant count |
* | LP  | 04/02/17 | Added idiworkc to income tests for child/sales tax cred.|
* | LP  | 03/12/22 | Added NMEDALL and NMEDANF prov. non-ref medical exp cred|
* | LP  | 03/12/09 | Added impothpe, NODISTC infirm dep. (18+) tax credit    |
* | LP  | 03/11/17 | Added NCGTCOPT and revised caregiver credit calculation |
* | LP  | 03/11/17 | Added impintsl (provincial student loan interest credit)|
* |     |          | using the new database variable idintstu                |
* | LP  | 03/11/12 | Added ideducpm and NEDXPMPT - part-time months of educ. |
* | CH  | 03/10/17 | Deleted iddisab, replaced ideducm by ideducfm           |
* | CH  | 03/05/16 | Changed Home Heating Fuel Rebate and added NHEATSAFLG   |
* | LP  | 02/06/17 | Added Mother-Baby Nutrition Supplement (NMBNS)          |
* | LP  | 01/07/18 | Renamed impmincar to impminco                           |
* | LP  | 01/06/12 | Added impmincar - provincial minimum tax carryover cred.|
* | LP  | 01/06/11 | Added NLVCMAX and NLVCRT labour sponsored venture cap.  |
* | LP  | 01/05/09 | Added NAMTPCTM and added another option to NAMTOPT      |
* | BBM | 01/04/19 | Dropped reference to vencap                             |
* | LP  | 01/04/02 | Added NHEATFLG & NHEATREB NFLD Home Heating Fuel Rebate |
* | LP  | 01/03/12 | Removed pre-1988 program parameter CTCIFLAG             |
* | LP  | 01/02/28 | Added NSF2 and NSCI2 - modified NFLD surtax formula     |
* | CH  | 00/10/24 | Added CPP deduction for the self-employed               |
* | CH  | 00/05/05 | Modified CGTC                                           |
* | LP  | 00/03/15 | Added Newfoundland and Labrador Child Benefit           |
* | CH  | 00/03/01 | Added provincial tax on taxable income                  |
* | CH  | 90/10/20 | Change to idvencap calculation                          |
* | TCB | 98/05/28 | Renamed *.cpp, ANSI function headers                    |
* | CH  | 97/10/10 | Refundable sales tax credit depends on census families  |
* | CH  | 97/10/03 | Added refundable sales tax credit                       |
* | BBM | 97/05/27 | Dropped idstksav -- Insufficient data in 1992           |
* | ER  | 95/09/09 | Added surtax                                            |
* | BBM | 94/09/26 | Removed political cont.tax credit flag NPTCFLAG         |
* | RSE | 94/03/17 | Added political contribution tax credit for 1993 +      |
* | BBM | 92/07/22 | Incorporated non-refundable provincial tax credit var   |
* | BBM | 92/07/08 | Modeled provincial tax credits, drop reference to idptc |
* | SFG | 92/07/06 | Created                                                 |
* |     |          |                                                         |
* +-----+----------+---------------------------------------------------------+
*
*Definitions:
*   Atxnfld  [global]  Compute provincial taxes for Newfoundland
*
*****************************************************************************/


/* ==================== C-RUNTIME LIBRARY INCLUDE FILES =================== */

#include <stdio.h>  /* definitions/declarations for standard I/O routines   */


/* ==================== SPSD/M INCLUDE FILES ============================== */

#include "spsm.h"   /* SPSM common manifest constants and macros            */
#include "sub.h"    /* Subroutine library declarations                      */
#include "vsu.h"    /* Household variable sub-structure (user's)            */
#include "vs.h"     /* Household variable structure and sub-structures      */
#include "mpu.h"    /* Tax/transfer parameter declarations (user's)         */
#include "mp.h"     /* Tax/transfer parameter declarations                  */


/* ==================== GLOBAL VARIABLE DEFINITIONS ======================= */

/* Give global string describing version of this module */

/*global*/ char FAR Ttxnfld[] = "Untitled"
#ifdef _MSC_VER
" [" __TIMESTAMP__ "]"
#endif
;


/* ==================== COMPILER PRAGMAS ================================== */

#ifdef MSCOVL

#endif


/* ==================== FUNCTION DEFINITIONS ============================== */


/*****************************************************************************
*Atxnfld - Compute provincial taxes for Newfoundland
*
*Synopsis:
*    void Atxnfld(         
*    P_hh hh              
*    )                    
*
*Description:
*
*Return Value:
*   None.
*
*Calls:
*   nneg     Change negative numbers to zero
*   isnzero  Is argument non-zero ?
*   minn     Find the minimum of two numbers
*   lkup1    Table look-up with interpolation/extrapolation
*   taxbak1  One level tax-back function
*   maxn     Find the maximum of two numbers
*
*Structure Members:
*   MP.CTCINC       (i)  Refundable CTC family income scaling factor
*   MP.FCBENCAL     (i)  Calculate child benefits for calendar year flag
*   MP.NAMTOPT      (i)  NFLD alternative minimum tax option
*   MP.NAMTPCTF     (i)  NFLD amt rate as pct of additional fed tax due to minimum tax
*   MP.NAMTPCTM     (i)  NFLD amt rate as pct of federal minimum tax amount
*   MP.NAMTTX       (i)  NFLD amt rate as tax on adjusted income
*   MP.NAXM         (i)  NFLD Age Amount
*   MP.NAXRR        (i)  NFLD Age Amount credit reduction rate
*   MP.NAXTD        (i)  NFLD Age Amount net income turndown
*   MP.NBXM         (i)  NFLD Basic Personal Exemption/amount
*   MP.NCB1         (i)  Nfld. child benefit for first child
*   MP.NCB1P        (i)  Nfld. child benefit for first child for 1st half of year
*   MP.NCB2         (i)  Nfld. child benefit for second child
*   MP.NCB2P        (i)  Nfld. child benefit for second child for 1st half of year
*   MP.NCB3         (i)  Nfld. child benefit for third child
*   MP.NCB3P        (i)  Nfld. child benefit for third child for 1st half of year
*   MP.NCB4         (i)  Nfld. child benefit for 4th and subsequent child
*   MP.NCB4P        (i)  Nfld. child benefit for 4th and subsequent child for 1st half of year
*   MP.NCBFLG       (i)  Newfoundland child benefit activation flag
*   MP.NCBPO        (i)  Nfld. child benefit family income phase out
*   MP.NCBPOP       (i)  Nfld. child benefit family income phase out for 1st half of year
*   MP.NCBTD        (i)  Nfld. child benefit family income turndown
*   MP.NCBTDP       (i)  Nfld. child benefit family income turndown for 1st half of year
*   MP.NCGTC        (i)  NFLD Caregiver Tax Credit
*   MP.NCGTCFLG     (i)  NFLD Caregiver Tax Credit activation flag
*   MP.NCGTCOPT     (i)  NFLD Caregiver Tax Credit Option (1=max, 2=greenbook)
*   MP.NCHATL1      (i)  NFLD Charitable Donations amount level 1
*   MP.NCHATR1      (i)  NFLD Charitable Donations tax credit rate 1
*   MP.NCHATR2      (i)  NFLD Charitable Donations tax credit rate 2
*   MP.NDTCR        (i)  NFLD dividend tax credit rate
*   MP.NDTCRLC      (i)  NFLD dividend tax credit rate from large (eligible) corporations
*   MP.NEDXPM       (i)  NFLD Education Amount per month of full-time studies
*   MP.NEDXPMPT     (i)  NFLD Education Amount per month of part-time studies
*   MP.NEMXM        (i)  NFLD equivalent to married amount
*   MP.NEMXMT       (i)  NFLD equivalent to married turndown level
*   MP.NHEATFLG     (i)  Newfoundland home heating fuel rebate activation flag
*   MP.NHEATINC     (i)  Newfoundland home heating fuel rebate - income test flag
*   MP.NHEATMIN     (i)  Newfoundland home heating fuel rebate minimum
*   MP.NHEATPO      (i)  Newfoundland home heating fuel rebate family income phase out
*   MP.NHEATREB     (i)  Newfoundland home heating fuel rebate amount
*   MP.NHEATRR      (i)  Newfoundland home heating fuel rebate reduction rate
*   MP.NHEATSAFLG   (i)  Newfoundland home heating fuel rebate - SA recipients eligible
*   MP.NHEATTD      (i)  Newfoundland home heating fuel rebate family income turndown
*   MP.NLITRF       (i)  NFLD low income tax reduction family maximum
*   MP.NLITRFIT     (i)  NFLD low income tax reduction family income threshold
*   MP.NLITRRR      (i)  NFLD low income tax reduction credit reduction rate
*   MP.NLITRS       (i)  NFLD low income tax reduction single maximum
*   MP.NLITRSIT     (i)  NFLD low income tax reduction single income threshold
*   MP.NLVCMAX      (i)  Maximum NFLD labour-sponsored funds tax credit allowed
*   MP.NLVCRT       (i)  Percent of NFLD labour-sponsored funds cost allowed as credit
*   MP.NMAXDX       (i)  NFLD Maximum Disability deduction/amount
*   MP.NMAXET       (i)  NFLD maximum on transfer of education and tuition amount
*   MP.NMBNS        (i)  Nfld. Mother-Baby Nutrition Supplement
*   MP.NMBNSEXT     (i)  Nfld. Mother-Baby Nutrition Supplement newborn extra benefit
*   MP.NMBNSEXTP    (i)  Nfld. Mother-Baby Nutrition Supplement newborn extra benefit for 1st half of year
*   MP.NMBNSP       (i)  Nfld. Mother-Baby Nutrition Supplement for 1st half of year
*   MP.NMEDALL      (i)  NFLD Medical allowance maximum lower limit
*   MP.NMEDANF      (i)  NFLD Medical allowance lower limit net income fraction
*   MP.NMXM         (i)  NFLD married amount
*   MP.NMXMT        (i)  NFLD married amount turndown level
*   MP.NODISTC      (i)  NFLD Maximum infirm dependent 18 or older tax credit
*   MP.NPNTCR       (i)  NFLD provincial non-refundable tax credit rate
*   MP.NPTC         (i)  Newfoundland political contribution table [total donations,donation allowed]
*   MP.NPTCBEN      (i)  Maximum Newfoundland political tax credit allowed
*   MP.NPTCrows     (i)  number of rows in NPTC
*   MP.NPTF         (i)  Newfoundland provincial tax fraction
*   MP.NPTX         (i)  NFLD tax table [taxable income,basic provincial tax]
*   MP.NPTXrows     (i)  number of rows in NPTX
*   MP.NSCI         (i)  Newfoundland provincial tax above which surtax applies
*   MP.NSCI2        (i)  Newfoundland provincial surtax level 2
*   MP.NSF          (i)  Newfoundland provincial surtax rate
*   MP.NSF2         (i)  Newfoundland provincial surtax rate 2
*   MP.NSTCA        (i)  NFLD sales tax credit amount for adults
*   MP.NSTCC        (i)  NFLD sales tax credit amount for children
*   MP.NSTCFLAG     (i)  NFLD sales tax credit activation flag
*   MP.NSTCL        (i)  NFLD sales tax credit reduction level
*   MP.NSTCR        (i)  NFLD sales tax credit reduction rate
*   MP.NTXFLG       (i)  NFLD tax on taxable income activation flag
*   MP.NYPNDL       (i)  NFLD Pension Income Deduction Amount
*   MP.PYINC        (i)  Deflator to calculate previous year income
*   MP.PYINCP       (i)  Deflator to calculate income from 2 years prior
*   cf.cfageeld     (i)  Age of eldest in census family
*   cf.cfin         (i)  First person in census family [pointer]
*   cf.cfinch       (i)  First child in census family [pointer]
*   cf.cfineld      (i)  Eldest person in census family [pointer]
*   cf.cfinspo      (i)  Spouse of eldest [pointer]
*   cf.cfnchild     (i)  Number of children (including 18+)
*   cf.cfnpers      (i)  Number of persons in census family
*   cf.cfspoflg     (i)  Census family contains married couple
*   fx.fxio         (i)  I/O expenditure categories [array]
*   hh.cf           (i)  Census family data [array]
*   hh.fx           (i)  SHS data [struct]
*   hh.hhncf        (i)  Number of census families in household
*   hh.hhnin        (i)  Number of individuals in household
*   hh.hhnnf        (i)  Number of nuclear families in household
*   hh.in           (i)  Individual data [array]
*   hh.nf           (i)  Nuclear family data [array]
*   id.idage        (i)  Age
*   id.idcfrh       (i)  Relationship to census family head
*   id.idcgtc       (i)  Caregivers tax credit (database) (315)
*   id.iddisoth     (i)  Disability amount for dependants (318)
*   id.iddisslf     (i)  Disability amount for self (316)
*   id.ideducfm     (i)  Eligible full-time months of education
*   id.ideducpm     (i)  Eligible part-time months of education
*   id.ididiv       (i)  Dividend income (actual)
*   id.idintstu     (i)  Interest paid on student loans (319)
*   id.idlabtxg     (i)  Gross Labour funds bought (413)
*   id.idmedgro     (i)  Medical expenses, gross (330)
*   id.idmincar     (i)  Minimum tax carryover (504)
*   id.idothpe      (i)  Amounts for Infirm Dependants (306)
*   id.idprvftc     (i)  Provincial foreign tax credit (Form T2036)
*   id.idprvpol     (i)  Provincial political contributions (565)
*   id.idsex        (i)  Sex
*   id.idtuitn      (i)  Tuition fees (320)
*   im.imamtfg      (i)  Minimum tax flag
*   im.imamtinc     (i)  Net adjusted income used for minimum tax
*   im.imamtprv     (i)  Federal minimum tax concept used for provincial minimum tax
*   im.imbft        (i)  Basic federal tax
*   im.imchara      (i)  Allowable charitable donations and gifts (calculated)
*   im.imcppse      (i)  CPP contributions deduction for self-emp
*   im.imcqppc      (i)  CPP/QPP contributions
*   im.imdedfn      (i)  All deductions from net income
*   im.imdepni      (i)  Dependant's net income
*   im.imicnet      (i)  Net Income (line 236)
*   im.imigist      (i)  GIS provincial top-up
*   im.imildivt     (i)  Dividend income from large (eligible) corporations (taxable)
*   im.imipnst      (i)  Taxable pension income (after splitting)
*   im.imisa        (i)  Social assistance (or replacement program)
*   im.imisdivt     (i)  Dividend income from small corporations (taxable)
*   im.imitax       (i)  Taxable income
*   im.immartxc     (i)  Married tax credit claimed
*   im.imminamt     (i)  Minimum Amount due to Federal Minimum Tax
*   im.imuccb       (i)  Universal Child Care Benefit amount
*   im.imuic        (i)  UIC contributions
*   nf.nfinch       (i)  First child in nuclear family [pointer]
*   nf.nfineld      (i)  Eldest person in nuclear family [pointer]
*   nf.nfinspo      (i)  Spouse of eldest [pointer]
*   nf.nfnkids      (i)  Number of children in nuclear family
*   nf.nfspoflg     (i)  Nuclear family contains married couple
*   im.imbpt        (io) Basic provincial tax
*   im.imncb        (io) Newfoundland Child Benefit
*   im.imnptc       (io) Non-refundable provincial tax credits
*   im.impatxc      (io) Prov Age amount tax credit
*   im.impbtc       (io) Prov Basic amount
*   im.impcgtc      (io) Prov Caregiver Tax Credit Level
*   im.impchrtc     (io) Prov Charitable Donations tax credit
*   im.impcpptc     (io) Prov CPP/QPP contributions tax credit
*   im.impdistc     (io) Prov Disability tax credit
*   im.impdtxc      (io) Provincial dividend tax credit
*   im.impedtxc     (io) Prov Education tax credit
*   im.impheatr     (io) Provincial Home Heating Fuel/Energy Rebate
*   im.impintsl     (io) Provincial interest on student loans tax credit
*   im.implvctc     (io) Provincial labour-sponsored funds tax credit
*   im.impmartc     (io) Prov Married and Equivalent to Married tax credit
*   im.impmeda      (io) Prov Medical expenses allowed (computed)
*   im.impmedtc     (io) Prov Medical Expenses tax credit
*   im.impminco     (io) Prov Minimum tax carryover
*   im.impothpe     (io) Provincial infirm dependents 18 or older tax credit
*   im.imppentc     (io) Prov Pension Income tax credit
*   im.impptc       (io) Provincial Political Contrib Tax Credit
*   im.imprvtax     (io) Prov gross provincial tax
*   im.impsur       (io) Provincial surtax
*   im.imptaxcr     (io) Prov total tax credits
*   im.imptc        (io) Refundable provincial tax credits
*   im.imptr        (io) Provincial tax reduction
*   im.impttxct     (io) Prov total tax credits transferred
*   im.imptutxc     (io) Prov Tuition tax credit
*   im.impuictc     (io) Prov UI/EI contributions tax credit
*   im.imtxp        (io) Provincial income tax payable
*   im.imnmbns      (o)  Newfoundland Mother-Baby Nutrition Supplement
*   im.impatxcr     (o)  Prov total tax credits applied
*   im.impctxct     (o)  Prov tax credits transferred from children
*   im.impstxct     (o)  Prov tax credits transferred from spouse
*
*Called by:
*   txprov   Compute provincial taxes
*
*****************************************************************************/
void Atxnfld(
    P_hh hh
)
{
    register int ini;
    register P_in in;
    register P_in ineld;
    register P_in inspo;
    register P_cf cf;
    register int cfi;
    register P_nf nf;
    register P_in nfeld;
    register P_in nfspo;
    register int nfi;
	register P_fx fx;

	fx = &hh->fx;

    NUMBER poltc=ZERO;
    NUMBER poltcr=ZERO;

    register NUMBER faminet = ZERO;

    NUMBER pstc = ZERO;
	NUMBER elgind = ZERO;      /* eligible individual for home heating fuel rebate  */
    int gotheat;               /* CF got the home heating benefit */
	NUMBER heatinc = ZERO;     /* head and spouse net income for heat rebate income test */
    int nelich;
    NUMBER kidpstc = ZERO;     /* sales tax credit for children over age limit */
    NUMBER kidinet = ZERO;     /* income for children over age limit */
    NUMBER cben = ZERO;		   /* Newfoundland and Labrador child benefit */
    NUMBER cbenmax = ZERO;	   /* Maximum Nfld. child benefit */
	NUMBER ncbrr = ZERO;       /* Nfld child benefit reduction rate */
    NUMBER cben2 = ZERO;		   /* Newfoundland and Labrador child benefit */
    NUMBER cbenmax2 = ZERO;	   /* Maximum Nfld. child benefit */
	NUMBER ncbrr2 = ZERO;       /* Nfld child benefit reduction rate */
    NUMBER cben1 = ZERO;		   /* Newfoundland and Labrador child benefit */
    NUMBER cbenmax1 = ZERO;	   /* Maximum Nfld. child benefit */
	NUMBER ncbrr1 = ZERO;       /* Nfld child benefit reduction rate */
    NUMBER nfinet = ZERO;	   /* Family net income for child benefit income test */
    NUMBER lvctc = ZERO;       /* Labour-sponsored venture capital tax cred */
	int ninfants;              /* Number of children under age 1 for MBNS */
	NUMBER mbns = ZERO;        /* Mother Baby Nutrition Supplement */
	NUMBER mbns2 = ZERO;        /* Mother Baby Nutrition Supplement */
	NUMBER mbns1 = ZERO;        /* Mother Baby Nutrition Supplement */
	NUMBER redinc=ZERO;        /* Income used for tax reduction */
    NUMBER totred=ZERO;        /* Total tax reduction amount */
    NUMBER ptr=ZERO;           /* Total tax reductions allowed */
	NUMBER incthr = ZERO;      /* Low income tax reduction income threshold */
	int ftype;                 /* Low Income Tax Reduction Family Type */

    DEBUG_ON("Atxnfld");

    /*******************************************************************
    *****  Calculations for tax on taxable income, 
    ********************************************************************/

    if (MP.NTXFLG) { 

       /* process each census family in household */
       for (cfi=0, cf=&hh->cf[0]; cfi<hh->hhncf; cfi++, cf++) {

          /* Do needed declarations/initialisations for each census family */
          NUMBER ctxcrt = ZERO;   /* total children's transferable credits  */
          NUMBER tfr1 = ZERO;     /* transfer type 1 */
          NUMBER tfr2 = ZERO;     /* tranfer type 2 */
          NUMBER txcrt = ZERO;    /* tax credits */
          NUMBER agered = ZERO;
          NUMBER adjamt = ZERO;
		  NUMBER netinc = ZERO;

          NUMBER cemc   = ZERO;   /* value of equivalent to married tax credit */
          NUMBER cinet   = ZERO;   /* value of current child's income */
          NUMBER minet   = ZERO;   /* value of child's income for child with least income */
          NUMBER inetfg   = ZERO;   /* went through process once */

          /*******************************************************************
          *****  Calculation of married and equivalent to married tax credits
          ********************************************************************/
         
          /* calculate equivalent to married credit */
 
          /* process children in census family */
          for (ini=0, in=cf->cfinch; ini<cf->cfnchild; ini++, in++) {
             /* Filter condition (ineligible for EM credit)  */
             if (in->id.idage > 18) {
                continue;
             }
             cinet = in->im.imdepni ;
             /* calculate EM credit if income is lower or if not done before */
             if (!cf->cfspoflg && (inetfg==ZERO || minet > cinet)) {
				inetfg=1;
				minet = cinet;
                cemc = MP.NPNTCR * nneg(MP.NEMXM - nneg(cinet - MP.NEMXMT));
             }
          }
          /* initialise pointers for head and spouse modelled variables */
          ineld = cf->cfineld;
          inspo = cf->cfinspo;     /* NB: is NULL if no spouse present */

          if (cf->cfspoflg) {
             DEBUG1("%s spouse present\n");
             /**
             * If the net income of the head is greater than the net
             * income of the spouse, the head gets the married
             * exemption 
             **/
             if (ineld->im.imicnet >= inspo->im.imicnet) {
                DEBUG1("%s head receives married tax credit\n");
                ineld->im.impmartc = MP.NPNTCR * nneg(MP.NMXM
                    - nneg(inspo->im.imdepni - MP.NMXMT));
             }
             else {
                DEBUG1("%s spouse receives married tax credit\n");
                inspo->im.impmartc = MP.NPNTCR * nneg(MP.NMXM 
                	- nneg(ineld->im.imdepni - MP.NMXMT));
             }
          }
          else { /* no spouse present */
             ineld->im.impmartc = cemc;
          }
     
          /* note, we are already in a census family loop */
 
          /* process persons in census family */
          for (ini=0, in=cf->cfin;  ini<cf->cfnpers;  ini++, in++) {
             /*********************************************************
             *****  Calculation of non-family tax credits
             **********************************************************/

			 /* calculate caregivers tax credit */
			 if (MP.NCGTCFLG && isnzero(in->id.idcgtc)) {
				/* if NGCTGOPT == 1 then */
				/* apply the maximum amount if they have any caregivers amount */
				 if (MP.NCGTCOPT == 1) {
					in->im.impcgtc = MP.NCGTC * MP.NPNTCR;
				 }
				 else {   /* use the greenbook imputed amount */
				 	in->im.impcgtc = in->id.idcgtc * MP.NPNTCR;
				 }
				 DEBUG2("%s cgtc =%.2f\n", in->im.impcgtc);
			 }


             /* calculate cpp/qpp contributions tax credit  */
             in->im.impcpptc = (in->im.imcqppc - in->im.imcppse) * MP.NPNTCR;
             DEBUG2("%s cppctc =%.2f\n", in->im.impcpptc);

             /* calculate ui contributions tax credit  */
             in->im.impuictc = in->im.imuic * MP.NPNTCR;
             DEBUG2("%s uctc  =%.2f\n", in->im.impuictc);

             /* calculate tuition tax credit */
             if (isnzero(in->id.idtuitn)) {
                in->im.imptutxc = in->id.idtuitn * MP.NPNTCR;
                DEBUG2("%s tutxc  =%.2f\n", in->im.imptutxc);
             }

             /* calculate personal tax credit */
             in->im.impbtc = MP.NPNTCR * MP.NBXM;
                DEBUG2("%s btc    =%.2f\n", in->im.impbtc);

			 /*  Calculate the net income concept to match tax forms */
			 /*  This income is used in the age and medical tax credit income tests */

			 netinc = in->im.imicnet ;

             /*  calculate age amount tax credit  */
             if (in->id.idage >= 65) {
                DEBUG1("%s age tax credit\n");
                agered = minn(MP.NAXM, MP.NAXRR * nneg(netinc - MP.NAXTD));
                adjamt = MP.NAXM - agered;
                in->im.impatxc = MP.NPNTCR * adjamt;
             }
             DEBUG2("%s atxc   =%.2f\n", in->im.impatxc);

             /* calculate prov pension income tax credit    */
             in->im.imppentc = MP.NPNTCR * minn(MP.NYPNDL, in->im.imipnst);
             DEBUG2("%s pentxc =%.2f\n", in->im.imppentc);
 
			 /* compute allowable medical expenses using the value on the database */
			 if (isnzero(in->id.idmedgro)) {
			 	in->im.impmeda = nneg(in->id.idmedgro -
			 		minn(MP.NMEDALL, MP.NMEDANF * netinc));
			  	DEBUG3("%s idmedgro= %.2f impmeda =%.2f\n",
			  		in->id.idmedgro, in->im.impmeda);
			 }

			 /* calculate medical expenses tax credit */
			 if (isnzero(in->im.impmeda)) {
			  	in->im.impmedtc = in->im.impmeda * MP.NPNTCR;
			   	DEBUG2("%s pmedtc =%.2f\n", in->im.impmedtc);
			 }

			 /* calculate amount for infirm dependents age 18 or older */
			 /*  if the filer has an amount for idothpe, then give max credit */

			 if (isnzero(in->id.idothpe)) {
   				in->im.impothpe = MP.NPNTCR * MP.NODISTC;
                DEBUG2("%s othpe =%.2f\n", in->im.impothpe);
			 }
		     
             /* calculate prov charitable donations tax credit */
             if (isnzero(in->im.imchara)) {
                in->im.impchrtc = (minn(MP.NCHATL1, in->im.imchara)  * MP.NCHATR1
                            + nneg(in->im.imchara - MP.NCHATL1) * MP.NCHATR2);
                DEBUG2("%s chartc =%.2f\n", in->im.impchrtc);
             }
 
             /* set prov disability tax credit for self to maximum    */
             if (isnzero(in->id.iddisslf)) {
                in->im.impdistc = MP.NPNTCR * MP.NMAXDX;
             }
             DEBUG2("%s disatc =%.2f\n", in->im.impdistc);

             /* set disability tax credit for other to maximum    */
             if (isnzero(in->id.iddisoth)) {
               in->im.impdistc += (MP.NPNTCR * MP.NMAXDX);
             }
             DEBUG2("%s disatc =%.2f\n", in->im.impdistc);

             /* calculate prov education allowance tax credit */
             if (isnzero(in->id.ideducfm)) {
                in->im.impedtxc = MP.NPNTCR * (in->id.ideducfm * MP.NEDXPM);
                DEBUG2("%s edtxc  =%.2f\n", in->im.impedtxc);
             }
			 /*  add in the tax credit amount associated with part-time studies */
			 if (isnzero(in->id.ideducpm)) {
				if (isnzero(in->id.iddisslf) && in->id.ideducfm == 0 ) {
				    /* give only part time students the full time credit
					   if they also have an amount for disability */
					in->im.impedtxc = MP.NPNTCR * (in->id.ideducpm * MP.NEDXPM);
				}
				else {  /* has some part and/or full time and not disabled */
					in->im.impedtxc += MP.NPNTCR * (in->id.ideducpm * MP.NEDXPMPT);
                	DEBUG2("%s edtxc  =%.2f\n", in->im.impedtxc);
				}
			 }

			 /* calculate the interest paid on student loans tax credit */
			 /*  new for version 10.0, apply the Greenbook value idintstu */
			 if (isnzero(in->id.idintstu)) {
				in->im.impintsl = MP.NPNTCR * in->id.idintstu;
				DEBUG2("%s intsl =%.2f\n", in->im.impintsl);
			 }

             /* calculate federal dividend tax credit */
             if (isnzero(in->id.ididiv)) {
				in->im.impdtxc = (in->im.imisdivt * MP.NDTCR)
								+ (in->im.imildivt * MP.NDTCRLC);
	    	   	DEBUG2("%s fdtxc  =%.2f\n", in->im.impdtxc);
             }

			 /* calculate the Newfoundland minimum tax carry-over tax credit */
			 if (isnzero(in->id.idmincar)) {
				if (MP.NAMTOPT == 2) {
				   /* Alternative minimum taxes are calculated, use NAMTPCTF, the
				   /*  amt rate as pct of additional fed tax due to minimum tax
				   /*  to calculte the minimum tax carry-over credit. */
				   in->im.impminco = in->id.idmincar * MP.NAMTPCTF;
				 }
				 else if (MP.NAMTOPT == 3) { 
						/* Alternative minimum taxes are calculated using NAMTTX. */
						in->im.impminco = in->id.idmincar * MP.NAMTTX;
					  }
				 else if (MP.NAMTOPT == 4) {
						/* Alternative minimum taxes are calculated using NAMTPCTM. */
						 in->im.impminco = in->id.idmincar * MP.NAMTPCTM;
				 }
				 DEBUG2("%s pminco =%.2f\n", in->im.impminco);
			 }
            
             /*********************************************************
             *****  Calculation of basic personal tax
             **********************************************************/
            
             /* calculate provincial tax before tax credits    */
             /* if alternative minimum tax , option 3 = tax structure on federal net adjusted income */
			 if (in->im.imamtfg && MP.NAMTOPT == 3) {
                in->im.imprvtax = MP.NAMTTX * in->im.imamtinc;
             }
             else {
                in->im.imprvtax = (NUMBER) lkup1(MP.NPTX, MP.NPTXrows, in->im.imitax);
             }
             in->im.imbpt = in->im.imprvtax;

             /* census family children */
             if (in->id.idcfrh >= 2) {
                /* total non-transferable tax credits applicable to dependent */
                in->im.imptaxcr = in->im.impbtc      /* basic personal tax credit       */
                        + in->im.impatxc     /* age tax credit                  */
                        + in->im.impothpe    /* infirm dependents 18 and older tax credit */
                        + in->im.impchrtc   /* charitable donations tax credit */
                        + in->im.impcpptc   /* CPP contributions tax credit    */
                        + in->im.impmedtc   /* medical expenses tax credit     */
                        + in->im.imppentc   /* pension income tax credit       */
                        + in->im.impuictc    /* UI contributions tax credit     */
                        + in->im.impdtxc    /* provincial dividend tax credit     */
				        + in->im.impcgtc     /* caregiver tax credit  */
				        + in->im.impminco    /* minimum tax carry over */
						+ in->im.impintsl   /* provincial interest on student loans credit */
                        ;
                DEBUG2("%s child's  non-transferable tax credits=%.2f\n",
                        in->im.imtaxcr);
                in->im.impatxcr = ZERO;
                if (isnzero(in->im.imptaxcr)) {
                   /* if child's basic federal tax is more than transferable */
                   /* tax credits, apply total amount to reduce tax          */
                   if (in->im.imbpt > in->im.imptaxcr) {
                      in->im.impatxcr += in->im.imptaxcr;
                      in->im.imbpt -= in->im.imptaxcr;
                   }
                   else { /* in->im.imbpt <= in->im.imptaxcr */
                      in->im.impatxcr += in->im.imbpt;
                      in->im.imbpt = ZERO;
                   }
                   DEBUG3("%s child's bft    =%.2f, atxcrt=%.2f\n",
                         in->im.imbpt, in->im.impatxcr);
                }
                /* total transferable tax credits must be processed in 2 parts*/
                /* tfr2 contains the education allowance and tuition tax      */
                /*      credits which are subject to a maximum transferable   */
                /*      calculation dependent on the parameter MAXET          */
                /* tfr1 contains all other transferable tax credits           */
                tfr1 = in->im.impdistc;
                tfr2 = in->im.impedtxc + in->im.imptutxc;
                txcrt = tfr1 + tfr2;
                DEBUG2("%s child's  transferable tax credits    =%.2f\n", txcrt);
                in->im.imptaxcr += txcrt;
                if (isnzero(txcrt)) {
                   /* if child's basic federal tax is more than transferable */
                   /* tax credits, apply total amount to reduce tax          */
                   if (in->im.imbpt > txcrt) {
                      in->im.impatxcr += txcrt;
                      /* in->im.imttxcrt = 0.0  and no need to increase ctxcrt  */
                      in->im.imbpt -= txcrt;
                   }
                   else { /* txcrt >= in->im.imbpt */
                      /* the child has some tax credit left for a parent    */
                      /* reduce basic federal tax to zero and calculate     */
                      /* actual amount of transferable tax credits          */
                      in->im.impatxcr += in->im.imbpt;
                      in->im.imbpt = ZERO;
                      tfr2 = minn(MP.NPNTCR * MP.NMAXET,tfr2);
                      /* first calculate disability credit, then education amount */
  
                      tfr1 = nneg(tfr1  /* disability credit */
                              - nneg( (MP.NPNTCR * in->im.imitax)     /* taxable income * credit tax rate 
                                                                            to preserve idendity */
                                      - in->im.impbtc      /* basic personal tax credit       */
                                      - in->im.impatxc     /* age tax credit                  */
                                     /* next two credits equal zero for CF children */
                                     /*- in->im.immartxc      married tax credit */
                                     - in->im.impcpptc   /* CPP contributions tax credit    */
                                     - in->im.impuictc    /* UI contributions tax credit     */
                                     - in->im.imppentc));  /* pension income tax credit       */

                      tfr2 = nneg(tfr2  /* education and tuition */
                              - nneg( (MP.NPNTCR * in->im.imitax)     /* taxable income * credit tax rate 
                                                                         to preserve idendity */
                                    - in->im.impbtc      /* basic personal tax credit       */
                                    - in->im.impatxc     /* age tax credit                  */
                                    /* next two credits equal zero for CF children */
                                    /*- in->im.immartxc      married tax credit */
                                    - in->im.impcpptc   /* CPP contributions tax credit    */
                                    - in->im.impuictc    /* UI contributions tax credit     */
                                    - in->im.imppentc));  /* pension income tax credit       */

             
                      in->im.impttxct = tfr1+tfr2;
                      /* add extra to family ctxcrt */
                      ctxcrt += in->im.impttxct;
                      DEBUG2("%s ctxcrt = %.2f\n", ctxcrt);
                   }
                }
                DEBUG4("%s child's bft    =%.2f, atxcrt=%.2f, ttxcrt=%.2f\n",
                      in->im.imbpt, in->im.impatxcr, in->im.impttxct);
             }

             /* head or spouse of census family */
             if (in->id.idcfrh < 2) {
                /* total non-transferable tax credits applicable to parent */
                in->im.imptaxcr = in->im.impbtc      /* basic personal tax credit       */
                       + in->im.impchrtc   /* charitable donations tax credit */
                       + in->im.impcpptc   /* CPP contributions tax credit    */
			 		   + in->im.impothpe   /* infirm dependent 18 or older tax credit */
                       + in->im.impmartc   /* married tax credit              */
                       + in->im.impmedtc   /* medical expenses tax credit     */
                       + in->im.impuictc    /* UI contributions tax credit     */
				       + in->im.impdtxc    /* provincial dividend tax credit     */
					   + in->im.impminco   /* minimum tax carry over    */
					   + in->im.impintsl   /* provincial interest on student loans credit */
                       ;
                DEBUG2("%s parent's non-transferable tax credits=%.2f\n",
                     in->im.imptaxcr);
                in->im.impatxcr = ZERO;
                if (isnzero(in->im.imptaxcr)) {
                   /* if parent's basic federal tax is more than transferable */
                   /* tax credits, apply total amount to reduce tax          */
                   if (in->im.imbpt > in->im.imptaxcr) {
                      in->im.impatxcr += in->im.imptaxcr;
                      in->im.imbpt -= in->im.imptaxcr;
                   }
                   else { /* in->im.imbpt <= in->im.imptaxcr */
                      in->im.impatxcr += in->im.imbpt;
                      in->im.imbpt = ZERO;
                   }
                   DEBUG3("%s parent's bft   =%.2f, atxcrt=%.2f\n",
                         in->im.imbpt, in->im.impatxcr);
                }
                /* total transferable tax credits must be processed in 2 parts*/
                /* tfr2 contains the education allowance and tuition tax      */
                /*      credits which are subject to a maximum transferable   */
                /*      calculation dependent on the parameter MAXET          */
                /* tfr1 contains all other transferable tax credits           */
                tfr1 = in->im.impatxc   /* age tax credit                        */
                    + in->im.impdistc   /* disability tax credit                 */
				    + in->im.impcgtc    /* caregiver tax credit                  */
                    + in->im.imppentc   /* pension income tax credit             */
                    ;
                tfr2 = in->im.impedtxc + in->im.imptutxc;
                txcrt = tfr1 + tfr2;
                DEBUG2("%s parent's transferable tax credits    =%.2f\n", txcrt);
                in->im.imptaxcr += txcrt;
                if (isnzero(txcrt)) {
                   /* if basic federal tax is more than transferable         */
                   /* tax credits, apply total amount to reduce tax          */
                   if (in->im.imbpt > txcrt) {
                      in->im.impatxcr += txcrt;
                      /* in->im.impttxct = 0.0 */
                      in->im.imbpt -= txcrt;
                   }
                   else { /* txcrt >= in->im.imbpt */
                      /* the parent has some tax credits left for a         */
                      /* their spouse (if present) so reduce basic federal  */
                      /* tax to zero and calculate actual amount of         */
                      /* transferable tax credits                           */
                      in->im.impatxcr += in->im.imbpt;
                      in->im.imbpt = ZERO;
  
                      tfr2 = minn(MP.NPNTCR * MP.NMAXET, tfr2);
                       /* NB: use expanded net income (as on tax form) */
                      /* follows Schedule 2 */
                      in->im.impttxct = nneg(tfr1 + tfr2
                                         - MP.NPNTCR * nneg(in->im.imdepni -in->im.imdedfn - MP.NBXM -
                                                         (in->im.imcqppc - in->im.imcppse) - in->im.imuic ));
   
                   }
                }
                DEBUG4("%s parent's bft   =%.2f, atxcrt=%.2f, ttxcrt=%.2f\n",
                    in->im.imbpt, in->im.impatxcr, in->im.impttxct);
             } /* end of head/spouse */
          } /* end of person in census family loop.  
              we are still in a census family loop */                           

          /* if there is a spouse in the family */
          if (cf->cfspoflg) {
             DEBUG1("%s spouse present\n");
 
             /* if provincial taxes owing of the elder is greater than the taxes   */
             /* owing of the spouse, the elder receives any tax credits  */
             /* not needed by the spouse and children                    */
             /* The impcgtc will be claimed by the person with the most taxes owing */
             if (ineld->im.imbpt >= inspo->im.imbpt) {
                txcrt = inspo->im.impttxct + ctxcrt;
                ineld->im.imptaxcr += txcrt;
                DEBUG2("%s elder receives transfered tax credits=%.2f\n", txcrt);
                ineld->im.impstxct = inspo->im.impttxct;
                ineld->im.impttxct = ZERO;
                ineld->im.impctxct = ctxcrt;
                if (isnzero(txcrt)) {
                   /* if basic federal tax is more than transfered           */
                   /* tax credits, apply total amount to reduce tax          */
                   if (ineld->im.imbpt > txcrt) {
                      ineld->im.impatxcr += txcrt;
                      ineld->im.imbpt -= txcrt;
                   }
                   else { /* txcrt >= ineld->im.imbpt */
                      ineld->im.impatxcr += ineld->im.imbpt;
                      ineld->im.imbpt = ZERO;
                   }	 
                }
                DEBUG4("%s elder's bft  =%.2f, stxcrt=%.2f, ctxcrt=%.2f\n",
                    ineld->im.imbpt, ineld->im.imstxcrt, ineld->im.impctxct);
             } 		 
             else { /* spouse has greater income */
                txcrt = ineld->im.impttxct + ctxcrt;
                inspo->im.imptaxcr += txcrt;
                DEBUG2("%s spouse receives transfered tax credits=%.2f\n", txcrt);
                inspo->im.impstxct = ineld->im.impttxct;
                inspo->im.impttxct = ZERO;
                inspo->im.impctxct = ctxcrt;
                if (isnzero(txcrt)) {
                   /* if basic federal tax is more than transfered           */
                   /* tax credits, apply total amount to reduce tax          */
                   if (inspo->im.imbpt > txcrt) {
                      inspo->im.impatxcr += txcrt;
                      inspo->im.imbpt -= txcrt;
                   }
                   else { /* txcrt >= inspo->im.imbpt */
                      inspo->im.impatxcr += inspo->im.imbpt;
                      inspo->im.imbpt = ZERO;
                   }
                }
                DEBUG4("%s spouse's bft=%.2f, stxcrt=%.2f, ctxcrt=%.2f\n",
                  inspo->im.imbpt, inspo->im.impstxct, inspo->im.impctxct);
             }
          } 
          else { /* no spouse present */
             txcrt = ctxcrt;
             ineld->im.imptaxcr += txcrt;
             DEBUG2("%s elder (alone) receives transfered tax credits=%.2f\n", txcrt);
             ineld->im.impstxct = ZERO;
             ineld->im.impttxct = ZERO;
             ineld->im.impctxct = ctxcrt;
             if (isnzero(txcrt)) {
                /* if basic federal tax is more than transfered           */
                /* tax credits, apply total amount to reduce tax          */
                if (ineld->im.imbpt > txcrt) {
                   ineld->im.impatxcr += txcrt;
                   ineld->im.imbpt -= txcrt;
                }
                else { /* txcrt >= ineld->im.imbpt */
                   ineld->im.impatxcr += ineld->im.imbpt;
                   ineld->im.imbpt = ZERO;
                }
             }
             DEBUG4("%s elder's bft  =%.2f, stxcrt=%.2f, ctxcrt=%.2f\n",
                ineld->im.imbpt, ineld->im.impstxct, ineld->im.impctxct);
          } 	 
       } 
    } /* end of tax on taxable income calculation */


    /*******************************************************************
    *****  Calculate provincial taxes 
    ********************************************************************/

    /* process each person in household */
    for (ini=0, in=&hh->in[0]; ini<hh->hhnin; ini++, in++) {
        DEBUG6("%s person %d: age=%d, sex=%d, marst=%d, cfrh=%d\n",
           ini, in->id.idage, in->id.idsex, in->id.idmarst, in->id.idcfrh);

        /* original tax as percentage of federal tax */
        if (!MP.NTXFLG) { /* basic provincial tax */
            in->im.imbpt = in->im.imbft * MP.NPTF;
            in->im.imtxp = in->im.imbpt;   /* initialise tax paid to BPT */
        }
        /* if NTXFLG is turned on, then it's the tax on taxable income
           the bpt has already been calculated in the census family loop */
		else {
			if (in->im.imamtfg && MP.NAMTOPT == 2) {
			   /* minimum tax is equal to a percentage of the additional federal tax
			   	   attributable to the alternative minimum tax */
               in->im.imbpt += in->im.imamtprv * MP.NAMTPCTF;
			}
			else {
				if ( in->im.imamtfg && MP.NAMTOPT == 4 ) {
				  /* minimum tax is equal to a percentage of the federal minimum
				     amount attributable to the alternative minimum tax */
					in->im.imbpt = in->im.imminamt * MP.NAMTPCTM;
				}
			}
            in->im.imtxp = in->im.imbpt;   /* initialise tax paid to BPT */
		}

      /* compute and add in surtax */
	  /* the surtax was modified in 2000 to include a second stage */

      in->im.impsur = ( MP.NSF * nneg(in->im.imtxp - MP.NSCI) )
      					+ ( MP.NSF2 * nneg(in->im.imtxp - MP.NSCI2) );
      in->im.imtxp += in->im.impsur;

      /* calculate and apply provincial foreign tax credit */
      in->im.imnptc = minn(in->im.imtxp,in->id.idprvftc);
      in->im.imtxp -= in->im.imnptc;

      /**
      * COMPUTE NON-REFUNDABLE TAX CREDITS
      * Note: The carryover of tax credits from up to seven previous years
      *       is not implemented due to lack of data. Users could adjust the
      *       value of NTCMAX to allow more of the current year claim.
      **/
      /* This code commented out starting with version 9.0 as the greenbook	*/
	  /* variable could not be imputed due to small sample size             */
      /* ptc = minn(in->id.idvencap, MP.NTCMAX);    */
      /* in->im.imnptc += minn(ptc,in->im.imtxp);	*/
      /* in->im.imtxp  -= minn(ptc,in->im.imtxp);	*/

        DEBUG4("%s NFLD bpt=%.2f, txp=%.2f, ptc=%.2f\n",
            in->im.imbpt, in->im.imtxp, in->im.imnptc);

        /**
        * Non-refundable Political Contribution Tax Credit
        * Data will be unavailable until 1993 greenbook (SPSD94)
        **/
        if (isnzero(in->id.idprvpol)) {
            DEBUG1("%s nfld poltc\n");
            poltcr = (NUMBER) lkup1(MP.NPTC, MP.NPTCrows, in->id.idprvpol);
            poltc   = minn(MP.NPTCBEN, poltcr);
            in->im.impptc  = minn(poltc, in->im.imtxp);
            DEBUG4("%s nfld pol: idpolcon=%.2f poltcr=%.2f poltc=%.2f\n",
                in->id.idprvpol, poltcr, poltc);

           /* apply political contribution tax credit */
            in->im.imnptc += in->im.impptc;
            in->im.imtxp  -= in->im.impptc;

            DEBUG3("%s nfld pol: idpolcon =%.2f impptc =%.2f\n",
                in->id.idprvpol, in->im.impptc);
        }
        else {
            in->im.impptc = ZERO;
        }

        /* Newfoundland labour-sponsored venture capital credit */
        if ( isnzero(in->id.idlabtxg) ) {
           lvctc = minn(MP.NLVCMAX, MP.NLVCRT * in->id.idlabtxg);
           in->im.implvctc = minn(lvctc, in->im.imtxp);
           in->im.imnptc += in->im.implvctc;
           in->im.imtxp  -= in->im.implvctc;
        }

	}

	
        /* COMPUTE NEWFOUNDLAND TAX REDUCTION (Reduction starts in 2005) 

    /* process each nuclear family in household */
    for (nfi=0, nf=&hh->nf[0];  nfi<hh->hhnnf;  nfi++, nf++) {

        /* initialize pointers */
        nfeld = nf->nfineld;
        nfspo = nf->nfinspo;
        NUMBER ptr = ZERO;
        NUMBER faminc = ZERO;

        /**
        * Eligible persons are over age 18, or have a spouse, or have kids
        * We will give the tax reduction to the higher net income in a head/spouse family
        **/
            
	   	/* --- Determine family type ---- */
	   	/* --- Set initially to single and update to family if appropriate --- */
	   	ftype = 0;	 /* treat as single */
	   	if (nf->nfspoflg || nfeld->im.immartxc > 0 || nf->nfnkids) {
	   		ftype = 1;	 /* treat as family */
	   	}

        /* --- Assign the reduction amounts --- */
        /* Eligible individuals without a spouse get the basic reduction amount */
        if (ftype == 0) {
           	totred = MP.NLITRS;
			incthr = MP.NLITRSIT;
		}
		else {    /* give the family amount */
			totred = MP.NLITRF;
			incthr = MP.NLITRFIT;
		}
			            
        /* --- Calculate the allowed tax reduction --- */
        if (nf->nfspoflg)  {
			/* Calculate the net income concept used for the income test */
			redinc = nneg(nfeld->im.imicnet + nfspo->im.imicnet 
						- nfeld->im.imuccb - nfspo->im.imuccb );
            ptr = nneg(totred - (nneg(redinc - incthr) * MP.NLITRRR));
           
            /* give to spouse with highest taxes outstanding first */
            if (nfeld->im.imtxp > nfspo->im.imtxp) {
                /* elder had higher taxes */
                nfeld->im.imptr = minn(ptr,nfeld->im.imtxp);
                nfeld->im.imtxp -= nfeld->im.imptr;
                /* if there is any unused reduction, transfer to the other spouse */
                if (nfeld->im.imptr < ptr) {
                    nfspo->im.imptr = minn((ptr - nfeld->im.imptr),nfspo->im.imtxp);
                    nfspo->im.imtxp -= nfspo->im.imptr;
                }
            }
            else {
                /* spouse had higher taxes */
                nfspo->im.imptr = minn(ptr,nfspo->im.imtxp);
                nfspo->im.imtxp -= nfspo->im.imptr;
                /* if there is any unused reduction, transfer to the other spouse */
                if (nfspo->im.imptr < ptr) {
                    nfeld->im.imptr = minn((ptr - nfspo->im.imptr),nfeld->im.imtxp);
                    nfeld->im.imtxp -= nfeld->im.imptr;
                }
            }
		}
        else {
			redinc = nneg(nfeld->im.imicnet - nfeld->im.imuccb );
			ptr = nneg(totred - (nneg(redinc - incthr) * MP.NLITRRR));
            nfeld->im.imptr = minn(ptr,nfeld->im.imtxp);
            nfeld->im.imtxp -= nfeld->im.imptr;
        }
    }

    /* CALCULATE PROVINCIAL SALES TAX CREDIT */

    if (MP.NSTCFLAG) {

        /* process each census family in household */
        for (cfi=0, cf=&hh->cf[0];  cfi<hh->hhncf;  cfi++, cf++) {
    
            nelich = 0 ;  /* eligible children in household */
              
    
            /* initialise elder's pointer */
            ineld = cf->cfineld;
    
            /* add in the Nfld sales tax credit of the filer */
            pstc = MP.NSTCA;
    
            /* calculate contribution of eldest to family net income */
            faminet = nneg( ineld->im.imicnet - ineld->im.imuccb );
            DEBUG2("%s faminet=%.2f\n", faminet);
            DEBUG1("%s including elder's social assistance etc. in faminet\n");
            DEBUG4("%s imigis=%.2f imispa=%.2f imisa=%.2f\n",
                 ineld->im.imigis, ineld->im.imispa, ineld->im.imisa);
    
            if (cf->cfspoflg) {
                DEBUG1("%s spouse present\n");
                inspo = cf->cfinspo;
    
                /* add in the Nfld sales tax credit of the spouse */
                pstc += MP.NSTCA;
                DEBUG2("%s spouses's pstc=%.2f\n", MP.NSTCA);
    
                /* add spouse's net income to family net income */
                faminet += nneg(inspo->im.imicnet - inspo->im.imuccb );
            }
    
    
            /* count kids and assign benefit to persons over the age of 19*/
            /* process children in census family */
            for (ini=0, in=cf->cfinch;  ini<cf->cfnchild;  in++) {
    
               ini++;
    
               kidinet = ZERO;
               kidpstc = ZERO;
    
               if (in->id.idage >= 19)  {
                   /* Old children qualify for their own benefit */
                   kidpstc = MP.NSTCA;
                   kidinet = nneg(in->im.imicnet - in->im.imuccb );
                   /* since these are children in census family, they cannot have a 
                      spouse or children of their own */
                   kidinet *= MP.PYINC;
    
                   /* tax back credit (pstc) at reduction rate PSTCR on kidinet */
                   /* in excess of PSTCL.                                       */
    
                   taxbak1(kidinet, MP.NSTCL, &kidpstc, MP.NSTCR);
    
                   in->im.imptc = kidpstc;
    
               }
    
               /* if child is young enough, count for additional deduction for parent */
               else nelich++;
    
            }
    
            /* only persons 19 and older, or people who are married or who have kids can apply for benefit */
            if (!cf->cfspoflg && nelich==0 && cf->cfageeld < 19) {
                DEBUG1("%s skipping census families who are too young to qualify for credit'\n");
                continue;
            }
            
    
            /* if GST, then credit is calculated using previous years income */
            faminet *= MP.PYINC;
    
            /* add in the federal sales tax credit of the children */
            if (nelich != 0) {
                DEBUG3("%s %d kids present, adding %.2f\n",
                    nelich, nelich * MP.NSTCC);
                pstc += nelich * MP.NSTCC;
            }
    
    
            /* tax back credit (pstc) at reduction rate NSTCR on faminet */
            /* in excess of NSTCL.                                       */
    
            DEBUG2("%s faminet for reduction=%.2f\n", faminet);
            DEBUG2("%s pstc before reduction=%.2f\n", pstc);
            taxbak1(faminet, MP.NSTCL, &pstc, MP.NSTCR);
            DEBUG2("%s pstc after  reduction=%.2f\n", pstc);
    
            /**
            * In the absence of any other information,
            * assign PSTC to spouse with higher net income.
            **/
    
            if (cf->cfspoflg && (inspo->im.imitax > ineld->im.imitax)) {
                DEBUG1("%s spouse has higher taxable income and gets pstc\n");
                inspo->im.imptc = pstc;
            }
            else {
                DEBUG1("%s elder has higher taxable income and gets pstc\n");
                ineld->im.imptc = pstc;
            }
        }

    }

    /**
    * Newfoundland and Labrador Child Benefit 
    **/

   if (MP.NCBFLG==1) {
        DEBUG1("%s child benefit program in effect\n");

      /* process each nuclear family in household */
       for (nfi=0, nf=&hh->nf[0];  nfi<hh->hhnnf;  nfi++, nf++) {
            DEBUG4("%s cben: nf %d spoflg=%d, nkids=%d\n",
            nfi, nf->nfspoflg, nf->nfnkids);

         if (nf->nfnkids == 0) {
               DEBUG1("%s cben: skipping nuclear family with no `children'\n");
               continue;
         }

		 /* Count the number of kids aged 1 for the Mother Baby Nutrition Supplement */
		ninfants = 0;   
		if (nf->nfnkids > 0) {
			for (ini=0, in=nf->nfinch; ini<nf->nfnkids; ini++, in++) {
				if (in->id.idage < 1 ) {
					ninfants++;
				}
			 }
		 }
         /* Initialize local variables and head and spouse pointers */
         ineld = nf->nfineld;
         inspo = nf->nfinspo;

         /* net income for child benefit matches federal definition */
         nfinet = MP.PYINC * nneg( ineld->im.imicnet - ineld->im.imuccb);

         if (nf->nfspoflg) {
             nfinet += MP.PYINC * nneg(inspo->im.imicnet - inspo->im.imuccb);
         }

         /* Scale income with user specified rates */
         nfinet = nfinet * MP.CTCINC;

            DEBUG2("%s cben: neti=%.2f\n", nfinet);

         /***
         * Calculate Newfoundland and Labrador Child Benefit
         ***/
         if (nf->nfnkids > 0) {

    	     /* initialize base benefits*/
        	 cben2 = ZERO;
		 	 cbenmax2 = ZERO;
            
         	 /* Assign base amount which is dependent on number of kids */
         	 cbenmax2 =  ((MP.NCB1) + (MP.NCB2 * minn(nneg(nf->nfnkids-1),1)) +
                             (MP.NCB3 * minn(nneg(nf->nfnkids-2),1)) +
                             (MP.NCB4 * nneg(nf->nfnkids-3))) ;


         	/* Tax Back basic benefits 
				Families with net income between the initial turndown level NCBTD and the 
				phase out income level NCBPO will receive part of the benefit.  */
         	/* no phase in since the program starts in July, and Federal CTB are given from July to June */
        
         	ncbrr2 = cbenmax2 / (MP.NCBPO - MP.NCBTD);
			cben2 = nneg(cbenmax2 - nneg((nfinet-MP.NCBTD)*ncbrr2));
				
			/* Announced in 2002, Newfoundland introduced a new Mother Baby Nutrition Supplement 
			   to be given to families with kids under 1 beginning in July 2002.
			   This program provides a monthly benefit to families who receive at least
			   one dollar of NCB, the income cut-off will always mirror the NCBPO.
			   Eligible recipients will receive the full amount - there are no partial benefits 
			   The program will be phased in in 2002 using the parameter NMBNSPI. */

			mbns2 = ZERO;
			if (nfinet < MP.NCBPO && ninfants > 0 && cben2 > 0 ) {
				mbns2 = (MP.NMBNS * ninfants);
			}

			/* Announced in the 2004 Newfoundland Budget, an extra benefit 
			   to be given to eligible mothers of newborn babies at the time of their birth. */

		   	if (mbns2 > 0 && MP.NMBNSEXT) {
				mbns2 += (MP.NMBNSEXT * ninfants);
			} 
			
	         DEBUG3("%s cben: cben after reduction cben=%.2f neti=%.2f\n",
	                    cben2, nfinet );

			 if ( MP.FCBENCAL ) {
			 	 cbenmax1 = ZERO;
	            
				 /* Adjust nfinet to represent net income from 2 years previous */

				 nfinet = (nfinet/MP.PYINC) * MP.PYINCP;  


	         	 /* Assign base amount which is dependent on number of kids */
	         	 cbenmax1 =  ((MP.NCB1P) + (MP.NCB2P * minn(nneg(nf->nfnkids-1),1)) +
	                             (MP.NCB3P * minn(nneg(nf->nfnkids-2),1)) +
	                             (MP.NCB4P * nneg(nf->nfnkids-3))) ;


	         	 /* Tax Back basic benefits 
					Families with net income between the initial turndown level NCBTD and the 
					phase out income level NCBPO will receive part of the benefit.  */
	         	 /* no phase in since the program starts in July, and Federal CTB are given from July to June */
	        
	         	 ncbrr1 = cbenmax1 / (MP.NCBPOP - MP.NCBTDP);
				 cben1 = nneg(cbenmax1 - nneg((nfinet-MP.NCBTDP)*ncbrr1));
					
				 /* Announced in 2002, Newfoundland introduced a new Mother Baby Nutrition Supplement 
				   to be given to families with kids under 1 beginning in July 2002.
				   This program provides a monthly benefit to families who receive at least
				   one dollar of NCB, the income cut-off will always mirror the NCBPO.
				   Eligible recipients will receive the full amount - there are no partial benefits 
				   The program will be phased in in 2002 using the parameter NMBNSPI. */

				 mbns1 = ZERO;
				 if (nfinet < MP.NCBPOP && ninfants > 0 && cben1 > 0 ) {
					mbns1 = (MP.NMBNSP * ninfants) ;
				 }

				 /* Announced in the 2004 Newfoundland Budget, an extra benefit 
				    to be given to eligible mothers of newborn babies at the time of their birth. */

			   	 if (mbns1 > 0 && MP.NMBNSEXTP) {
				  	mbns1 += (MP.NMBNSEXTP * ninfants);
				 } 
				
		         DEBUG3("%s cben: cben after reduction cben=%.2f neti=%.2f\n",
		                    cben1, nfinet );
				 
				 /* Inside the model for calendar year loop */
				 
				 cben = (cben1/ 2) + (cben2 / 2);
				 mbns = (mbns1/ 2) + (mbns2 / 2);
			 }
			 else {   /* use the July to June amounts for the whole year */
				 cben = cben2;
				 mbns = mbns2; 		

			 }

	         /* assign child benefits to mother if present */

	         if (nf->nfspoflg && (inspo->id.idsex == FEMALE)) {
	            DEBUG1("%s cben: spouse is the mother, gets CTC\n");
	            inspo->im.imncb  = cben;
				inspo->im.imnmbns = mbns;

	          }
	          else {
	             DEBUG1("%s cben: elder receives CTC\n");
	             ineld->im.imncb  = cben;
				 ineld->im.imnmbns = mbns;
	           }
		  }
      }
   }

	/* Home Heating Fuel Tax Credit */

    if (MP.NHEATFLG) {

		/* initialise flag to indicate that one family has already received the credit*/
		gotheat = 0;

        /* process each census family in household in reverse order */
		for (cfi=0, cf=&hh->cf[hh->hhncf-1]; cfi<hh->hhncf; cfi++, cf--) {


			/* initialise the number of eligible household individuals to 0 */
			elgind = 0;
			heatinc = 0;


			/* initialise elder's pointer */
			ineld = cf->cfineld;

			/* initialise spouse's pointer if spouse is present. */

			if (cf->cfspoflg) {
				inspo = cf->cfinspo;
			}
			
			/* Only those households that use home heating fuel as the primary source of heat
			   are eligible.  Assuming those households with net expenditure on natural gas
			   or other fuels are eligible.  */
	
			if ( fx->fxio[13] > 0 || fx->fxio[14] > 0 ) {
	

				/* beginning in 2005, the program changed from being targeted to 
					recipients of certain programs to an income test */
				if (MP.NHEATINC) {
					/* Need to capture the income of head and spouse's net income */
					heatinc = ineld->im.imicnet ;
					if (cf->cfspoflg) {
						heatinc += inspo->im.imicnet ;
					}
					if (heatinc < MP.NHEATPO) {
						elgind++;
					}
			   	}
				else {   /* program is targeted to GIS, NCB, SA recipients */
					/* The one time $100 rebate for households that use home heating fuel
					   and where an individual in that household receives any amount of the NFLD
					   Child Benefit, NFLD HST credit or the Senior's Benefit.  */
				
					/* Determine if any eligible individuals  - process persons in census family  */
				    for (ini=0, in=cf->cfin;  ini<cf->cfnpers;  ini++, in++) {
						if (in->im.imncb > 0 || in->im.imptc > 0 || in->im.imigist > 0 || (MP.NHEATSAFLG && in->im.imisa > 0)) {
							elgind++;
					   	}
					}
				}
			}

            /* is there an eligible person to receive the benefit, and is this the first 
               family in the household who can receive the benefit */
			if ( elgind > 0 && gotheat==0 ) {


			    /* If this is an eligible household, give to spouse with higher net income.	 */
				if (cf->cfspoflg && (inspo->im.imitax > ineld->im.imitax)) {
					DEBUG1("%s spouse has higher taxable income and gets heating rebate\n");
					if (MP.NHEATINC) {
						inspo->im.impheatr = maxn(MP.NHEATREB- nneg((heatinc - MP.NHEATTD)* MP.NHEATRR), MP.NHEATMIN);
					}
					else {
						inspo->im.impheatr = MP.NHEATREB ;
					}
				}
				else {
					DEBUG1("%s elder has higher taxable income and gets heating rebate\n");
					if (MP.NHEATINC) {
						ineld->im.impheatr = maxn(MP.NHEATREB- nneg((heatinc - MP.NHEATTD)* MP.NHEATRR), MP.NHEATMIN);
					}
					else {
						ineld->im.impheatr = MP.NHEATREB ;
				   		/* indicate that person has income */
					}
				}
                
                /* check that family has gotten credit */
				if (ineld->im.impheatr>0 || inspo->im.impheatr>0) {
                   gotheat=1;
				}

			}
		}
	}
    DEBUG_OFF("Atxnfld");
}
