/***
*Atxprov.cpp - Compute provincial taxes
*
*$Id: TXPROV.cpp 6.87 2007/09/18 17:22:08 hickcha Exp $
*
*   SPSD/M Copyright (c) 1987-1995, Minister of Industry.
*   All rights reserved.  Use, reproduction, or disclosure of this work,
*   as well as publication of results derived from this work, are subject
*   to the conditions specified in the SPSD/M License Agreement.
*
*Purpose:
*   This file contains the definition of the .c function.
*
*Revisions:
* +-----+----------+---------------------------------------------------------+
* | Who |   Date   | Description                                             |
* +-----+----------+---------------------------------------------------------+
* | TCB | 98/05/28 | Renamed *.cpp, ANSI function headers                    |
* | BBM | 92/07/06 | Add Manitoba Cost of living & property tax credits      |
* | BBM | 92/07/02 | Add Manitoba political contribution tax credits         |
* | BBM | 92/06/22 | Add Manitoba reform surtax and tax reduction            |
* | SFG | 91/07/17 | Protect Ont reduction from exceeding provincial tax     |
* | BBM | 91/07/10 | Add Saskatchewan Family Tax Credit                      |
* | BBM | 91/07/05 | Add N.B. provincial surtax (effective for 1991)         |
* | BBM | 91/07/05 | Ammend BC surtax code to allow dependant credits        |
* | BBM | 91/06/27 | Add option for Ont. tax red. based on personal amounts  |
* | BBM | 91/06/27 | Add N.S. provincial surtax                              |
* | SFG | 89/12/07 | Protect Sask reduction from exceeding provincial tax    |
* | --- | 89/10/13 | Release 4.0                                             |
* |     |          |                                                         |
* +-----+----------+---------------------------------------------------------+
*
*Definitions:
*   Atxprov  [global]  Compute provincial taxes
*
*****************************************************************************/


/* ==================== C-RUNTIME LIBRARY INCLUDE FILES =================== */

#include <stdio.h>  /* definitions/declarations for standard I/O routines   */


/* ==================== SPSD/M INCLUDE FILES ============================== */

#include "spsm.h"   /* SPSM common manifest constants and macros            */
#include "sub.h"    /* Subroutine library declarations                      */
#include "vsu.h"    /* Household variable sub-structure (user's)            */
#include "vs.h"     /* Household variable structure and sub-structures      */
#include "mpu.h"    /* Tax/transfer parameter declarations (user's)         */
#include "mp.h"     /* Tax/transfer parameter declarations                  */


/* ==================== GLOBAL VARIABLE DEFINITIONS ======================= */

/* Give global string describing version of this module */

/*global*/ char FAR Ttxprov[] = "Untitled"
#ifdef _MSC_VER
" [" __TIMESTAMP__ "]"
#endif
;


/* ==================== COMPILER PRAGMAS ================================== */

#ifdef MSCOVL

#endif


/* ==================== FUNCTION DEFINITIONS ============================== */


/*****************************************************************************
*Atxprov - Compute provincial taxes
*
*Synopsis:
*    void Atxprov(         
*    P_hh hh              
*    )                    
*
*Description:
*
*Return Value:
*   None.
*
*Calls:
*   txnfld   Compute provincial taxes for Newfoundland
*   txpei    Compute provincial taxes for P.E.I.
*   txns     Compute provincial taxes for Nova Scotia
*   txnb     Compute provincial taxes for New Brunswick
*   txque    Compute provincial taxes for Quebec
*   txont    Compute provincial taxes for Ontario
*   txman    Compute provincial taxes for Manitoba
*   txsask   Compute provincial taxes for Saskatchewan
*   txalta   Compute provincial taxes for Alberta
*   txbc     Compute provincial taxes for British Columbia
*
*Structure Members:
*   hd.hdprov       (i)  Province
*
*Called by:
*   drv      Tax/transfer calculator
*
*****************************************************************************/
void Atxprov(
	P_hh hh
)
{

	DEBUG_ON("Atxprov");

	switch (hh->hd.hdprov) {
		case PRNFLD:
			txnfld(hh);
			break;

		case PRPEI:
			txpei(hh);
			break;

		case PRNS:
			txns(hh);
			break;

		case PRNB:
			txnb(hh);
			break;

		case PRQUE:
			txque(hh);
			break;

		case PRONT:
			txont(hh);
			break;

		case PRMAN:
			txman(hh);
			break;

		case PRSASK:
			txsask(hh);
			break;

		case PRALTA:
			txalta(hh);
			break;

		case PRBC:
			txbc(hh);
			break;
	}
	DEBUG_OFF("Atxprov");
}
