/***
*Atxqinet.cpp - Compute net income (Quebec)
*
*$Id: Atxqinet.cpp 6.130 2007/09/18 17:22:12 hickcha Exp $
*
*   SPSD/M Copyright (c) 1987-1995, Minister of Industry.
*   All rights reserved.  Use, reproduction, or disclosure of this work,
*   as well as publication of results derived from this work, are subject
*   to the conditions specified in the SPSD/M License Agreement.
*
*Purpose:
*   This file contains the definition of the .c function.
*
*Revisions:
* +-----+----------+---------------------------------------------------------+
* | Who |   Date   | Description                                             |
* +-----+----------+---------------------------------------------------------+
* | LP  | 07/07/23 | Removed the nneg constraint on imqitot (no longer appl) |
* | CH  | 07/07/17 | Added new option for complementary amount               |
* | CH  | 07/02/22 | Make pension income split variables fractional          |
* | CH  | 07/02/06 | Added pension income splitting                          |
* | LP  | 07/01/25 | Apply QEEXPDED to idclergy - treat the same as imqalexp |
* | LP  | 07/01/23 | Removed imninc - no income flag - no longer used        |
* | LP  | 07/01/17 | Moved imqempdd from imqdedfn to imqdedft/tax form verify|
* | LP  | 07/01/16 | Removed imuccb from imqitot, add to imqitax (tax form)  |
* | LP  | 07/01/12 | Removed parameter QHSCDIR - no longer needed, fixed bug |
* | LP  | 06/12/13 | Switched iminet to imicnet, imitot to imictot (tax form)|
* | LP  | 06/07/11 | Added idclergy to imqdedft - deduct from total income   |
* | LP  | 06/06/01 | Added imuccb (universal child care benefit) to imqitot  |
* | LP  | 06/05/15 | Split taxable dividends in small/lrg imqldivt, imqsdivt |
* | CH  | 06/01/18 | Protected against division by 0 in QPIP se txcrd/ded    |
* | CH  | 06/01/04 | Moved QPIP stuff here                                   |
* | LP  | 05/12/20 | Added QPIP benefits in year (imqpipcbn) to total income |
* | LP  | 05/05/30 | Added QRNCGFLG to calc of disablity tax cred -simp. form|
* | LP  | 04/02/13 | Added idintstu to simplified tax form test              |
* | LP  | 04/02/05 | Added idialimo, idiworkc to imqitot, moved imrepay      |
* | LP  | 03/11/17 | Added imqintsl, QINTSLTC - student loan interest credit |
* | CH  | 03/10/17 | Deleted iditogv, replaced idiint + idioinv by idiinvrd  |
* | LP  | 02/04/30 | Added QNORTHDED, QSFDED - standardize net inc. on simp. |
* | LP  | 01/05/30 | Ensure that imqcapgt does not become negative           |
* | LP  | 01/02/28 | Removed pre-1988 database variable activation parameters|
* | LP  | 01/02/28 | Adjust the use of imqcppse in simplified tax form test  |
* | LP  | 00/11/16 | Apply QSPBFLAG, social prog benefits in total inc. flag |
* | CH  | 00/05/24 | Added iditrrsp                                          |
* | LP  | 00/05/03 | Apply QEEXPDED to employment expenses                   |
* | CH  | 00/04/14 | Apply QCAPGIR to capgex stkded and iloss                |
* | LP  | 00/04/11 | Added improved tax system for self-employed workers     |
* | LP  | 00/04/06 | Added QSFSMXI for simplified tax form work sheet        |
* | CH  | 00/03/28 | Added Employment expenses to simplifed tax calculation  |
* | CH  | 99/05/21 | Added simplified tax form calculation                   |
* | BBM | 99/02/11 | Drop idiroom from imqitot(now incl in idisenf as of 7.0)|
* | TCB | 98/05/28 | Renamed *.cpp, ANSI function headers                    |
* | EGA | 98/03/09 | Add idexplor, QTUIOPT, imqtuitc                         |
* | EGA | 98/02/13 | Add QDUESOPT, imqduetc                                  |
* | CCH | 97/08/28 | Added idothded, idexplor, idmovexp, iddalimo to imqdedft|
* | BBM | 94/09/30 | Add social repayments netted from total income option	 |
* | BBM | 94/09/30 | Add cpp/ui non-refundable tax credit option			 |
* | SFG | 90/09/27 | use imqtfa for quebec taxable FA                        |
* | --- | 89/10/13 | Release 4.0                                             |
* |     |          |                                                         |
* +-----+----------+---------------------------------------------------------+
*
*Definitions:
*   Atxqinet [global]  Compute net income (Quebec)
*
*****************************************************************************/



/* ==================== C-RUNTIME LIBRARY INCLUDE FILES =================== */

#include <stdio.h>  /* definitions/declarations for standard I/O routines   */


/* ==================== SPSD/M INCLUDE FILES ============================== */

#include "spsm.h"   /* SPSM common manifest constants and macros            */
#include "sub.h"    /* Subroutine library declarations                      */
#include "vsu.h"    /* Household variable sub-structure (user's)            */
#include "vs.h"     /* Household variable structure and sub-structures      */
#include "mpu.h"    /* Tax/transfer parameter declarations (user's)         */
#include "mp.h"     /* Tax/transfer parameter declarations                  */


/* ==================== GLOBAL VARIABLE DEFINITIONS ======================= */

/* Give global string describing version of this module */

/*global*/ char FAR Ttxqinet[] = "Untitled"
#ifdef _MSC_VER
" [" __TIMESTAMP__ "]"
#endif
;


/* ==================== COMPILER PRAGMAS ================================== */

#ifdef MSCOVL

#endif


/* ==================== FUNCTION DEFINITIONS ============================== */


/*****************************************************************************
*Atxqinet - Compute net income (Quebec)
*
*Synopsis:
*    void Atxqinet(        
*    P_hh hh              
*    )                    
*
*Description:
*
*Return Value:
*   None.
*
*Calls:
*   round    Round to nearest integer
*   minn     Find the minimum of two numbers
*   nneg     Change negative numbers to zero
*   isnzero  Is argument non-zero ?
*   lkup1    Table look-up with interpolation/extrapolation
*   isnneg   Is argument non-negative ?
*   txqccea  Compute child care expense allowance (Quebec)
*
*Structure Members:
*   MP.CPPXM        (i)  CPP/QPP exemptible earnings
*   MP.DIVPLC       (i)  Percentage of dividends from large (eligible) corporations
*   MP.QALEXP       (i)  Quebec proportion of other allowable employment expenses to use
*   MP.QCAPGIR      (i)  Quebec capital gains inclusion rate
*   MP.QCMPOPT      (i)  Quebec Complementary Credit option
*   MP.QCPPOPT      (i)  Quebec CPP/QPP contribution deduction/credit option [1=deduction,2=credit]
*   MP.QDGUR        (i)  Quebec dividend gross-up rate
*   MP.QDGURLC      (i)  Quebec dividend gross-up rate from large (eligible) corporations
*   MP.QDTCR        (i)  Quebec dividend tax credit rate
*   MP.QDTCRLC      (i)  Quebec dividend tax credit rate from large (eligible) corporations
*   MP.QDUESOPT     (i)  Quebec Dues Tax Credit option
*   MP.QEAMAX       (i)  Quebec maximum employment allowance deduction
*   MP.QEAP         (i)  Proportion of earnings for Quebec employment allowance deduction
*   MP.QEEXPDED     (i)  Quebec employment expenses deduction application flag
*   MP.QEMPDEDM     (i)  Quebec earned income deduction for workers maximum
*   MP.QEMPDEDP     (i)  Quebec earned income deduction percent of income
*   MP.QHSC         (i)  Quebec Health Services Fund Contribution table
*   MP.QHSCrows     (i)  number of rows in QHSC
*   MP.QHSOASFG     (i)  Quebec Health Services Fund Contribution OAS Deduction flag
*   MP.QINTSLTC     (i)  Quebec student loan interest tax credit flag
*   MP.QITSFSEW     (i)  Quebec improved tax system for self-employed worker activation flag
*   MP.QITSSEF      (i)  Quebec percentage of self-employ CPP/QPP contributions to convert to deduction
*   MP.QMAXDX       (i)  Quebec maximum disability deduction/amount
*   MP.QMEDANF      (i)  Quebec medical allowance lower limit net income fraction
*   MP.QNORTHDED    (i)  Quebec northern deductions - 0=for taxable income, 1=for net income
*   MP.QNTCR        (i)  Quebec nominal tax credit rate
*   MP.QPIPF        (i)  Quebec parental insurance plan contribution rate for paid workers
*   MP.QPIPFLAG     (i)  Quebec parental insurance plan activation flag
*   MP.QPIPFSE      (i)  Quebec parental insurance plan contribution rate for self-employed
*   MP.QREPFAMI     (i)  Quebec repayment of UI/OAS benefits deduct from income flag
*   MP.QREPNETFG    (i)  Social program repayments reduce Quebec net income flag
*   MP.QRNCGFLG     (i)  Quebec Natural Caregivers Tax Credit activation flag
*   MP.QSFDED       (i)  Quebec Simplified Form - additional deductions for net income calculation flag
*   MP.QSFDISFLAG   (i)  Quebec Simplified Form Disability tax credit inclusion flag
*   MP.QSFMEDFLAG   (i)  Quebec Simplified Form medical expense tax credit inclusion flag
*   MP.QSFOPT       (i)  Quebec Simplified Form Option (1=general 2=simplified 3=optimized)
*   MP.QSFSMXI      (i)  Quebec simplified form spouse maximum income for work sheet
*   MP.QSFTC        (i)  Quebec Simplified Form tax credit
*   MP.QSPBFLAG     (i)  Quebec inclusion of social program benefits in income flag
*   MP.QSPLTPNSFLAG (i)  Quebec flag to split pension income
*   MP.QTUIOPT      (i)  Quebec tuition tax credit option
*   MP.QTX          (i)  Quebec income tax table [taxable income,basic provincial tax]
*   MP.QTXrows      (i)  number of rows in QTX
*   MP.QUICOPT      (i)  Quebec UI contributions deduction/credit option [1=deduction,2=credit]
*   MP.WSCF         (i)  CPP/QPP contribution rate on employment earnings
*   MP.YMPE         (i)  CPP/QPP maximum pensionable earnings
*   cf.cfin         (i)  First person in census family [pointer]
*   cf.cfnpers      (i)  Number of persons in census family
*   cf.cfspoflg     (i)  Census family contains married couple
*   hh.cf           (i)  Census family data [array]
*   hh.hhncf        (i)  Number of census families in household
*   hh.hhnin        (i)  Number of individuals in household
*   hh.in           (i)  Individual data [array]
*   id.idalexp      (i)  Other allowable employment expenses (229)
*   id.idcapgex     (i)  Capital gains exemptions (254)
*   id.idcarry      (i)  Carrying charges (221)
*   id.idcfrh       (i)  Relationship to census family head
*   id.idclergy     (i)  Clergy residential deduction
*   id.idcloss      (i)  Allowable other years capital loss (253)
*   id.iddalimo     (i)  Alimony paid (220)
*   id.iddisoth     (i)  Disability amount for dependants (318)
*   id.iddisslf     (i)  Disability amount for self (316)
*   id.iddues       (i)  Union and professional dues (212)
*   id.idemplo      (i)  Employee home relocation loan dedn (248)
*   id.idexplor     (i)  Exploration and development expenses (224)
*   id.idialimo     (i)  Alimony income received
*   id.idicapg      (i)  Capital gains (actual)
*   id.idicqp       (i)  CPP/QPP income (114)
*   id.ididiv       (i)  Dividend income (actual)
*   id.idiemp       (i)  Wages & salaries
*   id.idiinvnd     (i)  Interest and other investment income
*   id.idiloss      (i)  Business investment losses (217)
*   id.idinspo      (i)  Person's spouse [pointer]
*   id.idintstu     (i)  Interest paid on student loans (319)
*   id.idipens      (i)  Pension income (115)
*   id.idisefm      (i)  Self-employed income - farming
*   id.idisenf      (i)  Self-employed income - non-farming
*   id.iditoth      (i)  Other taxable income (130)
*   id.iditrrsp     (i)  Taxable RRSP withdrawals
*   id.idiworkc     (i)  Workers compensation benefits
*   id.idmedgro     (i)  Medical expenses, gross (330)
*   id.idmovexp     (i)  Imputed moving expenses (219)
*   id.idnclos      (i)  Allowable other years non-capital loss (252)
*   id.idnorth      (i)  Northern deductions (255)
*   id.idothded     (i)  Other deductions from total income (232)
*   id.idpartlo     (i)  Limited partnership losses (251)
*   id.idrpp        (i)  Registered pension plan contributions (207)
*   id.idrrsp       (i)  RRSP calculated amount (208)
*   id.idspoflg     (i)  Person has spouse
*   id.idstkded     (i)  Stock option deduction (249)
*   id.idtuitn      (i)  Tuition fees (320)
*   im.imcqppc      (i)  CPP/QPP contributions
*   im.imicnet      (i)  Net Income (line 236)
*   im.imictot      (i)  Total Income (line 150)
*   im.imigis       (i)  GIS benefits
*   im.imioas       (i)  OAS benefits
*   im.imiotg       (i)  Other taxable demogrants
*   im.imisa        (i)  Social assistance (or replacement program)
*   im.imispa       (i)  Spouse's allowance
*   im.imiuib       (i)  Unemployment Insurance/Employment Insurance benefits
*   im.imoasr       (i)  OAS recovery
*   im.imqpipcbn    (i)  Quebec parental insurance plan calendar year benefits
*   im.imqpipp      (i)  Quebec parental insurance plan premiums for paid workers
*   im.imqpippse    (i)  Quebec parental insurance plan premiums for self-employed
*   im.imqpnsph     (i)  Quebec pension income split for head
*   im.imqpnsps     (i)  Quebec pension income split for spouse
*   im.imqtfa       (i)  Quebec taxable family allowances
*   im.imrepay      (i)  Social Benefits Repayments
*   im.imuibr       (i)  UI benefit recovery
*   im.imuic        (i)  UIC contributions
*   im.imqalexp     (io) Quebec allowable employment expenses
*   im.imqcapgt     (io) Quebec taxable capital gains
*   im.imqcppse     (io) Quebec self-employ. QPP/CPP Cont. deduction
*   im.imqdedea     (io) Quebec employment allowance
*   im.imqdedft     (io) Quebec deductions from total income
*   im.imqempdd     (io) Quebec earned income deduction for workers
*   im.imqidivt     (io) Quebec taxable dividends
*   im.imqiloss     (io) Quebec Modelled Business investment losses (234)
*   im.imqinet      (io) Quebec net income
*   im.imqipnst     (io) Quebec taxable pension income (after splitting)
*   im.imqitot      (io) Quebec total income
*   im.imqldivt     (io) Quebec taxable dividends from large (eligible) corporations
*   im.imqqpsedd    (io) Quebec parental insurance plan premium deduction for self-employed (Quebec)
*   im.imqsdivt     (io) Quebec taxable dividends from small corporations
*   im.imqsfflg     (io) Quebec simplified tax form flag 0=general 1=simplified
*   im.imqcpptc     (o)  Quebec CPP/QPP contributions tax credit
*   im.imqduetc     (o)  Quebec Dues Tax Credit
*   im.imqintsl     (o)  Quebec student loan interest tax credit
*   im.imqqpiptc    (o)  Quebec parental insurance plan premium tax credit for paid workers (Quebec)
*   im.imqqpsetc    (o)  Quebec parental insurance plan premium tax credit for self-employed (Quebec)
*   im.imqtuitc     (o)  Quebec Tuition Tax Credit
*   im.imquictc     (o)  Quebec UI contributions tax credit
*
*Called by:
*   txque    Compute provincial taxes for Quebec
*
*****************************************************************************/
void Atxqinet(
	P_hh hh
)
{
	register P_in in;  /* pointer to data for current person  */
	register P_in inspo;  /* pointer to spouse */

	P_cf cf;
	register int cfi;
    NUMBER headsplit = ZERO;   /* Amount of pension income head to give to spouse */
    NUMBER sposplit = ZERO;    /* Amount of pension income spouse to give to head */

	register int ini;

	register NUMBER qitot;

	DEBUG_ON("Atxqinet");

    /* Start by splitting pension income */
	/* process each census family in household */
	for (cfi=0, cf=&hh->cf[0];  cfi<hh->hhncf;  cfi++, cf++) {
        if ( MP.QSPLTPNSFLAG ) {
            /* split pension income, if appropriate */
            /* amount to be split is first set to zero */
            headsplit = 0.0;
            sposplit = 0.0;

            /* calculate amount to be split */
            if (cf->cfspoflg) {
    			for (ini=0, in=&cf->cfin[0]; ini<cf->cfnpers; ini++, in++) {
                    if (in->id.idcfrh==0 && in->im.imqpnsph>0 && in->id.idipens>0) {
                        headsplit= round(in->id.idipens * in->im.imqpnsph);
                    }
                    else if (in->id.idcfrh==1 && in->im.imqpnsps>0 && in->id.idipens>0) {
                        sposplit= round(in->id.idipens * in->im.imqpnsps);
                    }
                }
            }
            /* now split income */
            /* note, only one of headsplit or sposplit might be greater than 0, so use this fact to our advantage */
    		for (ini=0, in=&cf->cfin[0]; ini<cf->cfnpers; ini++, in++) {
                if (in->id.idcfrh==0) {
                    in->im.imqipnst = in->id.idipens - headsplit + sposplit;
                }
                else if (in->id.idcfrh==1) {
                    in->im.imqipnst = in->id.idipens + headsplit - sposplit;
                }
                else {
                    in->im.imqipnst = in->id.idipens ;
                }
            }
        }
        else {
            /* taxable pension income is equal to original pension income */
			for (ini=0, in=&cf->cfin[0]; ini<cf->cfnpers; ini++, in++) {
                 in->im.imqipnst = in->id.idipens;
			}
        }
	}

	/* process each person in household */
	for (ini=0, in=&hh->in[0]; ini<hh->hhnin; ini++, in++) {


		DEBUG6("%s person %d: age=%d, sex=%d, marst=%d, cfrh=%d\n",
		         ini, in->id.idage, in->id.idsex, in->id.idmarst, in->id.idcfrh);

		/****
		   If the simplified tax form is in existence (started in 1998) this 
		   calculations indicates which stream the person will file. 
		****/

		NUMBER qstc;  /* simplified tax form amount */
		NUMBER famnet;  /* family net income */
		NUMBER hsfinc;  /* income for HSF */
		NUMBER secon;   /* contributions to CPP/QPP on self-employed earnings */
		NUMBER qdivtc;  /* Quebec dividend tax credit for simplified form */
		NUMBER earninc = ZERO;  /* earned income for worker's deduction */

		qstc = ZERO;
		famnet=ZERO;
		hsfinc=ZERO;
		secon =ZERO;

        /* apply capital gains to allowable business losses */
        in->im.imqiloss = in->id.idiloss * MP.QCAPGIR;

		/* calculate the contributions to CPP/QPP on self-employed earnings first.
		   The Quebec 2000 budget announced changes to the treatment of these contributions
		   to enable the increasing number of self-employed workers to use the 
		   simplified tax form.  Without this change, their contributions would exceed
		   the flat amount granted under the simplified tax form, thus deriving no advantage
		   from using this system. */

		/* determine if the improved tax system for self employed workers is in effect */

		if (MP.QITSFSEW == 1 ) {  
		   /* contributions to CPP/QPP for self-employed earnings are those contributions
		      to CPP/QPP that are not from employment income */
		   secon = nneg(in->im.imcqppc - (MP.WSCF * minn((MP.YMPE - MP.CPPXM), 
		                          nneg(in->id.idiemp - MP.CPPXM))));
		   /* convert a proportion, QITSSEF (50% in 2000) of the tax credit granted in 
		      respect of amounts payable into a deduction in the calculation of income */
		   /* the variable represents the allowable proportion of contributions 
		      before converting	into the amount of the tax credit */
		   in->im.imqcppse = secon * MP.QITSSEF;
		}
	
		/* always use general tax form */
		if (MP.QSFOPT == 1) {
			in->im.imqsfflg = 0;
		}
		/* always use simplified tax form */
		else if (MP.QSFOPT == 2)  {
			in->im.imqsfflg =1;
		}
		/* optimize tax system */
		/* This calculation is a proxy of the worksheet which was provided to filers
		   which they could use in order to decide which tax form was to their advantage */
		else if (MP.QSFOPT == 3) {
			/* initialize spouse pointer */
		   inspo = in->id.idinspo;
		   /* initialize to simplified form tax credit*/
		   qstc = MP.QSFTC;
			
		   /* if there is a spouse and if their income is less than 6786 (QSFSMXI), then double the base amount*/
		   if (in->id.idspoflg) {
		      /* use federal total income as proxy */
			  if (inspo->im.imictot < MP.QSFSMXI) {
				 qstc += MP.QSFTC;
			  }
           }

            
           /* Remove tax credits */

		   qstc -= (  in->im.imcqppc  /* CPP contributions */
                    + in->im.imuic    /* UI contributions  */
					+ in->id.iddues);   /* union and professional dues */
		   if (isnzero(in->id.iddisslf) && !MP.QSFDISFLAG) {
		      qstc -= MP.QMAXDX;       /* amount for severe impairment */
		   }
		   if (MP.QITSFSEW == 1) { /* improved tax system for self-employed workers */
				/* under this system, add only half of the contributions to cpp contributions */
				/* since these are already included in imcqppc, which has already been subtracted 
				   from qstc, then add back half of contributions for self employment */
		      qstc += in->im.imqcppse;
		   }

	       if (qstc < 0) {
		      in->im.imqsfflg = 0;  /* person should use the general income tax return */
		   }
		   else { /* subtract non-refundable tax credits no longer available */
			  /* Health services fund */
			  /* The amount of dividend income to remove from total income for HSF
			   has always been the difference between the actual and taxable amounts.
			   With the 2006 split in dividend types (eligible/non-eligible) with
			   different gross up rates, the tax form now just calculates the difference.
			   Removed parameter QHSCDIR as it is no longer needed. */

		      hsfinc = nneg(in->im.imictot
					 - (in->id.idiemp    
        			   + (in->im.imqidivt - in->id.ididiv) 
        			   + in->im.imioas * MP.QHSOASFG)
					 - (in->im.imoasr * !MP.QHSOASFG  + 
						in->im.imuibr   + 
						in->id.iddalimo +
						in->id.idcarry  +
						in->im.imqiloss));
			  
			  if (MP.QITSFSEW == 1) { /* improved tax system for self-employed workers */
			      /* convert half of the tax credit granted in respect of CPP/QPP on 
				     self-employed earnings to a deduction in the calculation of income
					 used to determine the contribution to the Health Services Fund */
				  hsfinc -= in->im.imqcppse;
				  if (hsfinc < 0) {
				     hsfinc = 0;
				  }
			  }
		
			  qstc -= nneg((NUMBER) lkup1(MP.QHSC, MP.QHSCrows, hsfinc));

			  /* medical expenses */
              if (MP.QSFMEDFLAG==0) { /* only do if people are not eligible for medical
                                       expenses using the simplified tax form */
		          famnet = in->im.imicnet ;
			      if (in->id.idspoflg) {
				    famnet += inspo->im.imicnet;
			      }
		          if (isnzero(famnet)) {
                      qstc -= nneg(in->id.idmedgro - MP.QMEDANF * famnet);
			      }
              }

			  /* Tuition */
			  qstc -= in->id.idtuitn;

			 /* Student Loan Interest */
			  qstc -= in->id.idintstu;

			  /* Dividend tax credit */

			  qdivtc = ((in->id.ididiv * MP.DIVPLC * MP.QDGURLC * MP.QDTCRLC)
						+ (in->id.ididiv * (1 - MP.DIVPLC) * MP.QDGUR * MP.QDTCR))/ MP.QNTCR;
			  qstc -= nneg(qdivtc);

			  /* Assume that spouse transfers all disability credit */
			  if (in->id.idspoflg) {
			      if (isnzero(inspo->id.iddisslf)) {
				      qstc -= MP.QMAXDX;       /* amount for severe impairment */
				  }
			  }
			  /* Assume that other dependent transfers all disability credit */
		      if (isnzero(in->id.iddisoth) && !MP.QSFDISFLAG && !MP.QRNCGFLG) {
			      qstc -= MP.QMAXDX;       /* amount for severe impairment */
			  }
			  if (qstc < 0) {
			      in->im.imqsfflg = 0;  /* person should use the general income tax return */
			  }
			  else { /* subtract deductions */
                                       
                 /* if you are in the top tax bracket, adjust amount to reflect deductions */
				 if (in->im.imictot > (MP.QTX[MP.QTXrows-1][0])) {
					qstc = qstc * MP.QNTCR / (MP.QTX[MP.QTXrows-1][2]);
				 }

			     /* only do if people are not eligible for deductions
                                        using the simplified tax form */
                 if (MP.QSFDED==0) {
				     qstc -=  ( in->im.imqiloss     /* capital loss on disp of CPCC equities   */
					          + in->id.idmovexp    /* moving expenses                         */
					          + in->id.iddalimo    /* Alimony allowance paid out              */
					          + in->id.idothded    /* other deductions from net income        */
					          + in->id.idcarry     /* carrying charges                        */
						      + (minn(in->id.idiemp * MP.QEAP, MP.QEAMAX)) /* Quebec employment allowance */
					          + in->id.idexplor    /* exploration expenses                    */
                              );
                 }

                 qstc -=  ( in->id.idcloss   /* allowable other yrs capital loss     */
	                      + in->id.idnclos   /* allowable prior yrs non-capital loss */
                          + in->id.idemplo   /*home relocation loan deduction include in other ded*/
						  + (in->id.idstkded * (ONE - MP.QCAPGIR)) /*stock option deductio as part of other deduction */
						  + (!MP.QNORTHDED?in->id.idnorth:ZERO)   /*Northern ded used as designated remote area */
                          + in->id.idpartlo /* partner loss */
						  + (MP.QREPNETFG?in->im.imrepay:ZERO)  /* deduction of fed repayment of social benefits */
                          + in->id.idcapgex * MP.QCAPGIR
						  );

				  if (qstc < 0) {
				      in->im.imqsfflg = 0;  /* person should use the general income tax return */
				  }
				  else {
					  in->im.imqsfflg = 1;  /* person should use the simplified tax return */
				  }
			  }
		   }
		}

  		/* calculate QUE employment allowance */
		if (isnneg(in->id.idiemp)) {
			in->im.imqdedea = minn(in->id.idiemp * MP.QEAP, MP.QEAMAX);
			DEBUG2("%s qdedea  =%.2f\n", in->im.imqdedea);
		}

		/* compute Quebec taxable variables */
		in->im.imqalexp = in->id.idalexp * MP.QALEXP;
		in->im.imqldivt = (in->id.ididiv * MP.DIVPLC * MP.QDGURLC);
		in->im.imqsdivt = (in->id.ididiv * (1 - MP.DIVPLC) * MP.QDGUR);
		in->im.imqidivt = in->im.imqldivt + in->im.imqsdivt;
		in->im.imqcapgt = nneg(in->id.idicapg * MP.QCAPGIR);

		/* calculate total income excluding prov. family allowances */
		qitot = in->id.idiemp     /* earnings from employment                */
		     + in->id.idisenf     /* self-employed earnings: non-farming     */
	        + in->id.idisefm     /* farming net income                      */
		     + in->id.idiinvnd     /* investment income                         */
		     + in->im.imqidivt    /* taxable amount of Canadian dividends    */
		     + in->id.idicqp      /* CPP/QPP received                        */
		     + in->im.imqipnst     /* pension income                          */
		     + in->id.iditrrsp    /* taxable RRSP withdrawals                */
		     + in->id.iditoth     /* other taxable income                    */

		     + in->im.imiuib      /* modelled UI benefits received           */
			 + in->im.imqpipcbn   /* modelled QPIP benefits received         */
		     + in->im.imiotg      /* modelled new taxable demogrants         */
		     + in->im.imioas      /* modelled OAS benefits                   */
		     + in->im.imqcapgt    /* taxable capital gains                   */
			 + in->im.imqtfa      /* taxable family allowances               */
			 + in->id.idialimo	  /* alimony received                        */
			   /* beginning in 1994, social program benefits were included in total income. */
			   /* for the years 1994 to 1997, these social program benefits were then deducted from net income */
			   /* beginning in 1998, only the net federal supplements (gis, spa, wcb) were deducted from net income */
			 + (MP.QSPBFLAG?in->im.imisa:ZERO)   /* social assistance benefits if QSPBFLAG = 1   */
			 + (MP.QSPBFLAG?in->im.imigis:ZERO)  /* Guaranteed Income Supplement if QSPBFLAG = 1 */
			 + (MP.QSPBFLAG?in->im.imispa:ZERO)  /* Spouse's Allowances if QSPBFLAG = 1     */
			 + (MP.QSPBFLAG?in->id.idiworkc:ZERO)  /* Workers Compensation if QSPBFLAG = 1 */
			 ;

	   /* tax forms were changed in 1998.  Prior to 1998, employment expenses
	      were considered as a deduction in the calculation of net income.
		  Beginning in 1998, employment expenses are used to reduce total income.
		  The parameter QEEXPDED denotes where to apply employment expenses.
		  When QEEXPDED is set to 1, employment expenses are used as a deduction 
		  in the calculation of net income.  When QEEXPDED is 0, these expenses
		  are used to reduce total income as per tax forms for 1998 and beyond. 
		  Note that the clergy residence deduction is treated the same as 
		  the employment expense deduction.  */

		if (!MP.QEEXPDED) {
		   qitot -= (in->im.imqalexp + in->id.idclergy);
		}
		/* ensure total income is not negative */
		/* Version 15, this criteria was removed as total income may be negative for years modeled */
		in->im.imqitot = qitot;
		DEBUG2("%s qitot   =%.2f\n", in->im.imqitot);

		
		if (MP.QUICOPT == TXCR) {
			if (isnzero(in->im.imuic)) {
                if (MP.QCMPOPT != 3) {
				    /* calculate UI contributions tax credit */
				    in->im.imquictc = in->im.imuic * MP.QNTCR;
				    DEBUG2("%s uctc  =%.2f\n", in->im.imquictc);
                }
			}
		}

		if (MP.QCPPOPT == TXCR) {
			if (isnzero(in->im.imcqppc)) {
				/* calculate CPP contributions tax credit */
                if (MP.QCMPOPT != 3) {
                    /* Only calculate in years where it might be used */
			        if (MP.QITSFSEW == 1) {  /* Improved tax system for self-employed workers */
				        /* under this program, the tax credit granted to an individual on amounts
					       paid for in the contributions to CPP/QPP on self-employed earnings
					       will be granted for only 50% of these amounts. imqcppse represents this 
					       portion of CPP/QPP contributions on self-employed earnings */
				        in->im.imqcpptc = nneg(in->im.imcqppc - in->im.imqcppse) * MP.QNTCR;
				    }
				    else {
				         in->im.imqcpptc = in->im.imcqppc * MP.QNTCR;
				    }
				    DEBUG2("%s cppctc =%.2f\n", in->im.imcppctc);
                }
			}
		}

		if (MP.QPIPFLAG) {
            if (MP.QCMPOPT != 3) {
                /* Only calculate in years where it might be used */
    			in->im.imqqpiptc = in->im.imqpipp * MP.QNTCR;
            }
			/* calculate a refundable tax credit for the employee's share */
			if isnzero(MP.QPIPFSE) {
                if (MP.QCMPOPT != 3) {
                    /* Only calculate in years where it might be used */
    				in->im.imqqpsetc = in->im.imqpippse * (MP.QPIPF / isnzero(MP.QPIPFSE)) * MP.QNTCR;
                }
            	/* calculate the deduction */
				in->im.imqqpsedd = in->im.imqpippse * (1.0 - (MP.QPIPF / isnzero(MP.QPIPFSE)) );
			}
			else {
				in->im.imqqpsetc = ZERO;
				in->im.imqqpsedd = ZERO;
			}
		}

		/* calculate new deduction for workers as announced in 2005 Budget */

	 	earninc = in->id.idiemp + in->id.idisenf + in->id.idisefm;
	 	if (earninc > 0) {
	 		in->im.imqempdd = minn((earninc * MP.QEMPDEDP), MP.QEMPDEDM);
	 	}

		/* calculate deductions from total income */
		in->im.imqdedft =
		    in->im.imqempdd       /* deduction for workers */
		  + in->id.idrpp       /* registered pension plan contribution    */
	      + in->id.idrrsp      /* RRSP amount                             */
	      + in->im.imqiloss     /* capital loss on disp of CPCC equities   */
	      + in->id.idmovexp    /* moving expenses                         */
	      + in->id.iddalimo    /* Alimony allowance paid out              */
	      + in->id.idothded    /* other deductions from net income        */
	      + in->id.idcarry     /* carrying charges                        */
          + (MP.QEEXPDED?in->im.imqalexp:ZERO)   /* other allowable employment expenses     */
		  + (MP.QEEXPDED?in->id.idclergy:ZERO)   /* clergy residence deduction */
		  + in->im.imqdedea    /* modelled QUE employment allowance       */
	      + in->id.idexplor    /* exploration expenses                    */ 
	      + (MP.QNORTHDED?in->id.idnorth:ZERO)   /* northern deduction */	
	      + (MP.QITSFSEW?in->im.imqcppse:ZERO) /*improved tax system for self-employed workers */
          + (MP.QREPNETFG?in->im.imrepay:ZERO)  /* deduction of fed repayment of social benefits */
          + in->im.imqqpsedd      /* QPIP deduction for self-employed */
          ;

 	    
		
        /* Tuition as deduction or tax credit */
        if (MP.QTUIOPT == 1) {
	        in->im.imqdedft += in->id.idtuitn;     /* tuition fees                            */
		}
		else {
			in->im.imqtuitc += in->id.idtuitn*MP.QNTCR;
		}

		/* Interest on student loans tax credit if flagged on */
		if (MP.QINTSLTC == 1 && isnzero(in->id.idintstu)) {
		    in->im.imqintsl += in->id.idintstu * MP.QNTCR;
		}	

		/* dues as deduction or tax credit */
	    if (MP.QDUESOPT == 1)  {
	    	in->im.imqdedft +=  in->id.iddues   ;   /* union and professional dues             */
		}
        else {
        	in->im.imqduetc = in->id.iddues * MP.QNTCR;
		}
		/* increment dedft by other exemptions */
		if (MP.QCPPOPT == EXEM && isnzero(in->im.imcqppc)) {
			in->im.imqdedft += in->im.imcqppc; /* modelled CPP/QPP contributions*/
		}
		if (MP.QUICOPT == EXEM && isnzero(in->im.imuic)) {
	    	in->im.imqdedft += in->im.imuic;   /* modelled UI contributions     */
		}
	
		/* general tax system  or when the net income concept is standardized */		
		if (in->im.imqsfflg==0  || MP.QSFDED==1 ) {
			in->im.imqinet = nneg(in->im.imqitot - in->im.imqdedft);
		}
		/* simplified tax system */
		else {
			in->im.imqinet = nneg(in->im.imqitot 
								   - in->id.idrpp       /* registered pension plan contribution    */
	      						   - in->id.idrrsp      /* RRSP amount         */
								   - (MP.QREPFAMI?in->im.imrepay:ZERO)) /* Repayment of social benefits  */
	  							   ;
	  							   	
			if (MP.QITSFSEW == 1) { /* improved tax system for self-employed workers */
			   /* deduct half of the tax credit for CPP/QPP contributions on self-employed earnings
			      from the calculation of income   */
			   in->im.imqinet -= in->im.imqcppse;
			   if (in->im.imqinet < 0) {
			       in->im.imqinet = 0;
			   }
			}
		}

		DEBUG2("%s qinet   =%.2f\n", in->im.imqinet);
	}

	/* now complete computation of net income by doing the */
	/* child care expense allowance */
	txqccea(hh);

	DEBUG_OFF("Atxqinet");
}
