/***
*Aui.cpp - Compute UI benefits
*
*$Id: Aui.cpp 6.129 2007/09/18 17:22:12 hickcha Exp $
*
*   SPSD/M Copyright (c) 1987-1995, Minister of Industry.
*   All rights reserved.  Use, reproduction, or disclosure of this work,
*   as well as publication of results derived from this work, are subject
*   to the conditions specified in the SPSD/M License Agreement.
*
*Purpose:
*   This file contains the definition of the .c function.
*
*Revisions:
* +-----+----------+---------------------------------------------------------+
* | Who |   Date   | Description                                             |
* +-----+----------+---------------------------------------------------------+
* | LP  | 07/01/23 | Removed imninc and idninco- no income flags - not used  |
* | LP  | 06/12/12 | Switched iminet to imicnet (income tax form concept)    |
* | LP  | 06/06/16 | Add imbcss to net income for income tests               |
* | LP  | 06/06/13 | Add nneg to income tests that are reduced by imuccb     |
* | LP  | 06/05/30 | Subtract imuccb from net income                         |
* | CH  | 06/01/19 | Added earnings adjustment                               |
* | LP  | 06/01/19 | Fixed reference to first claim in QPIP second claim code|
* | CH  | 06/01/04 | Added comments                                          |
* | LP  | 05/12/20 | Added the Quebec Parental Insurance Plan calculations   |
* | LP  | 05/12/01 | Removed references to hdurb, was not used in code       |
* | LP  | 05/11/17 | Removed pre 1991 UI program options                     |
* | LP  | 05/04/15 | Added BXMEXT to eligibility tests                       |
* | LP  | 04/02/18 | Added idiworkc to net income concept for family supp.   |                                          
* | LP  | 04/02/02 | Minor change to week calculations                       |                                          
* | CH  | 03/10/17 | Deleted idinoth replaced idiint + idioinv by idiinvrd   |                                          
* | LP  | 01/07/18 | Renamed imuiydeps to imuiydep                           |                                          
* | CH  | 01/06/12 | Changed code to incorporate 9.0 database variables      |                                          
* | BBM | 01/04/19 | Remove references to quitp (not on the 9.0 database)    |                                          
* | CH  | 00/12/19 | Family supplement additions                             |                                          
* | CH  | 00/05/24 | Added iditrrsp                                          |
* | CH  | 00/05/01 | Added flag for type and modified training               |                                          
* | CH  | 00/02/29 | Changed maternity and paternity calculations            |                                          
* | CH  | 99/06/09 | Minor UITARGET change and removed unused indexing code  |                                          
* | EGA | 99/05/25 | Change UITARGET by province                             |                                          
* | EGA | 99/05/21 | Change UIEITKP                                          |
* | EGA | 99/03/25 | Add UITARGET for case selection                         |
* | BBM | 99/02/11 | Drop idiroom from income(now incl in idisenf as of 7.0) |
* | TCB | 98/05/28 | Renamed *.cpp, ANSI function headers                    |
* | EGA | 98/05/21 | UI/EI takeup rate                                       |
* | CH  | 97/10/02 | Changed family supplement and added reporting variables |
* | CH  | 97/09/29 | Bug fix: negative family supplements are not allowed    |
* | CH  | 97/08/14 | Added EI fishing benefits                               |
* | CH  | 97/07/31 | dropped idwkhour, added ucwkhr                          |
* | CH  | 97/06/02 | changed quits for EI                        			 |
* | CH  | 97/03/24 | changed EI                                  			 |
* | BBM | 97/05/27 | Substitute of uc[12]y1 for uc[12]prvwk                  |
* | SFG | 97/04/30 | MS-DOS: remove near/far & adjust overlay (memory probs.)|
* | SFG | 95/02/07 | tinker code in uitrnclm due to 16-bit compiler bug      |
* | BBM | 95/12/22 | add employment insurance reforms                        |
* | GJC | 93/03/08 | add claim duration parameters and training benefit chg  |
* | GJC | 93/01/28 | Implement training benefits                             |
* | --- | 89/10/13 | Release 4.0                                             |
* |     |          |                                                         |
* +-----+----------+---------------------------------------------------------+
*
*Definitions:
*   minp     [macro ]  Return minimum of two quantities
*   maxp     [macro ]  Return maximum of two quantities
*   Aui      [global]  Compute UI benefits
*   uiclm    [static]  Simulate a UI claim
*   uitrnclm [static]  tack on a training and other claim for those eligible
*   uisqz    [static]  Squeeze UI phases into time window
*   uielent  [static]  Test UI eligibility: entrance requirements
*   uiwkbas  [static]  UI weeks of benefits: basic entitlement
*
*****************************************************************************/


/* ==================== C-RUNTIME LIBRARY INCLUDE FILES =================== */

#include <stdio.h>  /* definitions/declarations for standard I/O routines   */


/* ==================== SPSD/M INCLUDE FILES ============================== */

#include "spsm.h"   /* SPSM common manifest constants and macros            */
#include "sub.h"    /* Subroutine library declarations                      */
#include "vsu.h"    /* Household variable sub-structure (user's)            */
#include "vs.h"     /* Household variable structure and sub-structures      */
#include "apu.h"    /* Database adjustment parameter (user's) declarations  */
#include "ap.h"     /* Database adjustment parameter declarations           */
#include "mpu.h"    /* Tax/transfer parameter declarations (user's)         */
#include "mp.h"     /* Tax/transfer parameter declarations                  */


/* ==================== MACRO DEFINITIONS ================================= */

/*****************************************************************************
*minp - Return minimum of two quantities
*
*Synopsis:
*
*Description:
*
*Return Value:
*   As described.
*
*Called by:
*   Aui      Compute UI benefits
*   uisqz    Squeeze UI phases into time window
*
*****************************************************************************/
#define minp(a,b) (a<b?a:b)


/*****************************************************************************
*maxp - Return maximum of two quantities
*
*Synopsis:
*
*Description:
*
*Return Value:
*   As described.
*
*Called by:
*   Aui      Compute UI benefits
*   uisqz    Squeeze UI phases into time window
*
*****************************************************************************/
#define maxp(a,b) (a>b?a:b)


/* ==================== GLOBAL VARIABLE DEFINITIONS ======================= */

/* Give global string describing version of this module */

/*global*/ char FAR Tui[] = "Untitled"
#ifdef _MSC_VER
" [" __TIMESTAMP__ "]"
#endif
;


/* ==================== FUNCTION PROTOTYPES =============================== */


static  int uiclm(P_in in, P_uc uic, int prvwk, P_ub uib, int prov, double wctb, int ucstart);
static  int uitrnclm(P_in in, P_uc uic, P_ub uib, int valid_claim);
static  void uisqz(int first, int last, int *p1, int *p2, int *p3, int *p4);
static  int uielent(int btyp, int wwork, double hwork, double fshearn, int nereflg, double uer, int prov, int ucstart);
static  int uiwkbas(int btyp, int wwork, double uer, int gotpa);


/* ==================== COMPILER PRAGMAS ================================== */

#ifdef MSCOVL

#endif


/* ==================== FUNCTION DEFINITIONS ============================== */


/*****************************************************************************
*Aui - Compute UI benefits
*
*Synopsis:
*    void Aui(             
*    P_hh hh              
*    )                    
*
*Description:
*
*Return Value:
*   None.
*
*Calls:
*   nneg     Change negative numbers to zero
*   lkup2    Table look-up without interpolation
*   uiclm    Simulate a UI claim
*   uitrnclm tack on a training and other claim for those eligible
*   maxp     Return maximum of two quantities
*   minp     Return minimum of two quantities
*   lkup1    Table look-up with interpolation/extrapolation
*   maxn     Find the maximum of two numbers
*   minn     Find the minimum of two numbers
*
*Structure Members:
*   MP.BXM          (i)  Basic personal exemption/amount
*   MP.BXMEXT       (i)  Basic personal amount extra top-up
*   MP.PYINC        (i)  Deflator to calculate previous year income
*   MP.QPIPBMTR     (i)  Quebec parental insurance plan maternity weeks benefit rate - basic plan
*   MP.QPIPBMTW     (i)  Quebec parental insurance plan maximum maternity weeks - basic plan
*   MP.QPIPBPRR1    (i)  Quebec parental insurance plan parental initial weeks benefit rate - basic plan
*   MP.QPIPBPRR2    (i)  Quebec parental insurance plan parental additional weeks benefit rate - basic plan
*   MP.QPIPBPRW1    (i)  Quebec parental insurance plan maximum parental initial weeks - basic plan
*   MP.QPIPBPRW2    (i)  Quebec parental insurance plan maximum parental additional weeks - basic plan
*   MP.QPIPBPTR     (i)  Quebec parental insurance plan paternity benefit rate - basic plan
*   MP.QPIPBPTW     (i)  Quebec parental insurance plan maximum paternity weeks - basic plan
*   MP.QPIPEADJ     (i)  Quebec parental insurance plan earnings adjustment
*   MP.QPIPEADJrows (i)  number of rows in QPIPEADJ
*   MP.QPIPEMIN     (i)  Quebec parental insurance plan minimum insurable earnings
*   MP.QPIPFLAG     (i)  Quebec parental insurance plan activation flag
*   MP.QPIPSMTR     (i)  Quebec parental insurance plan maternity benefit rate - special plan
*   MP.QPIPSMTW     (i)  Quebec parental insurance plan maximum maternity weeks - special plan
*   MP.QPIPSPRR     (i)  Quebec parental insurance plan parental benefit rate - special plan
*   MP.QPIPSPRW     (i)  Quebec parental insurance plan maximum parental weeks - special plan
*   MP.QPIPSPTR     (i)  Quebec parental insurance plan paternity benefit rate - special plan
*   MP.QPIPSPTW     (i)  Quebec parental insurance plan maximum paternity weeks - special plan
*   MP.QPIPTU       (i)  Quebec parental insurance plan option take up
*   MP.TARGETYEAR   (i)  Year of analysis
*   MP.UIDEPOPT     (i)  UI dependency option [1=normal, 2=Feb'94] (UI only)
*   MP.UIEIFS1      (i)  Max fam supplement 1 child (EI only)
*   MP.UIEIFS1rows  (i)  number of rows in UIEIFS1
*   MP.UIEIFS2      (i)  Max fam supplement 2 children (EI only)
*   MP.UIEIFS2rows  (i)  number of rows in UIEIFS2
*   MP.UIEIFS3      (i)  Max fam supplement 3+ children (EI only)
*   MP.UIEIFS3rows  (i)  number of rows in UIEIFS3
*   MP.UIEIFSFLG    (i)  UI EI calculate family supplement flag (EI only)
*   MP.UIEIFSOPT    (i)  UI EI calculate family supplement option (EI only)
*   MP.UIEIFSRL     (i)  UI EI family supplement reduction level(EI only)
*   MP.UIEIFSRR     (i)  UI EI family supplement reduction rate (EI only)
*   MP.UIEIFSTOPUP  (i)  Max fam supplement top up for more than 3 kids (EI only)
*   MP.UIEIFSTOPUProws (i)  number of rows in UIEIFSTOPUP
*   MP.UIEIFSYNG    (i)  Max fam supplement top up for young children (EI only)
*   MP.UIEIFSYNGrows (i)  number of rows in UIEIFSYNG
*   MP.UIEIOPT      (i)  UI Employment Insurance reform option [1=UI, 2=EI Dec'95]
*   MP.UIEITKP      (i)  UI EI takeup rate [index] : index based on prov, sex, age, weeks
*   MP.UIERNMAX     (i)  Maximum insurable earnings (UI and EI)
*   MP.UIFLAG       (i)  UI/EI Activation flag (UI and EI)
*   MP.UITARGET     (i)  UI/EI target for the number of cases (UI and EI)
*   cf.cfin         (i)  First person in census family [pointer]
*   cf.cfnpers      (i)  Number of persons in census family
*   hd.hdprov       (i)  Province
*   hh.cf           (i)  Census family data [array]
*   hh.hhncf        (i)  Number of census families in household
*   hh.hhnin        (i)  Number of individuals in household
*   hh.hhnnf        (i)  Number of nuclear families in household
*   hh.in           (i)  Individual data [array]
*   hh.nf           (i)  Nuclear family data [array]
*   id.idage        (i)  Age
*   id.idicapg      (i)  Capital gains (actual)
*   id.ididiv       (i)  Dividend income (actual)
*   id.idiemp       (i)  Wages & salaries
*   id.idiinvnd     (i)  Interest and other investment income
*   id.idinspo      (i)  Person's spouse [pointer]
*   id.idipens      (i)  Pension income (115)
*   id.idisefm      (i)  Self-employed income - farming
*   id.idisenf      (i)  Self-employed income - non-farming
*   id.iditoth      (i)  Other taxable income (130)
*   id.iditrrsp     (i)  Taxable RRSP withdrawals
*   id.idnf         (i)  Person's nuclear family [pointer]
*   id.idrand       (i)  Random numbers [array]
*   id.idsex        (i)  Sex
*   id.idspoflg     (i)  Person has spouse
*   id.iduirank     (i)  Predicted ranked likelihood of getting UI
*   id.uc1          (i)  UI claim #1 data [struct]
*   id.uc2          (i)  UI claim #2 data [struct]
*   im.imfcben      (i)  Total Federal Child Benefits
*   im.imicnet      (i)  Net Income (line 236)
*   im.imuccb       (i)  Universal Child Care Benefit amount
*   im.ub1          (i)  UI claim #1 results [struct]
*   im.ub2          (i)  UI claim #2 results [struct]
*   nf.nfin         (i)  First person in nuclear family [pointer]
*   nf.nfinch       (i)  First child in nuclear family [pointer]
*   nf.nfnkids      (i)  Number of children in nuclear family
*   nf.nfnpers      (i)  Number of persons in nuclear family
*   uc.ucbtyp       (i)  Claim type
*   uc.ucern        (i)  Insurable weekly earnings
*   uc.ucgotpa      (i)  Received parental benefits
*   uc.ucstart      (i)  Week claim established
*   uc.ucstat       (i)  Claim status flag
*   uc.ucwwork      (i)  Weeks of work prior to claim
*   uc.ucy1         (i)  Weeks on UI in first year before claim
*   im.imqpipcbn    (io) Quebec parental insurance plan calendar year benefits
*   im.imuiydep     (io) Number of dependents under 7 for family supplement (EI only)
*   ub.ubcalpd      (io) Benefits paid in calendar year
*   ub.ubp1         (io) Week # of first payment
*   ub.ubp6         (io) Week # of last training payment
*   im.imiuib       (o)  Unemployment Insurance/Employment Insurance benefits
*   im.imqpcmtb     (o)  Quebec parental insurance plan calendar year maternity benefits
*   im.imqpcmtw     (o)  Quebec parental insurance plan calendar year maternity weeks
*   im.imqpcprb     (o)  Quebec parental insurance plan calendar year parental benefits
*   im.imqpcprw     (o)  Quebec parental insurance plan calendar year parental weeks
*   im.imqpcptb     (o)  Quebec parental insurance plan calendar year paternity benefits
*   im.imqpcptw     (o)  Quebec parental insurance plan calendar year paternity weeks
*   im.imqpipcwk    (o)  Quebec parental insurance plan calendar year weeks
*   im.imqpipt      (o)  Quebec parental insurance plan type (basic/special)
*   im.imqpiptbn    (o)  Quebec parental insurance plan total benefits
*   im.imqpiptwk    (o)  Quebec parental insurance plan total weeks
*   im.imqptmtb     (o)  Quebec parental insurance plan total maternity benefits
*   im.imqptmtw     (o)  Quebec parental insurance plan total maternity weeks
*   im.imqptprb     (o)  Quebec parental insurance plan total parental benefits
*   im.imqptprw     (o)  Quebec parental insurance plan total parental weeks
*   im.imqptptb     (o)  Quebec parental insurance plan total paternity benefits
*   im.imqptptw     (o)  Quebec parental insurance plan total paternity weeks
*   im.imuibr       (o)  UI benefit recovery
*   im.imuidpfg     (o)  UI claimants has dependents flag
*   ub.ubcalfs      (o)  Family supplement paid in calendar year
*   ub.ubcalwk      (o)  Weeks on claim in calendar year
*   ub.ubclmfs      (o)  Family supplement paid on claim
*   ub.ubclmpd      (o)  Benefits paid on claim
*   ub.ubclmwk      (o)  Weeks on claim
*   ub.ubeiwbp      (o)  Weeks of past EI benefits
*   ub.ubern        (o)  Modelled insurable weekly earnings
*   ub.ubp1c        (o)  Week # of first payment (windowed)
*   ub.ubp2         (o)  Week # of start of second phase
*   ub.ubp2c        (o)  Week # of start of second phase (windowed)
*   ub.ubp3         (o)  Week # of start of third phase
*   ub.ubp3c        (o)  Week # of start of third phase (windowed)
*   ub.ubp4         (o)  Week # of last payment
*   ub.ubp4c        (o)  Week # of last payment (windowed)
*   ub.ubp5         (o)  Week # of last other type of ui/ei payment
*   ub.ubp5c        (o)  Week # of last other type of ui/ei payment (windowed)
*   ub.ubp6c        (o)  Week # of last training payment (windowed)
*
*Called by:
*   drv      Tax/transfer calculator
*
*****************************************************************************/
void Aui(
	P_hh hh
)
{
	P_in in;
	P_cf cf;
	P_nf nf;
	int ini;
	int cfi;
	int nfi;
    int index  ;

	NUMBER simpd;
	NUMBER income;
	int valid_claim;
	int oldclm;
	int dependents;
	int p1, p6;
	NUMBER wctb=ZERO; /* weekly child tax benefit of census family */
    NUMBER nfinet=ZERO; /* family income from last year */
    int nch0_6; /* number of kids aged 0 to 6 */
    int nkids; /* number of kids */
    int ykids; /* number of young dependents */
	NUMBER totearn = ZERO;   /* earnings for QPIP eligibility */
	NUMBER  wksmat;   /* number of maternity weeks  */
	NUMBER 	wksmatpy; /* number of maternity weeks in previous year */
	NUMBER	wksmatcy; /* number of maternity weeks in current year */
	NUMBER	wksmatny; /* number of maternity weeks in next year */
	NUMBER	wkspar1py; /* number of phase 1 parental weeks in previous year */
	NUMBER	wkspar1cy; /* number of phase 1 parental weeks in current year */
	NUMBER	wkspar1ny; /* number of phase 1 parental weeks in next year */
	NUMBER	wkspar2py; /* number of phase 2 parental weeks in previous year */
	NUMBER	wkspar2cy; /* number of phase 2 parental weeks in current year */
	NUMBER	wkspar2ny; /* number of phase 2 parental weeks in next year */
	NUMBER	wkspatpy;
	NUMBER	wkspatcy = 0;
	NUMBER 	wkspatny = 0;
	NUMBER 	qpmtbpy = 0;
	NUMBER		qpmtbcy = 0;
	NUMBER		qpmtbny = 0;
	NUMBER		qpprbpy = 0;
	NUMBER		qpprbcy = 0;
	NUMBER		qpprbny = 0;
	NUMBER		qpptbpy = 0;
	NUMBER		qpptbcy = 0;
	NUMBER		qpptbny = 0;
	NUMBER		wkspy = 0;
	NUMBER		wkscy = 0;
	NUMBER	wkspar1 = 0;
	NUMBER	wkspar2 = 0;
	NUMBER	par1r = 0;
	NUMBER	par2r = 0;
	NUMBER	matr = 0;
	NUMBER	wkspat = 0;
	NUMBER	patr = 0;
    NUMBER  wkearn = 0;
	 
	DEBUG_ON("Aui");

	if (!MP.UIFLAG) {
		DEBUG1("%s Turned off by UIFLAG\n");
		DEBUG_OFF("Aui");
		return;
	}

	if (MP.UIEIOPT==1 && MP.UIDEPOPT==2) {

		/* REFORM 1994: determine whether the claimant has any dependents 
		*  since net income has not yet been calculated, we have to cobble 
		*  something up
		*/

		/* process each census family in household */
		for (cfi=0, cf=&hh->cf[0]; cfi<hh->hhncf; cfi++, cf++) {

			/* initialise dependents */
			dependents = 0;

			/* process persons in census family */
			/* special trick to pass through family members backwards for efficiency */
			for (ini=0, in=cf->cfin+(cf->cfnpers-1); ini<cf->cfnpers;  ini++, in--) {

				/* define dependents to be non-elderly persons with
					incomes less than the basic amount */
				income = ZERO;

				/* here the pension income included in this income test is the
				   unsplit amount of pension income since the pension income
				   has not been split yet and the variable imipnst would be 0. */

				if (in->id.idage <= 64) {
					income = in->id.idiemp + in->id.idisenf + in->id.idisefm
               			     + in->id.idiinvnd + in->id.ididiv + in->id.idicapg 
		         			 + in->id.idipens + in->id.iditoth + in->id.iditrrsp;
		 			if (income < (MP.BXM + MP.BXMEXT)) {
		 				dependents++;
						break;
		 			}
				}
			}

			/* switch dependency flag on for all cf members
				in which there is at least one dependent */

			/* process persons in census family */
			if (dependents > 0) {
				for (ini=0, in=cf->cfin; ini<cf->cfnpers;  ini++, in++) {
					in->im.imuidpfg=1;
				}
			}
		}
	}
	else if (MP.UIEIFSFLG && MP.UIEIFSOPT==2) {

		/* process each nuclear family in household */
		for (nfi=0, nf=&hh->nf[0]; nfi<hh->hhnnf; nfi++, nf++) {
            nch0_6 = 0;
			for (ini=0, in=nf->nfinch;  ini<nf->nfnkids;  in++, ini++) {
                if (in->id.idage < 7) { 
                	nch0_6 ++;
				}
			}
            if (nch0_6 > 0) {
				for (ini=0, in=nf->nfin; ini<nf->nfnpers;  ini++, in++) {
					in->im.imuiydep=nch0_6;
				}
			}
        }
	}


	/* process each person in household backwards */
	for (ini=0, in=&hh->in[0]+(hh->hhnin-1); ini<hh->hhnin; ini++, in--) {

		/* initialize variables */
		simpd = ZERO;		
		wctb = ZERO;

		/**
		* FAMILY SUPPLEMENT
		*/

        if (MP.UIEIFSFLG) {
            /*
            * If UIEIFSOPT is equal to 1, the family supplement is
            * equal to the weekly child tax benefit
            * please note that since we assume that the child tax benefit
            * is given at 100% in July, the family supplement will be off for 
            * the first half of the year 
            */
            if (MP.UIEIFSOPT == 1) {		
		        if (in->id.idspoflg)  {
                    /* note that in cceopt we have saved the value of imfcben, imicnet and imisa */
 			        wctb = (in->im.imfcben + in->id.idinspo->im.imfcben) / 52;
                    nfinet = nneg(in->im.imicnet + in->id.idinspo->im.imicnet
                    			 - in->im.imuccb - in->id.idinspo->im.imuccb) * MP.PYINC;
		        }
		        else {
			        wctb = in->im.imfcben / 52;
                    nfinet = nneg(in->im.imicnet - in->im.imuccb) * MP.PYINC;
		        }

		        /* weekly child tax benefits are reducted if family income is over UIEIFSRL by
		           a rate of UIFSRR */

		        if (nfinet>MP.UIEIFSRL) {
			        wctb *= nneg(1 - (nneg(nfinet-MP.UIEIFSRL) * MP.UIEIFSRR));
                }
            }
            /* the family supplement is calculated based on tables */
            else if (MP.UIEIFSOPT == 2 && in->id.idnf->nfnkids>0) {
                nkids = in->id.idnf->nfnkids;
                ykids = in->im.imuiydep;
                /* note that imicnet and imuccb were saved in cceopt */
                nfinet = nneg(in->im.imicnet - in->im.imuccb)* MP.PYINC;
                if (in->id.idspoflg) {
                    nfinet += nneg(in->id.idinspo->im.imicnet - in->id.idinspo->im.imuccb) * MP.PYINC;
                }


                /* first assign base benefit */
                if (nkids == 1) {
                    wctb = (NUMBER) lkup2(MP.UIEIFS1, MP.UIEIFS1rows, (NUMBER) nfinet);
                }
                else if (nkids == 2) {
                    wctb = (NUMBER) lkup2(MP.UIEIFS2, MP.UIEIFS2rows, (NUMBER) nfinet);
                }
                else if (nkids == 3) {
                    wctb = (NUMBER) lkup2(MP.UIEIFS3, MP.UIEIFS3rows, (NUMBER) nfinet);
                }
                else {
                    wctb = (NUMBER) lkup2(MP.UIEIFS3, MP.UIEIFS3rows, (NUMBER) nfinet)
                         + (nkids-3) * (NUMBER) lkup2(MP.UIEIFSTOPUP, MP.UIEIFSTOPUProws, (NUMBER) nfinet);
                }
                /* add supplement for kids under 7 */
                wctb += ykids * (NUMBER) lkup2(MP.UIEIFSYNG, MP.UIEIFSYNGrows, (NUMBER) nfinet);
            }
            else {
                wctb = ZERO;
            }
        }

		if (in->id.uc1.ucstat && ( MP.UITARGET[hh->hd.hdprov] > in->id.iduirank/1000 )) {
			DEBUG1("%s process first claim\n");					  
			
			valid_claim = uiclm(in, &in->id.uc1, in->id.uc1.ucy1, &in->im.ub1,
				hh->hd.hdprov, wctb, in->id.uc1.ucstart);

			/* calculate the training benefits */
   			valid_claim = uitrnclm(in, &in->id.uc1, &in->im.ub1, valid_claim);

			DEBUG4("%s simulated values: earnings=%.2f, calwk=%d, calpd=%.2f\n",
					in->im.ub1.ubern, in->im.ub1.ubcalwk, in->im.ub1.ubcalpd);


			if (valid_claim) {
				DEBUG1("%s valid first claim\n");
				simpd += in->im.ub1.ubcalpd;
			}
			else {
				DEBUG1("%s first claim rejected\n");
			}
		}

		if (in->id.uc2.ucstat  && (in->id.iduirank/1000 < MP.UITARGET[hh->hd.hdprov])) {
			DEBUG1("%s process second claim\n");
			/* compute number of weeks on claim in 52 weeks prior to start     */
			/* of second claim.  claim2 structure is used for this calculation */
			/* and does not contain valid data on first claim after this.      */

			/* It might make some sense to implement some behavioural response */
			/* here, namely to displace the start of the second claim forward  */
			/* if eligibility would result from this.                          */

			p1 = 	maxp(in->im.ub1.ubp1,in->id.uc2.ucstart-52);
			p6 = 	minp(in->im.ub1.ubp6,in->id.uc2.ucstart);
			oldclm = maxp(0, p6 - p1);

			valid_claim = uiclm(in, &in->id.uc2, oldclm, &in->im.ub2,
				hh->hd.hdprov, wctb, in->id.uc2.ucstart);

			/* calculate the training benefits */
   			valid_claim = uitrnclm(in, &in->id.uc2, &in->im.ub2, valid_claim);

			DEBUG4("%s simulated values: earnings=%.2f, calwk=%d, calpd=%.2f\n",
					in->im.ub2.ubern, in->im.ub2.ubcalwk, in->im.ub2.ubcalpd);

			if (valid_claim) {
				DEBUG1("%s valid first claim\n");
				simpd += in->im.ub2.ubcalpd;
			}
			else {
				DEBUG1("%s second claim rejected\n");
			}
		}


		DEBUG2("%s simpd=%.2f\n", simpd);
		in->im.imiuib = simpd;
	
/********************************************************************
*  This section adjust the number of UI claims to administrative data
*********************************************************************/

/*index construction*/
	if (in->id.uc1.ucstat  && (in->id.iduirank/1000 < MP.UITARGET[hh->hd.hdprov])) { 
		index = hh->hd.hdprov;
		if (in->id.idrand[3] < (NUMBER) MP.UIEITKP[index]) {

			in->im.imuidpfg=0;
			in->im.imiuib = 0;
			in->im.imuibr = 0;
			in->im.ub1.ubclmwk = 0;
			in->im.ub1.ubcalwk = 0;
			in->im.ub1.ubeiwbp = 0;
			in->im.ub1.ubp1 = 0;   
			in->im.ub1.ubp2 = 0;   
			in->im.ub1.ubp3 = 0;   
			in->im.ub1.ubp4 = 0;   
			in->im.ub1.ubp5 = 0;   
			in->im.ub1.ubp6 = 0;   
			in->im.ub1.ubp1c = 0;  
			in->im.ub1.ubp2c = 0;  
			in->im.ub1.ubp3c = 0;  
			in->im.ub1.ubp4c = 0;  
			in->im.ub1.ubp5c = 0;  
			in->im.ub1.ubp6c = 0;  
			in->im.ub1.ubclmpd = 0;
			in->im.ub1.ubcalpd = 0;
			in->im.ub1.ubclmfs = 0;
			in->im.ub1.ubcalfs = 0;
			in->im.ub1.ubern = 0;  
			in->im.ub2.ubclmwk = 0;
			in->im.ub2.ubcalwk = 0;
			in->im.ub2.ubeiwbp = 0;
			in->im.ub2.ubp1 = 0;   
			in->im.ub2.ubp2 = 0;   
			in->im.ub2.ubp3 = 0;   
			in->im.ub2.ubp4 = 0;   
			in->im.ub2.ubp5 = 0;   
			in->im.ub2.ubp6 = 0;   
			in->im.ub2.ubp1c = 0;  
			in->im.ub2.ubp2c = 0;  
			in->im.ub2.ubp3c = 0;  
			in->im.ub2.ubp4c = 0;  
			in->im.ub2.ubp5c = 0;  
			in->im.ub2.ubp6c = 0;  
			in->im.ub2.ubclmpd = 0;
			in->im.ub2.ubcalpd = 0;
			in->im.ub2.ubclmfs = 0;
			in->im.ub2.ubcalfs = 0;
			in->im.ub2.ubern = 0;  

		}

	}

	/* Determine if eligible for Quebec parental insurance program */

	/* Initialize plan type to 'no plan' */
	in->im.imqpipt = 0;


    /* In theory, the parental insurance program should give benefits to people
       who are not eligible for EI (e.g. the self employed and part time workers, among
       others).  Variables to model this expansion are not yet available on the SPSM,
       so for now the program is modelled using the EI variables */


	if (MP.QPIPFLAG && hh->hd.hdprov == 4 && 
		(in->id.uc1.ucbtyp == 3 || in->id.uc1.ucbtyp == 4) &&
	 	(MP.TARGETYEAR > 2006 || (MP.TARGETYEAR == 2006 && in->id.uc1.ucstart > 0))){

		/* First determine if eligible for benefits.  */
		/* Calculate earnings */
		totearn = in->id.uc1.ucern * in->id.uc1.ucwwork;

        /* if weekly earnings at the max for EI, optionally increase them
           so that they can reach max for QPIP (e.g. EI max elible annual 
           earnings = 39000 while QPIP  = 57000 in 2006) */
        if ( in->id.uc1.ucern == MP.UIERNMAX ) {
            wkearn = maxn(in->id.uc1.ucern ,(NUMBER) lkup1(MP.QPIPEADJ, MP.QPIPEADJrows, in->id.idrand[7] ));
        }
        else wkearn = in->id.uc1.ucern;

		wksmatpy = 0;
		wksmatcy = 0;
		wksmatny = 0;
		wkspar1py = 0;
		wkspar1cy = 0;
		wkspar1ny = 0;
		wkspar2py = 0;
		wkspar2cy = 0;
		wkspar2ny = 0;
		wkspatpy = 0;
		wkspatcy = 0;
		wkspatny = 0;
		qpmtbpy = 0;
		qpmtbcy = 0;
		qpmtbny = 0;
		qpprbpy = 0;
		qpprbcy = 0;
		qpprbny = 0;
		qpptbpy = 0;
		qpptbcy = 0;
		qpptbny = 0;
		wkspy = 0;
		wksmat = 0;
		wkscy = 0;
		wkspar1 = 0;
		wkspar2 = 0;
		par1r = 0;
		par2r = 0;
		matr = 0;
		wkspat = 0;
		patr = 0;

		
		/* if eligible based on earnings, calculate how much in year to give */
		if (totearn > MP.QPIPEMIN ) {
			/* passed eligibility */

            /* split weeks into current and previous years */
			if (in->id.uc1.ucstart < 0) {
                /* previous year's weeks */
			 	wkspy = (in->id.uc1.ucstart * -1);
                /* current year's weeks */
				wkscy = 52;
			}
			else {  /* claim started in calendar year */
                /* current year weeks */
				wkscy = minn((52-in->id.uc1.ucstart), 52) ;
			}
			/* process maternity claim */
			if (in->id.uc1.ucbtyp == 3) {
			    /* determine plan type - basic or special */
				if (in->id.idrand[8] > MP.QPIPTU  ) {
					  in->im.imqpipt = 2;

					 /*  give special plan, shorter weeks, greater rate */
   					  wksmat =  MP.QPIPSMTW;  /* weeks of maternity */
					  matr = MP.QPIPSMTR;     /* benefit rate maternity*/
					  if (in->id.uc1.ucgotpa == 1) {
					  	  wkspar1 = MP.QPIPSPRW; /* weeks parental */
					  	  par1r = MP.QPIPSPRR;   /* benefit rate, parental */
					  }
				}
				else { /* give the basic plan */
				      in->im.imqpipt = 1;
					  wksmat = MP.QPIPBMTW; /* weeks maternity */
					  matr = MP.QPIPBMTR;   /* benefit rate maternity */
					  if (in->id.uc1.ucgotpa == 1) {
						  wkspar1 = MP.QPIPBPRW1; /* initial weeks, parental */
						  par1r = MP.QPIPBPRR1;   /* initial rate, parental */
					 	  wkspar2 = MP.QPIPBPRW2; /* additional weeks, parental */
					      par2r = MP.QPIPBPRR2;   /* additional rate, parental */
					  }
			    }
			}  /* end of a maternity benefit type claim */
			else {  /* must be a parental type claim - both men and women */
			    /* determine plan type - basic or special */
				if (in->id.idrand[8]> MP.QPIPTU  ) {
					  in->im.imqpipt = 2;

					  if (in->id.uc1.ucgotpa == 1) {
					  	  wkspar1 = MP.QPIPSPRW; /* weeks parental */
					  	  par1r = MP.QPIPSPRR;   /* rate parental */
					  }
					  if (in->id.idsex == 0) {
					     /* males qualify for paternity weeks and benefits */
						 wkspat = MP.QPIPSPTW; /* weeks paternity */
						 patr = MP.QPIPSPTR;   /* rates paternity*/
					  }
				}
				else { /* give the basic plan */
					  if (in->id.uc1.ucgotpa == 1) {
					  	  in->im.imqpipt = 1;
						  wkspar1 = MP.QPIPBPRW1; /* initial weeks parental*/
						  par1r = MP.QPIPBPRR1;   /* initial rate parental*/
					 	  wkspar2 = MP.QPIPBPRW2; /* additional weeks parental*/
					      par2r = MP.QPIPBPRR2;   /* additional rate parental*/
					  }
					  if (in->id.idsex == 0) {
					     /* males qualify for paternity weeks and benefits */
						 wkspat = MP.QPIPBPTW; /* weeks paternity*/
						 patr = MP.QPIPBPTR;   /* rate, paternity */
					  }
			    }

			}  /* end of a parental benefit type claim */

            /* split maternity benefits in previous year, current year, next year */                
			wksmatpy = minn(wkspy, wksmat);
			wksmatcy = minn((wksmat - wksmatpy), wkscy);
			wksmatny = wksmat - wksmatpy - wksmatcy;
			qpmtbpy = wksmatpy * wkearn * matr;
			qpmtbcy = wksmatcy * wkearn * matr;
			qpmtbny = wksmatny * wkearn * matr;

            /* split paternity benefits in previous year, current year, next year */                
			wkspatpy = minn((wkspy - wksmatpy), wkspat);
			wkspatcy = minn((wkspat - wkspatpy), (wkscy - wksmatcy));
			wkspatny = wkspat - wkspatpy - wkspatcy;
			qpptbpy = wkspatpy * wkearn * patr;
			qpptbcy = wkspatcy * wkearn * patr;
			qpptbny = wkspatny * wkearn * patr;													  
																  
            /* give parental benefits */
			if ((wkspy - wksmatpy - wkspatpy > 0) && wkspar1 > 0 ) {
			   /* still have weeks open in the previous year */
				wkspar1py = minn((wkspy - wksmatpy - wkspatpy), wkspar1);
				wkspar2py = minn((wkspy - wksmatpy - wkspatpy - wkspar1py), wkspar2);
			}
			wkspar1cy = minn(nneg(wkspar1 - wkspar1py),(wkscy - wksmatcy - wkspatcy));
			wkspar1ny = wkspar1 - wkspar1py - wkspar1cy;
			wkspar2cy = minn(nneg(wkspar2 - wkspar2py), (wkscy-wksmatcy - wkspatcy - wkspar1cy));
			wkspar2ny = wkspar2 - wkspar2py - wkspar2cy;
			qpprbpy = (wkspar1py * wkearn * par1r) +
					  (wkspar2py * wkearn * par2r);
			qpprbcy = (wkspar1cy * wkearn * par1r) +
					  (wkspar2cy * wkearn * par2r);
			qpprbny = (wkspar1ny * wkearn * par1r) +
					  (wkspar2ny * wkearn * par2r);
			
  		}

		
		in->im.imqpipcbn = qpmtbcy + qpptbcy + qpprbcy;
		in->im.imqpiptbn = qpmtbpy + qpmtbcy + qpmtbny 
		                 + qpptbpy + qpptbcy + qpptbny 
		                 + qpprbpy + qpprbcy + qpprbny;
		in->im.imqpipcwk = wksmatcy + wkspatcy + wkspar1cy + wkspar2cy;
		in->im.imqpiptwk = wksmatpy + wksmatcy + wksmatny +
						   wkspatpy + wkspatcy + wkspatny +
						   wkspar1py + wkspar1cy + wkspar1ny +
						   wkspar2py + wkspar2cy + wkspar2ny;
		in->im.imqpcmtb =  qpmtbcy;
		in->im.imqpcptb =  qpptbcy;
		in->im.imqpcprb =  qpprbcy;
		in->im.imqptmtb =  qpmtbpy + qpmtbcy + qpmtbny;
		in->im.imqptptb =  qpptbpy + qpptbcy + qpptbny;
		in->im.imqptprb =  qpprbpy + qpprbcy + qpprbny;
		in->im.imqpcmtw =  wksmatcy;
		in->im.imqpcptw =  wkspatcy;
		in->im.imqpcprw =  wkspar1cy + wkspar2cy;
		in->im.imqptmtw =  wksmatpy + wksmatcy + wksmatny;
		in->im.imqptptw =  wkspatpy + wkspatcy + wkspatny;
		in->im.imqptprw =  wkspar1py + wkspar1cy + wkspar1ny +
						   wkspar2py + wkspar2cy + wkspar2ny;


	}
    
    /* Since we only want to give one claim per year, only do second claim if first claim gave zero benefits */

	if (MP.QPIPFLAG && hh->hd.hdprov == 4 && 
		( in->id.uc2.ucbtyp == 3 || in->id.uc2.ucbtyp == 4) && in->im.imqpipcbn == 0 &&
	 	(MP.TARGETYEAR > 2006 || (MP.TARGETYEAR == 2006 && in->id.uc2.ucstart > 0))){

		/* do not allow two maternity/parental claims in the same year */
		/* First determine if eligible for benefits.  */
		/* Calculate earnings */
		totearn = in->id.uc2.ucern * in->id.uc2.ucwwork;

        /* if weekly earnings at the max for EI, optionally increase them
           so that they can reach max for QPIP (e.g. EI max elible annual 
           earnings = 39000 while QPIP  = 57000 in 2006) */
        if ( in->id.uc2.ucern == MP.UIERNMAX ) {
            wkearn = maxn(in->id.uc2.ucern ,(NUMBER) lkup1(MP.QPIPEADJ, MP.QPIPEADJrows, in->id.idrand[7] ));
        }
        else wkearn = in->id.uc2.ucern;

		wksmatpy = 0;
		wksmatcy = 0;
		wksmatny = 0;
		wkspar1py = 0;
		wkspar1cy = 0;
		wkspar1ny = 0;
		wkspar2py = 0;
		wkspar2cy = 0;
		wkspar2ny = 0;
		wkspatpy = 0;
		wkspatcy = 0;
		wkspatny = 0;
		qpmtbpy = 0;
		qpmtbcy = 0;
		qpmtbny = 0;
		qpprbpy = 0;
		qpprbcy = 0;
		qpprbny = 0;
		qpptbpy = 0;
		qpptbcy = 0;
		qpptbny = 0;
		wkspy = 0;
		wksmat = 0;
		wkscy = 0;
		wkspar1 = 0;
		wkspar2 = 0;
		par1r = 0;
		par2r = 0;
		matr = 0;
		wkspat = 0;
		patr = 0;
		
		/* if eligible based on earnings, calculate how much in year to give */
		if (totearn > MP.QPIPEMIN ) {
			/* passed eligibility */

            /* split weeks into current and previous years */
			if (in->id.uc2.ucstart < 0) {
                /* previous year's weeks */
			 	wkspy = (in->id.uc2.ucstart * -1);
                /* current year's weeks */
				wkscy = 52;
			}
			else {  /* claim started in calendar year */
                /* current year weeks */
				wkscy = minn((52-in->id.uc2.ucstart), 52) ;
			}
			/* process maternity claim */
			if (in->id.uc2.ucbtyp == 3) {
			    /* determine plan type - basic or special */
				if (in->id.idrand[8] > MP.QPIPTU  ) {
					  in->im.imqpipt = 2;

					 /*  give special plan, shorter weeks, greater rate */
					  wksmat =  MP.QPIPSMTW; /* weeks of maternity */
					  matr = MP.QPIPSMTR;    /* benefit rate maternity*/
					  if (in->id.uc2.ucgotpa == 1) {
					  	  wkspar1 = MP.QPIPSPRW; /* weeks parental */
					  	  par1r = MP.QPIPSPRR;   /* benefit rate, parental */
					  }
				}
				else { /* give the basic plan */
				      in->im.imqpipt = 1;
					  wksmat = MP.QPIPBMTW; /* weeks maternity */
					  matr = MP.QPIPBMTR;   /* benefit rate maternity */
					  if (in->id.uc2.ucgotpa == 1) {
						  wkspar1 = MP.QPIPBPRW1; /* initial weeks, parental */
						  par1r = MP.QPIPBPRR1;   /* initial rate, parental */
					 	  wkspar2 = MP.QPIPBPRW2; /* additional weeks, parental */
					      par2r = MP.QPIPBPRR2;   /* additional rate, parental */

					  }
			    }
			}  /* end of a maternity benefit type claim */
			else {  /* must be a parental type claim - both men and women */
			    /* determine plan type - basic or special */
				if (in->id.idrand[8] > MP.QPIPTU  ) {
					  in->im.imqpipt = 2;

					  if (in->id.uc2.ucgotpa == 1) {
					  	  wkspar1 = MP.QPIPSPRW; /* weeks parental */
					  	  par1r = MP.QPIPSPRR;   /* rate parental */
					  }
					  if (in->id.idsex == 0) {
					     /* males qualify for paternity weeks and benefits */
						 wkspat = MP.QPIPSPTW; /* weeks paternity */
						 patr = MP.QPIPSPTR;   /* rates paternity*/
					  }
				}
				else { /* give the basic plan */
				      in->im.imqpipt = 1;
					  if (in->id.uc2.ucgotpa == 1) {
						  wkspar1 = MP.QPIPBPRW1; /* initial weeks parental*/
						  par1r = MP.QPIPBPRR1;   /* initial rate parental*/
					 	  wkspar2 = MP.QPIPBPRW2; /* additional weeks parental*/
					      par2r = MP.QPIPBPRR2;   /* additional rate parental*/
					  }
					  if (in->id.idsex == 0) {
					     /* males qualify for paternity weeks and benefits */
						 wkspat = MP.QPIPBPTW; /* weeks paternity*/
						 patr = MP.QPIPBPTR;   /* rate, paternity */
					  }
			    }

			}  /* end of a parental benefit type claim */


            /* split maternity benefits in previous year, current year, next year */                
			wksmatpy = minn(wkspy, wksmat);
			wksmatcy = minn((wksmat - wksmatpy), wkscy);
			wksmatny = wksmat - wksmatpy - wksmatcy;
			qpmtbpy = wksmatpy * wkearn * matr;
			qpmtbcy = wksmatcy * wkearn * matr;
			qpmtbny = wksmatny * wkearn * matr;

            /* split paternity benefits in previous year, current year, next year */                
			wkspatpy = minn((wkspy - wksmatpy), wkspat);
			wkspatcy = minn((wkspat - wkspatpy), (wkscy - wksmatcy));
			wkspatny = wkspat - wkspatpy - wkspatcy;
			qpptbpy = wkspatpy * wkearn * patr;
			qpptbcy = wkspatcy * wkearn * patr;
			qpptbny = wkspatny * wkearn * patr;													  

            /* give parental benefits */
			if ((wkspy - wksmatpy - wkspatpy > 0) && wkspar1 > 0 ) {
			   /* still have weeks open in the previous year */
				wkspar1py = minn((wkspy - wksmatpy - wkspatpy), wkspar1);
				wkspar2py = minn((wkspy - wksmatpy - wkspatpy - wkspar1py), wkspar2);
			}
			wkspar1cy = minn(nneg(wkspar1 - wkspar1py),(wkscy - wksmatcy - wkspatcy));
			wkspar1ny = wkspar1 - wkspar1py - wkspar1cy;
			wkspar2cy = minn(nneg(wkspar2 - wkspar2py), (wkscy-wksmatcy - wkspatcy - wkspar1cy));
			wkspar2ny = wkspar2 - wkspar2py - wkspar2cy;
			qpprbpy = (wkspar1py * wkearn * par1r) +
					  (wkspar2py * wkearn * par2r);
			qpprbcy = (wkspar1cy * wkearn * par1r) +
					  (wkspar2cy * wkearn * par2r);
			qpprbny = (wkspar1ny * wkearn * par1r) +
					  (wkspar2ny * wkearn * par2r);
			
  		}
	
		in->im.imqpipcbn = qpmtbcy + qpptbcy + qpprbcy;
		in->im.imqpiptbn = qpmtbpy + qpmtbcy + qpmtbny + qpptbpy +
						   qpptbcy + qpptbny + qpprbpy + qpprbcy +
						   qpprbny;
		in->im.imqpipcwk = wksmatcy + wkspatcy + wkspar1cy + wkspar2cy;
		in->im.imqpiptwk = wksmatpy + wksmatcy + wksmatny +
						   wkspatpy + wkspatcy + wkspatny +
						   wkspar1py + wkspar1cy + wkspar1ny +
						   wkspar2py + wkspar2cy + wkspar2ny;
		in->im.imqpcmtb =  qpmtbcy;
		in->im.imqpcptb =  qpptbcy;
		in->im.imqpcprb =  qpprbcy;
		in->im.imqptmtb =  qpmtbpy + qpmtbcy + qpmtbny;
		in->im.imqptptb =  qpptbpy + qpptbcy + qpptbny;
		in->im.imqptprb =  qpprbpy + qpprbcy + qpprbny;
		in->im.imqpcmtw =  wksmatcy;
		in->im.imqpcptw =  wkspatcy;
		in->im.imqpcprw =  wkspar1cy + wkspar2cy;
		in->im.imqptmtw =  wksmatpy + wksmatcy + wksmatny;
		in->im.imqptptw =  wkspatpy + wkspatcy + wkspatny;
		in->im.imqptprw =  wkspar1py + wkspar1cy + wkspar1ny +
						   wkspar2py + wkspar2cy + wkspar2ny;

	
	}

}
	DEBUG_OFF("Aui");
	return;
}


/*****************************************************************************
*uiclm - Simulate a UI claim
*
*Synopsis:
*    static int uiclm(    
*    P_in in,             
*    P_uc uc,             
*    int prvwk,           
*    P_ub ub,             
*    int prov,            
*    double wctb,         
*    int ucstart          
*    )                    
*
*Description:
*
*Return Value:
*   None.
*
*Calls:
*   maxn     Find the maximum of two numbers
*   uielent  Test UI eligibility: entrance requirements
*   uiwkbas  UI weeks of benefits: basic entitlement
*   mini     Find the minimum of two quantities
*   randrnd  Randomly round a floating point number to an integer
*   uisqz    Squeeze UI phases into time window
*   lkup2    Table look-up without interpolation
*   round    Round to nearest integer
*   minn     Find the minimum of two numbers
*   nneg     Change negative numbers to zero
*   maxi     Find the maximum of two quantities
*
*Structure Members:
*   MP.UIBASRATE    (i)  Benefit rate for basic phase (UI only)
*   MP.UIEFFFLAG    (i)  Observed effective weekly benefit rate flag (UI and EI)
*   MP.UIEIDIV      (i)  EI minimum divisor [uer][divisor] (EI only)
*   MP.UIEIDIVFLG   (i)  EI minimum divisor flag (EI only)
*   MP.UIEIDIVrows  (i)  number of rows in UIEIDIV
*   MP.UIEIFIFLG    (i)  EI intensity rule exemption for family supplement receivers (EI only)
*   MP.UIEIFSFLG    (i)  UI EI calculate family supplement flag (EI only)
*   MP.UIEIMFSP     (i)  EI Maximum family supplement percent of earnings (EI only)
*   MP.UIEIMTYPFLG  (i)  Flag to model main benefit type (UI and EI)
*   MP.UIEIOPT      (i)  UI Employment Insurance reform option [1=UI, 2=EI Dec'95]
*   MP.UIEIRATE     (i)  Benefit rate under EI reform [Past Wks ben][Rate] (EI only)
*   MP.UIEIRrows    (i)  number of rows in UIEIRATE
*   MP.UIEIYRS      (i)  Number of years of previous EI benefits calculated (EI only)
*   MP.UIENSRATE    (i)  Enhanced rate for basic phase (UI only)
*   MP.UIENSRTCO    (i)  Enhanced rate cutoff (UI only)
*   MP.UIERNMAX     (i)  Maximum insurable earnings (UI and EI)
*   MP.UIEXTMATWKS  (i)  Additional weeks for maternity - behavioural response (UI and EI)
*   MP.UILFERATE    (i)  Benefit rate for labour force extended phase (UI only)
*   MP.UIMAXDUR     (i)  Maximum duration of a UI claim (UI and EI)
*   MP.UIREGWKFCT   (i)  UI regular benefit weeks adjustment factor (UI and EI)
*   MP.UIRGERATE    (i)  Benefit rate for regional extended phase (UI only)
*   MP.UITARGET     (i)  UI/EI target for the number of cases (UI and EI)
*   MP.UIWAITWKS    (i)  Minimum waiting period all claims (UI and EI)
*   id.idcfrh       (i)  Relationship to census family head
*   id.idinspo      (i)  Person's spouse [pointer]
*   id.idrand       (i)  Random numbers [array]
*   id.idspoflg     (i)  Person has spouse
*   id.iduirank     (i)  Predicted ranked likelihood of getting UI
*   im.imuidpfg     (i)  UI claimants has dependents flag
*   uc.ucbtyp       (i)  Claim type
*   uc.ucdivwk      (i)  Minimum divisor weeks
*   uc.uceff        (i)  Effective weekly rate
*   uc.ucern        (i)  Insurable weekly earnings
*   uc.ucgotpa      (i)  Received parental benefits
*   uc.uchrwk       (i)  Hours worked prior to claim
*   uc.ucmtyp       (i)  Main Claim type (majority of weeks)
*   uc.ucnere       (i)  New entrant re-entrant flag
*   uc.ucothwk      (i)  Weeks of other benefits
*   uc.ucstart      (i)  Week claim established
*   uc.ucstat       (i)  Claim status flag
*   uc.uctpcng      (i)  Also received regular benefits
*   uc.uctrnwk      (i)  Weeks of training benefits
*   uc.ucuer        (i)  Local unemployment rate (x10)
*   uc.ucweeks      (i)  Weeks of benefits
*   uc.ucwwork      (i)  Weeks of work prior to claim
*   uc.ucy1         (i)  Weeks on UI in first year before claim
*   uc.ucy2         (i)  Weeks on UI in second year prior to claim
*   uc.ucy3         (i)  Weeks on UI in third year prior to claim
*   uc.ucy4         (i)  Weeks on UI in fourth year prior to claim
*   uc.ucy5         (i)  Weeks on UI in fifth year prior to claim
*   ub.ubclmwk      (io) Weeks on claim
*   ub.ubp1         (io) Week # of first payment
*   ub.ubp1c        (io) Week # of first payment (windowed)
*   ub.ubp4         (io) Week # of last payment
*   ub.ubp4c        (io) Week # of last payment (windowed)
*   ub.ubcalfs      (o)  Family supplement paid in calendar year
*   ub.ubcalpd      (o)  Benefits paid in calendar year
*   ub.ubcalwk      (o)  Weeks on claim in calendar year
*   ub.ubclmfs      (o)  Family supplement paid on claim
*   ub.ubclmpd      (o)  Benefits paid on claim
*   ub.ubeiwbp      (o)  Weeks of past EI benefits
*   ub.ubern        (o)  Modelled insurable weekly earnings
*   ub.ubp2         (o)  Week # of start of second phase
*   ub.ubp2c        (o)  Week # of start of second phase (windowed)
*   ub.ubp3         (o)  Week # of start of third phase
*   ub.ubp3c        (o)  Week # of start of third phase (windowed)
*
*Called by:
*   Aui      Compute UI benefits
*
*****************************************************************************/
static int uiclm(
	P_in in,
	register P_uc uc,
	int prvwk,
	register P_ub ub,
	int prov,
	double wctb,
	int ucstart
)
{
	int btyp;
	int valid_claim;
	int weeks;       /* weeks of benefit */
	int wwork;       /* weeks worked in past 52 weeks */
	int hwork;       /* hours worked in past 52 weeks */
	int wi;          /* Dad's weeks ineligible for family supplement in dual ui family */
	int wait, start, last;
	int p1, p2, p3, p4;
	NUMBER uer = ZERO;
	NUMBER earnings = ZERO;
	NUMBER brate1 = ZERO;
	NUMBER brate2 = ZERO;
	NUMBER brate3 = ZERO;
	NUMBER calpd = ZERO;
	int calwk;
	int extclm;           /* behavioural response maximum extension */
	NUMBER maxfsup=ZERO;  /* Maximum weekly family supplement */
	int wbp5;             /* Local weeks of benefits in past 5 years */
	NUMBER fshearn;		  /* Earnings in past 31 weeks of fishermen */
    int nereflg;             /* New entrant or re-entrant flag */

	DEBUG_ON("uiclm");

	/* initialize work variables */
	p1 = 0;
	p2 = 0;
	p3 = 0;
	p4 = 0;
	valid_claim = TRUE;

    /* model first benefit type */
    if (!MP.UIEIMTYPFLG) {
    	btyp = uc->ucbtyp;
    }
    /* model main benefit type */
    else {
        btyp = uc->ucmtyp;
    }

    /* weeks worked in past 52 weeks */
	wwork = uc->ucwwork;
    /* hours worked in past 52 weeks */
  	hwork = uc->uchrwk;
	
      /* calculate weeks of benefits in past (up to 5 years) */
	wbp5 = 0;
	if (MP.UIEIOPT==2)  {
		if (MP.UIEIYRS > 0) { 
			wbp5 += uc->ucy1;
			if (MP.UIEIYRS > 1) {
				wbp5 += uc->ucy2;
				if (MP.UIEIYRS > 2)  {
					wbp5 += uc->ucy3;
					if (MP.UIEIYRS > 3) {
						wbp5 += uc->ucy4;
						if (MP.UIEIYRS > 4) {
							wbp5 += uc->ucy5;
						}
					}
				}
			}
		}
		/* save previous weeks of EI */
		ub->ubeiwbp = wbp5;
	}

    /* initialize new entrant re-entrant flag */
    nereflg = uc->ucnere;


	/* default is no behavioural response extension */
	extclm = 0;

	DEBUG4("%s claim type=%d, weeks worked=%d, weeks on prev claim=%d\n",
			 btyp, wwork, prvwk);

	earnings = uc->ucern;
	if (earnings > MP.UIERNMAX) {
		DEBUG2("%s ern=%.2f, setting to UIERNMAX\n", earnings);
		earnings = MP.UIERNMAX;
	}
	ub->ubern = earnings;

	/* regional UER are coded as 10 x % */
	uer = uc->ucuer / (NUMBER) 10.0;


	/* initialise components of benefit structure */
	ub->ubclmpd = ZERO;
	ub->ubclmwk = 0;
	ub->ubp1 = uc->ucstart;
	ub->ubp2 = ub->ubp1;
	ub->ubp3 = ub->ubp1;
	ub->ubp4 = ub->ubp1;

	/* training and other benefit types to be processed in training function */
	if (btyp == UITRN || btyp == UIOTH) {
		DEBUG1("%s return training benefit types\n");
		DEBUG_OFF("uiclm");
		return(valid_claim);
	}

	/* fishing benefits depend on earnings in the past 31 weeks */
	/* note, as approximation, all weeks in past year, up to 31, are used */
    fshearn = (NUMBER) uc->ucern * maxn(uc->ucwwork,31);

	/* test entrance requirements based on weeks of work by claim type */
	valid_claim = uielent(btyp, wwork, hwork, fshearn, nereflg, uer, prov, ucstart);
	if (!valid_claim) {
		DEBUG1("%s claim failed entry requirements\n");
		DEBUG_OFF("uiclm");
		return(valid_claim);
	}

	/* change claim type to regular for claimants who had some regular */
	/*  benefits                                                      */
	if ((btyp == UIMAT || btyp == UISIC || btyp == UIPAR) && uc->uctpcng) {
		DEBUG1("%s force claim type to regular\n");
		btyp = UIREG;
	}

	if (btyp == UIMAT) {
		extclm = MP.UIEXTMATWKS;
		DEBUG2("%s behavioural response for maternity claims=%d\n", extclm);
	}

	/* set up pointers:  p1 - first paid week                          */
	/*                   p2 - first week of second phase               */
	/*                   p3 - first week of third  phase               */
	/*                   p4 - week after last paid week                */
	/* initially each points to the week the claim was established     */
	/* the week of Jan 1 is coded as week 0                            */
	p1 = (int) uc->ucstart;
	p2 = p1;
	p3 = p1;
	p4 = p1;
	DEBUG2("%s p1=%d\n", p1);

	/* determine waiting period unit first week of benefits            */

	wait = MP.UIWAITWKS;

	/* shift all pointers to first week of benefits                    */
	p1 += wait;
	p2 += wait;
	p3 += wait;
	p4 += wait;
	DEBUG3("%s wait=%d, p1=%d\n", wait, p1);

	/* check for parental benefits */

	/* determine length of initial phase or basic entitlement          */
	if (MP.UIEIOPT==2)  {
		weeks = uiwkbas(btyp, hwork, uer, uc->ucgotpa);
	}
	else {
		weeks = uiwkbas(btyp, wwork, uer, uc->ucgotpa);
	}
	/* shift pointers to first week of benefits in second phase        */
	/*  leave p1 to point to first paid week                           */
	p2 += weeks;
	p3 = p2;
	p4 = p2;
	DEBUG3("%s basic entitlement=%d, p2=%d\n", weeks, p2);

	/* squeeze pointers between actual start and end of claim          */
	/* note that uc->ucweeks includes weeks of training benefits which should
	   be excluded */
	start = (int) uc->ucstart;
   	last 	= start + wait	+ mini(MP.UIMAXDUR,uc->ucweeks - uc->uctrnwk - uc->ucothwk);
	last 	+= (int) randrnd(MP.UIREGWKFCT*(p4-last), in->id.idrand[2]);

	/* add maximum behavioural adjustment to observed claim end */
	last += extclm;
	DEBUG3("%s start=%d, last=%d\n", start, last);
	uisqz(start, last, &p1, &p2, &p3, &p4);
	DEBUG5("%s p1=%d p2=%d p3=%d p4=%d\n", p1, p2, p3, p4);

    /********************************
    ***  Derive weekly benefit rate
    *********************************/


	if (MP.UIEFFFLAG) {
    	/* When UIEFFFLAG, set the benefit rate to the observed rate                */
		brate1 = uc->uceff;
		brate2 = uc->uceff;
		brate3 = uc->uceff;
	}
	else if (MP.UIEIOPT==2)  {
        /* Derive benefit rate under the EI system */

        /*** minimum divisor rule ***/
        
        /* ucdivwk is the number of weeks worked in the past 26 weeks or the minimum divisor,
            whichever is smaller */

  	 	if (MP.UIEIDIVFLG) {

			/* apply minimum divisor rule */
		    earnings = (earnings *  uc->ucdivwk / maxn(uc->ucdivwk,
		        	        (NUMBER) lkup2(MP.UIEIDIV, MP.UIEIDIVrows, uer)));
		}


        /*** intensity rule***/
	
		/* if the family supplement receivers expempt from intensity rule flag is on and if 
		   the person is eligible for the family rule, or if the claim in neither a regular nor
		   a fishing claim, then do not apply the intensity rule */
		if ((MP.UIEIFIFLG==1 && wctb>0) || !(btyp==UIREG || btyp==UIFSH))  {
			/* do not apply intensity rule */
				brate1 = round((NUMBER) lkup2(MP.UIEIRATE, MP.UIEIRrows, 0) * earnings);
		}	  
		else {
			/* intensity rule applied */ 
		    brate1 = round((NUMBER) lkup2(MP.UIEIRATE, MP.UIEIRrows, wbp5) * earnings);
		}

	}

	else {
		/* Derive the benefit rate under UI by using specified fractions of average eligible earnings */

		/* 1994 REFORM: basic rates vary wrt the presence of dependents */
		/* and earnings levels */
		if (in->im.imuidpfg) {
			if (earnings < (MP.UIERNMAX * MP.UIENSRTCO)	) {
				brate1 = round(MP.UIENSRATE * earnings);
			}
			else {
				brate1 = round(
							maxn(MP.UIENSRATE * (MP.UIERNMAX * MP.UIENSRTCO)
								 ,MP.UIBASRATE * earnings));
			}
		}
		else {
			brate1 = round(MP.UIBASRATE * earnings);
		}

		brate2 = round(MP.UILFERATE * earnings);
		brate3 = round(MP.UIRGERATE * earnings);
	}


	/* the following commented code is one of the FORGET proposals */
/*	
	modf(((2.0/3.0)*(((NUMBER) uc->ucwwork)/52.0)*earnings) + .5, &brate1);
	brate1 = round((2.0/3.0)*(uc->ucwwork/52.0)*earnings);
	brate2 = brate1;
	brate3 = brate1;
*/
	/* save claim event pointers */
	ub->ubp1 = p1;
	ub->ubp2 = p2;
	ub->ubp3 = p3;
	ub->ubp4 = p4;

	wi=0;  /* weeks in which both spouses are on UI */
	
	/* Calculate maximum weekly family supplement */
	if (MP.UIEIOPT==2 && MP.UIEIFSFLG==1 && wctb>0  && ( MP.UITARGET[prov] > in->id.iduirank/1000 ))  { 
        /* the total weekly benefits (supplement + brate1) cannot be greate than:
            - UIEIMFSP * insurable earnings
            - total benefits can't be more than 55% of maximum insurable earnings
        */
	 	maxfsup = nneg(minn((earnings * MP.UIEIMFSP)-brate1, 
	 	                (lkup2(MP.UIEIRATE, MP.UIEIRrows, 0) * MP.UIERNMAX) -brate1));
   	
		/* Calculate ineligible weeks for supplement for head in Dual UI family */
        /* I.E. if both spouses are getting UI at the same time, then only one can claim.
           We are doing the household in reverse order, so the spouses pointers to weeks should
           be set.
           wi represents any overlapping weeks */
		if( (in->id.idcfrh==0 && in->id.idspoflg && (in->id.idinspo->id.uc1.ucstat>0 || in->id.idinspo->id.uc2.ucstat>0))&& (in->id.iduirank/1000 < MP.UITARGET[prov]))  {
			wi = (int) (nneg(mini(p4, in->id.idinspo->im.ub1.ubp4) - maxi(p1, in->id.idinspo->im.ub1.ubp1))
			            + nneg(mini(p4, in->id.idinspo->im.ub2.ubp4) - maxi(p1, in->id.idinspo->im.ub2.ubp1)));
		}
   }


	/* compute claim-oriented reporting variables */
	ub->ubclmwk = p4 - p1;
	ub->ubclmpd = brate1 * (p2 - p1) 
	            + brate2 * (p3 - p2)	
	            + brate3 * (p4 - p3) 
	            + minn(maxfsup, wctb) * nneg(ub->ubclmwk - wi);
	ub->ubclmfs = minn(maxfsup, wctb) * nneg(ub->ubclmwk - wi);
	
	/* squeeze pointers into calendar year */
	uisqz(0, 52, &p1, &p2, &p3, &p4);
	DEBUG5("%s p1=%d p2=%d p3=%d p4=%d\n",	p1, p2, p3, p4);

	/* save calendar year windowed event pointers */
	ub->ubp1c = p1;
	ub->ubp2c = p2;
	ub->ubp3c = p3;
	ub->ubp4c = p4;

    /* Calculate ineligible weeks for supplement for heads in Dual UI family */
	if (MP.UIEIOPT==2 && MP.UIEIFSFLG==1 && wctb>0  && (in->id.iduirank/1000 < MP.UITARGET[prov]))  {
		if ((in->id.idcfrh==0 && in->id.idspoflg && (in->id.idinspo->id.uc1.ucstat>0 || in->id.idinspo->id.uc2.ucstat>0))&& (in->id.iduirank/1000 < MP.UITARGET[prov]))  {
			wi = (int) (nneg(mini(p4, in->id.idinspo->im.ub1.ubp4c) - maxi(p1, in->id.idinspo->im.ub1.ubp1c))
			            + nneg(mini(p4, in->id.idinspo->im.ub2.ubp4c) - maxi(p1, in->id.idinspo->im.ub2.ubp1c)));
		}
   }
	/* calculate weeks on claim in the calendar year and dollars       */
	/*  of benefits received                                           */
	calwk = p4 - p1;
	calpd = brate1 * (p2 - p1) 
	      + brate2 * (p3 - p2)	
	      + brate3 * (p4 - p3) 
	      + minn(maxfsup, wctb) * nneg(calwk-wi);

	/* round amount paid to nearest dollar */
	calpd = round(calpd);

	/* complete structure to be returned */
	ub->ubcalpd = calpd;
	ub->ubcalwk = calwk;
	ub->ubcalfs = minn(maxfsup,wctb) * nneg(calwk-wi);


	DEBUG_OFF("uiclm");
	return(valid_claim);
}


// Optimization must be disabled for the following function for the 16-bit compiler,
// to avoid a compiler failure.
#if defined(_MSDOS)
#pragma optimize("", off)
#endif
/*****************************************************************************
*uitrnclm - tack on a training and other claim for those eligible
*
*Synopsis:
*    static int uitrnclm(  
*    P_in in,             
*    P_uc uc,             
*    P_ub ub,             
*    int valid_claim      
*    )                    
*
*Description:
*
*Return Value:
*   None.
*
*Calls:
*   randrnd  Randomly round a floating point number to an integer
*
*Structure Members:
*   MP.UIEIMTYPFLG  (i)  Flag to model main benefit type (UI and EI)
*   MP.UIOTHBNFCT   (i)  UI other benefits per week adjustment factor (EI and EI)
*   MP.UIOTHWKFCT   (i)  UI other benefits weeks adjustment factor (UI and EI)
*   MP.UITRNBNFCT   (i)  UI training benefit per week adjustment factor (EI and EI)
*   MP.UITRNWKFCT   (i)  UI training benefit weeks adjustment factor (UI and EI)
*   id.idrand       (i)  Random numbers [array]
*   ub.ubp4         (i)  Week # of last payment
*   ub.ubp4c        (i)  Week # of last payment (windowed)
*   uc.ucbtyp       (i)  Claim type
*   uc.ucmtyp       (i)  Main Claim type (majority of weeks)
*   uc.ucothbr      (i)  Other benefits weekly rate
*   uc.ucothwk      (i)  Weeks of other benefits
*   uc.uctrnbr      (i)  Training benefit weekly rate
*   uc.uctrnwk      (i)  Weeks of training benefits
*   ub.ubp5         (io) Week # of last other type of ui/ei payment
*   ub.ubp5c        (io) Week # of last other type of ui/ei payment (windowed)
*   ub.ubp6c        (io) Week # of last training payment (windowed)
*   ub.ubcalpd      (o)  Benefits paid in calendar year
*   ub.ubcalwk      (o)  Weeks on claim in calendar year
*   ub.ubclmpd      (o)  Benefits paid on claim
*   ub.ubclmwk      (o)  Weeks on claim
*   ub.ubp6         (o)  Week # of last training payment
*
*Called by:
*   Aui      Compute UI benefits
*
*****************************************************************************/
static int uitrnclm(
	P_in in,
	P_uc uc,
	P_ub ub,
	int valid_claim
)
{
	int train_weeks;
	NUMBER train_weekly_dollars = ZERO;
	NUMBER train_dollars = ZERO;
	int other_weeks;
	NUMBER other_weekly_dollars = ZERO;
	NUMBER other_dollars = ZERO;
    int btyp;

	DEBUG_ON("uitrnclm");

	/* initialise other type and training phases to end at the end of the 'standard'
		part of the claim */
	ub->ubp5 = ub->ubp4;
	ub->ubp5c = ub->ubp4c;
    if (!MP.UIEIMTYPFLG) {
        btyp = uc->ucbtyp;
    }
    else {
        btyp = uc->ucmtyp;
    }

    if ( (btyp == UIOTH || valid_claim) && (uc->ucothbr > ZERO)) {
		DEBUG1("%s processing an eligible claim\n");

		/* increment the length of the claim by the database value
			of other weeks weeks. Then, increment the claim paid
			note the use of the duration and
			benefits per week factors to get aggregate benefits right
		*/
		other_weeks = uc->ucothwk + (int) randrnd(uc->ucothwk * MP.UIOTHWKFCT, in->id.idrand[6]);
		other_weekly_dollars = uc->ucothbr * (ONE + MP.UIOTHBNFCT);

		ub->ubp5 += other_weeks;
		ub->ubclmwk += other_weeks;
		other_dollars = other_weekly_dollars * other_weeks;
	  	ub->ubclmpd += other_dollars;  


		/* do the same for the calendar year estimates */
		ub->ubp5c += other_weeks;
		if (ub->ubp5c > 52) ub->ubp5c=52;
		ub->ubcalwk += ub->ubp5c - ub->ubp4c;
		ub->ubcalpd += other_weekly_dollars * (ub->ubp5c - ub->ubp4c);
    }

	ub->ubp6 = ub->ubp5;
	ub->ubp6c = ub->ubp5c;

    if ( (btyp == UITRN || valid_claim) && (uc->uctrnbr > ZERO) ) {
		/* increment the length of the claim by the database value
			of training weeks. then, increment the claim paid
			note the use of the duration and
			benefits per week factors to get aggregate benefits right
		*/
		train_weeks = uc->uctrnwk + (int) randrnd(uc->uctrnwk * MP.UITRNWKFCT, in->id.idrand[2]);
		train_weekly_dollars = uc->uctrnbr * (ONE + MP.UITRNBNFCT);

		ub->ubp6 += train_weeks;
		ub->ubclmwk += train_weeks;
		train_dollars = train_weekly_dollars * train_weeks;
	  	ub->ubclmpd += train_dollars;  


		/* do the same for the calendar year estimates */
		ub->ubp6c += train_weeks;
		if (ub->ubp6c > 52) ub->ubp6c=52;
		ub->ubcalwk += ub->ubp6c - ub->ubp5c;
		ub->ubcalpd += train_weekly_dollars * (ub->ubp6c - ub->ubp5c);
	}

	return(valid_claim);
	DEBUG_OFF("uitrnclm");
}
#if defined(_MSDOS)
#pragma optimize("", on)
#endif


/*****************************************************************************
*uisqz - Squeeze UI phases into time window
*
*Synopsis:
*    static void uisqz(   
*    int first,           
*    int last,            
*    int *p1,             
*    int *p2,             
*    int *p3,             
*    int *p4              
*    )                    
*
*Description:
*
*Return Value:
*   None.
*
*Calls:
*   maxp     Return maximum of two quantities
*   minp     Return minimum of two quantities
*
*Called by:
*   uiclm    Simulate a UI claim
*
*****************************************************************************/
static void uisqz(
	register int first,
	register int last,
	register int *p1,
	register int *p2,
	register int *p3,
	register int *p4
)
{
	DEBUG_ON("uisqz")
	DEBUG3("%s first=%d last=%d\n", first, last);
	DEBUG5("%s p1=%d p2=%d p3=%d p4=%d\n", *p1, *p2, *p3, *p4)

	/* ensure that p1 is within range <first, last>         */
	/*  note: we assume first <= last                       */
	*p1 = maxp(*p1, first);
	*p1 = minp(*p1, last);

	/* ensure that p4 is within range <first, last>         */
	*p4 = minp(*p4, last);
	*p4 = maxp(*p4, first);

	/* ensure that p3 is within range <first, p4>           */
	*p3 = minp(*p3, *p4);
	*p3 = maxp(*p3, first);

	/* ensure that p2 is within range <first, p4>           */
	*p2 = minp(*p2, *p4);
	*p2 = maxp(*p2, first);

	DEBUG5("%s p1=%d p2=%d p3=%d p4=%d\n", *p1, *p2, *p3, *p4)
	DEBUG_OFF("uisqz")
}


/*****************************************************************************
*uielent - Test UI eligibility: entrance requirements
*
*Synopsis:
*    static int uielent(  
*    int btyp,            
*    int wwork,           
*    double hwork,        
*    double fshearn,      
*    int nereflg,         
*    double uer,          
*    int prov,            
*    int ucstart          
*    )                    
*
*Description:
*
*Return Value:
*   None.
*
*Structure Members:
*   MP.QPIPFLAG     (i)  Quebec parental insurance plan activation flag
*   MP.TARGETYEAR   (i)  Year of analysis
*   MP.UIEINEREFLG  (i)  Flag to check for hours for new entrants and re-entrants (EI only)
*   MP.UIEIOPT      (i)  UI Employment Insurance reform option [1=UI, 2=EI Dec'95]
*   MP.UIENTFLAG    (i)  Basic entrance requirements flag (UI and EI)
*   MP.UIFSHERMIN   (i)  Min. earnings to qualify for fish. benefits [unempl. rate] (EI only)
*   MP.UIFSHErows   (i)  number of rows in UIFSHERMIN
*   MP.UIFSHMINWK   (i)  Minimum weeks to qualify for fishing benefits (UI only)
*   MP.UIMATHRMIN   (i)  Minimum hours to qualify for maternity benefits (EI only)
*   MP.UIMATMINWK   (i)  Minimum weeks to qualify for maternity benefits (UI only)
*   MP.UINEREHRMIN  (i)  Minimum hours to qualify for new entrant or re-entrant (EI only)
*   MP.UIREGHRMIN   (i)  Min. hours to qualify for reg. benefits [unempl. rate] (EI only)
*   MP.UIREGMINWK   (i)  Minimum weeks to qualify for regular benefits (UI only)
*   MP.UIRMHRrows   (i)  number of rows in UIREGHRMIN
*   MP.UISICHRMIN   (i)  Minimum hours to qualify for sickness benefits (EI only)
*   MP.UISICMINWK   (i)  Minimum weeks to qualify for sickness benefits (UI only)
*
*Calls:
*   lkup2    Table look-up without interpolation
*
*Called by:
*   uiclm    Simulate a UI claim
*
*****************************************************************************/
static int uielent(
	int btyp,
	register int wwork,
	register double hwork,
	register double fshearn,
    register int nereflg,
	double uer,
	int prov,
	int ucstart
)
{
	register int valid_claim;

	DEBUG_ON("uielent");
	DEBUG3("%s claim type=%d weeks worked=%d\n", btyp, wwork);

	valid_claim = TRUE;

	if (!MP.UIENTFLAG) {
		DEBUG1("%s leaving uielent: execution suppressed\n");
		DEBUG_OFF("uielent");
		return(valid_claim);
	}

	/* test entrance requirements based on weeks of work by claim type */
	switch (btyp) {
		case UIREG:
			if (MP.UIEIOPT==2)  {
                if (MP.UIEINEREFLG && nereflg==1) {
                    /* new entrant or re-entrant test */
                    if (hwork < MP.UINEREHRMIN) {
                        valid_claim = FALSE;
                    }
                }
				else {
				    if (hwork < lkup2(MP.UIREGHRMIN,MP.UIRMHRrows, (double) uer)) {
					    DEBUG1("%s invalid regular claim\n");
					    valid_claim = FALSE;
				    }
                }
			}
			else if (wwork < MP.UIREGMINWK) {
				DEBUG1("%s invalid regular claim\n");
				valid_claim = FALSE;
			}
			break;

		case UIMAT:
		   	if (MP.UIEIOPT==2)  {
			    if (hwork < MP.UIMATHRMIN) {
				    DEBUG1("%s invalid maternity claim\n");
				    valid_claim = FALSE;
				}    
			}
			else if (wwork < MP.UIMATMINWK) {
				DEBUG1("%s invalid maternity claim\n");
				valid_claim = FALSE;
			}
			if (MP.QPIPFLAG && prov == 4 && 
			   ((MP.TARGETYEAR == 2006 && ucstart >= 0) || MP.TARGETYEAR > 2006) ) {
				valid_claim = FALSE;
			}
			break;
		case UIPAR:
		   	if (MP.UIEIOPT==2)  {
			    if (hwork < MP.UIMATHRMIN) {
				    DEBUG1("%s invalid maternity claim\n");
				    valid_claim = FALSE;
				}    
			}
			else if (wwork < MP.UIMATMINWK) {
				DEBUG1("%s invalid maternity claim\n");
				valid_claim = FALSE;
			}
			if (MP.QPIPFLAG && prov == 4 && 
			   ((MP.TARGETYEAR == 2006 && ucstart >= 0) || MP.TARGETYEAR > 2006) ) {
				valid_claim = FALSE;
			}
			break;
		case UISIC:
			if (MP.UIEIOPT==2)  {
			    if (hwork < MP.UISICHRMIN) {
				    DEBUG1("%s invalid sickness claim\n");
				    valid_claim = FALSE;
				}    
			}
			else if (wwork < MP.UISICMINWK) {
				DEBUG1("%s invalid sickness claim\n");
				valid_claim = FALSE;
			}
			break;
		case UIFSH:
			if (MP.UIEIOPT==2)  {
			    if (fshearn < lkup2(MP.UIFSHERMIN,MP.UIFSHErows, (double) uer)) {
				    DEBUG1("%s invalid fishing claim\n");
				    valid_claim = FALSE;
				}    
			}
			else if (wwork < MP.UIFSHMINWK) {
				DEBUG1("%s invalid fishing claim\n");
				valid_claim = FALSE;
			}
			break;
		default:
			valid_claim = TRUE;
	}
	
	
	DEBUG2("%s valid_claim=%d\n", valid_claim);
	DEBUG_OFF("uielent");
	return(valid_claim);
}



/*****************************************************************************
*uiwkbas - UI weeks of benefits: basic entitlement
*
*Synopsis:
*    static int uiwkbas(  
*    int btyp,            
*    int amtwork,         
*    double uer,          
*    int gotpa            
*    )                    
*
*Description:
*
*Return Value:
*   None.
*
*Calls:
*   STRN     Retrieve a string constructed from a number
*   fataltr  display fatal error message with traceback and exit
*
*Structure Members:
*   MP.UIBASFLAG    (i)  Basic phase calculation flag (UI and EI)
*   MP.UIEIOPT      (i)  UI Employment Insurance reform option [1=UI, 2=EI Dec'95]
*   MP.UIEWK        (i)  Entitlement (weeks) [wkwrk, uer] (UI and EI)
*   MP.UIMAXFSHWKS  (i)  Maximum number of weeks - fishing (UI and EI)
*   MP.UIMAXMATWKS  (i)  Maximum number of weeks - maternity (UI and EI)
*   MP.UIMAXPARWKS  (i)  Maximum number of weeks - parental (UI and EI)
*   MP.UIMAXSICWKS  (i)  Maximum number of weeks - sickness (UI and EI)
*
*Called by:
*   uiclm    Simulate a UI claim
*
*****************************************************************************/
static int uiwkbas(
	int btyp,
	register int amtwork,
	double uer,
	int gotpa
)
{
	register int wbasic;
	int tmprow;
	int tmpcol;
    int wwork;

	DEBUG_ON("uiwkbas");
	DEBUG3("%s claim type=%d, amtwork=%d\n", btyp, amtwork);

	wbasic = 0;

	if (!MP.UIBASFLAG) {
		DEBUG1("%s leaving uiwkbas: execution suppressed\n");
		DEBUG_OFF("uiwkbas");
		return(wbasic);
	}

	switch (btyp) {
		case UIREG:
			DEBUG1("%s regular claim\n");
			 /* Apr '89 reform  and the EI system */

			/**
			* Create index into the columns of the UIEWK array.
			* UIEWKC1 is the upper limit uer for the first column of UIEWK.
			* Because the intervals are open below and closed above, a bit
			* of arithmetic gymnastics is required to calculate the correct
			* integer index.  Note that the cast to int truncates floating
			* point values in C.
			**/
                
			tmpcol = (int) ((uer + (NUMBER) 0.9999) - UIEWKC1);
			/* truncate calculated column to array limits */
			if (tmpcol < 0) {
 				tmpcol = 0;
 			}
 			else if (tmpcol >= UIEWKCMAX) {
 				tmpcol = UIEWKCMAX - 1;
 			}
 
 			/**
 			* Create index into the rows of UIEWK array.
 			* UIEWKR1 is the weeks worked for the first row of UIEWK
            * under the UI system, or the hours worked divided by
            * UIEIWHCF under the EI system
			**/

             /**
             * Under the EI system, the rows of the array represent hours worked
             * starting at 350 hours with increments of 35.  So we start by converting 
             * the hours by dividing them by 35 = UIEIHWCF
             **/
                
             if (MP.UIEIOPT==2) {
                 /* EI system */
                 wwork = (int) amtwork/UIEIHWCF;
             }
             else {
                 /* UI system */
                 wwork = amtwork;
             }

   		     tmprow = wwork - UIEWKR1;

			 /* truncate calculated row to array limits */
			 if (tmprow < 0) {
			 	tmprow = 0;
			 }
			 else if (tmprow >= UIEWKRMAX) {
			 	tmprow = UIEWKRMAX - 1;
			 }

			 wbasic = MP.UIEWK[tmprow][tmpcol];
			break;
		case UIMAT:
			DEBUG1("%s maternity claim\n");
			wbasic = MP.UIMAXMATWKS;
			/* if the person got parental benefits, then add them to the max */
			if (gotpa=1) wbasic = wbasic + MP.UIMAXPARWKS;
			break;
		case UISIC:
			DEBUG1("%s sick claim\n");
			wbasic = MP.UIMAXSICWKS;
			break;
		case UIFSH:
			DEBUG1("%s fishing claim\n");
			wbasic = MP.UIMAXFSHWKS;
			break;
		case UIPAR:
			DEBUG1("%s parental claim\n");
			wbasic = MP.UIMAXPARWKS;
			break;
		default:
			DEBUG2("%s invalid claim type=%d\n", btyp);
			fataltr(STRN(223), btyp);
			/* NOT_REACHED */
			DEBUG_OFF("");
	}
	DEBUG2("%s basic entitlement in weeks: wbasic=%d\n", wbasic);
	DEBUG_OFF("uiwkbas");
	return(wbasic);
}




