/***
*adju.cpp - SPSD database adjustment (user defined)
*
*$Id: adju.cpp 6.89 2007/09/18 17:20:30 hickcha Exp $
*
*   SPSD/M Copyright (c) 1987-1989, Minister of Regional Industrial Expansion.
*   All rights reserved.  Use, reproduction, or disclosure of this work,
*   as well as publication of results derived from this work, are subject
*   to the conditions specified in the SPSD/M License Agreement.
*
*Purpose:
*   This file contains the definition of the adju.c function.  It provides
*   a controlled manner in which the user can add database adjustment
*   algorithms to the spsm.  See the SPSD/M Programmer's Guide for more
*   information.
*
*Revisions:
* +-----+----------+---------------------------------------------------------+
* | Who |   Date   | Description                                             |
* +-----+----------+---------------------------------------------------------+
* | LP  | 00/06/06 | Renamed AGENAME to Standard from Standard adjustment    |
* | TCB | 98/05/28 | Renamed *.cpp, ANSI function headers                    |
* | --- | 89/10/13 | Release 4.0                                             |
* |     |          |                                                         |
* +-----+----------+---------------------------------------------------------+
*
*Definitions:
*   adju     [global]  SPSD database adjustment (user defined)
*
*****************************************************************************/


/* ==================== C-RUNTIME LIBRARY INCLUDE FILES =================== */

#include <stdio.h>  /* definitions/declarations for standard I/O routines   */


/* ==================== SPSD/M INCLUDE FILES ============================== */

#include "spsm.h"   /* SPSM common manifest constants and macros            */
#include "sub.h"    /* Subroutine library declarations                      */
#include "vsu.h"    /* Household variable sub-structure (user's)            */
#include "vs.h"     /* Household variable structure and sub-structures      */
#include "apu.h"    /* Database adjustment parameter (user's) declarations  */
#include "ap.h"     /* Database adjustment parameter declarations           */


/* ==================== GLOBAL VARIABLE DECLARATIONS ====================== */

/* AGENAME is the global data ageing identifier.
*/

/*global*/ char AGENAME[IDSIZE+1] = "Unnamed";


/* ==================== COMPILER PRAGMAS ================================== */

#ifdef MSCOVL
#pragma alloc_text(MODEL_TEXT,adju)
#endif


/* ==================== FUNCTION DEFINITIONS ============================== */

/*****************************************************************************
*adju - SPSD database adjustment (user defined)
*
*Synopsis:
*    void adju(           
*    P_hh hh              
*    )                    
*
*Description:
*
*Return Value:
*   None.
*
*Calls:
*   adj      Perform SPSD database adjustment
*
*Called by:
*   phase4   Perform simulation
*
*****************************************************************************/
void  adju(
	P_hh hh
)
{

	DEBUG_ON("adju");

	/* Just call the standard adjustment algorithm. */
	adj(hh);

	/* Place user-specified database adjustments here. */

	DEBUG_OFF("adju");
}


