/***
*cpdu.cpp - Execution control parameter definitions (user's)
*
*$Id: cpdu.cpp 6.87 2007/09/18 17:23:49 hickcha Exp $
*
*   SPSD/M Copyright (c) 1987-1989, Minister of Regional Industrial Expansion.
*   All rights reserved.  Use, reproduction, or disclosure of this work,
*   as well as publication of results derived from this work, are subject
*   to the conditions specified in the SPSD/M License Agreement.
*
*Purpose:
*   This file contains the definition of the cpdu.c function.
*
*Revisions:
* +-----+----------+---------------------------------------------------------+
* | Who |   Date   | Description                                             |
* +-----+----------+---------------------------------------------------------+
* | TCB | 98/05/28 | Renamed *.cpp, ANSI function headers                    |
* | SFG | 95/10/18 | Add pragma to suppress near/far warnings in MSDOS 16-bit|
* | --- | 89/10/13 | Release 4.0                                             |
* |     |          |                                                         |
* +-----+----------+---------------------------------------------------------+
*
*Usage:
*   This is a place holder module.  It is intended to be used to add new
*   execution control parameters of a temporary nature to the model.
*   Two files are used when adding a new parameter to the model.
*
*   cpu.h    - is a header file which defines the new parameters.  It
*                should be modified first when adding a new parameter.
*   cpdu.c   - is a C-language program which enables the model to understand
*                how to read and modify the new parameters.  Each new
*                parameter in cpu.h must have a corresponding entry
*                in cpdu.c
*
*   This file will be rarely if ever used by the glass box user.
*
*Definitions:
*   cpdu     [global]  Execution control parameter definitions (user's)
*
*****************************************************************************/


/* ==================== C-RUNTIME LIBRARY INCLUDE FILES =================== */

#include <stdio.h>  /* definitions/declarations for standard I/O routines   */


/* ==================== SPSD/M INCLUDE FILES ============================== */

#include "spsm.h"   /* SPSM common manifest constants and macros            */
#include "sub.h"    /* Subroutine library declarations                      */
#include "pm.h"     /* Parameter manipulation package declarations          */
#include "cpu.h"    /* Control parameter (user's) declarations              */
#include "cp.h"     /* Control parameters declarations                      */

/* ==================== STATIC VARIABLE DEFINITIONS ======================= */

static char NEAR F_MONEY[]  = "8.2";
static char NEAR F_FRACT[]  = "8.5";


/* ==================== COMPILER PRAGMAS ================================== */

// eliminate spurious 'near/far mismatch' from MS-DOS compiler
#if defined(_MSDOS)
#pragma warning(disable : 4762)
#endif

#ifdef MSCOVL
#pragma alloc_text(INIT_TEXT,cpdu)
#endif


/* ==================== FUNCTION DEFINITIONS ============================== */

/*****************************************************************************
*cpdu - Execution control parameter definitions (user's)
*
*Synopsis:
*    void cpdu(           
*    P_pc pcp             
*    )                    
*
*Description:
*
*Return Value:
*   None.
*
*Called by:
*   phase1   Perform initialisation tasks
*   pubmeta  Publish internal meta information in XML format
*
*****************************************************************************/
void  cpdu(
	P_pc pcp
)
{
	DEBUG_ON("cpdu");

	pcp;   /* reference to avoid compiler warnings */

	DEBUG_OFF("cpdu");
}



