/***
*mpd.cpp - Standard tax/transfer parameter definitions
*
*$Id: mpd.cpp 6.88 2007/09/18 17:22:09 hickcha Exp $
*
*   SPSD/M Copyright (c) 1987-1995, Minister of Industry.
*   All rights reserved.  Use, reproduction, or disclosure of this work,
*   as well as publication of results derived from this work, are subject
*   to the conditions specified in the SPSD/M License Agreement.
*
*Purpose:
*   This file contains the definition of the .c function.
*
*Revisions:
* +-----+----------+---------------------------------------------------------+
* | Who |   Date   | Description                                             |
* +-----+----------+---------------------------------------------------------+
* | SFG | 05/05/10 | Removed second argument to mpd, Ampd                    |
* | TCB | 98/05/28 | Renamed *.cpp, ANSI function headers                    |
* | --- | 89/10/13 | Release 4.0                                             |
* |     |          |                                                         |
* +-----+----------+---------------------------------------------------------+
*
*Definitions:
*   mpd      [global]  Tax/transfer model parameter definitions
*
*****************************************************************************/


/* ==================== C-RUNTIME LIBRARY INCLUDE FILES =================== */

#include <stdio.h>  /* definitions/declarations for standard I/O routines   */


/* ==================== SPSD/M INCLUDE FILES ============================== */

#include "spsm.h"   /* SPSM common manifest constants and macros            */
#include "sub.h"    /* Subroutine library declarations                      */
#include "pm.h"     /* Parameter manipulation package declarations          */
#include "mpu.h"    /* Tax/transfer parameter declarations (user's)         */
#include "mp.h"     /* Tax/transfer parameter declarations                  */


/* ==================== GLOBAL VARIABLE DEFINITIONS ======================= */

/* Give global string describing version of this module */

/*global*/ char FAR Smpd[] = "Untitled"
#ifdef _MSC_VER
" [" __TIMESTAMP__ "]"
#endif
;


/* ==================== STATIC VARIABLE DEFINITIONS ======================= */

static char NEAR F_FRACT[]  = "8.5";
static char NEAR F_LKTUR[]  = "8.0 8.3 10.4";


/* ==================== COMPILER PRAGMAS ================================== */

#ifdef MSCOVL
#pragma alloc_text(INIT_TEXT,mpd)
#endif


/* ==================== FUNCTION DEFINITIONS ============================== */


/*****************************************************************************
*mpd - Tax/transfer model parameter definitions
*
*Synopsis:
*    void mpd(            
*    P_pc pcp              resulting parameter chain
*    )                    
*
*Description:
*
*Return Value:
*   None.
*
*
*Calls:
*   mpd1     Tax/transfer model parameter definitions
*   mpd2     Tax/transfer model parameter definitions (cont.)
*   mpd3     Tax/transfer model parameter definitions (cont.)
*   mpd4     Tax/transfer model parameter definitions (cont.)
*
*Called by:
*   phase1   Perform initialisation tasks
*   pubmeta  Publish internal meta information in XML format
*
*****************************************************************************/
void mpd(
	P_pc pcp  /* resulting parameter chain         */
)
{
	DEBUG_ON("mpd");

	mpd1(pcp);
	mpd2(pcp);
	mpd3(pcp);
	mpd4(pcp);

	DEBUG_OFF("mpd");
}



