/***
*mpu.h - Tax/transfer parameter declarations (user's)
*
*$Id: mpu.h 6.92 2007/09/18 17:18:31 hickcha Exp $
*
*   SPSD/M Copyright (c) 1987-1989, Minister of Regional Industrial Expansion.
*   All rights reserved.  Use, reproduction, or disclosure of this work,
*   as well as publication of results derived from this work, are subject
*   to the conditions specified in the SPSD/M License Agreement.
*
*Purpose:
*   This file declares the parameter structure, associated macro symbols,
*   and function prototypes associated with 'user hooks' for tax/transfer
*   parameters.
*
*Revisions:
* +-----+----------+---------------------------------------------------------+
* | Who |   Date   | Description                                             |
* +-----+----------+---------------------------------------------------------+
* | CH  | 05/09/20 | Added Acceopt                                           |
* | SFG | 05/05/10 | Removed second argument to mpd, Ampd                    |
* | LP  | 01/03/05 | Removed Federal Senior's Benefit program                |
* | --- | 89/10/13 | Release 4.0                                             |
* |     |          |                                                         |
* +-----+----------+---------------------------------------------------------+
*
*Usage:
*   This is a place holder module.  Please see the description in the file
*   /spsm/glass/Ampd.c or the SPSD/M Programmer's Guide for a description
*   of how to add a new tax/transfer parameter to SPSM.
*
*****************************************************************************/



/* ==================== MANIFEST CONSTANTS ================================ */

/**
* Fixed constants defining the number of rows in vectors, look-up tables,
* or two-dimensional tables should be defined as macros and placed in this
* section.  In this way they can be used both to define the array sizes
* in this file, and also in the companion functions 'mpd.c' and 'Ampd.c'
* where the values of these limits are required again.
**/


/* ==================== STRUCTURE DECLARATION MACROS ====================== */

#define S_UM   struct UM_
#define P_UM   S_UM *



/* ==================== STRUCTURE DECLARATIONS ============================ */

/**
* Parameters may be added freely to the following structure, provided only
* that the UM structure does not exceed UPRMSIZE (defined in mp.h) bytes.
*
* The existing `UMDUMMY' entry can be removed after one or more real entries
* have been added, if desired.
*
* To add a Flag or Option, insert an entry of the form

	int XXXXX;

* To add a numeric scalar parameter insert an entry of the form

	NUMBER XXXXX;

* Please see the SPSD/M Programmer's Guide, or examine the file
* /spsm/defs/mp.h, for information on how to add more complicated
* parameter types.
**/

typedef struct UM_ {
	int UMDUMMY;      /* dummy entry                                    */
} UM_;



/* ==================== GLOBAL VARIABLE DECLARATIONS ====================== */


/**
* The following global strings serve to identify the version of each
* tax/transfer module in the 'alternate' algorithm.  They are combined
* to form the ALGDESC informational control parameter.
**/

extern char FAR Ttxcalc[];
extern char FAR Ttxccea[];
extern char FAR Ttxctc[];
extern char FAR Tctmod[];
extern char FAR Tcall[];
extern char FAR Tdrv[];
extern char FAR Tfamod[];
extern char FAR Ttxfstc[];
extern char FAR Tgis[];
extern char FAR Tgist[];
extern char FAR Ttxhstr[];
extern char FAR Ttxinet[];
extern char FAR Ttxitax[];
extern char FAR Tmemo1[];
extern char FAR Tmemo2[];
extern char FAR Toas[];
extern char FAR Ttxhhexp[];
extern char FAR Ttxprov[];
extern char FAR Ttxnfld[];
extern char FAR Ttxpei[];
extern char FAR Ttxns[];
extern char FAR Ttxnb[];
extern char FAR Ttxque[];
extern char FAR Ttxont[];
extern char FAR Ttxman[];
extern char FAR Ttxsask[];
extern char FAR Ttxalta[];
extern char FAR Ttxbc[];
extern char FAR Ttxqccea[];
extern char FAR Ttxqhstr[];
extern char FAR Ttxqinet[];
extern char FAR Ttxqitax[];
extern char FAR Ttxqcalc[];
extern char FAR Tsamod[];
extern char FAR Tui[];
extern char FAR Tdem[];
extern char FAR Tgai[];
extern char FAR Tmpc[];
extern char FAR Tmpd[];
extern char FAR Tcceopt[];



/* ==================== FUNCTION PROTOTYPES =============================== */

/**
* A prototpe for a user version of each tax/transfer algorithm is provided
* below.  These prototypes are based on those given in the file mp.h,
* but have a leading 'A' prepended to the function name.  
* See the SPSD/M Programmer's Guide for more information.
**/

#ifdef P_hh    /* declare prototypes taking hhld or sub-structures */
	extern  void Atxcalc(P_hh hhld);
	extern  void Atxccea(P_hh hhld);
	extern  void Atxctc(P_hh hhld);
	extern  void Actmod(P_hh hhld);
	extern  void Acall(P_hh hhld);
	extern  void Adrv(P_hh hhld);
	extern  void Afamod(P_hh hhld);
	extern  void Atxfstc(P_hh hhld);
	extern  void Agis(P_hh hhld);
	extern  void Agist(P_hh hhld);
	extern  void Atxhstr(P_hh hhld);
	extern  void Atxinet(P_hh hhld);
	extern  void Atxitax(P_hh hhld);
	extern  void Amemo1(P_hh hhld);
	extern  void Amemo2(P_hh hhld);
	extern  void Aoas(P_hh hhld);
	extern  void Atxhhexp(P_hh hhld);
	extern  void Atxprov(P_hh hhld);
	extern  void Atxnfld(P_hh hhld);
	extern  void Atxpei(P_hh hhld);
	extern  void Atxns(P_hh hhld);
	extern  void Atxnb(P_hh hhld);
	extern  void Atxque(P_hh hhld);
	extern  void Atxont(P_hh hhld);
	extern  void Atxman(P_hh hhld);
	extern  void Atxsask(P_hh hhld);
	extern  void Atxalta(P_hh hhld);
	extern  void Atxbc(P_hh hhld);
	extern  void Atxqccea(P_hh hhld);
	extern  void Atxqhstr(P_hh hhld);
	extern  void Atxqinet(P_hh hhld);
	extern  void Atxqitax(P_hh hhld);
	extern  void Atxqcalc(P_hh hhld);
	extern  void Asamod(P_hh hhld);
	extern  void Aui(P_hh hhld);
	extern  void Adem(P_hh hhld);
	extern  void Agai(P_hh hhld);
	extern  void Acceopt(P_hh hhld, void (* drv)(P_hh));
#endif

#ifdef P_pc
	extern  void Ampd(P_pc pcp);
#endif

extern  int  Ampc(void);
