/***
*tbiu.cpp - Routines to produce user-programmed model tables
*
*$Id: TBIU.cpp 6.87 2007/09/18 17:23:48 hickcha Exp $
*
*   SPSD/M Copyright (c) 1987-1989, Minister of Regional Industrial Expansion.
*   All rights reserved.  Use, reproduction, or disclosure of this work,
*   as well as publication of results derived from this work, are subject
*   to the conditions specified in the SPSD/M License Agreement.
*
*Purpose:
*   This file contains the definition of the .c function.
*
*Revisions:
* +-----+----------+---------------------------------------------------------+
* | Who |   Date   | Description                                             |
* +-----+----------+---------------------------------------------------------+
* | TCB | 98/05/28 | Renamed *.cpp, ANSI function headers                    |
* | --- | 89/10/13 | Release 4.0                                             |
* |     |          |                                                         |
* +-----+----------+---------------------------------------------------------+
*
*Definitions:
*   tbiu     [global]  Process request for user hard-wired tables
*   tblu     [global]  Increment user hard-wired tables
*   tbpu     [global]  Print user hard-wired tables
*   tbwu     [static]  Adjust weights for user hard-wired tables
*
*****************************************************************************/


/* ==================== C-RUNTIME LIBRARY INCLUDE FILES =================== */

#include <stdio.h>  /* definitions/declarations for standard I/O routines   */
#include <time.h>   /* definitions/declarations for time routines           */
#include <string.h> /* declarations for string manipulation functions       */
#include <malloc.h> /* declarations and definitions for memory ...          */


/* ==================== SPSD/M INCLUDE FILES ============================== */

#include "spsm.h"   /* SPSM common manifest constants and macros            */
#include "sub.h"    /* Subroutine library declarations                      */
#include "vsu.h"    /* Household variable sub-structure (user's)            */
#include "vs.h"     /* Household variable structure and sub-structures      */
#include "cpu.h"    /* Control parameter (user's) declarations              */
#include "cp.h"     /* Control parameters declarations                      */


/* ==================== FUNCTION PROTOTYPES =============================== */

static  void  tbwu(double dwgt);


/* ==================== COMPILER PRAGMAS ================================== */

#ifdef MSCOVL
#pragma alloc_text(DIALOG_TEXT,tbiu)
#pragma alloc_text(MODEL_TEXT,tblu)
#pragma alloc_text(REPORT_TEXT,tbpu,tbwu)
#endif


/* ==================== FUNCTION DEFINITIONS ============================== */

/*****************************************************************************
*tbiu - Process request for user hard-wired tables
*
*Synopsis:
*    void tbiu()          
*
*Description:
*
*Return Value:
*   None.
*
*Called by:
*   phase23  Engage in user dialogue, and prepare for simulation
*
*****************************************************************************/
void  tbiu()
{
	DEBUG_ON("tbiu");

	DEBUG_OFF("tbiu");
}


/*****************************************************************************
*tblu - Increment user hard-wired tables
*
*Synopsis:
*    void tblu(           
*    P_hh hh              
*    )                    
*
*Description:
*
*Return Value:
*   None.
*
*Called by:
*   phase4   Perform simulation
*
*****************************************************************************/
void  tblu(
	P_hh hh
)
{
	DEBUG_ON("tblu");

	hh;

	DEBUG_OFF("tblu");
}


/*****************************************************************************
*tbpu - Print user hard-wired tables
*
*Synopsis:
*    void tbpu(           
*    FILE *tblfp          
*    )                    
*
*Description:
*
*Return Value:
*   None.
*
*Called by:
*   phase5   Print reports, etc.
*
*****************************************************************************/
void  tbpu(
	FILE *tblfp
)
{
	DEBUG_ON("tbpu");

	tblfp;

	DEBUG_OFF("tbpu");
}


/*****************************************************************************
*tbwu - Adjust weights for user hard-wired tables
*
*Synopsis:
*    static void tbwu(    
*    double dwgt          
*    )                    
*
*Description:
*
*Return Value:
*   None.
*
*****************************************************************************/
static void  tbwu(
	register double dwgt
)
{
	DEBUG_ON("tbwu");

	dwgt;

	DEBUG_OFF("tbwu");
}
