/***
*mpd2.cpp - Tax/transfer model parameter definitions (cont.)
*
*$Id: mpd2.cpp 6.174 2007/09/18 17:22:09 hickcha Exp $
*
*   SPSD/M Copyright (c) 1987-1995, Minister of Industry.
*   All rights reserved.  Use, reproduction, or disclosure of this work,
*   as well as publication of results derived from this work, are subject
*   to the conditions specified in the SPSD/M License Agreement.
*
*Purpose:
*   This file contains the definition of the .c function.
*
*Revisions:
* +-----+----------+---------------------------------------------------------+
* | Who |   Date   | Description                                             |
* +-----+----------+---------------------------------------------------------+
* | CH  | 07/07/26 | Labeled dimensions of ASHELTER, ASHELTERP               |
* | LP  | 07/07/08 | Added Manitoba Child Benefit parameters (MCBFLAG +)     |
* | LP  | 07/07/04 | Added NL Senior Benefit parameters for senior couples   |
* | LP  | 07/06/22 | Added WITB Supplement for Disabilities                  |
* | LP  | 07/06/04 | Added Ontario Child Benefit parameters                  |
* | LP  | 07/04/24 | Relabeled previous child tax credit parms as refundable |
* | LP  | 07/04/04 | Added Working Income Tax Benefit (WITB) - ref. credit   |
* | LP  | 07/02/20 | Changed Ont/Alt clawback parm, add clawback for cal year|
* | CH  | 07/02/22 | Added PENSPLTINCR                                       |
* | CH  | 07/02/06 | Added pension income splitting                          |
* | LP  | 07/01/25 | Deleted CLERGYRD - not required, clergy always deducted |
* | LP  | 06/07/04 | Added Ont. Home Electricity Relief Program - OHEATFLG+  |
* | LP  | 06/06/19 | Moved CLERGYRD to under 'Deductions from total income'  |
* | LP  | 06/06/13 | Added prev. yr's parms for Alta Sen. Ben. for calendar  |
* | LP  | 06/06/12 | Added a third option to CTCOPT to calculate both        |
* | LP  | 06/06/12 | Added phase in rates for Federal Child Tax Benefit      |
* | LP  | 06/06/05 | Added previous years' parms for GST credit for calendar |
* | LP  | 06/05/25 | Added UCCBFLAG & UCCBAMT universal child care benefit   |
* | LP  | 06/05/24 | Added previous years' parms for provincial child benefit|
* | LP  | 06/05/23 | Added previous years' parms for federal child benefit   |
* |     |          | to enable proper calendar year calculations             |
* | LP  | 06/05/15 | Added FDGURLC and DIVPLC - large corp dividend parms    |
* | CH  | 06/05/11 | Added ONCBSFT Ontario flow through of sa claw           |
* | LP  | 06/05/08 | Added MEDRTD refundable medical expense income turndown |
* | LP  | 06/05/05 | Removed CCEALIM - no longer used                        |
* | LP  | 06/01/23 | Added SASKTECA - Sask. temporary energy cost allowance  |
* | LP  | 06/01/17 | Added SACLAWOPT to imsaclaw for incl in total/disp inc  |
* | LP  | 05/11/23 | Added NS rebate for elec VHEATERB, removed VHEATFRR     |
* | LP  | 05/11/14 | Added N.B. Home Heating Oil Benefit program (BHEAT..)   |
* | LP  | 05/10/25 | Added income test to NFLD home heating fuel rebate      |
* | LP  | 05/10/21 | Added Energy Cost Benefit (FECBFLAG, FECBGIS, FECBNCBS) |
* | LP  | 05/07/13 | Added CLERGYRD - Clergy Residence Deduction Flag        |
* | LP  | 05/07/08 | Added back SA clawback parameters (SACLAWFLAG, etc.)    |
* | LP  | 05/05/06 | Added VHEATFLG + VHEAT series N.S. home-heating rebate  |
* | LP  | 05/04/15 | Added BXMEXT, MXMEXT, EMXMEXT, MXMTEXT, EMXMTEXT        |
* | LP  | 04/06/22 | Added Sask. Child Benefit Single Parent Amount - SCBSPA |
* | LP  | 04/05/27 | Added NMBNSEXT, NMBNSEPI - Nfld MBNS newborn extra ben  |
* | LP  | 04/03/09 | Added ASBSAB, ASBSABRR supplemental accommodation benef.|
* | LP  | 04/02/23 | Removed SA clawback parameters,SACLAWFLAG, SACLAWPR, etc|
* | LP  | 04/02/20 | Removed ALTAWP & Sask. Employment Supplement parameters |
* | LP  | 03/12/19 | Added CCEPTFLG part time student eligibility for cce    |
* | CH  | 03/05/16 | NS Taxpayer refund program implemented                  |
* | CH  | 03/05/14 | Added NHEATSAFLG                                        |
* | LP  | 02/09/04 | Revised number sequence                                 |
* | LP  | 02/06/21 | Added OCCSEXT one time $100 payment to OCCS families    |
* | LP  | 02/06/17 | Added Nfld Mother-Baby Nutrition Supp. (NMBNS & NMBNSPI)|
* | LP  | 02/05/02 | Added SA Clawback parameter SACLAWFLAG, SACLAWPR, etc.  |
* | LP  | 01/07/10 | Added Sask. Employment Supplement take up rate SESTK    |
* | LP  | 01/06/22 | Added Employment Supplementary benefit for under 13     |
* | LP  | 01/04/05 | Added NBSBSPA NB seniors' benefit SPA eligibility flag  |
* | LP  | 01/04/03 | Added BC, Alta, & Sask. Home Heating Assistance Rebates |
* | LP  | 01/04/02 | Added NHEATFLG & NHEATREB NFLD Home Heating Fuel Rebate |
* | LP  | 01/03/12 | Removed pre-1988 program parameters                     |
* | CH  | 00/10/24 | Added CPP deduction for the self-employed               |
* | CH  | 00/10/24 | Removed medical expense supplement turndown             |
* | CH  | 00/10/24 | Added relief for heating expenses                       |
* | LP  | 00/06/05 | Added GSTCTUNC - GST take up by number of elig. children|
* | LP  | 00/06/01 | Added CPP Contribution Take ups by age range and income |                                          
* | CH  | 00/05/24 | Added ALEXDEDFLG                                        |                                          
* | LP  | 00/05/03 | Added OCWISSP max annual benefit for single parents     |
* | LP  | 00/04/16 | Added NS Direct Assistance for families with kids flag  |
* | CH  | 00/04/10 | Added GSTAXM                                            |
* | CH  | 00/03/29 | Added BC family bonus parameters                        |
* | LP  | 00/03/16 | Add Nova Scotia Child Benefit income phase out level    |
* | LP  | 00/03/16 | Add Newfoundland and Labrador Child Benefit program     |
* | LP  | 99/05/25 | Add B.C. Earned Income Benefit                          |
* | LP  | 99/05/25 | Add BC Family Bonus Flag for program changes BCFBIFS    |
* | LP  | 99/05/25 | Add NFLD Low Income Senior's Benefit                    |
* | EGA | 99/05/25 | SATARGET by province                                    |
* | CH  | 99/04/20 | Add NS child benefit                                    |
* | CH  | 99/04/16 | Added GSTASPFLAG                                        |
* | CH  | 99/04/15 | Added BXMSPI                                            |
* | EGA | 99/03/25 | Add SAPFLAG and SATARGET                                |
* | TCB | 98/05/28 | Renamed *.cpp, ANSI function headers                    |
* | BBM | 98/05/11 | Add OCWISFLG, OCWISTD, OCWISRR parameters(Ont Child WIS)|
* | CH  | 98/05/01 | added SASK emp. supp. phase in                          |
* | CH  | 98/05/01 | added SASK child benefit and employment supplement      |
* | CH  | 98/04/08 | added NB Low income seniors' benefit                    |
* | CH  | 98/03/09 | added CCESYNG CCESOLD                                   |
* | CH  | 98/02/26 | deleted CCEOPT                                          |
* | CH  | 98/02/05 | added ASBSSOPT                                          |
* | CH  | 98/02/05 | add ASBNOASS ASBNOASM ASBEMP ASBRR, removed ASBTD ASBMAR|
* | CH  | 98/02/03 | added NS Direct Assistance flag VDASFLAG and renamed var|
* | CH  | 98/02/03 | added NS Direct Assistance VDASB VDACB VDASI VDACI      |
* | CH  | 98/01/22 | added Fed. Refundable medical expense supplement        |
* | BBM | 97/10/15 | added Ont. Refundable child care tax credit parms       |
* | BBM | 97/10/07 | Implement B.C. Family Bonus parameters                  |
* | CH  | 97/10/07 | Add FSTCREF                                             |
* | CH  | 97/10/01 | Add NBCBPI                                              |
* | CH  | 97/09/15 | Add FCBEMX                                              |
* | CH  | 97/09/11 | Add FCBERR1,FCBERR2,FCBERR3                             |
* | ER  | 96/09/19 | Add CCE Deduction rate full-time student (CCESFLAG)     |
* | BBM | 96/04/16 | Parameterize the maximum age for old kid to get CCEA    |
* | RSE | 94/04/07 | add Alberta seniors benefit for 1994 and beyond         |
* | GJC | 94/03/09 | eliminate MP.FCBNCC from structure                      |
* | RSE | 94/02/24 | added age exemption changes from 1994 budget            | 
* | RSE | 94/02/22 | changed name of FCBNCC to FCBYNG and added FCBYNGR      | 
* | GJC | 93/01/20 | provincialise SAFS                                      |
* | BBM | 92/07/14 | Add CTC fudge parameters CTCTUR CTCINC                  |
* | --- | 89/10/13 | Release 4.0                                             |
* |     |          |                                                         |
* +-----+----------+---------------------------------------------------------+
*
*Definitions:
*   mpd2     [global]  Tax/transfer model parameter definitions (cont.)
*
*****************************************************************************/


/* ==================== C-RUNTIME LIBRARY INCLUDE FILES =================== */

#include <stdio.h>  /* definitions/declarations for standard I/O routines   */


/* ==================== SPSD/M INCLUDE FILES ============================== */

#include "spsm.h"   /* SPSM common manifest constants and macros            */
#include "sub.h"    /* Subroutine library declarations                      */
#include "pm.h"     /* Parameter manipulation package declarations          */
#include "mpu.h"    /* Tax/transfer parameter declarations (user's)         */
#include "mp.h"     /* Tax/transfer parameter declarations                  */


/* ==================== STATIC VARIABLE DEFINITIONS ======================= */

static char NEAR F_FRACT[]  = "8.5";
static char NEAR F_LKTUR[]  = "8.0 8.3 10.4";


/* ==================== COMPILER PRAGMAS ================================== */

// eliminate spurious 'near/far mismatch' from MS-DOS compiler
#if defined(_MSDOS)
#pragma warning(disable : 4762)
#endif

#ifdef MSCOVL
#pragma alloc_text(INIT_TEXT,mpd2)
#endif


/* ==================== FUNCTION DEFINITIONS ============================== */


/*****************************************************************************
*mpd2 - Tax/transfer model parameter definitions (cont.)
*
*Synopsis:
*    void mpd2(           
*    P_pc pcp             
*    )                    
*
*Description:
*
*Return Value:
*   None.
*
*Calls:
*   pmaddent Define and add a parameter
*
*Structure Members:
*   MP.AHEATFLG     (i)  Alberta Energy Tax Refund activation flag
*   MP.AHEATREB     (i)  Alberta Energy Tax Refund amount
*   MP.ALEXPP       (i)  Proportion of other allowable employment expenses to use as deduction
*   MP.ALTAMIN      (i)  Alberta GIS supplement minimum annual benefit
*   MP.ALTASC       (i)  Alberta GIS supplement maximum annual benefit
*   MP.ALTASOPT     (i)  Alberta seniors option [1=GIST,2=new seniors benefit 1994]
*   MP.ANCBSFT1     (i)  Alberta social assistance NCBS flow-through amount for first child
*   MP.ANCBSFT1P    (i)  Alberta SA NCBS flow-through amount for first child for 1st half of year
*   MP.ANCBSFT2     (i)  Alberta social assistance NCBS flow-through amount for second child
*   MP.ANCBSFT2P    (i)  Alberta SA NCBS flow-through amount for second child for 1st half of year
*   MP.ANCBSFT3     (i)  Alberta social assistance NCBS flow-through amount for third (or more) child
*   MP.ANCBSFT3P    (i)  Alberta SA NCBS flow-through amount for third (or more) child for 1st half of year
*   MP.ASBBASIC     (i)  Alberta seniors benefit annual basic benefit
*   MP.ASBBASICP    (i)  Alberta seniors benefit annual basic benefit for 1st half of year
*   MP.ASBBOASP     (i)  Alberta seniors benefit Basic OAS from previous year
*   MP.ASBCYFLG     (i)  Alberta seniors benefit calendar year calculation flag
*   MP.ASBEMP       (i)  Alberta seniors benefit employment inclusion rate
*   MP.ASBEMPP      (i)  Alberta seniors benefit employment inclusion rate for 1st half of year
*   MP.ASBNOAS      (i)  Alberta seniors benefit reduction if no OAS [senior type]
*   MP.ASBNOASP     (i)  Alberta seniors benefit reduction if no OAS for 1st half of year [senior type]
*   MP.ASBNOASProws (i)  number of rows in ASBNOASP
*   MP.ASBNOASrows  (i)  number of rows in ASBNOAS
*   MP.ASBNSS       (i)  Alberta seniors benefit non-senior spouse supplement
*   MP.ASBNSSP      (i)  Alberta seniors benefit non-senior spouse supplement for 1st half of year
*   MP.ASBRENT      (i)  Alberta seniors benefit renter supplement
*   MP.ASBRENTP     (i)  Alberta seniors benefit renter supplement for 1st half of year
*   MP.ASBRR        (i)  Alberta seniors benefit reduction rate [senior type]
*   MP.ASBRRP       (i)  Alberta seniors benefit reduction rate for 1st half of year [senior type]
*   MP.ASBRRProws   (i)  number of rows in ASBRRP
*   MP.ASBRRrows    (i)  number of rows in ASBRR
*   MP.ASBSAB       (i)  Alberta seniors benefit supplemental accommodation benefit
*   MP.ASBSABP      (i)  Alberta seniors benefit supplemental accommodation benefit for 1st half of year
*   MP.ASBSABRR     (i)  Alberta seniors benefit supplemental accommodation reduction rate
*   MP.ASBSABRRP    (i)  Alberta seniors benefit supplemental accommodation reduction rate for 1st half of year
*   MP.ASBSS        (i)  Alberta seniors benefit senior spouse supplement
*   MP.ASBSSOPT     (i)  Alberta seniors benefit 1 senior couple option [1=model separately,2=model as senior couples]
*   MP.ASBSSOPTP    (i)  Alberta seniors benefit 1 senior couple option for 1st half of year
*   MP.ASBSSP       (i)  Alberta seniors benefit senior spouse supplement for 1st half of year
*   MP.ASHELTER     (i)  Alberta Shelter Increase by number of persons in household
*   MP.ASHELTERP    (i)  Alberta Shelter Increase by number of persons in household for 1st half of year
*   MP.ASHELTFLG    (i)  Alberta Shelter Increase under NCBS clawback flag
*   MP.ASHELTFLGP   (i)  Alberta Shelter Increase under NCBS clawback flag for 1st half of year
*   MP.AXM          (i)  Age amount
*   MP.AXPI         (i)  Age amount phase in rate for 1994 and beyond
*   MP.AXRR         (i)  Age amount credit reduction rate
*   MP.AXTD         (i)  Age amount net income turndown
*   MP.BCBEIS1      (i)  B.C. Earned Income Benefit for first child
*   MP.BCBEIS1P     (i)  B.C. Earned Income Benefit for first child for 1st half of year
*   MP.BCBEIS2      (i)  B.C. Earned Income Benefit for second child
*   MP.BCBEIS2P     (i)  B.C. Earned Income Benefit for second child for 1st half of year
*   MP.BCBEIS3      (i)  B.C. Earned Income Benefit for each additional child
*   MP.BCBEIS3P     (i)  B.C. Earned Income Benefit for each additional child for 1st half of year
*   MP.BCBEITD      (i)  B.C. Earned Income Benefit Turndown
*   MP.BCBEITDP     (i)  B.C. Earned Income Benefit Turndown for 1st half of year
*   MP.BCBEMX       (i)  B.C. Earned Income Benefit Income Reduction
*   MP.BCBEMXP      (i)  B.C. Earned Income Benefit Income Reduction for 1st half of year
*   MP.BCBERR1      (i)  B.C. EIB reduction rate for families with 1 child
*   MP.BCBERR1P     (i)  B.C. EIB reduction rate for families with 1 child for 1st half of year
*   MP.BCBERR2      (i)  B.C. EIB reduction rate for families with 2 children
*   MP.BCBERR2P     (i)  B.C. EIB reduction rate for families with 2 children for 1st half of year
*   MP.BCBERR3      (i)  B.C. EIB reduction rate for families with 3+ children
*   MP.BCBERR3P     (i)  B.C. EIB reduction rate for families with 3+ children for 1st half of year
*   MP.BCC          (i)  British Columbia GIS supplement: married pensioners
*   MP.BCEIBFLG     (i)  Activate B.C. Earned Income Benefit Program
*   MP.BCEIBFLGP    (i)  Activate B.C. Earned Income Benefit Program for 1st half of year
*   MP.BCEIBPI      (i)  B.C. Earned Income Benefit Income Phase In
*   MP.BCEIBPIP     (i)  B.C. Earned Income Benefit Income Phase In for 1st half of year
*   MP.BCFBBAS      (i)  B.C. Family Bonus amount per child
*   MP.BCFBBASP     (i)  B.C. Family Bonus amount per child for 1st half of year
*   MP.BCFBFLAG     (i)  Activate B.C. Family Bonus Program
*   MP.BCFBIFS      (i)  Activate B.C. Family Bonus to include Federal NCS
*   MP.BCFBIFSP     (i)  Activate B.C. Family Bonus to include Federal NCS for 1st half of year
*   MP.BCFBNCS1     (i)  B.C. Family Bonus National Child Supplement for first child
*   MP.BCFBNCS1P    (i)  B.C. Family Bonus National Child Supplement for first child for 1st half of year
*   MP.BCFBNCS2     (i)  B.C. Family Bonus National Child Supplement for second child
*   MP.BCFBNCS2P    (i)  B.C. Family Bonus National Child Supplement for second child for 1st half of year
*   MP.BCFBNCS3     (i)  B.C. Family Bonus National Child Supplement for each additional child
*   MP.BCFBNCS3P    (i)  B.C. Family Bonus National Child Supplement for each additional child for 1st half of year
*   MP.BCFBNCSRR1   (i)  B.C. Family Bonus NCS reduction rate for families with 1 child
*   MP.BCFBNCSRR1P  (i)  B.C. Family Bonus NCS reduction rate for families with 1 child for 1st half of year
*   MP.BCFBNCSRR2   (i)  B.C. Family Bonus NCS reduction rate for families with 2 children
*   MP.BCFBNCSRR2P  (i)  B.C. Family Bonus NCS reduction rate for families with 2 children for 1st half of year
*   MP.BCFBNCSRR3   (i)  B.C. Family Bonus NCS reduction rate for families with 3+ children
*   MP.BCFBNCSRR3P  (i)  B.C. Family Bonus NCS reduction rate for families with 3+ children for 1st half of year
*   MP.BCFBNCSTD    (i)  B.C. Family Bonus National Child Supplement Turndown
*   MP.BCFBNCSTDP   (i)  B.C. Family Bonus National Child Supplement Turndown for 1st half of year
*   MP.BCFBRR       (i)  B.C. Family Bonus multiple child reduction rate
*   MP.BCFBRRP      (i)  B.C. Family Bonus multiple child reduction rate for 1st half of year
*   MP.BCFBRRS      (i)  B.C. Family Bonus single child reduction rate
*   MP.BCFBRRSP     (i)  B.C. Family Bonus single child reduction rate for 1st half of year
*   MP.BCFBTD       (i)  B.C. Family Bonus Turndown
*   MP.BCFBTDP      (i)  B.C. Family Bonus Turndown for 1st half of year
*   MP.BCS          (i)  British Columbia GIS supplement: single pensioners
*   MP.BHEATBEN     (i)  New Brunswick Home Heating Oil Benefit [income, benefit]
*   MP.BHEATBENrows (i)  number of rows in BHEATBEN
*   MP.BHEATFLG     (i)  New Brunswick Home Heating Oil Benefit activation flag
*   MP.BHEATPO      (i)  New Brunswick Home Heating Oil Benefit family income phase out
*   MP.BHEATSA      (i)  New Brunswick Home Heating Oil Benefit for SA recipients flag
*   MP.BXM          (i)  Basic personal exemption/amount
*   MP.BXMEXT       (i)  Basic personal amount extra top-up
*   MP.BXMS         (i)  Basic personal exemption supplement
*   MP.BXMSPI       (i)  Basic personal exemption supplement phase in
*   MP.BXMSRR       (i)  Basic personal exemption supplement reduction rate
*   MP.CAPGIR       (i)  Capital gains inclusion rate
*   MP.CCEAEMPF     (i)  CCEA fraction of employment income (Limit `B')
*   MP.CCEAOAGE     (i)  CCEA Maximum eligible age for oldest child
*   MP.CCEAOLD      (i)  CCEA old child limit
*   MP.CCEATFLG     (i)  CCEA eligible->claimable transformation activation flag
*   MP.CCEATFR      (i)  CCEA eligible->claimable fraction
*   MP.CCEATLL      (i)  CCEA eligible->claimable lower limit
*   MP.CCEAYNG      (i)  CCEA young child limit
*   MP.CCEPTFLG     (i)  CCE part-time student flag
*   MP.CCEROPT      (i)  Child care expense deduction recipient [1=mother,2=lower income]
*   MP.CCESFLAG     (i)  CCE full-time student flag
*   MP.CCESOLD      (i)  CCEA old child limit for full-time students
*   MP.CCESYNG      (i)  CCEA young child limit for full-time students
*   MP.CCEZOPT      (i)  CCE young kid optimization rules [1=use, 2=zero, 3=optimize]
*   MP.CHEATFAM     (i)  British Columbia Refundable Energy Credit for families
*   MP.CHEATFLG     (i)  British Columbia Refundable Energy Credit activation flag
*   MP.CHEATSNG     (i)  British Columbia Refundable Energy Credit for singles
*   MP.CPP60T64     (i)  CPP/QPP Contributions Take up (60 - 64) by earnings with CPP income
*   MP.CPP60T64rows (i)  number of rows in CPP60T64
*   MP.CPPGT64      (i)  CPP/QPP Contributions Take up (over 64) by earnings with CPP income
*   MP.CPPGT64rows  (i)  number of rows in CPPGT64
*   MP.CPPLT60      (i)  CPP/QPP Contributions Take up (under 60) by earnings with CPP income
*   MP.CPPLT60rows  (i)  number of rows in CPPLT60
*   MP.CPPSEDEDFLG  (i)  CPP/QPP contribution deduction for self-employed earnings flag
*   MP.CPPSEDFRC    (i)  CPP/QPP contribution deduction fraction for self-employed earnings
*   MP.CPPXM        (i)  CPP/QPP exemptible earnings
*   MP.CTCERF       (i)  Refundable CTC child care expense reduction fraction
*   MP.CTCINC       (i)  Refundable CTC family income scaling factor
*   MP.CTCOPT       (i)  Refundable Child tax credit option
*   MP.CTCPC        (i)  Refundable Child tax credit per child
*   MP.CTCREF       (i)  Refundable CTC post-reform rules flag
*   MP.CTCRR        (i)  Refundable Child tax credit reduction rate
*   MP.CTCSUP       (i)  Refundable CTC young child supplement
*   MP.CTCTD        (i)  Family income refundable child tax credit turndown
*   MP.CTCTUR       (i)  Refundable CTC take up rate table [benefit,rate]
*   MP.CTCTURrows   (i)  number of rows in CTCTUR
*   MP.CTNUMREG     (i)  number of rows in region dimension parms
*   MP.DIVPLC       (i)  Percentage of dividends from large (eligible) corporations
*   MP.EMXM         (i)  Married equivalent exemption/amount
*   MP.EMXMEXT      (i)  Married equivalent amount extra top-up
*   MP.EMXMT        (i)  Married equivalent exemption/amount turndown level
*   MP.EMXMTEXT     (i)  Married equivalent amount turndown level extra top-up
*   MP.FACTISENF    (i)  Scale-up factor for non-farm self-employment income
*   MP.FCBBAS       (i)  Basic child benefit (per child)
*   MP.FCBBASP      (i)  Basic child benefit (per child) for 1st half of year
*   MP.FCBECI       (i)  Child benefits earning supplement cut-in level
*   MP.FCBECIP      (i)  Child benefits earning supplement cut-in level for 1st half of year
*   MP.FCBEIE       (i)  Flag for WIS dependent on number of children
*   MP.FCBEIEP      (i)  Flag for WIS dependent on number of children for 1st half of year
*   MP.FCBEIS       (i)  Child benefits earned income supplement
*   MP.FCBEIS1      (i)  WIS/NCBS for first child
*   MP.FCBEIS1P     (i)  WIS/NCBS for first child for 1st half of year
*   MP.FCBEIS2      (i)  WIS/NCBS for second child
*   MP.FCBEIS2P     (i)  WIS/NCBS for second child for 1st half of year
*   MP.FCBEIS3      (i)  WIS/NCBS for each additional child
*   MP.FCBEIS3P     (i)  WIS/NCBS for each additional child for 1st half of year
*   MP.FCBEISP      (i)  Child benefits earned income supplement for 1st half of year
*   MP.FCBEMX       (i)  Earnings where WIS phase-in is at maximum
*   MP.FCBEMXP      (i)  Earnings where WIS phase-in is at maximum for 1st half of year
*   MP.FCBENCAL     (i)  Calculate child benefits for calendar year flag
*   MP.FCBERR       (i)  Child benefits earning supplement reduction rate
*   MP.FCBERR1      (i)  WIS/NCBS reduction rate for families with 1 child
*   MP.FCBERR1P     (i)  WIS/NCBS reduction rate for families with 1 child for 1st half of year
*   MP.FCBERR2      (i)  WIS/NCBS reduction rate for families with 2 children
*   MP.FCBERR2P     (i)  WIS/NCBS reduction rate for families with 2 children for 1st half of year
*   MP.FCBERR3      (i)  WIS/NCBS reduction rate for families with 3+ children
*   MP.FCBERR3P     (i)  WIS/NCBS reduction rate for families with 3+ children for 1st half of year
*   MP.FCBERRP      (i)  Child benefits earning supplement reduction rate for 1st half of year
*   MP.FCBESR       (i)  Child benefits earned income supplement rate
*   MP.FCBESRP      (i)  Child benefits earned income supplement rate for 1st half of year
*   MP.FCBETD       (i)  WIS/NCBS turndown level
*   MP.FCBETDP      (i)  WIS/NCBS turndown level for 1st half of year
*   MP.FCBLRG       (i)  Supplement for 3rd and subsequent kids
*   MP.FCBLRGP      (i)  Supplement for 3rd and subsequent kids for 1st half of year
*   MP.FCBPI        (i)  Federal Child Tax Benefit phase-in rate
*   MP.FCBPIP       (i)  Federal Child Tax Benefit phase-in rate for 2nd half of year
*   MP.FCBRR        (i)  Multi-children family income reduction rate
*   MP.FCBRRP       (i)  Multi-children family income reduction rate for 1st half of year
*   MP.FCBRRS       (i)  Single-child family income reduction rate
*   MP.FCBRRSP      (i)  Single-child family income reduction rate for 1st half of year
*   MP.FCBTD        (i)  Federal child benefits family income turndown
*   MP.FCBTDP       (i)  Federal child benefits family income turndown for 1st half of year
*   MP.FCBUCCB      (i)  Flag for Supplement for children age 6
*   MP.FCBUCCBP     (i)  Flag for Supplement for children age 6 for 1st half of year
*   MP.FCBYNG       (i)  Supplement for children under age 7
*   MP.FCBYNGP      (i)  Supplement for children under age 7 for 1st half of year
*   MP.FCBYNGR      (i)  Child care expense reduction rate
*   MP.FCBYNGRP     (i)  Child care expense reduction rate for 1st half of year
*   MP.FDGUR        (i)  Federal dividend gross-up rate
*   MP.FDGURLC      (i)  Federal dividend gross-up rate from large (eligible) corporations
*   MP.FECBFLAG     (i)  Federal Energy Cost Benefit activation flag
*   MP.FECBGIS      (i)  Federal Energy Cost Benefit for GIS recipients
*   MP.FECBNCBS     (i)  Federal Energy Cost Benefit for NCBS recipients
*   MP.FSTCC        (i)  Federal sales tax credit amount for dependant
*   MP.FSTCCP       (i)  Federal sales tax credit amount for dependant for 1st half of year
*   MP.FSTCF        (i)  Federal sales tax credit amount for filer
*   MP.FSTCFP       (i)  Federal sales tax credit amount for filer for 1st half of year
*   MP.FSTCL        (i)  Federal sales tax credit reduction level
*   MP.FSTCLP       (i)  Federal sales tax credit reduction level for 1st half of year
*   MP.FSTCR        (i)  Federal sales tax credit reduction rate
*   MP.FSTCRP       (i)  Federal sales tax credit reduction rate for 1st half of year
*   MP.FSTCS        (i)  Federal sales tax credit amount for spouse
*   MP.FSTCSP       (i)  Federal sales tax credit amount for spouse for 1st half of year
*   MP.GISTFLAG     (i)  Provincial GIS top-up flag
*   MP.GSTAC        (i)  GST additional credit amount
*   MP.GSTACP       (i)  GST additional credit amount for 1st half of year
*   MP.GSTAR        (i)  GST additional credit rate of net income
*   MP.GSTARP       (i)  GST additional credit rate of net income for 1st half of year
*   MP.GSTASPFLAG   (i)  Maximum GST additional credit for single parents flag
*   MP.GSTASPFLAGP  (i)  Maximum GST additional credit for single parents flag for 1st half of year
*   MP.GSTAXM       (i)  GST additional credit exemption
*   MP.GSTAXMP      (i)  GST additional credit exemption for 1st half of year
*   MP.GSTCTUNC     (i)  GST credit take up by number of children
*   MP.GSTCTUNCrows (i)  number of rows in GSTCTUNC
*   MP.GSTCYFLG     (i)  GST credit calendar year calculation activation flag
*   MP.GSTFLAG      (i)  GST credit activation flag
*   MP.HEATFAM      (i)  Federal relief for heating expenses for families
*   MP.HEATRLFLG    (i)  Federal relief for heating expenses activation flag
*   MP.HEATSNG      (i)  Federal relief for heating expenses for singles
*   MP.MANC         (i)  Manitoba GIS supplement: married pensioners
*   MP.MANCNPF      (i)  Manitoba GIS supplement reduction point: married
*   MP.MANS         (i)  Manitoba GIS supplement: single pensioners
*   MP.MANSNPF      (i)  Manitoba GIS supplement reduction point: single
*   MP.MCBAMT       (i)  Manitoba child benefit amount per child
*   MP.MCBEIR       (i)  Manitoba Child benefit earned income phase-in rate
*   MP.MCBFLAG      (i)  Manitoba child benefit activation flag
*   MP.MCBMINE      (i)  Manitoba child benefit minimum earnings threshold
*   MP.MCBPO        (i)  Manitoba child benefit phase out
*   MP.MCBTD        (i)  Manitoba child benefit turndown
*   MP.MCLAWPCT     (i)  Manitoba SA Clawback percentage kids over flow through age in families [#kids][#kids<age]
*   MP.MCLAWPCTP    (i)  Manitoba SA Clawback percentage kids over flow through age for 1st half of year [#kids][#kids<age]
*   MP.MCLAWPCTProws (i)  number of rows in MCLAWPCTP
*   MP.MCLAWPCTrows (i)  number of rows in MCLAWPCT
*   MP.MCLAWSA12    (i)  Manitoba Social assistance NCBS clawback for children 12 and under
*   MP.MCLAWSA12P   (i)  Manitoba SA NCBS clawback for children 12 and under for 1st half of year
*   MP.MCLAWSA6     (i)  Manitoba Social assistance NCBS clawback for children 6 and under
*   MP.MCLAWSA6P    (i)  Manitoba SA NCBS clawback for children 6 and under for 1st half of year
*   MP.MEDREMIN     (i)  Minimum earnings for refundable medical expense supplement
*   MP.MEDRMAX      (i)  Maximum expenses allowed for medical expense supplement
*   MP.MEDRRATE     (i)  Proportion of expenses allowed for medical expense supplement
*   MP.MEDRRR       (i)  Reduction rate for the medical expense supplement
*   MP.MEDRTD       (i)  Refundable medical expense supplement income turndown
*   MP.MXM          (i)  Married exemption/amount
*   MP.MXMEXT       (i)  Married amount extra top-up
*   MP.MXMT         (i)  Married exemption/amount turndown level
*   MP.MXMTEXT      (i)  Married amount turndown level extra top-up
*   MP.NBCBBAS      (i)  NB Basic child benefit (per child)
*   MP.NBCBBASP     (i)  NB Basic child benefit (per child) for 1st half of year
*   MP.NBCBECI      (i)  NB Child benefits earning supplement cut-in level
*   MP.NBCBECIP     (i)  NB Child benefits earning supplement cut-in level for 1st half of year
*   MP.NBCBEIS      (i)  NB Child benefits earned income supplement
*   MP.NBCBEISP     (i)  NB Child benefits earned income supplement for 1st half of year
*   MP.NBCBERR      (i)  NB Child benefits earning supplement reduction rate
*   MP.NBCBERRP     (i)  NB Child benefits earning supplement reduction rate for 1st half of year
*   MP.NBCBESR      (i)  NB Child benefits earned income supplement rate
*   MP.NBCBESRP     (i)  NB Child benefits earned income supplement rate for 1st half of year
*   MP.NBCBETD      (i)  NB Child benefits earning supplement turndown level
*   MP.NBCBETDP     (i)  NB Child benefits earning supplement turndown level for 1st half of year
*   MP.NBCBPI       (i)  NB Child benefits phase-in rate
*   MP.NBCBPI1P     (i)  NB Child benefits phase-in rate for 1st half of year
*   MP.NBCBPI2P     (i)  NB Child benefits phase-in rate for 2nd half of year
*   MP.NBCBRR       (i)  NB Multi-children family income reduction rate
*   MP.NBCBRRP      (i)  NB Multi-children family income reduction rate for 1st half of year
*   MP.NBCBRRS      (i)  NB Single-child family income reduction rate
*   MP.NBCBRRSP     (i)  NB Single-child family income reduction rate for 1st half of year
*   MP.NBCBTD       (i)  NB child benefits family income turndown
*   MP.NBCBTDP      (i)  NB child benefits family income turndown for 1st half of year
*   MP.NBCTBFLG     (i)  NB child benefit activation flag
*   MP.NBSB         (i)  New Brunswick Low-Income Seniors' Benefit
*   MP.NBSBSPA      (i)  N.B. Low-Income Seniors' Benefit - SPA eligibility
*   MP.NCB1         (i)  Nfld. child benefit for first child
*   MP.NCB1P        (i)  Nfld. child benefit for first child for 1st half of year
*   MP.NCB2         (i)  Nfld. child benefit for second child
*   MP.NCB2P        (i)  Nfld. child benefit for second child for 1st half of year
*   MP.NCB3         (i)  Nfld. child benefit for third child
*   MP.NCB3P        (i)  Nfld. child benefit for third child for 1st half of year
*   MP.NCB4         (i)  Nfld. child benefit for 4th and subsequent child
*   MP.NCB4P        (i)  Nfld. child benefit for 4th and subsequent child for 1st half of year
*   MP.NCBFLG       (i)  Newfoundland child benefit activation flag
*   MP.NCBPO        (i)  Nfld. child benefit family income phase out
*   MP.NCBPOP       (i)  Nfld. child benefit family income phase out for 1st half of year
*   MP.NCBTD        (i)  Nfld. child benefit family income turndown
*   MP.NCBTDP       (i)  Nfld. child benefit family income turndown for 1st half of year
*   MP.NCLAWSA1     (i)  Newfoundland social assistance clawback amount for first child
*   MP.NCLAWSA1P    (i)  Newfoundland SA clawback amount for first child for 1st half of year
*   MP.NCLAWSA2     (i)  Newfoundland social assistance clawback amount for each additional child
*   MP.NCLAWSA2P    (i)  Newfoundland SA clawback amount for each additional child for 1st half of year
*   MP.NFSBBAS      (i)  NFLD Low-Income Seniors' Benefit base amount
*   MP.NFSBCBAS     (i)  NFLD Low-Income Seniors' Benefit base amount for senior couples
*   MP.NFSBCRR      (i)  NFLD Low-Income Seniors' Benefit reduction rate for senior couples
*   MP.NFSBCTD      (i)  NFLD Low-Income Seniors' Benefit turndown for senior couples
*   MP.NFSBRR       (i)  NFLD Low-Income Seniors' Benefit reduction rate
*   MP.NFSBTD       (i)  NFLD Low-Income Seniors' Benefit turndown
*   MP.NHEATFLG     (i)  Newfoundland home heating fuel rebate activation flag
*   MP.NHEATINC     (i)  Newfoundland home heating fuel rebate - income test flag
*   MP.NHEATMIN     (i)  Newfoundland home heating fuel rebate minimum
*   MP.NHEATPO      (i)  Newfoundland home heating fuel rebate family income phase out
*   MP.NHEATREB     (i)  Newfoundland home heating fuel rebate amount
*   MP.NHEATRR      (i)  Newfoundland home heating fuel rebate reduction rate
*   MP.NHEATSAFLG   (i)  Newfoundland home heating fuel rebate - SA recipients eligible
*   MP.NHEATTD      (i)  Newfoundland home heating fuel rebate family income turndown
*   MP.NMBNS        (i)  Nfld. Mother-Baby Nutrition Supplement
*   MP.NMBNSEXT     (i)  Nfld. Mother-Baby Nutrition Supplement newborn extra benefit
*   MP.NMBNSEXTP    (i)  Nfld. Mother-Baby Nutrition Supplement newborn extra benefit for 1st half of year
*   MP.NMBNSP       (i)  Nfld. Mother-Baby Nutrition Supplement for 1st half of year
*   MP.NS13         (i)  Nova Scotia GIS supplement for 1/3 GIS
*   MP.NS23         (i)  Nova Scotia GIS supplement for 2/3 GIS
*   MP.NSLT13       (i)  Nova Scotia GIS supplement for less than 1/3 GIS
*   MP.NSMAX        (i)  Nova Scotia maximum GIS supplement level
*   MP.NSTXREFAMT   (i)  NS Taxpayer refund amount
*   MP.NSTXREFFLG   (i)  NS Taxpayer refund flag
*   MP.NUMPERrows   (i)  number of rows in ASHELTER
*   MP.OCBAMT       (i)  Ontario Child Benefit amount per child
*   MP.OCBAMTP      (i)  Ontario Child Benefit amount per child for 1st half of year
*   MP.OCBFLAG      (i)  Ontario Child Benefit activation flag
*   MP.OCBMIN       (i)  Ontario Child Benefit minimum benefit
*   MP.OCBPIP       (i)  Ontario Child Benefit flag for 1st half of year
*   MP.OCBRR        (i)  Ontario Child Benefit reduction rate
*   MP.OCBRRP       (i)  Ontario Child Benefit reduction rate for 1st half of year
*   MP.OCBTD        (i)  Ontario Child Benefit family income turndown
*   MP.OCBTDP       (i)  Ontario Child Benefit family income turndown for 1st half of year
*   MP.OCCEAFLG     (i)  Ont. Child Care Expense Credit activation flag
*   MP.OCCEAPCT     (i)  Ont. Child Care Expense Credit qualifying percentage
*   MP.OCCEAPCTP    (i)  Ont. Child Care Expense Credit qualifying percentage for 1st half of year
*   MP.OCCEARR      (i)  Ont. Child Care Expense Credit benefit reduction rate
*   MP.OCCEARRP     (i)  Ont. Child Care Expense Credit benefit reduction rate for 1st half of year
*   MP.OCCEATD      (i)  Ont. Child Care Expense Credit family income turndown
*   MP.OCCEATDP     (i)  Ont. Child Care Expense Credit family income turndown for 1st half of year
*   MP.OCCEAYNG     (i)  Ont. Child Care Expense Credit allowance per child
*   MP.OCCEAYNGP    (i)  Ont. Child Care Expense Credit allowance per child for 1st half of year
*   MP.OCCSEXT      (i)  Ont. Child Care Supplement One-time payment of extra benefit
*   MP.OCCSOCB      (i)  Ont. Child Care Supplement reduced by Ontario Child Benefit flag
*   MP.OCCSPOPYR    (i)  Ont. Child Care Supplement phase out year proportion born pre July
*   MP.OCCSPOYR     (i)  Ont. Child Care Working Income Supplement phase out year
*   MP.OCWISFLG     (i)  Ont. Child Care Working Income Supplement activation flag
*   MP.OCWISFLGP    (i)  Ont. Child Care Working Income Supplement activation flag for 1st half of year
*   MP.OCWISRR      (i)  Ont. Child Care Working Income Supplement Rate [children][rr]
*   MP.OCWISRRP     (i)  Ont. Child Care Working Income Supplement Rate [children][rr] for 1st half of year
*   MP.OCWISRRProws (i)  number of rows in OCWISRRP
*   MP.OCWISRRrows  (i)  number of rows in OCWISRR
*   MP.OCWISSP      (i)  Ont. Child Care Working Income Supplement maximum benefit for single parents
*   MP.OCWISSPP     (i)  Ont. Child Care Working Income Supplement maximum benefit for single parents for 1st half of year
*   MP.OCWISTD      (i)  Ont. Child Care Working Income Supplement minimum earnings
*   MP.OCWISTDP     (i)  Ont. Child Care Working Income Supplement minimum earnings for 1st half of year
*   MP.OHEATFAM     (i)  Ontario Home Electricity Relief amount for families
*   MP.OHEATFLG     (i)  Ontario Home Electricity Relief activation flag
*   MP.OHEATFTD     (i)  Ontario Home Electricity Relief income turndown for families
*   MP.OHEATMIN     (i)  Ontario Home Electricity Relief minimum
*   MP.OHEATRR      (i)  Ontario Home Electricity Relief reduction rate
*   MP.OHEATSNG     (i)  Ontario Home Electricity Relief amount for singles
*   MP.OHEATSTD     (i)  Ontario Home Electricity Relief income turndown for singles
*   MP.ONCBSFT1     (i)  Ontario social assistance NCBS flow-through amount for first child
*   MP.ONCBSFT1P    (i)  Ontario SA NCBS flow-through amount for first child for 1st half of year
*   MP.ONCBSFT2     (i)  Ontario social assistance NCBS flow-through amount for second child
*   MP.ONCBSFT2P    (i)  Ontario SA NCBS flow-through amount for second child for 1st half of year
*   MP.ONCBSFT3     (i)  Ontario social assistance NCBS flow-through amount for third (or more) child
*   MP.ONCBSFT3P    (i)  Ontario SA NCBS flow-through amount for third (or more) child for 1st half of year
*   MP.ONTC         (i)  Ontario GIS supplement: married pensioners
*   MP.ONTFPTG      (i)  Ontario property tax grant (fraction of rent)
*   MP.ONTPTG       (i)  Ontario property tax grant for seniors
*   MP.ONTS         (i)  Ontario GIS supplement: single pensioners
*   MP.ONTSTG       (i)  Ontario sales tax grant for seniors
*   MP.PENSPLTINCR  (i)  Increment by which to split pension income
*   MP.PNCBSFT      (i)  P.E.I. social assistance NCBS flow-through amount per child
*   MP.PNCBSFTP     (i)  P.E.I. SA NCBS flow-through amount per child for 1st half of year
*   MP.QNCBSFT1     (i)  Quebec social assistance NCBS flow-through amount for first child
*   MP.QNCBSFT1P    (i)  Quebec SA NCBS flow-through amount for first child for 1st half of year
*   MP.QNCBSFT2     (i)  Quebec social assistance NCBS flow-through amount for second child
*   MP.QNCBSFT2P    (i)  Quebec SA NCBS flow-through amount for second child for 1st half of year
*   MP.QNCBSFT3     (i)  Quebec social assistance NCBS flow-through amount for third (or more) child
*   MP.QNCBSFT3P    (i)  Quebec SA NCBS flow-through amount for third (or more) child for 1st half of year
*   MP.REPNETFLAG   (i)  Social program repayments reduce net income flag
*   MP.SACLAWFLAG   (i)  Social assistance NCBS clawback flag
*   MP.SACLAWOPT    (i)  Social assistance NCBS clawback include in tax/income flag
*   MP.SACLAWPR     (i)  Social assistance clawback flag [prov]
*   MP.SAELDOPT     (i)  SA for elderly calculation method [1=~SA,2=GIST->~SA,3=diff]
*   MP.SAFLAG       (i)  Social assistance flag
*   MP.SAFS         (i)  Federal share of social assistance [prov]
*   MP.SAPFLAG      (i)  Social assistance predicted value flag
*   MP.SASKC        (i)  Saskatchewan GIS supplement: married pensioners
*   MP.SASKMINC     (i)  Saskatchewan GIS supplement minimum benefits: married
*   MP.SASKMINS     (i)  Saskatchewan GIS supplement minimum benefits: single
*   MP.SASKRR1      (i)  Saskatchewan GIS supplement reduction rate: regular
*   MP.SASKRR2      (i)  Saskatchewan GIS supplement reduction rate: 1 GIS
*   MP.SASKRR3      (i)  Saskatchewan GIS supplement reduction rate: SPA
*   MP.SASKS        (i)  Saskatchewan GIS supplement: single pensioners
*   MP.SASKTECA     (i)  Saskatchewan GIS supplement temporary energy cost allowance
*   MP.SATARGET     (i)  Social assistance target for predicted SA
*   MP.SATARGETrows (i)  number of rows in SATARGET
*   MP.SCB1         (i)  Sask Child Benefit max for 1st child
*   MP.SCB1P        (i)  Sask Child Benefit max for 1st child for 1st half of year
*   MP.SCB2         (i)  Sask Child Benefit max for 2nd child
*   MP.SCB2P        (i)  Sask Child Benefit max for 2nd child for 1st half of year
*   MP.SCB3         (i)  Sask Child Benefit max for 3rd and additional child
*   MP.SCB3P        (i)  Sask Child Benefit max for 3rd and additional child for 1st half of year
*   MP.SCBFLG       (i)  Sask Child Benefit activation flag
*   MP.SCBRR1       (i)  Sask Child Benefit 1st reduction rate [number of kids]
*   MP.SCBRR1P      (i)  Sask Child Benefit 1st reduction rate [number of kids] for 1st half of year
*   MP.SCBRR1rows   (i)  number of rows in SCBRR1
*   MP.SCBRR2       (i)  Sask Child Benefit 2nd reduction rate [number of kids]
*   MP.SCBRR2P      (i)  Sask Child Benefit 2nd reduction rate [number of kids] for 1st half of year
*   MP.SCBRR2rows   (i)  number of rows in SCBRR2
*   MP.SCBSPA       (i)  Sask Child Benefit Single Parent Amount
*   MP.SCBSPAP      (i)  Sask Child Benefit Single Parent Amount for 1st half of year
*   MP.SCBTD1       (i)  Sask Child Benefit 1st turndown
*   MP.SCBTD1P      (i)  Sask Child Benefit 1st turndown for 1st half of year
*   MP.SCBTD2       (i)  Sask Child Benefit 2nd turndown
*   MP.SCBTD2P      (i)  Sask Child Benefit 2nd turndown for 1st half of year
*   MP.SECF         (i)  CPP/QPP contribution rate on self-employment earnings
*   MP.SFAOUT       (i)  Proportion of social assistance to eliminate
*   MP.SHEATFAM     (i)  Saskatchewan Home Heating Assistance Rebate for families
*   MP.SHEATFLG     (i)  Saskatchewan Home Heating Assistance Rebate activation flag
*   MP.SHEATSNG     (i)  Saskatchewan Home Heating Assistance Rebate for singles
*   MP.SPLTPNSFLAG  (i)  Flag to split pension income
*   MP.UCCBAMT      (i)  Universal child care benefit amount for each child < 6
*   MP.UCCBFLAG     (i)  Universal child care benefit activation flag
*   MP.VCBBAS1      (i)  NS child benefit for first child
*   MP.VCBBAS1P     (i)  NS child benefit for first child for 1st half of year
*   MP.VCBBAS2      (i)  NS child benefit for second child
*   MP.VCBBAS2P     (i)  NS child benefit for second child for 1st half of year
*   MP.VCBBAS3      (i)  NS child benefit for third or additional child
*   MP.VCBBAS3P     (i)  NS child benefit for third or additional child for 1st half of year
*   MP.VCBFLG       (i)  NS child benefit activation flag
*   MP.VCBPO        (i)  NS child benefit family income phase out
*   MP.VCBPOP       (i)  NS child benefit family income phase out for 1st half of year
*   MP.VCBTD        (i)  NS child benefit turndown
*   MP.VCBTDP       (i)  NS child benefit turndown for 1st half of year
*   MP.VDACB        (i)  NS Direct assistance benefit for couples
*   MP.VDACI        (i)  NS Direct assistance maximum income for couples
*   MP.VDAFLAG      (i)  NS Direct assistance benefit flag
*   MP.VDAFWC       (i)  NS Direct assistance benefit for families with children flag
*   MP.VDASB        (i)  NS Direct assistance benefit for singles
*   MP.VDASI        (i)  NS Direct assistance maximum income for singles
*   MP.VHEATERB     (i)  Nova Scotia home heating fuel rebate amount for electricity
*   MP.VHEATFLG     (i)  Nova Scotia Home Heating Assistance Rebate activation flag
*   MP.VHEATFTD     (i)  Nova Scotia home heating fuel rebate income turndown for families
*   MP.VHEATREB     (i)  Nova Scotia home heating fuel rebate amount for oil
*   MP.VHEATSTD     (i)  Nova Scotia home heating fuel rebate income turndown for singles
*   MP.VHEATTU      (i)  Nova Scotia home heating fuel rebate take up
*   MP.WITBFAM      (i)  Working Income Tax Benefit amount for couples/single parents
*   MP.WITBFLAG     (i)  Working Income Tax Benefit activation flag
*   MP.WITBFPO      (i)  WITB Family Net Income Phase-out Threshold
*   MP.WITBMINE     (i)  Working Income Tax Benefit Minimum Earnings Threshold
*   MP.WITBPIR      (i)  Working Income Tax Benefit Phase in Rate
*   MP.WITBRR       (i)  Working Income Tax Benefit Reduction Rate
*   MP.WITBSAMT     (i)  WITB Supplement for Disabilities Amount
*   MP.WITBSFPO     (i)  WITB Supplement for Disabilities Family Net Income Phase-out Threshold
*   MP.WITBSMINE    (i)  WITB Supplement for Disabilities Minimum Earnings Threshold
*   MP.WITBSNG      (i)  Working Income Tax Benefit amount for singles
*   MP.WITBSPIR     (i)  WITB Supplement for Disabilities Phase in Rate
*   MP.WITBSPO      (i)  WITB Single Net Income Phase-out Threshold
*   MP.WITBSRR      (i)  WITB Supplement for Disabilities Reduction Rate
*   MP.WITBSSPO     (i)  WITB Supplement for Disabilities Single Net Income Phase-out Threshold
*   MP.WSCF         (i)  CPP/QPP contribution rate on employment earnings
*   MP.WSCM         (i)  Ratio of self-employed to employed contribution fraction
*   MP.YCXM1        (i)  Dependent child amount (1st child)
*   MP.YCXM2        (i)  Dependent child amount (2nd child)
*   MP.YCXM3        (i)  Dependent child amount (3rd ,etc.)
*   MP.YCXMT        (i)  Dependent child exemption/amount turndown level
*   MP.YMPE         (i)  CPP/QPP maximum pensionable earnings
*
*Called by:
*   mpd      Tax/transfer model parameter definitions
*
*****************************************************************************/
void mpd2(
	P_pc pcp
)
{
	DEBUG_ON("mpd2");

	/*          Provincial Elderly Programs */
	pmaddent(pcp, "2.3.2.5",   NULL,                 NULL,    P_DUMMY,  C_STR,  0,      0, NULL, 0);
	pmaddent(pcp, "GISTFLAG", (char *)&MP.GISTFLAG,  NULL,    P_SCL,    C_INT,  E_FLAG, 0, NULL, 0);

	/*               Newfoundland */
	pmaddent(pcp, "2.3.2.5.1",   NULL,               NULL,    P_DUMMY,   C_STR, 0,      0, NULL, 0);
	pmaddent(pcp, "NFSBTD",  (char *)&MP.NFSBTD,     NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NFSBBAS", (char *)&MP.NFSBBAS,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NFSBRR",  (char *)&MP.NFSBRR,     F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NFSBCTD",  (char *)&MP.NFSBCTD,   NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NFSBCBAS", (char *)&MP.NFSBCBAS,  NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NFSBCRR",  (char *)&MP.NFSBCRR,   F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);

	/*               Nova Scotia */
	pmaddent(pcp, "2.3.2.5.2",   NULL,               NULL,    P_DUMMY,  C_STR,  0,      0, NULL, 0);
	pmaddent(pcp, "NSMAX",   (char *)&MP.NSMAX,      NULL,    P_SCL,    C_NUM,  0,      0, NULL, 0);
	pmaddent(pcp, "NS23",    (char *)&MP.NS23,       NULL,    P_SCL,    C_NUM,  0,      0, NULL, 0);
	pmaddent(pcp, "NS13",    (char *)&MP.NS13,       NULL,    P_SCL,    C_NUM,  0,      0, NULL, 0);
	pmaddent(pcp, "NSLT13",  (char *)&MP.NSLT13,     NULL,    P_SCL,    C_NUM,  0,      0, NULL, 0);

	/*               New Brunswick */
	pmaddent(pcp, "2.3.2.5.3",   NULL,               NULL,    P_DUMMY,  C_STR,  0,      0, NULL, 0);
	pmaddent(pcp, "NBSB",    (char *)&MP.NBSB,       NULL,    P_SCL,    C_NUM,  0,      0, NULL, 0);
	pmaddent(pcp, "NBSBSPA", (char *)&MP.NBSBSPA,  NULL,    P_SCL,    C_INT,  E_FLAG, 0, NULL, 0);

	/*               Ontario */
	pmaddent(pcp, "2.3.2.5.4",   NULL,               NULL,    P_DUMMY,   C_STR, 0,      0, NULL, 0);
	pmaddent(pcp, "ONTS",    (char *)&MP.ONTS,       NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "ONTC",    (char *)&MP.ONTC,       NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "ONTSTG",  (char *)&MP.ONTSTG,     NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "ONTPTG",  (char *)&MP.ONTPTG,     NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "ONTFPTG", (char *)&MP.ONTFPTG,    F_FRACT,    P_SCL,  C_NUM, 0,      0, NULL, 0);

	/*               Manitoba */
	pmaddent(pcp, "2.3.2.5.5",   NULL,               NULL,    P_DUMMY,   C_STR, 0,      0, NULL, 0);
	pmaddent(pcp, "MANS",    (char *)&MP.MANS,       NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "MANC",    (char *)&MP.MANC,       NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "MANSNPF", (char *)&MP.MANSNPF,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "MANCNPF", (char *)&MP.MANCNPF,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);

	/*               Saskatchewan */
	pmaddent(pcp, "2.3.2.5.6",   NULL,               NULL,    P_DUMMY,   C_STR, 0,      0, NULL, 0);
	pmaddent(pcp, "SASKS",   (char *)&MP.SASKS,      NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "SASKC",   (char *)&MP.SASKC,      NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "SASKMINS",(char *)&MP.SASKMINS,   NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "SASKMINC",(char *)&MP.SASKMINC,   NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "SASKRR1", (char *)&MP.SASKRR1,    F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "SASKRR2", (char *)&MP.SASKRR2,    F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "SASKRR3", (char *)&MP.SASKRR3,    F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "SASKTECA",(char *)&MP.SASKTECA,   NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);

	/*               Alberta */
	pmaddent(pcp, "2.3.2.5.7",   NULL,               NULL,    P_DUMMY,   C_STR, 0,      0, NULL, 0);
	pmaddent(pcp, "ALTAMIN", (char *)&MP.ALTAMIN,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "ALTASC",  (char *)&MP.ALTASC,     NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "ASBBASIC",(char *)&MP.ASBBASIC,   NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "ASBSS",   (char *)&MP.ASBSS,      NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "ASBNSS",  (char *)&MP.ASBNSS,     NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "ASBRENT", (char *)&MP.ASBRENT,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "ALTASOPT",(char *)&MP.ALTASOPT,   NULL,    P_SCL,     C_INT, E_OPT,  2, NULL, 0);
	pmaddent(pcp, "ASBNOAS", (char *)&MP.ASBNOAS[0], NULL,    P_VCT,     C_NUM, E_FIXL, ASBNOASMAX, &MP.ASBNOASrows, 0, "astype");
	pmaddent(pcp, "ASBEMP",  (char *)&MP.ASBEMP,     F_FRACT, P_SCL,     C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "ASBRR",   (char *)&MP.ASBRR[0],   NULL,    P_VCT,     C_NUM, E_FIXL, ASBRRMAX, &MP.ASBRRrows, 0, "astype");
	pmaddent(pcp, "ASBSSOPT",(char *)&MP.ASBSSOPT,   NULL,    P_SCL,     C_INT, E_OPT,  2, NULL, 0);
	pmaddent(pcp, "ASBSAB",  (char *)&MP.ASBSAB,     NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "ASBSABRR",(char *)&MP.ASBSABRR,   F_FRACT, P_SCL,     C_NUM, E_FRCT, 0, NULL, 0);

	/*               Alberta for the calendar year */
	pmaddent(pcp, "2.3.2.5.7.1",   NULL,               NULL,    P_DUMMY,   C_STR, 0,      0, NULL, 0);
	pmaddent(pcp, "ASBCYFLG",(char *)&MP.ASBCYFLG,   NULL,    P_SCL,     C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "ASBBASICP",(char *)&MP.ASBBASICP,  NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "ASBSSP",   (char *)&MP.ASBSSP,     NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "ASBNSSP",  (char *)&MP.ASBNSSP,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "ASBRENTP", (char *)&MP.ASBRENTP,   NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "ASBNOASP", (char *)&MP.ASBNOASP[0],NULL,    P_VCT,     C_NUM, E_FIXL, ASBNOASPMAX, &MP.ASBNOASProws, 0, "astype");
	pmaddent(pcp, "ASBEMPP",  (char *)&MP.ASBEMPP,    F_FRACT, P_SCL,     C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "ASBRRP",   (char *)&MP.ASBRRP[0],  NULL,    P_VCT,     C_NUM, E_FIXL, ASBRRPMAX, &MP.ASBRRProws, 0, "astype");
	pmaddent(pcp, "ASBSSOPTP",(char *)&MP.ASBSSOPTP,  NULL,    P_SCL,     C_INT, E_OPT,  2, NULL, 0);
	pmaddent(pcp, "ASBSABP",  (char *)&MP.ASBSABP,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "ASBSABRRP",(char *)&MP.ASBSABRRP,  F_FRACT, P_SCL,     C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "ASBBOASP", (char *)&MP.ASBBOASP,      NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	/*               British Columbia */
	pmaddent(pcp, "2.3.2.5.8",   NULL,               NULL,    P_DUMMY,   C_STR, 0,      0, NULL, 0);
	pmaddent(pcp, "BCS",     (char *)&MP.BCS,        NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BCC",     (char *)&MP.BCC,        NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);

	/*          Federal Sales Tax Credit */
	pmaddent(pcp, "2.3.2.6",   NULL,                 NULL,    P_DUMMY,   C_STR, 0,      0, NULL, 0);
	pmaddent(pcp, "FSTCF",   (char *)&MP.FSTCF,      NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FSTCS",   (char *)&MP.FSTCS,      NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FSTCC",   (char *)&MP.FSTCC,      NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FSTCL",   (char *)&MP.FSTCL,      NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FSTCR",   (char *)&MP.FSTCR,      F_FRACT, P_SCL,     C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "GSTFLAG", (char *)&MP.GSTFLAG,    NULL,    P_SCL,     C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "GSTAC",   (char *)&MP.GSTAC,      NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "GSTAR",   (char *)&MP.GSTAR,      F_FRACT, P_SCL,     C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "GSTAXM",  (char *)&MP.GSTAXM,     NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "GSTASPFLAG", (char *)&MP.GSTASPFLAG,    NULL,    P_SCL,     C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "GSTCTUNC",  (char *)&MP.GSTCTUNC[0][0],F_LKTUR, P_LKPXY, C_NUM, E_FRCT, GSTCTUNCMAX, &MP.GSTCTUNCrows, 0);

	/*          Federal Sales Tax Credit for the calendar year */
	pmaddent(pcp, "2.3.2.6.1",   NULL,                 NULL,    P_DUMMY,   C_STR, 0,      0, NULL, 0);
	pmaddent(pcp, "GSTCYFLG",(char *)&MP.GSTCYFLG,   NULL,    P_SCL,     C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "FSTCFP",   (char *)&MP.FSTCFP,      NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FSTCSP",   (char *)&MP.FSTCSP,      NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FSTCCP",   (char *)&MP.FSTCCP,      NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FSTCLP",   (char *)&MP.FSTCLP,      NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FSTCRP",   (char *)&MP.FSTCRP,      F_FRACT, P_SCL,     C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "GSTACP",   (char *)&MP.GSTACP,      NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "GSTARP",   (char *)&MP.GSTARP,      F_FRACT, P_SCL,     C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "GSTAXMP",  (char *)&MP.GSTAXMP,     NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "GSTASPFLAGP", (char *)&MP.GSTASPFLAGP,    NULL,    P_SCL,     C_INT, E_FLAG, 0, NULL, 0);

	/*          Federal Refundable Child Tax Credit */
	pmaddent(pcp, "2.3.2.7",   NULL,                 NULL,    P_DUMMY,   C_STR, 0,      0, NULL, 0);
	pmaddent(pcp, "CTCOPT",  (char *)&MP.CTCOPT,     NULL,    P_SCL,     C_INT, E_OPT,  3, NULL, 0);
	pmaddent(pcp, "CTCPC",   (char *)&MP.CTCPC,      NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "CTCTD",   (char *)&MP.CTCTD,      NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "CTCRR",   (char *)&MP.CTCRR,      F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "CTCREF",  (char *)&MP.CTCREF,     NULL,    P_SCL,     C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "CTCSUP",  (char *)&MP.CTCSUP,     NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "CTCERF",  (char *)&MP.CTCERF,     F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "CTCTUR",  (char *)&MP.CTCTUR[0][0],F_LKTUR,P_LKPXY,   C_NUM, E_FRCT, CTCTURMAX, &MP.CTCTURrows, 0);
	pmaddent(pcp, "CTCINC",  (char *)&MP.CTCINC,     F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);

	/*          Federal Child Benefits program */
	pmaddent(pcp, "2.3.2.8",   NULL,               NULL,    P_DUMMY,   C_STR, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBBAS",  (char *)&MP.FCBBAS,     NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBYNG",  (char *)&MP.FCBYNG,     NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBYNGR", (char *)&MP.FCBYNGR,    F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBUCCB", (char *)&MP.FCBUCCB,    NULL,    P_SCL,     C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "FCBLRG",  (char *)&MP.FCBLRG,     NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBTD",   (char *)&MP.FCBTD,      NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBRR",   (char *)&MP.FCBRR,      F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBRRS",  (char *)&MP.FCBRRS,     F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBESR",  (char *)&MP.FCBESR,     F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBERR",  (char *)&MP.FCBERR,     F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBERR1", (char *)&MP.FCBERR1,    F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBERR2", (char *)&MP.FCBERR2,    F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBERR3", (char *)&MP.FCBERR3,    F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBEIS",  (char *)&MP.FCBEIS,     NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBECI",  (char *)&MP.FCBECI,     NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBEMX",  (char *)&MP.FCBEMX,     NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBETD",  (char *)&MP.FCBETD,     NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBEIE",  (char *)&MP.FCBEIE,     NULL,    P_SCL,     C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "FCBEIS1", (char *)&MP.FCBEIS1,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBEIS2", (char *)&MP.FCBEIS2,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBEIS3", (char *)&MP.FCBEIS3,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBPI",   (char *)&MP.FCBPI,      F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	/*          Federal Child Benefits program for the calendar year */
	pmaddent(pcp, "2.3.2.8.1",   NULL,               NULL,    P_DUMMY,   C_STR, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBENCAL",(char *)&MP.FCBENCAL,   NULL,    P_SCL,     C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "FCBBASP", (char *)&MP.FCBBASP,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBYNGP", (char *)&MP.FCBYNGP,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBYNGRP",(char *)&MP.FCBYNGRP,   F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBUCCBP",(char *)&MP.FCBUCCBP,   NULL,    P_SCL,     C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "FCBLRGP", (char *)&MP.FCBLRGP,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBTDP",  (char *)&MP.FCBTDP,     NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBRRP",  (char *)&MP.FCBRRP,     F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBRRSP", (char *)&MP.FCBRRSP,    F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBESRP", (char *)&MP.FCBESRP,    F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBERRP", (char *)&MP.FCBERRP,    F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBERR1P",(char *)&MP.FCBERR1P,   F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBERR2P",(char *)&MP.FCBERR2P,   F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBERR3P",(char *)&MP.FCBERR3P,   F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBEISP", (char *)&MP.FCBEISP,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBECIP", (char *)&MP.FCBECIP,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBEMXP", (char *)&MP.FCBEMXP,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBETDP", (char *)&MP.FCBETDP,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBEIEP", (char *)&MP.FCBEIEP,    NULL,    P_SCL,     C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "FCBEIS1P",(char *)&MP.FCBEIS1P,   NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBEIS2P",(char *)&MP.FCBEIS2P,   NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBEIS3P",(char *)&MP.FCBEIS3P,   NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FCBPIP",  (char *)&MP.FCBPIP,     F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);

	/*          Universal Child Care Benefit */
	pmaddent(pcp, "2.3.2.9",   NULL,               NULL,    P_DUMMY,   C_STR, 0,      0, NULL, 0);
	pmaddent(pcp, "UCCBFLAG",(char *)&MP.UCCBFLAG,  NULL,    P_SCL,     C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "UCCBAMT", (char *)&MP.UCCBAMT,   NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);

	/*          Provincial Children Programs */
	pmaddent(pcp, "2.3.2.10",   NULL,                 NULL,    P_DUMMY,  C_STR,  0,      0, NULL, 0);

	/*          Newfoundland and Labrador Child Benefits program */
	pmaddent(pcp, "2.3.2.10.1",  NULL,                  NULL,    P_DUMMY,   C_STR, 0,      0, NULL, 0);
	pmaddent(pcp, "NCBFLG",  (char *)&MP.NCBFLG,     NULL,    P_SCL,     C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "NCB1",    (char *)&MP.NCB1,       NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "NCB2",    (char *)&MP.NCB2,       NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "NCB3",    (char *)&MP.NCB3,       NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "NCB4",    (char *)&MP.NCB4,       NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "NCBTD",   (char *)&MP.NCBTD,      NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "NCBPO",   (char *)&MP.NCBPO,      NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "NMBNS",    (char *)&MP.NMBNS,       NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "NMBNSEXT",   (char *)&MP.NMBNSEXT,     NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	/*          Newfoundland and Labrador Child Benefits program for calendar year */
	pmaddent(pcp, "2.3.2.10.1.1",  NULL,                  NULL,    P_DUMMY,   C_STR, 0,      0, NULL, 0);
	pmaddent(pcp, "NCB1P",    (char *)&MP.NCB1P,       NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "NCB2P",    (char *)&MP.NCB2P,       NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "NCB3P",    (char *)&MP.NCB3P,       NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "NCB4P",    (char *)&MP.NCB4P,       NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "NCBTDP",   (char *)&MP.NCBTDP,      NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "NCBPOP",   (char *)&MP.NCBPOP,      NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "NMBNSP",    (char *)&MP.NMBNSP,       NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "NMBNSEXTP",   (char *)&MP.NMBNSEXTP,     NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);

	/*          New Brunswick Child Benefits program */
	pmaddent(pcp, "2.3.2.10.2",  NULL,                  NULL,    P_DUMMY,   C_STR, 0,      0, NULL, 0);
	pmaddent(pcp, "NBCTBFLG",(char *)&MP.NBCTBFLG,   NULL,    P_SCL,     C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "NBCBBAS", (char *)&MP.NBCBBAS,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NBCBTD",  (char *)&MP.NBCBTD,     NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NBCBRR",  (char *)&MP.NBCBRR,     F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NBCBRRS", (char *)&MP.NBCBRRS,    F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NBCBESR", (char *)&MP.NBCBESR,    F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NBCBERR", (char *)&MP.NBCBERR,    F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NBCBEIS", (char *)&MP.NBCBEIS,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NBCBECI", (char *)&MP.NBCBECI,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NBCBETD", (char *)&MP.NBCBETD,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NBCBPI",  (char *)&MP.NBCBPI,     F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);

	/*          New Brunswick Child Benefits program for the calendar year */
	pmaddent(pcp, "2.3.2.10.2.1",  NULL,                  NULL,    P_DUMMY,   C_STR, 0,      0, NULL, 0);
	pmaddent(pcp, "NBCBBASP",(char *)&MP.NBCBBASP,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NBCBTDP", (char *)&MP.NBCBTDP,     NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NBCBRRP", (char *)&MP.NBCBRRP,     F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NBCBRRSP",(char *)&MP.NBCBRRSP,    F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NBCBESRP",(char *)&MP.NBCBESRP,    F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NBCBERRP",(char *)&MP.NBCBERRP,    F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NBCBEISP",(char *)&MP.NBCBEISP,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NBCBECIP",(char *)&MP.NBCBECIP,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NBCBETDP",(char *)&MP.NBCBETDP,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NBCBPI1P",(char *)&MP.NBCBPI1P,    F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NBCBPI2P",(char *)&MP.NBCBPI2P,    F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);

	/*          Nova Scotia Child Benefits program */
	pmaddent(pcp, "2.3.2.10.3",  NULL,                NULL,    P_DUMMY,   C_STR, 0,      0, NULL, 0);
	pmaddent(pcp, "VCBFLG",  (char *)&MP.VCBFLG,     NULL,    P_SCL,     C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "VCBTD",   (char *)&MP.VCBTD,      NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "VCBBAS1", (char *)&MP.VCBBAS1,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "VCBBAS2", (char *)&MP.VCBBAS2,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "VCBBAS3", (char *)&MP.VCBBAS3,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "VCBPO",   (char *)&MP.VCBPO,      NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);

	/*          Nova Scotia Child Benefits program for the calendar year */
	pmaddent(pcp, "2.3.2.10.3.1",  NULL,                NULL,    P_DUMMY,   C_STR, 0,      0, NULL, 0);
	pmaddent(pcp, "VCBTDP",  (char *)&MP.VCBTDP,     NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "VCBBAS1P",(char *)&MP.VCBBAS1P,   NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "VCBBAS2P",(char *)&MP.VCBBAS2P,   NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "VCBBAS3P",(char *)&MP.VCBBAS3P,   NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "VCBPOP",  (char *)&MP.VCBPOP,     NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);

	/*          Ontario Child Benefit  */
	pmaddent(pcp, "2.3.2.10.4",   NULL,                NULL,    P_DUMMY,   C_STR, 0,      0, NULL, 0);
	pmaddent(pcp, "OCBFLAG",(char *)&MP.OCBFLAG,   NULL,    P_SCL,     C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "OCBAMT",(char *)&MP.OCBAMT,   NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OCBTD", (char *)&MP.OCBTD,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OCBRR", (char *)&MP.OCBRR,    F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OCBMIN",(char *)&MP.OCBMIN,   NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	/*          Ontario Child Benefit for the calendar year  */
	pmaddent(pcp, "2.3.2.10.4.1",   NULL,                NULL,    P_DUMMY,   C_STR, 0,      0, NULL, 0);
	pmaddent(pcp, "OCBAMTP",(char *)&MP.OCBAMTP,   NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OCBTDP", (char *)&MP.OCBTDP,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OCBRRP", (char *)&MP.OCBRRP,    F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OCBPIP", (char *)&MP.OCBPIP,   NULL, P_SCL,     C_INT, E_FLAG, 0, NULL, 0);
	/*          Ontario refundable child care expense tax credit */
	pmaddent(pcp, "2.3.2.10.5",   NULL,                NULL,    P_DUMMY,   C_STR, 0,      0, NULL, 0);
	pmaddent(pcp, "OCCEAFLG",(char *)&MP.OCCEAFLG,   NULL,    P_SCL,     C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "OCCEAYNG",(char *)&MP.OCCEAYNG,   NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OCCEAPCT",(char *)&MP.OCCEAPCT,   F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OCCEATD", (char *)&MP.OCCEATD,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OCCEARR", (char *)&MP.OCCEARR,    F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OCWISFLG",(char *)&MP.OCWISFLG,   NULL,    P_SCL,     C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "OCWISTD", (char *)&MP.OCWISTD,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OCWISSP", (char *)&MP.OCWISSP,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OCWISRR", (char *)&MP.OCWISRR[0][0],F_LKTUR, P_LKPXY,C_NUM, 0, OCWISRRMAX, &MP.OCWISRRrows, 0);
	pmaddent(pcp, "OCCSEXT", (char *)&MP.OCCSEXT,   NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OCCSPOYR", (char *)&MP.OCCSPOYR,   NULL,    P_SCL, C_INT, 0,       0, NULL, 0);
	pmaddent(pcp, "OCCSPOPYR",  (char *)&MP.OCCSPOPYR,   F_FRACT,  P_SCL,   C_NUM, 0,       0, NULL, 0);				  
	pmaddent(pcp, "OCCSOCB", (char *)&MP.OCCSOCB,   NULL,    P_SCL,     C_INT, E_FLAG, 0, NULL, 0);
	/*          Ontario refundable child care expense tax credit for the calendar year  */
	pmaddent(pcp, "2.3.2.10.5.1",   NULL,                NULL,    P_DUMMY,   C_STR, 0,      0, NULL, 0);
	pmaddent(pcp, "OCCEAYNGP",(char *)&MP.OCCEAYNGP,   NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OCCEAPCTP",(char *)&MP.OCCEAPCTP,   F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OCCEATDP", (char *)&MP.OCCEATDP,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OCCEARRP", (char *)&MP.OCCEARRP,    F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OCWISFLGP",(char *)&MP.OCWISFLGP,   NULL,    P_SCL,     C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "OCWISTDP", (char *)&MP.OCWISTDP,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OCWISSPP", (char *)&MP.OCWISSPP,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OCWISRRP", (char *)&MP.OCWISRRP[0][0],F_LKTUR, P_LKPXY,C_NUM, 0, OCWISRRPMAX, &MP.OCWISRRProws, 0);

	/* 			Manitoba Child Benefit program  */

	pmaddent(pcp, "2.3.2.10.6",   NULL,                NULL,    P_DUMMY,   C_STR, 0,       0, NULL, 0);
	pmaddent(pcp, "MCBFLAG", (char *)&MP.MCBFLAG,    NULL,    P_SCL,     C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "MCBTD",   (char *)&MP.MCBTD,      NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "MCBAMT",  (char *)&MP.MCBAMT,     NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "MCBPO",   (char *)&MP.MCBPO,      NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "MCBMINE", (char *)&MP.MCBMINE,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "MCBEIR",  (char *)&MP.MCBEIR,     F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);

	/*          Saskatchewan Child Benefit program */
	pmaddent(pcp, "2.3.2.10.7",   NULL,                NULL,    P_DUMMY,   C_STR, 0,       0, NULL, 0);
	pmaddent(pcp, "SCBFLG",  (char *)&MP.SCBFLG,     NULL,    P_SCL,     C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "SCB1",    (char *)&MP.SCB1,       NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "SCB2",    (char *)&MP.SCB2,       NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "SCB3",    (char *)&MP.SCB3,       NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "SCBTD1",  (char *)&MP.SCBTD1,     NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "SCBTD2",  (char *)&MP.SCBTD2,     NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "SCBRR1",  (char *)&MP.SCBRR1[0],  "8.6",   P_VCT,     C_NUM, 0, SCBRR1MAX, &MP.SCBRR1rows, 0, "snkids");
	pmaddent(pcp, "SCBRR2",  (char *)&MP.SCBRR2[0],  "8.6",   P_VCT,     C_NUM, 0, SCBRR2MAX, &MP.SCBRR2rows, 0, "snkids");
	pmaddent(pcp, "SCBSPA",  (char *)&MP.SCBSPA,     NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);

	/*          Saskatchewan Child Benefit program for the calendar year  */
	pmaddent(pcp, "2.3.2.10.7.1",   NULL,                NULL,    P_DUMMY,   C_STR, 0,       0, NULL, 0);
	pmaddent(pcp, "SCB1P",   (char *)&MP.SCB1P,      NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "SCB2P",   (char *)&MP.SCB2P,      NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "SCB3P",   (char *)&MP.SCB3P,      NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "SCBTD1P", (char *)&MP.SCBTD1P,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "SCBTD2P", (char *)&MP.SCBTD2P,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "SCBRR1P", (char *)&MP.SCBRR1P[0], "8.6",   P_VCT,     C_NUM, 0, SCBRR1MAX, &MP.SCBRR1rows, 0, "snkids");
	pmaddent(pcp, "SCBRR2P", (char *)&MP.SCBRR2P[0], "8.6",   P_VCT,     C_NUM, 0, SCBRR2MAX, &MP.SCBRR2rows, 0, "snkids");
	pmaddent(pcp, "SCBSPAP", (char *)&MP.SCBSPAP,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);

	/*          British Columbia Family Bonus program */
	pmaddent(pcp, "2.3.2.10.8",   NULL,                NULL,    P_DUMMY,   C_STR, 0,       0, NULL, 0);
	pmaddent(pcp, "BCFBFLAG",(char *)&MP.BCFBFLAG,   NULL,    P_SCL,     C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "BCFBBAS", (char *)&MP.BCFBBAS,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "BCFBTD",  (char *)&MP.BCFBTD,     NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "BCFBRRS", (char *)&MP.BCFBRRS,    F_FRACT, P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "BCFBRR",  (char *)&MP.BCFBRR,     F_FRACT, P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "BCFBIFS",  (char *)&MP.BCFBIFS,     NULL, P_SCL,     C_INT, E_FLAG,       0, NULL, 0);
	pmaddent(pcp, "BCFBNCS1", (char *)&MP.BCFBNCS1,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BCFBNCS2", (char *)&MP.BCFBNCS2,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BCFBNCS3", (char *)&MP.BCFBNCS3,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BCFBNCSRR1", (char *)&MP.BCFBNCSRR1,    F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BCFBNCSRR2", (char *)&MP.BCFBNCSRR2,    F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BCFBNCSRR3", (char *)&MP.BCFBNCSRR3,    F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BCFBNCSTD",  (char *)&MP.BCFBNCSTD,     NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BCEIBFLG",(char *)&MP.BCEIBFLG,   NULL,    P_SCL,     C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "BCBERR1", (char *)&MP.BCBERR1,    F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BCBERR2", (char *)&MP.BCBERR2,    F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BCBERR3", (char *)&MP.BCBERR3,    F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BCBEITD",  (char *)&MP.BCBEITD,     NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BCBEMX",  (char *)&MP.BCBEMX,     NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BCEIBPI",  (char *)&MP.BCEIBPI,     NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BCBEIS1", (char *)&MP.BCBEIS1,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BCBEIS2", (char *)&MP.BCBEIS2,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BCBEIS3", (char *)&MP.BCBEIS3,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);

	/*          British Columbia Family Bonus program for the calendar year */
	pmaddent(pcp, "2.3.2.10.8.1",   NULL,                NULL,    P_DUMMY,   C_STR, 0,       0, NULL, 0);
	pmaddent(pcp, "BCFBBASP", (char *)&MP.BCFBBASP,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "BCFBTDP",  (char *)&MP.BCFBTDP,     NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "BCFBRRSP", (char *)&MP.BCFBRRSP,    F_FRACT, P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "BCFBRRP",  (char *)&MP.BCFBRRP,     F_FRACT, P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "BCFBIFSP",  (char *)&MP.BCFBIFSP,     NULL, P_SCL,     C_INT, E_FLAG,       0, NULL, 0);
	pmaddent(pcp, "BCFBNCS1P", (char *)&MP.BCFBNCS1P,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BCFBNCS2P", (char *)&MP.BCFBNCS2P,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BCFBNCS3P", (char *)&MP.BCFBNCS3P,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BCFBNCSRR1P", (char *)&MP.BCFBNCSRR1P,    F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BCFBNCSRR2P", (char *)&MP.BCFBNCSRR2P,    F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BCFBNCSRR3P", (char *)&MP.BCFBNCSRR3P,    F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BCFBNCSTDP",  (char *)&MP.BCFBNCSTDP,     NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BCEIBFLGP",(char *)&MP.BCEIBFLGP,   NULL,    P_SCL,     C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "BCBERR1P", (char *)&MP.BCBERR1P,    F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BCBERR2P", (char *)&MP.BCBERR2P,    F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BCBERR3P", (char *)&MP.BCBERR3P,    F_FRACT, P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BCBEITDP",  (char *)&MP.BCBEITDP,     NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BCBEMXP",  (char *)&MP.BCBEMXP,     NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BCEIBPIP",  (char *)&MP.BCEIBPIP,     NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BCBEIS1P", (char *)&MP.BCBEIS1P,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BCBEIS2P", (char *)&MP.BCBEIS2P,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BCBEIS3P", (char *)&MP.BCBEIS3P,    NULL,    P_SCL,     C_NUM, 0,      0, NULL, 0);

	/*          Other Social Assistance Parameters */
	pmaddent(pcp, "2.3.2.11",   NULL,                NULL,    P_DUMMY,   C_STR, 0,       0, NULL, 0);
	pmaddent(pcp, "SAFLAG",  (char *)&MP.SAFLAG,     NULL,    P_SCL,     C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "SAPFLAG", (char *)&MP.SAPFLAG,    NULL,    P_SCL,     C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "SAELDOPT",(char *)&MP.SAELDOPT,   NULL,    P_SCL,     C_INT, E_OPT,   3, NULL, 0);
	pmaddent(pcp, "SAFS",    (char *)MP.SAFS,        NULL,    P_VCT,     C_NUM, E_FIXL,  NUMREG, &MP.CTNUMREG, 0, "prov");
	pmaddent(pcp, "SFAOUT",  (char *)&MP.SFAOUT,     F_FRACT, P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "SATARGET",(char *)&MP.SATARGET[0], F_FRACT, P_VCT,    C_NUM, 0, SATARGETMAX, &MP.SATARGETrows, 0, "prov");
	pmaddent(pcp, "SACLAWFLAG", (char *)&MP.SACLAWFLAG,    NULL,    P_SCL,     C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "SACLAWPR",(char *)&MP.SACLAWPR[0], NULL, P_VCT,    C_INT, E_FIXL, NUMREG, &MP.CTNUMREG, 0, "prov");
	pmaddent(pcp, "SACLAWOPT", (char *)&MP.SACLAWOPT,    NULL,    P_SCL,     C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "NCLAWSA1", (char *)&MP.NCLAWSA1,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "NCLAWSA2", (char *)&MP.NCLAWSA2,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "PNCBSFT", (char *)&MP.PNCBSFT,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QNCBSFT1", (char *)&MP.QNCBSFT1,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QNCBSFT2", (char *)&MP.QNCBSFT2,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QNCBSFT3", (char *)&MP.QNCBSFT3,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "ONCBSFT1", (char *)&MP.ONCBSFT1,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "ONCBSFT2", (char *)&MP.ONCBSFT2,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "ONCBSFT3", (char *)&MP.ONCBSFT3,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MCLAWSA6", (char *)&MP.MCLAWSA6,    NULL,    P_SCL,     C_NUM, 0,  0, NULL, 0);
	pmaddent(pcp, "MCLAWSA12", (char *)&MP.MCLAWSA12,    NULL,    P_SCL,     C_NUM, 0,  0, NULL, 0);
	pmaddent(pcp, "MCLAWPCT",  (char *)&MP.MCLAWPCT,       "8.2",    P_TBL,   C_NUM, 0, MCLAWPCTRMAX, &MP.MCLAWPCTrows, MCLAWPCTCMAX);
	pmaddent(pcp, "ANCBSFT1", (char *)&MP.ANCBSFT1,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "ANCBSFT2", (char *)&MP.ANCBSFT2,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "ANCBSFT3", (char *)&MP.ANCBSFT3,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "ASHELTFLG", (char *)&MP.ASHELTFLG,    NULL,    P_SCL,     C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "ASHELTER",  (char *)&MP.ASHELTER[0],    F_FRACT,   P_VCT, C_NUM,   E_FIXL, NUMPERMAX, &MP.NUMPERrows, 0, "ashlt");

	/*          Social Assistance Clawback Parameters for the calendar year */

	pmaddent(pcp, "2.3.2.11.1",   NULL,                NULL,    P_DUMMY,   C_STR, 0,       0, NULL, 0);
	pmaddent(pcp, "NCLAWSA1P", (char *)&MP.NCLAWSA1P,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "NCLAWSA2P", (char *)&MP.NCLAWSA2P,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "PNCBSFTP", (char *)&MP.PNCBSFTP,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QNCBSFT1P", (char *)&MP.QNCBSFT1P,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QNCBSFT2P", (char *)&MP.QNCBSFT2P,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QNCBSFT3P", (char *)&MP.QNCBSFT3P,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "ONCBSFT1P", (char *)&MP.ONCBSFT1P,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "ONCBSFT2P", (char *)&MP.ONCBSFT2P,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "ONCBSFT3P", (char *)&MP.ONCBSFT3P,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MCLAWSA6P", (char *)&MP.MCLAWSA6P,    NULL,    P_SCL,     C_NUM, 0,  0, NULL, 0);
	pmaddent(pcp, "MCLAWSA12P", (char *)&MP.MCLAWSA12P,    NULL,    P_SCL,     C_NUM, 0,  0, NULL, 0);
	pmaddent(pcp, "MCLAWPCTP",  (char *)&MP.MCLAWPCTP,       "8.2",    P_TBL,   C_NUM, 0, MCLAWPCTPRMAX, &MP.MCLAWPCTProws, MCLAWPCTPCMAX);
	pmaddent(pcp, "ANCBSFT1P", (char *)&MP.ANCBSFT1P,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "ANCBSFT2P", (char *)&MP.ANCBSFT2P,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "ANCBSFT3P", (char *)&MP.ANCBSFT3P,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "ASHELTFLGP", (char *)&MP.ASHELTFLGP,    NULL,    P_SCL,     C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "ASHELTERP",  (char *)&MP.ASHELTERP[0],    F_FRACT,   P_VCT, C_NUM,   E_FIXL, NUMPERMAX, &MP.NUMPERrows, 0, "ashlt");

	/*          Federal Refundable Medical Expense Supplement */
	pmaddent(pcp, "2.3.2.12",   NULL,                NULL,    P_DUMMY,   C_STR, 0,       0, NULL, 0);
	pmaddent(pcp, "MEDREMIN",(char *)&MP.MEDREMIN,   NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MEDRRATE",(char *)&MP.MEDRRATE,   F_FRACT, P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MEDRMAX", (char *)&MP.MEDRMAX,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MEDRRR",  (char *)&MP.MEDRRR,     F_FRACT, P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MEDRTD",  (char *)&MP.MEDRTD,     NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);

	/*          Federal Refundable Working Income Tax Benefit */
	pmaddent(pcp, "2.3.2.13",   NULL,                NULL,    P_DUMMY,   C_STR, 0,       0, NULL, 0);
	pmaddent(pcp, "WITBFLAG",  (char *)&MP.WITBFLAG,NULL,    P_SCL,     C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "WITBSNG",   (char *)&MP.WITBSNG,  NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "WITBFAM",   (char *)&MP.WITBFAM,  NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "WITBFPO",   (char *)&MP.WITBFPO,  NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "WITBSPO",   (char *)&MP.WITBSPO,  NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "WITBMINE",  (char *)&MP.WITBMINE, NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "WITBRR",    (char *)&MP.WITBRR,   F_FRACT, P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "WITBPIR",   (char *)&MP.WITBPIR,  F_FRACT, P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "WITBSMINE", (char *)&MP.WITBSMINE, NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "WITBSAMT",  (char *)&MP.WITBSAMT,  NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "WITBSRR",   (char *)&MP.WITBSRR,   F_FRACT, P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "WITBSPIR",  (char *)&MP.WITBSPIR,  F_FRACT, P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "WITBSFPO",  (char *)&MP.WITBSFPO,  NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "WITBSSPO",  (char *)&MP.WITBSSPO,  NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);

	/*          Federal relief for heating expenses */
	pmaddent(pcp, "2.3.2.14",   NULL,                NULL,    P_DUMMY,   C_STR, 0,       0, NULL, 0);
	pmaddent(pcp, "HEATRLFLG", (char *)&MP.HEATRLFLG,NULL,    P_SCL,     C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "HEATSNG",   (char *)&MP.HEATSNG,  NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "HEATFAM",   (char *)&MP.HEATFAM,  NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "FECBFLAG",  (char *)&MP.FECBFLAG,NULL,    P_SCL,     C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "FECBGIS",   (char *)&MP.FECBGIS,  NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "FECBNCBS",  (char *)&MP.FECBNCBS,  NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);

	/*          Provincial relief for heating expenses */
	pmaddent(pcp, "2.3.2.15",   NULL,                NULL,    P_DUMMY,   C_STR, 0,       0, NULL, 0);

	/*          Newfoundland and Labrador Home Heating Fuel Rebate */
	pmaddent(pcp, "2.3.2.15.1",  NULL,                  NULL,    P_DUMMY,   C_STR, 0,      0, NULL, 0);
	pmaddent(pcp, "NHEATFLG", (char *)&MP.NHEATFLG,  NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "NHEATREB", (char *)&MP.NHEATREB,   NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "NHEATSAFLG",(char *)&MP.NHEATSAFLG,  NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "NHEATINC", (char *)&MP.NHEATINC,   NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "NHEATTD",  (char *)&MP.NHEATTD,    NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "NHEATPO",  (char *)&MP.NHEATPO,    NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "NHEATMIN", (char *)&MP.NHEATMIN,   NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "NHEATRR",  (char *)&MP.NHEATRR,    F_FRACT,    P_SCL, C_NUM, 0,       0, NULL, 0);

	/*          Nova Scotia Home Heating Assistance Rebate    */
	pmaddent(pcp, "2.3.2.15.2",  NULL,                  NULL,    P_DUMMY,   C_STR, 0,      0, NULL, 0);
	pmaddent(pcp, "VHEATFLG", (char *)&MP.VHEATFLG,  NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "VHEATREB", (char *)&MP.VHEATREB,   NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "VHEATERB", (char *)&MP.VHEATERB,   NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "VHEATSTD", (char *)&MP.VHEATSTD,   NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "VHEATFTD", (char *)&MP.VHEATFTD,   NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "VHEATTU",  (char *)&MP.VHEATTU,    F_FRACT,    P_SCL, C_NUM, 0,       0, NULL, 0);

	/*          New Brunswick Home Heating Oil Benefit    */
	pmaddent(pcp, "2.3.2.15.3",  NULL,                  NULL,    P_DUMMY,   C_STR, 0,      0, NULL, 0);
	pmaddent(pcp, "BHEATFLG", (char *)&MP.BHEATFLG,  NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "BHEATBEN", (char *)&MP.BHEATBEN[0][0],   F_LKTUR, P_LKPXY, C_NUM, E_NONE, BHEATBENMAX, &MP.BHEATBENrows, 0);
	pmaddent(pcp, "BHEATSA",  (char *)&MP.BHEATSA,    NULL,    P_SCL, C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "BHEATPO",  (char *)&MP.BHEATPO,    NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);

	/*          Ontario Home Electricity Relief Program    */
	pmaddent(pcp, "2.3.2.15.4",  NULL,                  NULL,    P_DUMMY,   C_STR, 0,      0, NULL, 0);
	pmaddent(pcp, "OHEATFLG", (char *)&MP.OHEATFLG,  NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "OHEATSNG", (char *)&MP.OHEATSNG,   NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "OHEATFAM", (char *)&MP.OHEATFAM,   NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "OHEATSTD", (char *)&MP.OHEATSTD,   NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "OHEATFTD", (char *)&MP.OHEATFTD,   NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "OHEATMIN", (char *)&MP.OHEATMIN,   NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "OHEATRR",  (char *)&MP.OHEATRR,    F_FRACT,    P_SCL, C_NUM, 0,       0, NULL, 0);

	/*          Saskatchewan Home Heating Assistance Rebate    */
	pmaddent(pcp, "2.3.2.15.5",  NULL,                  NULL,    P_DUMMY,   C_STR, 0,      0, NULL, 0);
	pmaddent(pcp, "SHEATFLG", (char *)&MP.SHEATFLG,  NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "SHEATSNG", (char *)&MP.SHEATSNG,   NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "SHEATFAM", (char *)&MP.SHEATFAM,   NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);

	/*          Alberta Energy Tax Refund */
	pmaddent(pcp, "2.3.2.15.6",  NULL,                  NULL,    P_DUMMY,   C_STR, 0,      0, NULL, 0);
	pmaddent(pcp, "AHEATFLG", (char *)&MP.AHEATFLG,  NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "AHEATREB", (char *)&MP.AHEATREB,   NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);

	/*          British Columbia Refundable Energy Credit    */
	pmaddent(pcp, "2.3.2.15.7",  NULL,                  NULL,    P_DUMMY,   C_STR, 0,      0, NULL, 0);
	pmaddent(pcp, "CHEATFLG", (char *)&MP.CHEATFLG,  NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "CHEATSNG", (char *)&MP.CHEATSNG,   NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "CHEATFAM", (char *)&MP.CHEATFAM,   NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);

	/*          Nova Scotia Direct Assistance Program */
	pmaddent(pcp, "2.3.2.16",   NULL,                NULL,    P_DUMMY,   C_STR, 0,       0, NULL, 0);
	pmaddent(pcp, "VDAFLAG", (char *)&MP.VDAFLAG,    NULL,    P_SCL,     C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "VDASB",   (char *)&MP.VDASB,      NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "VDACB",   (char *)&MP.VDACB,      NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "VDASI",   (char *)&MP.VDASI,      NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "VDACI",   (char *)&MP.VDACI,      NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "VDAFWC",  (char *)&MP.VDAFWC,     NULL,    P_SCL,     C_INT, E_FLAG,  0, NULL, 0);

	/*          Nova Scotia Taxpayer Refund */
	pmaddent(pcp, "2.3.2.17",   NULL,                      NULL,    P_DUMMY,   C_STR, 0,       0, NULL, 0);
	pmaddent(pcp, "NSTXREFFLG", (char *)&MP.NSTXREFFLG,    NULL,    P_SCL,     C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "NSTXREFAMT", (char *)&MP.NSTXREFAMT,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);

	/*     Calculation of Total Income */
	pmaddent(pcp, "2.3.3",   NULL,                   NULL,    P_DUMMY,   C_STR, 0,       0, NULL, 0);
	pmaddent(pcp, "CAPGIR",  (char *)&MP.CAPGIR,     F_FRACT, P_SCL,     C_NUM, E_FRCT,  0, NULL, 0);
	pmaddent(pcp, "FDGUR",   (char *)&MP.FDGUR,      F_FRACT, P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "FDGURLC", (char *)&MP.FDGURLC,    F_FRACT, P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "DIVPLC",  (char *)&MP.DIVPLC,     F_FRACT, P_SCL,     C_NUM, E_FRCT,  0, NULL, 0);
	pmaddent(pcp, "SPLTPNSFLAG",(char *)&MP.SPLTPNSFLAG,   NULL,    P_SCL,     C_INT,  E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "PENSPLTINCR",(char *)&MP.PENSPLTINCR,   F_FRACT, P_SCL,     C_NUM, E_FRCT,  0, NULL, 0);

	/*     Personal Taxes */
	pmaddent(pcp, "2.3.4",   NULL,                   NULL,    P_DUMMY,   C_STR, 0,       0, NULL, 0);

	/*          Deductions from Total Income */
	pmaddent(pcp, "2.3.4.1",   NULL,                 NULL,    P_DUMMY,   C_STR, 0,       0, NULL, 0);
	pmaddent(pcp, "REPNETFLAG",(char *)&MP.REPNETFLAG,NULL,   P_SCL,     C_INT,  E_FLAG, 0, NULL, 0);

	/*               Employment Expense Deduction */
	pmaddent(pcp, "2.3.4.1.1",   NULL,               NULL,    P_DUMMY,   C_STR, 0,       0, NULL, 0);
	pmaddent(pcp, "ALEXPP",  (char *)&MP.ALEXPP,     F_FRACT, P_SCL,     C_NUM, E_FRCT,  0, NULL, 0);
	pmaddent(pcp, "FACTISENF",(char *)&MP.FACTISENF, F_FRACT, P_SCL,     C_NUM, 0,       0, NULL, 0);

	/*               CPP/QPP Contributions */
	pmaddent(pcp, "2.3.4.1.2",   NULL,               NULL,    P_DUMMY,   C_STR, 0,       0, NULL, 0);
	pmaddent(pcp, "CPPXM",   (char *)&MP.CPPXM,      NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "YMPE",    (char *)&MP.YMPE,      NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "SECF",    (char *)&MP.SECF,      F_FRACT, P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "WSCF",    (char *)&MP.WSCF,      F_FRACT, P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "WSCM",    (char *)&MP.WSCM,      F_FRACT, P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "CPPLT60", (char *)&MP.CPPLT60[0][0],F_LKTUR, P_LKPXY, C_NUM, E_FRCT, CPPLT60MAX, &MP.CPPLT60rows, 0);
	pmaddent(pcp, "CPP60T64",(char *)&MP.CPP60T64[0][0],F_LKTUR, P_LKPXY, C_NUM, E_FRCT, CPP60T64MAX, &MP.CPP60T64rows, 0);
	pmaddent(pcp, "CPPGT64", (char *)&MP.CPPGT64[0][0],F_LKTUR, P_LKPXY, C_NUM, E_FRCT, CPPGT64MAX, &MP.CPPGT64rows, 0);
	pmaddent(pcp, "CPPSEDEDFLG",(char *)&MP.CPPSEDEDFLG,   NULL,    P_SCL,     C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "CPPSEDFRC",(char *)&MP.CPPSEDFRC,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);


	/*               Child Care Expense Deduction */
	pmaddent(pcp, "2.3.4.1.3",   NULL,               NULL,    P_DUMMY,   C_STR, 0,       0, NULL, 0);
	pmaddent(pcp, "CCEATFLG",(char *)&MP.CCEATFLG,   NULL,    P_SCL,     C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "CCEATLL", (char *)&MP.CCEATLL,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "CCEATFR", (char *)&MP.CCEATFR,    F_FRACT, P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "CCEAYNG", (char *)&MP.CCEAYNG,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "CCEAOLD", (char *)&MP.CCEAOLD,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "CCEAEMPF",(char *)&MP.CCEAEMPF,   F_FRACT, P_SCL,     C_NUM, E_FRCT,  0, NULL, 0);
	pmaddent(pcp, "CCESFLAG",(char *)&MP.CCESFLAG,   NULL,    P_SCL,     C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "CCEAOAGE",(char *)&MP.CCEAOAGE,   NULL,    P_SCL,     C_INT, 0,       0, NULL, 0);
	pmaddent(pcp, "CCEROPT", (char *)&MP.CCEROPT,    NULL,    P_SCL,     C_INT, E_OPT,   2, NULL, 0);
	pmaddent(pcp, "CCEZOPT", (char *)&MP.CCEZOPT,    NULL,    P_SCL,     C_INT, E_OPT,   3, NULL, 0);
	pmaddent(pcp, "CCESYNG", (char *)&MP.CCESYNG,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "CCESOLD", (char *)&MP.CCESOLD,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "CCEPTFLG",(char *)&MP.CCEPTFLG,   NULL,    P_SCL,     C_INT, E_FLAG,  0, NULL, 0);

	/*          Personal Tax Credits */
	pmaddent(pcp, "2.3.4.2",   NULL,                 NULL,    P_DUMMY,   C_STR, 0,       0, NULL, 0);

	/*               Basic Tax Credit */
	pmaddent(pcp, "2.3.4.2.1",   NULL,               NULL,    P_DUMMY,   C_STR, 0,       0, NULL, 0);
	pmaddent(pcp, "BXM",     (char *)&MP.BXM,        NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "BXMEXT",  (char *)&MP.BXMEXT,     NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "BXMS",    (char *)&MP.BXMS,       NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "BXMSRR",  (char *)&MP.BXMSRR,     F_FRACT, P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "BXMSPI",  (char *)&MP.BXMSPI,     F_FRACT, P_SCL,     C_NUM, 0,       0, NULL, 0);

	/*               Age Tax Credit */
	pmaddent(pcp, "2.3.4.2.2",   NULL,               NULL,    P_DUMMY,   C_STR, 0,       0, NULL, 0);
	pmaddent(pcp, "AXM",     (char *)&MP.AXM,        NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "AXTD",    (char *)&MP.AXTD,       NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "AXRR",    (char *)&MP.AXRR,       F_FRACT, P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "AXPI",    (char *)&MP.AXPI,       F_FRACT, P_SCL,     C_NUM, 0,       0, NULL, 0);


	/*               Spousal Tax Credit */
	pmaddent(pcp, "2.3.4.2.3",   NULL,               NULL,    P_DUMMY,   C_STR, 0,       0, NULL, 0);
	pmaddent(pcp, "MXM",     (char *)&MP.MXM,        NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MXMT",    (char *)&MP.MXMT,       NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MXMEXT",  (char *)&MP.MXMEXT,     NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MXMTEXT", (char *)&MP.MXMTEXT,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);

	/*               Spouse Equivalent Tax Credit */
	pmaddent(pcp, "2.3.4.2.4",   NULL,               NULL,    P_DUMMY,   C_STR, 0,       0, NULL, 0);
	pmaddent(pcp, "EMXM",    (char *)&MP.EMXM,       NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "EMXMT",   (char *)&MP.EMXMT,      NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "EMXMEXT", (char *)&MP.EMXMEXT,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "EMXMTEXT",(char *)&MP.EMXMTEXT,   NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);

	/*               Tax Credit for Wholly Dependent Children Aged 17 and Under */
	pmaddent(pcp, "2.3.4.2.5",   NULL,               NULL,    P_DUMMY,   C_STR, 0,       0, NULL, 0);
	pmaddent(pcp, "YCXM1",   (char *)&MP.YCXM1,      NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "YCXM2",   (char *)&MP.YCXM2,      NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "YCXM3",   (char *)&MP.YCXM3,      NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "YCXMT",   (char *)&MP.YCXMT,      NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);

	DEBUG_OFF("mpd2");
}
