/***
*mpd3.cpp - Tax/transfer model parameter definitions (cont.)
*
*$Id: mpd3.cpp 6.185 2007/09/18 17:22:09 hickcha Exp $
*
*   SPSD/M Copyright (c) 1987-1995, Minister of Industry.
*   All rights reserved.  Use, reproduction, or disclosure of this work,
*   as well as publication of results derived from this work, are subject
*   to the conditions specified in the SPSD/M License Agreement.
*
*Purpose:
*   This file contains the definition of the .c function.
*
*Revisions:								   
* +-----+----------+---------------------------------------------------------+
* | Who |   Date   | Description                                             |
* +-----+----------+---------------------------------------------------------+
* | CH  | 07/07/30 | Added QTUITRFFLG                                        |
* | CH  | 07/07/26 | Labeled dimensions of QCAMIN and QCAMAX                 |
* | LP  | 07/07/20 | Added 2 flags to CCE - QCCEEIFLG and QCCEEITST          |
* | CH  | 07/07/17 | Added QCMPOPT QPSXMINC QTPCFLG QESSNEEDS QLAXOLDDEP     |
* | CH  | 07/03/19 | Deleted label of QCAMAX and QCAMIN                      |
* | CH  | 07/02/22 | Added QPENSPLTINCR                                      |
* | LP  | 07/02/13 | Removed QDTCWCA, use revised QPSXM for all years/program|
* | LP  | 07/02/12 | Added QSTRMAGE, minimum age flag for Q. Sales Tax Credit|
* | CH  | 07/02/06 | Added pension income splitting                          |
* | LP  | 07/02/02 | Removed QAMTINCRT, added QAMTCAPR                       |
* | LP  | 07/01/25 | Changed dollar type vectors from NULL to 8.2            |
* | LP  | 07/01/25 | Changed QFAMDED format from F_FRACT to NULL             |
* | LP  | 07/01/22 | Removed provincial UCCB in income test flags - _UCCBITF |
* | LP  | 07/01/22 | Added AMTDIVLC - AMT Dividend Rate for eligible dividend|
* | LP  | 07/01/15 | Remove VUCCBTC, add PYCTCAPM, PYCTCPI, VYCTCAPM, VYCTCPI|
* | LP  | 07/01/12 | Removed parameter QHSCDIR, QDIVRAT - no longer needed   |
* | LP  | 06/06/09 | Removed provincial AXPI series, QCCEA1,2,3 not required |
* | LP  | 06/06/07 | Add flags to remove UCCB from income tests NB,NS,PEI,NF |
* | LP  | 06/06/01 | Added VUCCBTC - N.S. non-ref UCCB tax credit flag       |
* | LP  | 06/05/15 | Added fed/prov large corp dividend tax credit rates     |
* | LP  | 06/05/12 | Added more decimals spaces/precision to FTX             |
* | LP  | 06/05/11 | Added Canada Employment Credit EMPTXC                   |
* | LP  | 06/05/05 | Added textbook tax credit TEXTPMFT and TEXTPMPT         |
* | LP  | 05/11/29 | Added a third option to QFATCOPT - for 2005 onwards     |
* | LP  | 05/11/17 | Removed QSTROPT, pre 1991 parameter                     |
* | LP  | 05/11/03 | Added EDDISPT, flag pt disabled students get ft educ amt|
* | CH  | 05/09/12 | Deleted CHATPROP                                        |
* | LP  | 05/05/30 | Added QRNCGFLG, QRNCGTC refund natural caregivers tx crd|
* | LP  | 05/05/11 | Added new deduction for workers (QEMPDEDP and QEMPDEDM) |
* | LP  | 04/07/14 | Added QAMTSTTC - spouse transfer tax credit flag for AMT|
* | LP  | 04/07/09 | Added Nfld. Low Income Tax Reduction - NLITR series     |
* | LP  | 04/06/18 | Added Child Assistance - QCAFLAG + others and new non-  |
* |     |          | ref dep cred (QDTCWCA, QDTCNCA1, QDTCNCA2 and QDTCSPA)  |
* | LP  | 04/06/09 | Added Work Premium Refundable Credit - QWPFLAG + others |
* | LP  | 04/05/13 | Added QSTSCA - Que Single Tax System Complementary Amt  |
* | LP  | 04/02/11 | Added QREPFAMI QHSSFLSS QHSSFUIR QHSSFALM QHSSFCAR      |
* |     |          | QNORFAMI QTRSAFAM QTRWCFAM                              |
* | LP  | 04/01/06 | Removed prov/federal CGTC/HPTC take ups and turn downs  |
* | LP  | 03/12/22 | Added prov. non-ref medical tax credit _MEDALL & _MEDANF|
* | LP  | 03/12/19 | Added CHATPROP - gifts of depreciable property flag     |
* | LP  | 03/12/18 | Added QODISTC - infirm dependents 18 and over tax credit|
* | LP  | 03/12/18 | Added ODISTC - infirm dependents (18+) tax credit       |
* | LP  | 03/12/09 | Added NODISTC, PODISTC, VODISTC, BODISTC  (infirm dep)  |
* | LP  | 03/12/08 | Added QHPTCOPT - Quebec housing parent tax credit option|
* | LP  | 03/11/17 | Added CGTCOPT                                           |
* | LP  | 03/11/17 | Added BCGTCOPT, VCGTCOPT, PCGTCOPT, NCGTCOPT            |
* | LP  | 03/11/17 | Added INTSLFLG - Fed. stud loan interest tax credit flag|
* | LP  | 03/11/17 | Added QINTSLTC - Quebec student loan interest tax credit|
* | LP  | 03/11/13 | Added BEDXPMPT, VEDXPMPT, PEDXPMPT, NEDXPMPT, EDXPMPT   |
* | CH  | 03/05/22 | Added Extra QSTR                                        |
* | LP  | 03/01/15 | Added precision to QAMTTX                               |
* | LP  | 02/09/04 | Revised number sequence                                 |
* | LP  | 02/04/26 | Added QNORTHDED, QSFDED, QSFMEDFLAG, QSFTXCR            |
* | BBM | 01/06/20 | Drop NTCMAX VHOSPR VHOSPRM VHOT VHOTM for 9.0-no GB data|
* | LP  | 01/06/11 | Added NLVCMAX and NLVCRT labour sponsored venture cap.  |
* | LP  | 01/05/31 | Added N.B. Low-Income Tax Reduction parameters          |
* | LP  | 01/05/16 | Added new Quebec Alternative Minimum Tax parameters     |
* |     |          |   and removed QCAPRAT                                   |
* | LP  | 01/05/09 | Added new Federal Alternative Minimum Tax parameters    |
* |     |          |   and new provincial alternative minimum tax parameters |                    
* | BBM | 01/04/19 | Dropped VHOSPMAX (9.0 database change)                  |
* | LP  | 01/03/12 | Removed pre-1988 program parameters                     |
* | LP  | 01/02/28 | Added NSF2 and NSCI2 - modified NFLD surtax formula     |
* | LP  | 00/11/16 | Removed QDEPNIFG flag for SA, etc in net income flag    |
* | LP  | 00/11/16 | Added QSPBFLAG, QSADED, QNFSDED (social benefits flags) |
* | LP  | 00/10/18 | Added QFAMNETI (family net income concept for credits)  |
* | CH  | 00/04/14 | Added precision to provincial tax tables                |
* | LP  | 00/04/13 | Added QITSFSEW QITSSEF improv. sys. for self-empl       |
* | CH  | 00/04/07 | Added QFATCK6YR QFATCK6PYR                              |
* | CH  | 00/04/07 | Added more Quebec family allowance parameters           |
* | LP  | 00/04/06 | Added QSFSMXI for simplified tax form work sheet        |
* | LP  | 00/04/03 | Added QGIFTHCR, QGIFTL1, QGFTCR higher cred. rate - gift|
* | LP  | 00/03/23 | Added QEEXPDED emp. exp. deduction application flag     |
* | LP  | 00/03/21 | Added Quebec refundable tax credit for medical expenses |
* | CH  | 00/03/21 | Added PEI tax reduction                                 |
* | CH  | 00/03/01 | Added provincial tax on taxable income                  |
* | CH  | 99/05/28 | Added QAMTXSTKFLG                                       |
* | CH  | 99/04/21 | Added Quebec combined age, living alone and retirement  |
* |     |          |   and modified Simplified Low Income parameters         |
* | CH  | 99/03/22 | Added Labour-sponsored Funds parameters                 |
* | TCB | 98/05/28 | Renamed *.cpp, ANSI function headers                    |
* | CH  | 98/05/22 | Added N.S. Pharmacare VPHOPT VPHTDC                     |
* | EGA | 98/04/21 | Added Que max to gifts to crowns                        |
* | EGA | 98/04/07 | Quebec Anti-Poverty Fund                                |
* | CH  | 98/04/07 | Added Federal Surtax Tax Reduction FSURTRMX,RR,RL       |
* | CH  | 98/04/06 | RRSP/RPP not included in Alternative minimum tax (AMTRP)|
* | EGA | 98/04/06 | Supplement for young kids in large families in QFATC    |
* | EGA | 98/04/02 | Quebec Low income credit: QLICRFLG, QLICR and			 |
* |     |          | Family credit reform: QFAMFLG, QFAMRAT                  |
* | EGA | 98/03/27 | mod. of Quebec political contribution: QPCOPT, QPCTR    |
* | EGA | 98/03/24 | Caregiver Tax Credit: CGTC,CGTCTD,CGTCFLAG,CGTCTC,CGTCTK|
* | EGA | 98/03/17 | Quebec parameters ordered                               |
* | EGA | 98/03/09 | add QDUESOPT, QFATCSUP, QFATCSUP,QFATCMIN,QFATCMNK,   	 |
* |     |          | QFATCMXK, QFATCSRR, QFATCMRR, QFATD4K, QFATD4KI,        |
* |     |          | QTUIOPT, QAMTXFLG, QAMTXREF, QCAPAMTX, QDIVRAT, QCAPRAT,|
* |     |          | QAMTX, QAMTTX                                           |
* | EGA | 98/03/09 | delete QFATC1-3, QFATCM1-3,QFAMTC,QFAMTD1-3,QFABTD1-3   |
* |     |          | QMAXTAX, QFATCRR1-4 						             |
* | EGA | 98/02/18 | add QFATC1-3, QFATCM1-3,QFAMTC,QFAMTD1-3,QFABTD1-3      |
* |     |          | QMAXTAX, QFATCRR1-4, QFATCTK,QFATCOPT                   |
* | EGA | 98/02/13 | add QDUESOPT                                            |
* | EGA | 98/02/12 | add QMEDOPT                                             |
* | EGA | 98/02/12 | add QYPRR, QYPTD, QYPPI                                 |
* | EGA | 98/02/11 | add QAXRR, QAXTD, QAXPI,QLAXRR, QLAXTD, QLAXPI          |
* | EGA | 98/02/05 | add QHTCFTC, QHPTCTK                                    |
* | EGA | 97/12/17 | add QHTCFLG, QHPTC                                      |
* | EGA | 97/12/09 | add QFAMDED                                             |
* | EGA | 97/12/09 | add QCRDFLG                                             |
* | EGA | 97/10/15 | rename QSTFTYP3 and 4 to QSTRFTP3 and 4                 |
* | EGA | 97/10/10 | Add Quebec newborn random increse in ranking flag       |
* | CH  | 97/10/09 | Add NFLD sales tax credit activation flag               |
* | CH  | 97/10/01 | Add NFLD sales tax credit parameters                    |
* | EGA | 97/09/10 | add QSTREFLAG,change QSTRFTYPE to QSTRFTYP3, QSTRFTYP4  |
* | EGA | 97/09/11 | add QSTRFALG, QSTRRR, QSTRCHILD,QSTRFTYPE.              |
* | EGA | 97/09/10 | add QCAPGFLAG                                           |
* | BBM | 97/09/08 | Add VHOTM VHOSPRM for Nova Scotia HOSP changes 1994 ->  |
* | BBM | 97/05/27 | Remove VSTKMAX -- no data for 1992                      |
* | ER  | 96/09/09 | Added NSCI NSF - Newfoundland surtax 1996->             |
* | BBM | 95/06/21 | Add Nova Scotia Tax Reduction parameters(Begins in 1994)|
* | BBM | 95/05/23 | Add Nova Scotia Pharmacare parameters                   |
* | BBM | 94/10/05 | Add Quebec refundable child care expense credit parms   |
* | BBM | 94/09/29 | Add quebec net income / tax credit option parameters    |
* | BBM | 94/09/29 | Add quebec tax reduction parameters                     |
* | BBM | 94/09/29 | Add quebec health services tax parameters               |
* | BBM | 94/09/28 | Add quebec surtax parameters QHSF QHSF2 QHSCI QHSCI2    |
* | BBM | 94/09/26 | Remove NPTCFLAG                                         |
* | GJC | 93/04/16 | add parms for nova scotia two-tier surtax               |
* | RSE | 94/03/16 | add Newfoundland political contribution tax credit 1993+|
* | GJC | 93/04/01 | remove MP.CAPGAL and MP.CAPGEFLR                        |
* | GJC | 93/02/17 | add capital gains effective annual effective an limit rt|
* | BBM | 92/07/07 | Prov. political tax credit parameters                   |
* | BBM | 92/06/21 | Fed political tax credit parameters                     |
* | BBM | 91/07/05 | Added BSCI BSF - New Brunswick surtax 1991->            |
* | BBM | 91/07/05 | added VSCI VSF - Nova Scotia Surtax 1990->              |
* | --- | 89/10/13 | Release 4.0                                             |
* |     |          |                                                         |
* +-----+----------+---------------------------------------------------------+
*
*Definitions:
*   mpd3     [global]  Tax/transfer model parameter definitions (cont.)
*
*****************************************************************************/


/* ==================== C-RUNTIME LIBRARY INCLUDE FILES =================== */

#include <stdio.h>  /* definitions/declarations for standard I/O routines   */


/* ==================== SPSD/M INCLUDE FILES ============================== */

#include "spsm.h"   /* SPSM common manifest constants and macros            */
#include "sub.h"    /* Subroutine library declarations                      */
#include "pm.h"     /* Parameter manipulation package declarations          */
#include "mpu.h"    /* Tax/transfer parameter declarations (user's)         */
#include "mp.h"     /* Tax/transfer parameter declarations                  */


/* ==================== STATIC VARIABLE DEFINITIONS ======================= */

static char NEAR F_FRACT[]  = "8.5";
static char NEAR F_LKTUR[]  = "8.0 8.3 10.4";
static char NEAR F_LKTURI[]  = "8.0 8.3 10.4";


/* ==================== COMPILER PRAGMAS ================================== */

// eliminate spurious 'near/far mismatch' from MS-DOS compiler
#if defined(_MSDOS)
#pragma warning(disable : 4762)
#endif

#ifdef MSCOVL
#pragma alloc_text(INIT_TEXT,mpd3)
#endif


/* ==================== FUNCTION DEFINITIONS ============================== */


/*****************************************************************************
*mpd3 - Tax/transfer model parameter definitions (cont.)
*
*Synopsis:
*    void mpd3(           
*    P_pc pcp             
*    )                    
*
*Description:
*
*Return Value:
*   None.
*
*Calls:
*   pmaddent Define and add a parameter
*
*Structure Members:
*   MP.AMTDIV       (i)  Alternative minimum tax: percentage of taxable dividends
*   MP.AMTDIVLC     (i)  Alternative minimum tax: percentage of eligible taxable dividends
*   MP.AMTEX        (i)  Alternate minimum tax: exemption level
*   MP.AMTFORTX     (i)  Alternative minimum tax: Foreign Income Tax Rate
*   MP.AMTINCRT     (i)  Alternative minimum tax: Inclusion Rate
*   MP.AMTNEGTI     (i)  Alternative minimum tax: Allow Negative Taxable Income Flag
*   MP.AMTPRVDF     (i)  Alternative minimum tax: prov. tax difference definition[prov]
*   MP.AMTRPFLG     (i)  RRSP/RPP included in Alternate minimum tax (1=included)
*   MP.AMTSTK       (i)  Alternative minimum tax: Stock Option Proportion
*   MP.AMTTX        (i)  Alternate minimum tax rate
*   MP.BAMTOPT      (i)  N.B. alternative minimum tax option
*   MP.BAMTPCTF     (i)  N.B. amt rate as pct of additional fed tax due to minimum tax
*   MP.BAMTPCTM     (i)  N.B. amt rate as pct of federal minimum tax amount
*   MP.BAMTTX       (i)  N.B. amt rate as tax on adjusted income
*   MP.BAXM         (i)  N.B. Age Amount
*   MP.BAXRR        (i)  N.B. Age Amount credit reduction rate
*   MP.BAXTD        (i)  N.B. Age Amount net income turndown
*   MP.BBXM         (i)  N.B. Basic Personal Exemption/amount
*   MP.BCGTC        (i)  N.B. Caregiver Tax Credit
*   MP.BCGTCFLG     (i)  N.B. Caregiver Tax Credit activation flag
*   MP.BCGTCOPT     (i)  N.B. Caregiver Tax Credit Option (1=max, 2=greenbook)
*   MP.BCHATL1      (i)  N.B. Charitable Donations amount level 1
*   MP.BCHATR1      (i)  N.B. Charitable Donations tax credit rate 1
*   MP.BCHATR2      (i)  N.B. Charitable Donations tax credit rate 2
*   MP.BDTCR        (i)  N.B. dividend tax credit rate
*   MP.BDTCRLC      (i)  N.B. dividend tax credit rate from large (eligible) corporations
*   MP.BEDXPM       (i)  N.B. Education Amount per month of full-time studies
*   MP.BEDXPMPT     (i)  N.B. Education Amount per month of part-time studies
*   MP.BEMXM        (i)  N.B. equivalent to married amount
*   MP.BEMXMT       (i)  N.B. equivalent to married turndown level
*   MP.BLVCMAX      (i)  Maximum N.B. labour-sponsored funds tax credit allowed
*   MP.BLVCRT       (i)  Percent of N.B. labour-sponsored funds cost allowed as credit
*   MP.BMAXDX       (i)  N.B. Maximum Disability deduction/amount
*   MP.BMAXET       (i)  N.B. maximum on transfer of education and tuition amount
*   MP.BMEDALL      (i)  N.B. Medical allowance maximum lower limit
*   MP.BMEDANF      (i)  N.B. Medical allowance lower limit net income fraction
*   MP.BMXM         (i)  N.B. married amount
*   MP.BMXMT        (i)  N.B. married amount turndown level
*   MP.BODISTC      (i)  N.B. Maximum infirm dependent 18 or older tax credit
*   MP.BPNTCR       (i)  N.B. provincial non-refundable tax credit rate
*   MP.BPTC         (i)  New Brunsw. political contribution table [total donations,donation allowed]
*   MP.BPTCBEN      (i)  Maximum New Brunswick political tax credit allowed
*   MP.BPTCrows     (i)  number of rows in BPTC
*   MP.BPTF         (i)  New Brunswick provincial tax fraction
*   MP.BPTX         (i)  N.B. tax table [taxable income,basic provincial tax]
*   MP.BPTXrows     (i)  number of rows in BPTX
*   MP.BSCI         (i)  New Brunswick provincial tax above which surtax applies
*   MP.BSF          (i)  New Brunswick provincial surtax rate
*   MP.BTRBAS       (i)  Base N.B. low income tax reduction
*   MP.BTRRR        (i)  N.B. low income tax reduction Reduction Rate
*   MP.BTRSP        (i)  N.B. low income tax reduction for spouse or equivalent-to-spouse
*   MP.BTRTD        (i)  N.B. low income tax reduction Turndown
*   MP.BTXFLG       (i)  N.B. tax on taxable income activation flag
*   MP.BYPNDL       (i)  N.B. Pension Income Deduction Amount
*   MP.CGTC         (i)  Caregiver Tax Credit
*   MP.CGTCFLG      (i)  Caregiver Tax Credit activation flag
*   MP.CGTCOPT      (i)  Caregiver Tax Credit option (1=max, 2=greenbook)
*   MP.CHATL1       (i)  Charitable donations amount level 1
*   MP.CHATNF       (i)  Charitable donations maximum net income fraction
*   MP.CHATR1       (i)  Charitable donations tax credit rate 1
*   MP.CHATR2       (i)  Charitable donations tax credit rate 2
*   MP.CTCAMTPC     (i)  Child Tax Credit amount per child
*   MP.CTNUMREG     (i)  number of rows in region dimension parms
*   MP.EDDISPT      (i)  Part time students with disabilities flag
*   MP.EDXPM        (i)  Education amount per month of full-time studies
*   MP.EDXPMPT      (i)  Education amount per month of part-time studies
*   MP.EMPTXC       (i)  Canada Employment Credit
*   MP.FDTCR        (i)  Federal dividend tax credit rate
*   MP.FDTCRLC      (i)  Federal dividend tax credit rate from large (eligible) corporations
*   MP.FLVCMAX      (i)  Maximum labour-sponsored funds tax credit allowed
*   MP.FLVCRT       (i)  Percent of labour-sponsored funds cost allowed as credit [prov]
*   MP.FNTCR        (i)  Federal non-refundable tax credit rate
*   MP.FPTC         (i)  Federal political contribution table [total donations,donation allowed]
*   MP.FPTCBEN      (i)  Maximum federal political tax credit allowed
*   MP.FPTCrows     (i)  number of rows in FPTC
*   MP.FSURL1       (i)  Federal surtax level 1
*   MP.FSURL2       (i)  Federal surtax level 2
*   MP.FSURR1       (i)  Federal surtax rate 1
*   MP.FSURR2       (i)  Federal surtax rate 2
*   MP.FSURTRMX     (i)  Maximum federal surtax reduction
*   MP.FSURTRRL     (i)  Federal surtax reduction reduction level
*   MP.FSURTRRR     (i)  Federal surtax reduction reduction rate
*   MP.FTX          (i)  Federal tax table [taxable income,basic federal tax]
*   MP.FTXrows      (i)  number of rows in FTX
*   MP.IMSHTOPT     (i)  Paid rent and property tax imputation option
*   MP.INTSLFLG     (i)  Interest on Student Loans Tax Credit Activation Flag
*   MP.MAXDX        (i)  Maximum disability deduction/amount
*   MP.MAXET        (i)  Maximum on transfer of education and tuition amount
*   MP.MEDALL       (i)  Medical allowance maximum lower limit
*   MP.MEDANF       (i)  Medical allowance lower limit net income fraction
*   MP.NAMTOPT      (i)  NFLD alternative minimum tax option
*   MP.NAMTPCTF     (i)  NFLD amt rate as pct of additional fed tax due to minimum tax
*   MP.NAMTPCTM     (i)  NFLD amt rate as pct of federal minimum tax amount
*   MP.NAMTTX       (i)  NFLD amt rate as tax on adjusted income
*   MP.NAXM         (i)  NFLD Age Amount
*   MP.NAXRR        (i)  NFLD Age Amount credit reduction rate
*   MP.NAXTD        (i)  NFLD Age Amount net income turndown
*   MP.NBXM         (i)  NFLD Basic Personal Exemption/amount
*   MP.NCGTC        (i)  NFLD Caregiver Tax Credit
*   MP.NCGTCFLG     (i)  NFLD Caregiver Tax Credit activation flag
*   MP.NCGTCOPT     (i)  NFLD Caregiver Tax Credit Option (1=max, 2=greenbook)
*   MP.NCHATL1      (i)  NFLD Charitable Donations amount level 1
*   MP.NCHATR1      (i)  NFLD Charitable Donations tax credit rate 1
*   MP.NCHATR2      (i)  NFLD Charitable Donations tax credit rate 2
*   MP.NDTCR        (i)  NFLD dividend tax credit rate
*   MP.NDTCRLC      (i)  NFLD dividend tax credit rate from large (eligible) corporations
*   MP.NEDXPM       (i)  NFLD Education Amount per month of full-time studies
*   MP.NEDXPMPT     (i)  NFLD Education Amount per month of part-time studies
*   MP.NEMXM        (i)  NFLD equivalent to married amount
*   MP.NEMXMT       (i)  NFLD equivalent to married turndown level
*   MP.NLITRF       (i)  NFLD low income tax reduction family maximum
*   MP.NLITRFIT     (i)  NFLD low income tax reduction family income threshold
*   MP.NLITRRR      (i)  NFLD low income tax reduction credit reduction rate
*   MP.NLITRS       (i)  NFLD low income tax reduction single maximum
*   MP.NLITRSIT     (i)  NFLD low income tax reduction single income threshold
*   MP.NLVCMAX      (i)  Maximum NFLD labour-sponsored funds tax credit allowed
*   MP.NLVCRT       (i)  Percent of NFLD labour-sponsored funds cost allowed as credit
*   MP.NMAXDX       (i)  NFLD Maximum Disability deduction/amount
*   MP.NMAXET       (i)  NFLD maximum on transfer of education and tuition amount
*   MP.NMEDALL      (i)  NFLD Medical allowance maximum lower limit
*   MP.NMEDANF      (i)  NFLD Medical allowance lower limit net income fraction
*   MP.NMXM         (i)  NFLD married amount
*   MP.NMXMT        (i)  NFLD married amount turndown level
*   MP.NODISTC      (i)  NFLD Maximum infirm dependent 18 or older tax credit
*   MP.NPNTCR       (i)  NFLD provincial non-refundable tax credit rate
*   MP.NPTC         (i)  Newfoundland political contribution table [total donations,donation allowed]
*   MP.NPTCBEN      (i)  Maximum Newfoundland political tax credit allowed
*   MP.NPTCrows     (i)  number of rows in NPTC
*   MP.NPTF         (i)  Newfoundland provincial tax fraction
*   MP.NPTX         (i)  NFLD tax table [taxable income,basic provincial tax]
*   MP.NPTXrows     (i)  number of rows in NPTX
*   MP.NSCI         (i)  Newfoundland provincial tax above which surtax applies
*   MP.NSCI2        (i)  Newfoundland provincial surtax level 2
*   MP.NSF          (i)  Newfoundland provincial surtax rate
*   MP.NSF2         (i)  Newfoundland provincial surtax rate 2
*   MP.NSTCA        (i)  NFLD sales tax credit amount for adults
*   MP.NSTCC        (i)  NFLD sales tax credit amount for children
*   MP.NSTCFLAG     (i)  NFLD sales tax credit activation flag
*   MP.NSTCL        (i)  NFLD sales tax credit reduction level
*   MP.NSTCR        (i)  NFLD sales tax credit reduction rate
*   MP.NTXFLG       (i)  NFLD tax on taxable income activation flag
*   MP.NYPNDL       (i)  NFLD Pension Income Deduction Amount
*   MP.ODISTC       (i)  Maximum infirm dependent 18 or older tax credit
*   MP.PAMTOPT      (i)  P.E.I. alternative minimum tax option
*   MP.PAMTPCTF     (i)  P.E.I. amt rate as pct of additional fed tax due to minimum tax
*   MP.PAMTPCTM     (i)  P.E.I. amt rate as pct of federal minimum tax amount
*   MP.PAMTTX       (i)  P.E.I. amt rate as tax on adjusted income
*   MP.PAXM         (i)  P.E.I. Age Amount
*   MP.PAXRR        (i)  P.E.I. Age Amount credit reduction rate
*   MP.PAXTD        (i)  P.E.I. Age Amount net income turndown
*   MP.PBXM         (i)  P.E.I. Basic Personal Exemption/amount
*   MP.PCGTC        (i)  P.E.I. Caregiver Tax Credit
*   MP.PCGTCFLG     (i)  P.E.I. Caregiver Tax Credit activation flag
*   MP.PCGTCOPT     (i)  P.E.I. Caregiver Tax Credit Option (1=max, 2=greenbook)
*   MP.PCHATL1      (i)  P.E.I. Charitable Donations amount level 1
*   MP.PCHATR1      (i)  P.E.I. Charitable Donations tax credit rate 1
*   MP.PCHATR2      (i)  P.E.I. Charitable Donations tax credit rate 2
*   MP.PDTCR        (i)  P.E.I. dividend tax credit rate
*   MP.PDTCRLC      (i)  P.E.I. dividend tax credit rate from large (eligible) corporations
*   MP.PEDXPM       (i)  P.E.I. Education Amount per month of full-time studies
*   MP.PEDXPMPT     (i)  P.E.I. Education Amount per month of part-time studies
*   MP.PEMXM        (i)  P.E.I. equivalent to married amount
*   MP.PEMXMT       (i)  P.E.I. equivalent to married turndown level
*   MP.PLVCMAX      (i)  Maximum P.E.I. labour-sponsored funds tax credit allowed
*   MP.PLVCRT       (i)  Percent of P.E.I. labour-sponsored funds cost allowed as credit
*   MP.PMAXDX       (i)  P.E.I. Maximum Disability deduction/amount
*   MP.PMAXET       (i)  P.E.I. maximum on transfer of education and tuition amount
*   MP.PMEDALL      (i)  P.E.I. Medical allowance maximum lower limit
*   MP.PMEDANF      (i)  P.E.I. Medical allowance lower limit net income fraction
*   MP.PMXM         (i)  P.E.I. married amount
*   MP.PMXMT        (i)  P.E.I. married amount turndown level
*   MP.PODISTC      (i)  P.E.I. Maximum infirm dependent 18 or older tax credit
*   MP.PPNTCR       (i)  P.E.I. provincial non-refundable tax credit rate
*   MP.PPTC         (i)  P.E.I. political contribution table [total donations,donation allowed]
*   MP.PPTCBEN      (i)  Maximum P.E.I. political tax credit allowed
*   MP.PPTCrows     (i)  number of rows in PPTC
*   MP.PPTF         (i)  P.E.I. provincial tax fraction
*   MP.PPTX         (i)  P.E.I. tax table [taxable income,basic provincial tax]
*   MP.PPTXrows     (i)  number of rows in PPTX
*   MP.PSCI         (i)  P.E.I. provincial tax above which surtax applies
*   MP.PSF          (i)  P.E.I. provincial surtax rate
*   MP.PTRBAS       (i)  Base PEI low income tax reduction
*   MP.PTRKID       (i)  PEI low income tax reduction for dependent child
*   MP.PTRRR        (i)  PEI low income tax reduction Reduction Rate
*   MP.PTRSP        (i)  PEI low income tax reduction for spouse or equivalent-to-spouse
*   MP.PTRTD        (i)  PEI low income tax reduction Turndown
*   MP.PTXFLG       (i)  P.E.I. tax on taxable income activation flag
*   MP.PYCTCAPM     (i)  P.E.I. Young Child Tax Credit Amount per Month
*   MP.PYCTCPI      (i)  P.E.I. Young Child Tax Credit Phase in
*   MP.PYPNDL       (i)  P.E.I. Pension Income Deduction Amount
*   MP.QALEXP       (i)  Quebec proportion of other allowable employment expenses to use
*   MP.QAMTCAPR     (i)  Quebec Alternative Minimum Tax Capital inclusion rate
*   MP.QAMTCBX      (i)  Quebec Alternative Minimum Tax Calculate Basic Exemption
*   MP.QAMTDIV      (i)  Quebec Alternative Minimum Tax Taxable Dividend Limit
*   MP.QAMTNEGTI    (i)  Quebec Alternative Minimum Tax Allow Negative Taxable Income
*   MP.QAMTRITC     (i)  Quebec Alternative Minimum Tax Retirement Income Credit Deduction
*   MP.QAMTRPFLG    (i)  RRSP/RPP included in Quebec Alternative Minimum Tax (1=include)
*   MP.QAMTSTTC     (i)  Quebec Alternative Minimum Tax Spouse Transfer of Tax Credits Flag
*   MP.QAMTTX       (i)  QAMTX tax rate
*   MP.QAMTX        (i)  QAMTX exemption level
*   MP.QAMTXFLG     (i)  Quebec alternative minimum tax, QAMTX, activation flag
*   MP.QAMTXREF     (i)  Quebec alternative minimum tax 1995 reform indicator (flag)
*   MP.QAMTXSTKFLG  (i)  QAMTX stock option deduction inclusion (1=stk can be deducted)
*   MP.QAPFFLG      (i)  Quebec anti-poverty fund activation flag
*   MP.QAPFRAT      (i)  Quebec anti-poverty fund rate
*   MP.QAXM         (i)  Quebec age exemption/amount
*   MP.QAXPI        (i)  Quebec age exemption reduction phase in
*   MP.QAXRR        (i)  Quebec age exemption reduction rate
*   MP.QAXTD        (i)  Quebec age exemption income turn down
*   MP.QBXM         (i)  Quebec basic personal exemption/amount
*   MP.QCAFLAG      (i)  Quebec Child Assistance refundable tax credit flag
*   MP.QCALRFLG     (i)  Quebec combined age, living alone retirement credit
*   MP.QCAMAX       (i)  Quebec Child Assistance Maximum [number of children]
*   MP.QCAMAXrows   (i)  number of rows in QCAMAX
*   MP.QCAMIN       (i)  Quebec Child Assistance Minimum [number of children]
*   MP.QCAMINrows   (i)  number of rows in QCAMIN
*   MP.QCAPAMTX     (i)  QAMTX taxable capital ratio
*   MP.QCAPGIR      (i)  Quebec capital gains inclusion rate
*   MP.QCARR        (i)  Quebec Child Assistance Reduction Rate
*   MP.QCASPMAX     (i)  Quebec Child Assistance Maximum Single Parent additional credit
*   MP.QCASPMIN     (i)  Quebec Child Assistance Minimum Single Parent additional credit
*   MP.QCATDC       (i)  Quebec Child Assistance Income Turndown for couples
*   MP.QCATDS       (i)  Quebec Child Assistance Income Turndown for single parents
*   MP.QCCEAOLD     (i)  Quebec CCEA old child limit
*   MP.QCCEAYNG     (i)  Quebec CCEA young child limit
*   MP.QCCEEIFLG    (i)  Quebec Refundable CCE EI Benefits in Earned Income flag
*   MP.QCCEEITST    (i)  Quebec Refundable CCE Earned Income Test flag
*   MP.QCCEOPT      (i)  Quebec CCE calculation option [1=deduction,2=refundable credit]
*   MP.QCCETCR      (i)  Refundable CCE credit rate [net income, % cce claimable]
*   MP.QCCETCRrows  (i)  number of rows in QCCETCR
*   MP.QCHATNF      (i)  Quebec charitable donations maximum % net income
*   MP.QCMPOPT      (i)  Quebec Complementary Credit option
*   MP.QCPPOPT      (i)  Quebec CPP/QPP contribution deduction/credit option [1=deduction,2=credit]
*   MP.QCRDFLG      (i)  Quebec income credit flag [1=if social contribution are deducted]
*   MP.QDGUR        (i)  Quebec dividend gross-up rate
*   MP.QDGURLC      (i)  Quebec dividend gross-up rate from large (eligible) corporations
*   MP.QDTCNCA1     (i)  Quebec Dependent Tax Credit Amount for first dependent without child assistance
*   MP.QDTCNCA2     (i)  Quebec Dependent Tax Credit Amount for other dependents without child assistance
*   MP.QDTCR        (i)  Quebec dividend tax credit rate
*   MP.QDTCRLC      (i)  Quebec dividend tax credit rate from large (eligible) corporations
*   MP.QDTCSPA      (i)  Quebec Dependent Tax Credit Single Parent Amount (no child assistance)
*   MP.QDUESOPT     (i)  Quebec Dues Tax Credit option
*   MP.QEAMAX       (i)  Quebec maximum employment allowance deduction
*   MP.QEAP         (i)  Proportion of earnings for Quebec employment allowance deduction
*   MP.QEEXPDED     (i)  Quebec employment expenses deduction application flag
*   MP.QEIA1        (i)  Quebec eligible income family type #1
*   MP.QEIA2        (i)  Quebec eligible income family type #2
*   MP.QEIA3        (i)  Quebec eligible income family type #3
*   MP.QEIA4        (i)  Quebec eligible income family type #4
*   MP.QEIA5        (i)  Quebec eligible income family type #5
*   MP.QEIAA        (i)  Quebec eligible income aged amount
*   MP.QEMPDEDM     (i)  Quebec earned income deduction for workers maximum
*   MP.QEMPDEDP     (i)  Quebec earned income deduction percent of income
*   MP.QESSNEEDS    (i)  Quebec essential needs for transfer of parental contributions
*   MP.QFAMDED      (i)  Quebec Family related deduction on income in refundable credits
*   MP.QFAMFLG      (i)  Quebec family income deduction activation flag
*   MP.QFAMNETI     (i)  Quebec family allowance tax credit net income concept flag
*   MP.QFAMRAT      (i)  Quebec family income rate
*   MP.QFATCHIRR    (i)  QFATC High income reduction rate
*   MP.QFATCHITD    (i)  QFATC High income turndown
*   MP.QFATCK6      (i)  QFATC Supplement for kids under 6 in large families [#kids][#kids<6]
*   MP.QFATCK6PYR   (i)  QFATC supplement for kids under 6 phase out year proportion
*   MP.QFATCK6YR    (i)  QFATC Supplement for kids under 6 phase out year
*   MP.QFATCK6rows  (i)  number of rows in QFATCK6
*   MP.QFATCMIN     (i)  QFATC minimum benefit paid
*   MP.QFATCMNK     (i)  QFATC Minimum benefits by kid rank
*   MP.QFATCMNKrows (i)  number of rows in QFATCMNK
*   MP.QFATCMRR     (i)  QFATC turn down income levels and reduction rate for married parents
*   MP.QFATCMRRrows (i)  number of rows in QFATCMRR
*   MP.QFATCMXK     (i)  QFATC Maximum benefits by kid rank
*   MP.QFATCMXKrows (i)  number of rows in QFATCMXK
*   MP.QFATCOPT     (i)  Quebec Family Allowance Tax Credit Option
*   MP.QFATCSRR     (i)  QFATC turn down income levels and reduction rate for single parent
*   MP.QFATCSRRrows (i)  number of rows in QFATCSRR
*   MP.QFATCSUP     (i)  Quebec Family Allowance Tax Credit Supplement for single parent
*   MP.QFATCTK      (i)  QFATC Take-up rates by total income
*   MP.QFATCTKrows  (i)  number of rows in QFATCTK
*   MP.QFATD4K      (i)  QFATC turn down income for 4 children and more
*   MP.QFATD4KI     (i)  QFATC turn down income increase by child for 4 children and more
*   MP.QFTRA1       (i)  Quebec family tax reduction family type #1
*   MP.QFTRA2       (i)  Quebec family tax reduction family type #2
*   MP.QFTRA3       (i)  Quebec family tax reduction family type #3
*   MP.QFTRA4       (i)  Quebec family tax reduction family type #4
*   MP.QFTRFLAG     (i)  Quebec family tax reduction activation flag
*   MP.QFTRRR       (i)  Quebec family tax reduction reduction rate
*   MP.QGFTCR       (i)  Quebec credit rate for gifts over upper limit
*   MP.QGIFTFLG     (i)  Quebec max to gifts to Federal/Province/Crown activation flag
*   MP.QGIFTHCR     (i)  Quebec higher tax credit on large gifts activation flag
*   MP.QGIFTL1      (i)  Quebec minimum gift limit subject to higher credit rate
*   MP.QGIFTOPT     (i)  Quebec gifts as tax credit
*   MP.QHPTC        (i)  Quebec Housing Parent Tax Credit
*   MP.QHPTCFLG     (i)  Quebec Housing Parent Tax Credit activation flag
*   MP.QHPTCOPT     (i)  Quebec Housing Parent Tax Credit Calculation option
*   MP.QHSC         (i)  Quebec Health Services Fund Contribution table
*   MP.QHSCFLAG     (i)  Quebec Health Services Fund Contribution calculation flag
*   MP.QHSCI        (i)  Quebec surtax first cut-in level
*   MP.QHSCI2       (i)  Quebec surtax second cut-in level
*   MP.QHSCrows     (i)  number of rows in QHSC
*   MP.QHSF         (i)  Quebec surtax first level rate
*   MP.QHSF2        (i)  Quebec surtax second level rate
*   MP.QHSOASFG     (i)  Quebec Health Services Fund Contribution OAS Deduction flag
*   MP.QHSSFALM     (i)  Quebec Health Services Fund Contrib. Alimony Paid Deduction flag
*   MP.QHSSFCAR     (i)  Quebec Health Services Fund Contrib. Carrying Charges Deduction flag
*   MP.QHSSFLSS     (i)  Quebec Health Services Fund Contrib. Allowable Losses Deduction flag
*   MP.QHSSFUIR     (i)  Quebec Health Services Fund Contrib. UI/EI Repayment Deduction flag
*   MP.QINTSLTC     (i)  Quebec student loan interest tax credit flag
*   MP.QITSFSEW     (i)  Quebec improved tax system for self-employed worker activation flag
*   MP.QITSSEF      (i)  Quebec percentage of self-employ CPP/QPP contributions to convert to deduction
*   MP.QLAXM        (i)  Quebec living alone exemption/amount
*   MP.QLAXOLDDEP   (i)  Quebec living alone amount if all dependents 18 or over
*   MP.QLAXPI       (i)  Quebec living alone phase-in
*   MP.QLAXRR       (i)  Quebec living alone reduction rate
*   MP.QLAXTD       (i)  Quebec living alone turn down
*   MP.QLPXM        (i)  Quebec lone parent exemption/amount
*   MP.QLVCMAX      (i)  Maximum Quebec labour-sponsored funds tax credit allowed
*   MP.QLVCRT       (i)  Percent of Quebec labour-sponsored funds cost allowed as credit
*   MP.QMAXDX       (i)  Quebec maximum disability deduction/amount
*   MP.QMEDALL      (i)  Quebec medical allowance maximum lower limit
*   MP.QMEDANF      (i)  Quebec medical allowance lower limit net income fraction
*   MP.QMEDINC      (i)  Income definition for Que. refundable tax credit for medical expenses
*   MP.QMEDOPT      (i)  Quebec Medical Tax Credit option
*   MP.QMEDRATE     (i)  Proportion of expenses allowed for refundable tax credit for medical expenses
*   MP.QMEDRMAX     (i)  Maximum expenses allowed for Que. refundable tax credit for medical expenses
*   MP.QMEDRMIN     (i)  Minimum earnings for Quebec refundable tax credit for medical expenses
*   MP.QMEDRRR      (i)  Reduction rate for the Que. refundable tax credit for medical expenses
*   MP.QMEDRTD      (i)  Turndown level for Que. refundable tax credit for medical expenses
*   MP.QMRTCFLG     (i)  Quebec refundable tax credits for medical expenses activation flag
*   MP.QMXM         (i)  Quebec married exemption/amount
*   MP.QNFSDED      (i)  Quebec deduction of net federal supplements (SPA and GIS) from net income flag
*   MP.QNORFAMI     (i)  Quebec Northern Deductions from Family Tax Credit Income flag
*   MP.QNORTHDED    (i)  Quebec northern deductions - 0=for taxable income, 1=for net income
*   MP.QNTCR        (i)  Quebec nominal tax credit rate
*   MP.QODISTC      (i)  Quebec infirm dependent amount (18 and over)
*   MP.QPCOPT       (i)  Quebec political contribution option
*   MP.QPCTR        (i)  Quebec political contribution tax rates
*   MP.QPCTRrows    (i)  number of rows in QPCTR
*   MP.QPENSPLTINCR (i)  Quebec increment by which to split pension income
*   MP.QPSXM        (i)  Quebec post-secondary exemption/amount
*   MP.QPSXMINC     (i)  Quebec income ratio for post-secondary exemption/amount
*   MP.QPTC         (i)  Quebec political contribution table [total donations,donation allowed]
*   MP.QPTCBEN      (i)  Maximum Quebec political tax credit allowed
*   MP.QPTRGISB     (i)  Quebec property tax rebate GIS bonus
*   MP.QPTRMTP      (i)  Quebec property tax minimum tax per person
*   MP.QPTRMTR      (i)  Quebec property tax maximum tax for reduction
*   MP.QPTRRR       (i)  Quebec property tax rebate reduction rate
*   MP.QPTRTF       (i)  Quebec property tax fraction
*   MP.QREPFAMI     (i)  Quebec repayment of UI/OAS benefits deduct from income flag
*   MP.QREPNETFG    (i)  Social program repayments reduce Quebec net income flag
*   MP.QRNCGFLG     (i)  Quebec Natural Caregivers Tax Credit activation flag
*   MP.QRNCGTC      (i)  Quebec Natural Caregivers Tax Credit
*   MP.QRTRFLAG     (i)  Quebec real estate rebate activation flag
*   MP.QSADED       (i)  Quebec deduction of social assistance benefits from net income flag
*   MP.QSFDED       (i)  Quebec Simplified Form - additional deductions for net income calculation flag
*   MP.QSFDISFLAG   (i)  Quebec Simplified Form Disability tax credit inclusion flag
*   MP.QSFMEDFLAG   (i)  Quebec Simplified Form medical expense tax credit inclusion flag
*   MP.QSFOPT       (i)  Quebec Simplified Form Option (1=general 2=simplified 3=optimized)
*   MP.QSFSMXI      (i)  Quebec simplified form spouse maximum income for work sheet
*   MP.QSFTC        (i)  Quebec Simplified Form tax credit
*   MP.QSFTXCR      (i)  Quebec Simplified Form - transfer unused credits to spouse under either tax system
*   MP.QSPBFLAG     (i)  Quebec inclusion of social program benefits in income flag
*   MP.QSPLTPNSFLAG (i)  Quebec flag to split pension income
*   MP.QSTRBCRD     (i)  Quebec sales tax rebate base credit
*   MP.QSTRCHILD    (i)  Quebec sales tax rebate children dependent credit
*   MP.QSTREXT      (i)  Quebec sales tax rebate extra amount
*   MP.QSTRFLAG     (i)  Quebec sales tax rebate activation flag
*   MP.QSTRFTP3     (i)  Quebec sales tax rebate family type 3 credit
*   MP.QSTRFTP4     (i)  Quebec sales tax rebate family type 4 credit
*   MP.QSTRMAGE     (i)  Quebec sales tax rebate minimum age flag
*   MP.QSTRRR       (i)  Quebec sales tax rebate reduction rate
*   MP.QSTSCA       (i)  Quebec Single Tax System Complementary Amount
*   MP.QTAP         (i)  Quebec tax abatement proportion of basic federal tax
*   MP.QTPCFLG      (i)  Quebec transfer of recognized parental contribution to education activation flag
*   MP.QTRBE        (i)  Quebec Tax Reduction Breakeven
*   MP.QTROPT       (i)  Quebec Tax Reduction calculation option 1=universal 2=income tested
*   MP.QTRP         (i)  Quebec tax Reduction proportion
*   MP.QTRSAFAM     (i)  Quebec Social Assistance Included in Family Tax Credit Income flag
*   MP.QTRWCFAM     (i)  Quebec Workers Compensation Included in Family Tax Credit Income flag
*   MP.QTUIOPT      (i)  Quebec tuition tax credit option
*   MP.QTUITRFFLG   (i)  Quebec flag to allow transfer of tuition tax credit to parents
*   MP.QTX          (i)  Quebec income tax table [taxable income,basic provincial tax]
*   MP.QTXrows      (i)  number of rows in QTX
*   MP.QUICOPT      (i)  Quebec UI contributions deduction/credit option [1=deduction,2=credit]
*   MP.QWPCR        (i)  Quebec Work Premium Credit Rate [family type]
*   MP.QWPCRrows    (i)  number of rows in QWPCR
*   MP.QWPEIPI      (i)  Quebec Work Premium Employment Income Phase In [family type]
*   MP.QWPEIPIrows  (i)  number of rows in QWPEIPI
*   MP.QWPFLAG      (i)  Quebec Work Premium refundable tax credit flag
*   MP.QWPMAX       (i)  Quebec Work Premium Maximum [family type]
*   MP.QWPMAXrows   (i)  number of rows in QWPMAX
*   MP.QWPRR        (i)  Quebec Work Premium Reduction Rate
*   MP.QWPTD        (i)  Quebec Work Premium Income Turndown [family type]
*   MP.QWPTDrows    (i)  number of rows in QWPTD
*   MP.QYCXM1       (i)  Quebec dependent child #1 amount
*   MP.QYCXM2       (i)  Quebec dependent child #2 amount
*   MP.QYPDL        (i)  Quebec deduction limit for pension income
*   MP.QYPPI        (i)  Quebec deduction phase-in for pension income
*   MP.QYPRR        (i)  Quebec deduction reduction rate for pension income
*   MP.QYPTD        (i)  Quebec deduction turn down for pension income
*   MP.TEXTPMFT     (i)  Textbook amount per month of full-time studies
*   MP.TEXTPMPT     (i)  Textbook amount per month of part-time studies
*   MP.VAMTOPT      (i)  N.S. alternative minimum tax option
*   MP.VAMTPCTF     (i)  N.S. amt rate as pct of additional fed tax due to minimum tax
*   MP.VAMTPCTM     (i)  N.S. amt rate as pct of federal minimum tax amount
*   MP.VAMTTX       (i)  N.S. amt rate as tax on adjusted income
*   MP.VAXM         (i)  N.S. Age Amount
*   MP.VAXRR        (i)  N.S. Age Amount credit reduction rate
*   MP.VAXTD        (i)  N.S. Age Amount net income turndown
*   MP.VBXM         (i)  N.S. Basic Personal Exemption/amount
*   MP.VCGTC        (i)  N.S. Caregiver Tax Credit
*   MP.VCGTCFLG     (i)  N.S. Caregiver Tax Credit activation flag
*   MP.VCGTCOPT     (i)  N.S. Caregiver Tax Credit Option (1=max, 2=greenbook)
*   MP.VCHATL1      (i)  N.S. Charitable Donations amount level 1
*   MP.VCHATR1      (i)  N.S. Charitable Donations tax credit rate 1
*   MP.VCHATR2      (i)  N.S. Charitable Donations tax credit rate 2
*   MP.VDTCR        (i)  N.S. dividend tax credit rate
*   MP.VDTCRLC      (i)  N.S. dividend tax credit rate from large (eligible) corporations
*   MP.VEDXPM       (i)  N.S. Education Amount per month of full-time studies
*   MP.VEDXPMPT     (i)  N.S. Education Amount per month of part-time studies
*   MP.VEMXM        (i)  N.S. equivalent to married amount
*   MP.VEMXMT       (i)  N.S. equivalent to married turndown level
*   MP.VLVCMAX      (i)  Maximum N.S. labour-sponsored funds tax credit allowed
*   MP.VLVCRT       (i)  Percent of N.S. labour-sponsored funds cost allowed as credit
*   MP.VMAXDX       (i)  N.S. Maximum Disability deduction/amount
*   MP.VMAXET       (i)  N.S. maximum on transfer of education and tuition amount
*   MP.VMEDALL      (i)  N.S. Medical allowance maximum lower limit
*   MP.VMEDANF      (i)  N.S. Medical allowance lower limit net income fraction
*   MP.VMXM         (i)  N.S. married amount
*   MP.VMXMT        (i)  N.S. married amount turndown level
*   MP.VODISTC      (i)  N.S. Maximum infirm dependent 18 or older tax credit
*   MP.VPHOPT       (i)  Nova Scotia pharmacare premium option (1=GIS, 2=income)
*   MP.VPHPREM      (i)  Nova Scotia pharmacare premium
*   MP.VPHRR        (i)  Nova Scotia pharmacare tax credit reduction rate
*   MP.VPHTC        (i)  Nova Scotia pharmacare refundable tax credit
*   MP.VPHTD        (i)  Nova Scotia pharmacare tax credit turndown
*   MP.VPHTDC       (i)  Nova Scotia pharmacare tax credit turndown for couples
*   MP.VPNTCR       (i)  N.S. provincial non-refundable tax credit rate
*   MP.VPTC         (i)  Nova Scotia political contribution table [total donations,donation allowed]
*   MP.VPTCBEN      (i)  Maximum Nova Scotia political tax credit allowed
*   MP.VPTCrows     (i)  number of rows in VPTC
*   MP.VPTF         (i)  Nova Scotia provincial tax fraction
*   MP.VPTX         (i)  N.S. tax table [taxable income,basic provincial tax]
*   MP.VPTXrows     (i)  number of rows in VPTX
*   MP.VSCI         (i)  Nova Scotia provincial tax above which surtax applies
*   MP.VSCI2        (i)  Nova Scotia provincial tax above which surtax applies (2nd level)
*   MP.VSF          (i)  Nova Scotia provincial surtax rate
*   MP.VSF2         (i)  Nova Scotia provincial surtax rate (2nd level)
*   MP.VTRBAS       (i)  Nova Scotia tax reduction basic amount
*   MP.VTREM        (i)  Nova Scotia tax reduction equivalent to spouse amount
*   MP.VTRKID       (i)  Nova Scotia tax reduction child amount
*   MP.VTRRR        (i)  Nova Scotia tax reduction family income reduction rate
*   MP.VTRSP        (i)  Nova Scotia tax reduction spouse amount
*   MP.VTRTD        (i)  Nova Scotia tax reduction family income turndown
*   MP.VTXFLG       (i)  N.S. tax on taxable income activation flag
*   MP.VYCTCAPM     (i)  N.S. Young Child Tax Credit Amount per Month
*   MP.VYCTCPI      (i)  N.S. Young Child Tax Credit Phase in
*   MP.VYPNDL       (i)  N.S. Pension Income Deduction Amount
*   MP.YPNDL        (i)  Maximum pension income deduction/amount
*
*Called by:
*   mpd      Tax/transfer model parameter definitions
*
*****************************************************************************/
void mpd3(
	P_pc pcp
)
{
	DEBUG_ON("mpd3");

	/*          Other Deductions from Net Income */
	pmaddent(pcp, "2.3.4.3",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);

	/*               Pension Income Tax Credit */
	pmaddent(pcp, "2.3.4.3.1",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "YPNDL",    (char *)&MP.YPNDL,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);

	/*               Medical Expense Tax Credit */
	pmaddent(pcp, "2.3.4.3.2",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
   pmaddent(pcp, "MEDANF",  (char *)&MP.MEDANF,    F_FRACT,   P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "MEDALL",  (char *)&MP.MEDALL,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);

	/*               Charitable Donation Deduction / Tax Credit */
	pmaddent(pcp, "2.3.4.3.3",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
   pmaddent(pcp, "CHATNF",  (char *)&MP.CHATNF,    F_FRACT,   P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
   pmaddent(pcp, "CHATL1",  (char *)&MP.CHATL1,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
   pmaddent(pcp, "CHATR1",  (char *)&MP.CHATR1,    F_FRACT,   P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "CHATR2",  (char *)&MP.CHATR2,    F_FRACT,   P_SCL, C_NUM, E_FRCT, 0, NULL, 0);

	/*               Disability Tax Credit */
	pmaddent(pcp, "2.3.4.3.4",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "MAXDX",   (char *)&MP.MAXDX,      NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "ODISTC",  (char *)&MP.ODISTC,     NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);

	/*               Education Deduction / Tax Credit */
	pmaddent(pcp, "2.3.4.3.5",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "EDXPM",   (char *)&MP.EDXPM,     NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "EDXPMPT", (char *)&MP.EDXPMPT,    NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "MAXET",   (char *)&MP.MAXET,      NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "EDDISPT", (char *)&MP.EDDISPT,   NULL,    P_SCL, C_INT, E_FLAG, 0, NULL, 0);

	/*               Textbook Tax Credit */
	pmaddent(pcp, "2.3.4.3.6",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "TEXTPMFT", (char *)&MP.TEXTPMFT,    NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "TEXTPMPT", (char *)&MP.TEXTPMPT,    NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);

	/*               Caregiver Tax Credit */
	pmaddent(pcp, "2.3.4.3.7",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "CGTC",    (char *)&MP.CGTC,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);				  
	pmaddent(pcp, "CGTCFLG", (char *)&MP.CGTCFLG,   NULL,    P_SCL, C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "CGTCOPT", (char *)&MP.CGTCOPT,   NULL,    P_SCL, C_INT, E_OPT, 2, NULL, 0);

	/*          Interest on Student Loans Tax Credit */
	pmaddent(pcp, "2.3.4.3.8",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "INTSLFLG", (char *)&MP.INTSLFLG,   NULL,    P_SCL, C_INT, E_FLAG, 0, NULL, 0);
	
	/*          Canada Employment Credit */
	pmaddent(pcp, "2.3.4.3.9",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "EMPTXC", (char *)&MP.EMPTXC,   NULL,    P_SCL, C_NUM, 0,        0, NULL, 0);
	
	/*          Child Tax Credit */
	pmaddent(pcp, "2.3.4.3.10",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "CTCAMTPC", (char *)&MP.CTCAMTPC,    NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);

	/*          Federal Taxes */
	pmaddent(pcp, "2.3.4.4",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);

	/*               Basic Federal Tax */
	pmaddent(pcp, "2.3.4.4.1",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "FTX",     (char *)&MP.FTX[0][0],  "8.0 10.4 10.6",     P_LKPSL, C_NUM, 0,    FTXMAX, &MP.FTXrows, 0);
	pmaddent(pcp, "FNTCR",   (char *)&MP.FNTCR,      F_FRACT,     P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "FDTCR",   (char *)&MP.FDTCR,      F_FRACT,  P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FDTCRLC", (char *)&MP.FDTCRLC,    F_FRACT,  P_SCL, C_NUM, 0,      0, NULL, 0);

	/*               Federal Surtax */
	pmaddent(pcp, "2.3.4.4.2",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "FSURL1",  (char *)&MP.FSURL1,     NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FSURR1",  (char *)&MP.FSURR1,     F_FRACT,  P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FSURL2",  (char *)&MP.FSURL2,     NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FSURR2",  (char *)&MP.FSURR2,     F_FRACT,  P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FSURTRMX",  (char *)&MP.FSURTRMX, NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FSURTRRR",  (char *)&MP.FSURTRRR, F_FRACT,  P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "FSURTRRL",  (char *)&MP.FSURTRRL, NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);

	/*               Federal Political Contribution Tax Credit */
	pmaddent(pcp, "2.3.4.4.3",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "FPTC",    (char *)&MP.FPTC[0][0], NULL,     P_LKPSL, C_NUM, 0,    FPTCMAX, &MP.FPTCrows, 0);
	pmaddent(pcp, "FPTCBEN", (char *)&MP.FPTCBEN,    NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);

	/*               Federal Labour-sponsored Funds Tax Credit */
	pmaddent(pcp, "2.3.4.4.4",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "FLVCRT", (char *)&MP.FLVCRT[0],  NULL,      P_VCT, C_NUM,    E_FIXL, NUMREG, &MP.CTNUMREG, 0, "prov");
	pmaddent(pcp, "FLVCMAX", (char *)&MP.FLVCMAX,    NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);

	/*               Federal Alternate Minimum Tax */
	pmaddent(pcp, "2.3.4.4.5",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "AMTEX",   (char *)&MP.AMTEX,      NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "AMTTX",   (char *)&MP.AMTTX,      F_FRACT,  P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "AMTRPFLG",  (char *)&MP.AMTRPFLG,   NULL,   P_SCL, C_INT,    E_FLAG,   0, NULL, 0);
	pmaddent(pcp, "AMTSTK",   (char *)&MP.AMTSTK,      F_FRACT,  P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "AMTINCRT",   (char *)&MP.AMTINCRT,      F_FRACT,  P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "AMTDIV",   (char *)&MP.AMTDIV,      F_FRACT,  P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "AMTDIVLC", (char *)&MP.AMTDIVLC,    F_FRACT,  P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "AMTFORTX",   (char *)&MP.AMTFORTX,      F_FRACT,  P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "AMTNEGTI",  (char *)&MP.AMTNEGTI,     NULL,    P_SCL, C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "AMTPRVDF",    (char *)MP.AMTPRVDF,        NULL,    P_VCT,     C_INT, E_FIXL,  NUMREG, &MP.CTNUMREG, 0, "prov");

	

	/*               Quebec Tax Abatement */
	pmaddent(pcp, "2.3.4.4.6",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "QTAP",    (char *)&MP.QTAP,       F_FRACT,  P_SCL, C_NUM, 0,      0, NULL, 0);

	/*               Provincial Taxes */
	pmaddent(pcp, "2.3.4.5",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "IMSHTOPT",  (char *)&MP.IMSHTOPT,   NULL,    P_SCL, C_INT,  E_OPT, 2, NULL, 0);

	/*                    Newfoundland */
	pmaddent(pcp, "2.3.4.5.1",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "NPTF",    (char *)&MP.NPTF,       F_FRACT,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NSCI",    (char *)&MP.NSCI,       NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "NSF",     (char *)&MP.NSF,        F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "NSCI2",   (char *)&MP.NSCI2,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "NSF2",    (char *)&MP.NSF2,       F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "NPTC",    (char *)&MP.NPTC[0][0], NULL,    P_LKPSL, C_NUM, 0,    NPTCMAX, &MP.NPTCrows, 0); 
	pmaddent(pcp, "NPTCBEN", (char *)&MP.NPTCBEN,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);				  
	pmaddent(pcp, "NLVCRT",  (char *)&MP.NLVCRT,     F_FRACT, P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NLVCMAX", (char *)&MP.NLVCMAX,    NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NSTCA",   (char *)&MP.NSTCA,      NULL,    P_SCL, C_NUM,  0,      0, NULL, 0);
	pmaddent(pcp, "NSTCC",   (char *)&MP.NSTCC,      NULL,    P_SCL, C_NUM,  0,      0, NULL, 0);
	pmaddent(pcp, "NSTCL",   (char *)&MP.NSTCL,      NULL,    P_SCL, C_NUM,  0,      0, NULL, 0);
	pmaddent(pcp, "NSTCR",   (char *)&MP.NSTCR,      F_FRACT, P_SCL, C_NUM,  E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "NSTCFLAG", (char *)&MP.NSTCFLAG,  NULL,    P_SCL, C_INT,  E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "2.3.4.5.1.1",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "NTXFLG",  (char *)&MP.NTXFLG,     NULL,    P_SCL, C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "NMXM",    (char *)&MP.NMXM,       NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NMXMT",   (char *)&MP.NMXMT,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NEMXM",   (char *)&MP.NEMXM,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NEMXMT",  (char *)&MP.NEMXMT,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NPNTCR",  (char *)&MP.NPNTCR,     F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "NBXM",    (char *)&MP.NBXM,       NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NAXM",    (char *)&MP.NAXM,       NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NAXTD",   (char *)&MP.NAXTD,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NAXRR",   (char *)&MP.NAXRR,      F_FRACT, P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NYPNDL",  (char *)&MP.NYPNDL,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
    pmaddent(pcp, "NMEDANF", (char *)&MP.NMEDANF,    F_FRACT,   P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "NMEDALL", (char *)&MP.NMEDALL,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
   	pmaddent(pcp, "NCHATL1", (char *)&MP.NCHATL1,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
    pmaddent(pcp, "NCHATR1", (char *)&MP.NCHATR1,    F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "NCHATR2", (char *)&MP.NCHATR2,    F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "NMAXDX",  (char *)&MP.NMAXDX,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NODISTC", (char *)&MP.NODISTC,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NEDXPM",  (char *)&MP.NEDXPM,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NEDXPMPT",(char *)&MP.NEDXPMPT,   NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NMAXET",  (char *)&MP.NMAXET,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NPTX",    (char *)&MP.NPTX[0][0], "8.0 10.4 10.6", P_LKPSL, C_NUM, 0, NPTXMAX, &MP.NPTXrows, 0);
	pmaddent(pcp, "NCGTC",   (char *)&MP.NCGTC,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);				  
	pmaddent(pcp, "NCGTCFLG",(char *)&MP.NCGTCFLG,   NULL,    P_SCL, C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "NCGTCOPT",(char *)&MP.NCGTCOPT,   NULL,    P_SCL, C_INT, E_OPT, 2, NULL, 0);
	pmaddent(pcp, "NDTCR",   (char *)&MP.NDTCR,      F_FRACT,  P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NDTCRLC", (char *)&MP.NDTCRLC,    F_FRACT,  P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "NAMTOPT", (char *)&MP.NAMTOPT,    NULL,    P_SCL, C_INT, E_OPT,   4, NULL, 0);
	pmaddent(pcp, "NAMTTX",  (char *)&MP.NAMTTX,     F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "NAMTPCTF",(char *)&MP.NAMTPCTF,   F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "NAMTPCTM",(char *)&MP.NAMTPCTM,   F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "NLITRS",  (char *)&MP.NLITRS,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);				  
	pmaddent(pcp, "NLITRF",  (char *)&MP.NLITRF,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);				  
	pmaddent(pcp, "NLITRSIT",(char *)&MP.NLITRSIT,   NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);				  
	pmaddent(pcp, "NLITRFIT",(char *)&MP.NLITRFIT,   NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);				  
	pmaddent(pcp, "NLITRRR", (char *)&MP.NLITRRR,    F_FRACT, P_SCL, C_NUM, 0,      0, NULL, 0);



	/*                    Prince Edward Island */
	pmaddent(pcp, "2.3.4.5.2",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "PPTF",    (char *)&MP.PPTF,       F_FRACT,  P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "PSCI",    (char *)&MP.PSCI,       NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "PSF",     (char *)&MP.PSF,        F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "PPTC",    (char *)&MP.PPTC[0][0], NULL,    P_LKPSL, C_NUM, 0,    PPTCMAX, &MP.PPTCrows, 0); 
	pmaddent(pcp, "PPTCBEN", (char *)&MP.PPTCBEN,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);				  
	pmaddent(pcp, "PLVCRT",  (char *)&MP.PLVCRT,     F_FRACT, P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "PLVCMAX", (char *)&MP.PLVCMAX,    NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "PTRBAS",  (char *)&MP.PTRBAS,     NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "PTRSP",   (char *)&MP.PTRSP,      NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "PTRKID",  (char *)&MP.PTRKID,     NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "PTRTD",   (char *)&MP.PTRTD,      NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "PTRRR",   (char *)&MP.PTRRR,       F_FRACT, P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "2.3.4.5.2.1",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "PTXFLG",  (char *)&MP.PTXFLG,     NULL,    P_SCL, C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "PMXM",    (char *)&MP.PMXM,       NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "PMXMT",   (char *)&MP.PMXMT,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "PEMXM",   (char *)&MP.PEMXM,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "PEMXMT",  (char *)&MP.PEMXMT,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "PPNTCR",  (char *)&MP.PPNTCR,     F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "PBXM",    (char *)&MP.PBXM,       NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "PAXM",    (char *)&MP.PAXM,       NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "PAXTD",   (char *)&MP.PAXTD,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "PAXRR",   (char *)&MP.PAXRR,      F_FRACT, P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "PYPNDL",  (char *)&MP.PYPNDL,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
    pmaddent(pcp, "PMEDANF", (char *)&MP.PMEDANF,    F_FRACT,   P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "PMEDALL", (char *)&MP.PMEDALL,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
   	pmaddent(pcp, "PCHATL1", (char *)&MP.PCHATL1,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
    pmaddent(pcp, "PCHATR1", (char *)&MP.PCHATR1,    F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "PCHATR2", (char *)&MP.PCHATR2,    F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "PMAXDX",  (char *)&MP.PMAXDX,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "PODISTC", (char *)&MP.PODISTC,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "PEDXPM",  (char *)&MP.PEDXPM,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "PEDXPMPT",(char *)&MP.PEDXPMPT,   NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "PMAXET",  (char *)&MP.PMAXET,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "PYCTCAPM",(char *)&MP.PYCTCAPM,   NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "PYCTCPI", (char *)&MP.PYCTCPI,    F_FRACT, P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "PPTX",    (char *)&MP.PPTX[0][0], "8.0 10.4 10.6", P_LKPSL, C_NUM, 0, PPTXMAX, &MP.PPTXrows, 0);
	pmaddent(pcp, "PCGTC",   (char *)&MP.PCGTC,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);				  
	pmaddent(pcp, "PCGTCFLG",(char *)&MP.PCGTCFLG,   NULL,    P_SCL, C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "PCGTCOPT",(char *)&MP.PCGTCOPT,   NULL,    P_SCL, C_INT, E_OPT, 2, NULL, 0);
	pmaddent(pcp, "PDTCR",   (char *)&MP.PDTCR,      F_FRACT,  P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "PDTCRLC", (char *)&MP.PDTCRLC,    F_FRACT,  P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "PAMTOPT", (char *)&MP.PAMTOPT,    NULL,    P_SCL, C_INT, E_OPT,   4, NULL, 0);
	pmaddent(pcp, "PAMTTX",  (char *)&MP.PAMTTX,     F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "PAMTPCTF",(char *)&MP.PAMTPCTF,   F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "PAMTPCTM",(char *)&MP.PAMTPCTM,   F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);

	/*                    Nova Scotia */
	pmaddent(pcp, "2.3.4.5.3",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "VPTF",     (char *)&MP.VPTF,      F_FRACT,  P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "VSCI",    (char *)&MP.VSCI,       NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "VSCI2",   (char *)&MP.VSCI2,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
 	pmaddent(pcp, "VSF",     (char *)&MP.VSF,        F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "VSF2",    (char *)&MP.VSF2,       F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "VPTC",    (char *)&MP.VPTC[0][0], NULL,    P_LKPSL, C_NUM, 0,    VPTCMAX, &MP.VPTCrows, 0); 
	pmaddent(pcp, "VPTCBEN", (char *)&MP.VPTCBEN,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);				  
	pmaddent(pcp, "VPHPREM", (char *)&MP.VPHPREM,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "VPHTC",   (char *)&MP.VPHTC,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "VPHTD",   (char *)&MP.VPHTD,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "VPHTDC",  (char *)&MP.VPHTDC,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "VPHRR",   (char *)&MP.VPHRR,      F_FRACT, P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "VPHOPT",  (char *)&MP.VPHOPT,     NULL,     P_SCL, C_INT, E_OPT,  2, NULL, 0);
	pmaddent(pcp, "VTRBAS",  (char *)&MP.VTRBAS,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "VTRSP",   (char *)&MP.VTRSP,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "VTREM",   (char *)&MP.VTREM,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "VTRKID",  (char *)&MP.VTRKID,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "VTRTD",   (char *)&MP.VTRTD,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "VTRRR",   (char *)&MP.VTRRR,      F_FRACT, P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "VLVCRT",  (char *)&MP.VLVCRT,     F_FRACT, P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "VLVCMAX", (char *)&MP.VLVCMAX,    NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "2.3.4.5.3.1",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "VTXFLG",  (char *)&MP.VTXFLG,     NULL,    P_SCL, C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "VMXM",    (char *)&MP.VMXM,       NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "VMXMT",   (char *)&MP.VMXMT,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "VEMXM",   (char *)&MP.VEMXM,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "VEMXMT",  (char *)&MP.VEMXMT,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "VPNTCR",  (char *)&MP.VPNTCR,     F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "VBXM",    (char *)&MP.VBXM,       NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "VAXM",    (char *)&MP.VAXM,       NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "VAXTD",   (char *)&MP.VAXTD,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "VAXRR",   (char *)&MP.VAXRR,      F_FRACT, P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "VYPNDL",  (char *)&MP.VYPNDL,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
    pmaddent(pcp, "VMEDANF", (char *)&MP.VMEDANF,    F_FRACT,   P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "VMEDALL", (char *)&MP.VMEDALL,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
   	pmaddent(pcp, "VCHATL1", (char *)&MP.VCHATL1,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
    pmaddent(pcp, "VCHATR1", (char *)&MP.VCHATR1,    F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "VCHATR2", (char *)&MP.VCHATR2,    F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "VMAXDX",  (char *)&MP.VMAXDX,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "VODISTC", (char *)&MP.VODISTC,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "VEDXPM",  (char *)&MP.VEDXPM,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "VEDXPMPT",(char *)&MP.VEDXPMPT,   NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "VMAXET",  (char *)&MP.VMAXET,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "VYCTCAPM",(char *)&MP.VYCTCAPM,   NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "VYCTCPI", (char *)&MP.VYCTCPI,    F_FRACT, P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "VPTX",    (char *)&MP.VPTX[0][0], "8.0 10.4 10.6", P_LKPSL, C_NUM, 0, VPTXMAX, &MP.VPTXrows, 0);
	pmaddent(pcp, "VCGTC",   (char *)&MP.VCGTC,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);				  
	pmaddent(pcp, "VCGTCFLG",(char *)&MP.VCGTCFLG,   NULL,    P_SCL, C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "VCGTCOPT",(char *)&MP.VCGTCOPT,   NULL,    P_SCL, C_INT, E_OPT, 2, NULL, 0);
	pmaddent(pcp, "VDTCR",   (char *)&MP.VDTCR,      F_FRACT,  P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "VDTCRLC", (char *)&MP.VDTCRLC,    F_FRACT,  P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "VAMTOPT", (char *)&MP.VAMTOPT,    NULL,    P_SCL, C_INT, E_OPT,   4, NULL, 0);
	pmaddent(pcp, "VAMTTX",  (char *)&MP.VAMTTX,     F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "VAMTPCTF",(char *)&MP.VAMTPCTF,   F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "VAMTPCTM",(char *)&MP.VAMTPCTM,   F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);

	/*                    New Brunswick */
	pmaddent(pcp, "2.3.4.5.4",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "BPTF",    (char *)&MP.BPTF,       F_FRACT,  P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BSCI",    (char *)&MP.BSCI,       NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "BSF",     (char *)&MP.BSF,        F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "BPTC",    (char *)&MP.BPTC[0][0], NULL,    P_LKPSL, C_NUM, 0,    BPTCMAX, &MP.BPTCrows, 0); 
	pmaddent(pcp, "BPTCBEN", (char *)&MP.BPTCBEN,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);				  
	pmaddent(pcp, "BLVCRT",  (char *)&MP.BLVCRT,     F_FRACT, P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BLVCMAX", (char *)&MP.BLVCMAX,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BTRBAS",  (char *)&MP.BTRBAS,     NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BTRSP",   (char *)&MP.BTRSP,      NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BTRTD",   (char *)&MP.BTRTD,      NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BTRRR",   (char *)&MP.BTRRR,       F_FRACT, P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "2.3.4.5.4.1",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "BTXFLG",  (char *)&MP.BTXFLG,     NULL,    P_SCL, C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "BMXM",    (char *)&MP.BMXM,       NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BMXMT",   (char *)&MP.BMXMT,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BEMXM",   (char *)&MP.BEMXM,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BEMXMT",  (char *)&MP.BEMXMT,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BPNTCR",  (char *)&MP.BPNTCR,     F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "BBXM",    (char *)&MP.BBXM,       NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BAXM",    (char *)&MP.BAXM,       NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BAXTD",   (char *)&MP.BAXTD,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BAXRR",   (char *)&MP.BAXRR,      F_FRACT, P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BYPNDL",  (char *)&MP.BYPNDL,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
    pmaddent(pcp, "BMEDANF", (char *)&MP.BMEDANF,    F_FRACT,   P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "BMEDALL", (char *)&MP.BMEDALL,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
   	pmaddent(pcp, "BCHATL1", (char *)&MP.BCHATL1,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
    pmaddent(pcp, "BCHATR1", (char *)&MP.BCHATR1,    F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "BCHATR2", (char *)&MP.BCHATR2,    F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "BMAXDX",  (char *)&MP.BMAXDX,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BODISTC", (char *)&MP.BODISTC,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BEDXPM",  (char *)&MP.BEDXPM,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BEDXPMPT",(char *)&MP.BEDXPMPT,   NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BMAXET",  (char *)&MP.BMAXET,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BPTX",    (char *)&MP.BPTX[0][0], "8.0 10.4 10.6", P_LKPSL, C_NUM, 0, BPTXMAX, &MP.BPTXrows, 0);
	pmaddent(pcp, "BCGTC",   (char *)&MP.BCGTC,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);				  
	pmaddent(pcp, "BCGTCFLG",(char *)&MP.BCGTCFLG,   NULL,    P_SCL, C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "BCGTCOPT",(char *)&MP.BCGTCOPT,   NULL,    P_SCL, C_INT, E_OPT, 2, NULL, 0);
	pmaddent(pcp, "BDTCR",   (char *)&MP.BDTCR,      F_FRACT,  P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BDTCRLC", (char *)&MP.BDTCRLC,    F_FRACT,  P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "BAMTOPT", (char *)&MP.BAMTOPT,    NULL,    P_SCL, C_INT, E_OPT,   4, NULL, 0);
	pmaddent(pcp, "BAMTTX",  (char *)&MP.BAMTTX,     F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "BAMTPCTF",(char *)&MP.BAMTPCTF,   F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "BAMTPCTM",(char *)&MP.BAMTPCTM,   F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);

	/*                    Quebec */
	pmaddent(pcp, "2.3.4.5.5",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	
	/*                    Net Incomes */
	pmaddent(pcp, "2.3.4.5.5.1",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "QSPLTPNSFLAG", (char *)&MP.QSPLTPNSFLAG,    NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "QPENSPLTINCR",(char *)&MP.QPENSPLTINCR,   F_FRACT, P_SCL,     C_NUM, E_FRCT,  0, NULL, 0);
	pmaddent(pcp, "QALEXP",   (char *)&MP.QALEXP,     F_FRACT,    P_SCL, C_NUM, E_FRCT,  0, NULL, 0);
	pmaddent(pcp, "QCAPGIR",  (char *)&MP.QCAPGIR,    F_FRACT, P_SCL, C_NUM, E_FRCT,  0, NULL, 0);
	pmaddent(pcp, "QCPPOPT",  (char *)&MP.QCPPOPT,    NULL,    P_SCL, C_INT, E_OPT,   2, NULL, 0);
	pmaddent(pcp, "QDGUR",    (char *)&MP.QDGUR,      F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QDGURLC",  (char *)&MP.QDGURLC,    F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QDUESOPT", (char *)&MP.QDUESOPT,    NULL,    P_SCL, C_INT, E_OPT,   2, NULL, 0);
	pmaddent(pcp, "QEAMAX",   (char *)&MP.QEAMAX,     NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QEAP",     (char *)&MP.QEAP,       F_FRACT,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QNTCR",    (char *)&MP.QNTCR,      F_FRACT, P_SCL, C_NUM, E_FRCT,  0, NULL, 0);
	pmaddent(pcp, "QTUIOPT",  (char *)&MP.QTUIOPT,       NULL,     P_SCL,   C_INT, E_OPT,   2, NULL, 0);
	pmaddent(pcp, "QUICOPT",  (char *)&MP.QUICOPT,    NULL,    P_SCL, C_INT, E_OPT,   2, NULL, 0);
	pmaddent(pcp, "QSPBFLAG", (char *)&MP.QSPBFLAG,    NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "QNORFAMI", (char *)&MP.QNORFAMI,   NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "QREPFAMI", (char *)&MP.QREPFAMI,   NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "QTRSAFAM", (char *)&MP.QTRSAFAM,   NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "QTRWCFAM", (char *)&MP.QTRWCFAM,   NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	
	/*                    Child Care Expenditures */
	pmaddent(pcp, "2.3.4.5.5.1.1",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "QCCEAOLD", (char *)&MP.QCCEAOLD,   NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QCCEAYNG", (char *)&MP.QCCEAYNG,   NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
    pmaddent(pcp, "QCCEOPT",  (char *)&MP.QCCEOPT,    NULL,    P_SCL, C_INT, E_OPT,   2, NULL, 0);
	
	/*                    Taxable Income and Individual Exemptions */
	pmaddent(pcp, "2.3.4.5.5.2",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "QBXM",     (char *)&MP.QBXM,       NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QCHATNF",  (char *)&MP.QCHATNF,    F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QGIFTFLG",  (char *)&MP.QGIFTFLG,  NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "QGIFTOPT",  (char *)&MP.QGIFTOPT,  NULL,    P_SCL, C_INT, E_OPT,   2, NULL, 0);
	pmaddent(pcp, "QMAXDX",   (char *)&MP.QMAXDX,     NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QREPNETFG",(char *)&MP.QREPNETFG,  NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "QEEXPDED", (char *)&MP.QEEXPDED,   NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "QGIFTHCR",  (char *)&MP.QGIFTHCR,  NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "QGIFTL1",  (char *)&MP.QGIFTL1,    NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QGFTCR",   (char *)&MP.QGFTCR,     F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QNFSDED",  (char *)&MP.QNFSDED,    NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "QSADED",   (char *)&MP.QSADED,     NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "QNORTHDED",(char *)&MP.QNORTHDED,  NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "QSTSCA",   (char *)&MP.QSTSCA,     NULL,    P_SCL, C_NUM,  0,      0, NULL, 0);				  
	pmaddent(pcp, "QCMPOPT",  (char *)&MP.QCMPOPT,    NULL,    P_SCL, C_INT, E_OPT,   3, NULL, 0);				  
	pmaddent(pcp, "QEMPDEDM", (char *)&MP.QEMPDEDM,   NULL,    P_SCL, C_NUM, 0,  0, NULL, 0);
	pmaddent(pcp, "QEMPDEDP", (char *)&MP.QEMPDEDP,   F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	
	
	/*                    Age Tax Credit */
	pmaddent(pcp, "2.3.4.5.5.2.1",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "QAXM",     (char *)&MP.QAXM,       NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QAXPI",    (char *)&MP.QAXPI,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QAXRR",    (char *)&MP.QAXRR,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QAXTD",    (char *)&MP.QAXTD,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	
	/*                    Health Services Fund */
	pmaddent(pcp, "2.3.4.5.5.2.2",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "QHSC",     (char *)&MP.QHSC[0][0], NULL,    P_LKPSL, C_NUM, 0,     QHSCMAX, &MP.QHSCrows, 0);
	pmaddent(pcp, "QHSCFLAG", (char *)&MP.QHSCFLAG,   NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "QHSOASFG", (char *)&MP.QHSOASFG,   NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "QHSSFLSS", (char *)&MP.QHSSFLSS,   NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "QHSSFUIR", (char *)&MP.QHSSFUIR,   NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "QHSSFALM", (char *)&MP.QHSSFALM,   NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "QHSSFCAR", (char *)&MP.QHSSFCAR,   NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	
	/*                    Medical Expenses */
	pmaddent(pcp, "2.3.4.5.5.2.3",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "QMEDALL",  (char *)&MP.QMEDALL,    NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);				  
	pmaddent(pcp, "QMEDANF",  (char *)&MP.QMEDANF,    F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QMEDOPT",  (char *)&MP.QMEDOPT,    NULL,    P_SCL, C_INT, E_OPT,   2, NULL, 0);
	
	/*                    Retirement Income */
	pmaddent(pcp, "2.3.4.5.5.2.4",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "QYPDL",    (char *)&MP.QYPDL,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QYPPI",    (char *)&MP.QYPPI,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QYPRR",    (char *)&MP.QYPRR,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QYPTD",    (char *)&MP.QYPTD,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	
	/*                    Family Related Deductions or Credits */
	pmaddent(pcp, "2.3.4.5.5.3",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "QPSXM",    (char *)&MP.QPSXM,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QPSXMINC", (char *)&MP.QPSXMINC,   NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	
	/*                    Dependant credit */
	pmaddent(pcp, "2.3.4.5.5.3.1",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "QYCXM1",   (char *)&MP.QYCXM1,     NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QYCXM2",   (char *)&MP.QYCXM2,     NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QODISTC",  (char *)&MP.QODISTC,    NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QDTCNCA1", (char *)&MP.QDTCNCA1,   NULL,    P_SCL, C_NUM, 0,  0, NULL, 0);
	pmaddent(pcp, "QDTCNCA2", (char *)&MP.QDTCNCA2,   NULL,    P_SCL, C_NUM, 0,  0, NULL, 0);
	pmaddent(pcp, "QDTCSPA",  (char *)&MP.QDTCSPA,    NULL,    P_SCL, C_NUM, 0,  0, NULL, 0);
	pmaddent(pcp, "QTPCFLG",  (char *)&MP.QTPCFLG,    NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "QESSNEEDS",(char *)&MP.QESSNEEDS,  NULL,    P_SCL, C_NUM, 0,  0, NULL, 0);
	
	/*                    Living Alone exemption/credit */
	pmaddent(pcp, "2.3.4.5.5.3.2",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "QLAXM",    (char *)&MP.QLAXM,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QLAXPI",   (char *)&MP.QLAXPI,     NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QLAXRR",   (char *)&MP.QLAXRR,     NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QLAXTD",   (char *)&MP.QLAXTD,     NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QLPXM",    (char *)&MP.QLPXM,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QLAXOLDDEP",    (char *)&MP.QLAXOLDDEP,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	
	/*                    Married credit */
	pmaddent(pcp, "2.3.4.5.5.3.3",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "QMXM",     (char *)&MP.QMXM,       NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	
	/*                    Medical exemption/credit */
	pmaddent(pcp, "2.3.4.5.5.3.4",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	
	/*                    Taxable Income and non-refundable credits */
	pmaddent(pcp, "2.3.4.5.5.4",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "QCRDFLG",  (char *)&MP.QCRDFLG,    NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "QDTCR",    (char *)&MP.QDTCR,      F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QDTCRLC",  (char *)&MP.QDTCRLC,    F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QTX",      (char *)&MP.QTX[0][0],  NULL,    P_LKPSL, C_NUM, 0,     QTXMAX, &MP.QTXrows, 0);
	pmaddent(pcp, "QFAMFLG",  (char *)&MP.QFAMFLG,    NULL,    P_SCL,   C_INT,  E_FLAG,  0, 		NULL, 		0);
	pmaddent(pcp, "QFAMRAT",  (char *)&MP.QFAMRAT,    NULL,    P_SCL,   C_NUM,  0,       0, 		NULL, 		0);				  
	pmaddent(pcp, "QFAMDED",  (char *)&MP.QFAMDED,    NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QCALRFLG", (char *)&MP.QCALRFLG,   NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "QINTSLTC", (char *)&MP.QINTSLTC,   NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "QTUITRFFLG", (char *)&MP.QTUITRFFLG,   NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);

	/*                    Alternative Minimum Tax */
	pmaddent(pcp, "2.3.4.5.5.4.1",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "QAMTTX",    (char *)&MP.QAMTTX,      F_FRACT, P_SCL, C_NUM, E_FRCT,  0, NULL, 0);
	pmaddent(pcp, "QAMTX",    (char *)&MP.QAMTX,         NULL,     P_SCL,   C_NUM, 0,       0, NULL, 0);				  
	pmaddent(pcp, "QAMTXFLG", (char *)&MP.QAMTXFLG,      NULL,     P_SCL,   C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "QAMTXREF", (char *)&MP.QAMTXREF,      NULL,     P_SCL,   C_NUM, 0,       0, NULL, 0);				  
	pmaddent(pcp, "QAMTXSTKFLG", (char *)&MP.QAMTXSTKFLG,      NULL,     P_SCL,   C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "QCAPAMTX", (char *)&MP.QCAPAMTX,      NULL,     P_SCL,   C_NUM, 0,       0, NULL, 0);				  
	pmaddent(pcp, "QAMTNEGTI", (char *)&MP.QAMTNEGTI,      NULL,     P_SCL,   C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "QAMTCBX", (char *)&MP.QAMTCBX,      NULL,     P_SCL,   C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "QAMTRPFLG", (char *)&MP.QAMTRPFLG,      NULL,     P_SCL,   C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "QAMTRITC", (char *)&MP.QAMTRITC,      NULL,     P_SCL,   C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "QAMTDIV",    (char *)&MP.QAMTDIV,         NULL,     P_SCL,   C_NUM, 0,       0, NULL, 0);				  
	pmaddent(pcp, "QAMTCAPR",   (char *)&MP.QAMTCAPR,      F_FRACT,  P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "QAMTSTTC",  (char *)&MP.QAMTSTTC,      NULL,     P_SCL,   C_INT, E_FLAG,  0, NULL, 0);
	
	/*                    Child Care Credit */
	pmaddent(pcp, "2.3.4.5.5.4.2",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "QCCETCR",  (char *)&MP.QCCETCR[0][0],F_LKTUR, P_LKPXY, C_NUM, E_FRCT, QCCETCRMAX, &MP.QCCETCRrows, 0);
	pmaddent(pcp, "QCCEEIFLG", (char *)&MP.QCCEEIFLG,   NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "QCCEEITST", (char *)&MP.QCCEEITST,   NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	
	/*                    Family Tax Reduction */
	pmaddent(pcp, "2.3.4.5.5.4.3",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "QFTRA1",   (char *)&MP.QFTRA1,     NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QFTRA2",   (char *)&MP.QFTRA2,     NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QFTRA3",   (char *)&MP.QFTRA3,     NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QFTRA4",   (char *)&MP.QFTRA4,     NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QFTRFLAG", (char *)&MP.QFTRFLAG,   NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "QFTRRR",   (char *)&MP.QFTRRR,     F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	
	/*                    Political Contribution */
	pmaddent(pcp, "2.3.4.5.5.4.4",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "QPTC",     (char *)&MP.QPTC,       F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QPTCBEN",  (char *)&MP.QPTCBEN,    NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);				  
	pmaddent(pcp, "QPCOPT",   (char *)&MP.QPCOPT,     NULL,    P_SCL, C_INT, E_OPT,   2, NULL, 0);
	pmaddent(pcp, "QPCTR",    (char *)&MP.QPCTR[0][0],F_LKTUR, P_LKPXY, C_NUM, E_FRCT, QPCTRMAX, &MP.QPCTRrows, 0);

	/*                    Surtax and Anti-Poverty Fund*/
	pmaddent(pcp, "2.3.4.5.5.4.5",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "QHSCI",    (char *)&MP.QHSCI,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QHSCI2",   (char *)&MP.QHSCI2,     NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QHSF",     (char *)&MP.QHSF,       F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QHSF2",    (char *)&MP.QHSF2,      F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QAPFFLG",  (char *)&MP.QAPFFLG,    NULL,    P_SCL,   C_INT,  E_FLAG,  0, 		NULL, 		0);
	pmaddent(pcp, "QAPFRAT",  (char *)&MP.QAPFRAT,    F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	
	/*                    Tax Reduction */
	pmaddent(pcp, "2.3.4.5.5.4.6",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "QTRBE",    (char *)&MP.QTRBE,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QTROPT",   (char *)&MP.QTROPT,     NULL,    P_SCL, C_INT, E_OPT,   2, NULL, 0);
	pmaddent(pcp, "QTRP",     (char *)&MP.QTRP,       F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	
	/*                    Simplified Tax System Tax Credit */
	pmaddent(pcp, "2.3.4.5.5.4.7",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "QSFTC",    (char *)&MP.QSFTC,      NULL,    P_SCL,   C_NUM,  0,       0, 	 NULL, 		0);				  
	pmaddent(pcp, "QSFOPT",   (char *)&MP.QSFOPT,     NULL,    P_SCL,   C_INT,  E_OPT,   3,      NULL,      0);
	pmaddent(pcp, "QSFDISFLAG", (char *)&MP.QSFDISFLAG,   NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "QSFSMXI",  (char *)&MP.QSFSMXI,    NULL,    P_SCL,   C_NUM,  0,       0,      NULL, 0);
	pmaddent(pcp, "QSFDED",   (char *)&MP.QSFDED,    NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "QSFTXCR",  (char *)&MP.QSFTXCR,   NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "QSFMEDFLAG",   (char *)&MP.QSFMEDFLAG,     NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	
	/*                    Labour-sponsored Funds Tax Credit */
	pmaddent(pcp, "2.3.4.5.5.4.8",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "QLVCRT",  (char *)&MP.QLVCRT,     F_FRACT, P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "QLVCMAX", (char *)&MP.QLVCMAX,    NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);

	/*                    Improved Tax System for Self-Employed Workers */
	pmaddent(pcp, "2.3.4.5.5.4.9",  NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "QITSFSEW",  (char *)&MP.QITSFSEW,      NULL,   P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "QITSSEF",  (char *)&MP.QITSSEF,    F_FRACT, P_SCL, C_NUM, 0,      0, NULL, 0);

	/*                    Refundable Tax Credit */
	pmaddent(pcp, "2.3.4.5.5.5",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	
	/*                    Sales Tax Credit */
	pmaddent(pcp, "2.3.4.5.5.5.1",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "QSTRBCRD", (char *)&MP.QSTRBCRD,   NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QSTRCHILD",(char *)&MP.QSTRCHILD,  NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QSTRFLAG", (char *)&MP.QSTRFLAG,   NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "QSTRFTP3", (char *)&MP.QSTRFTP3,   NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QSTRFTP4", (char *)&MP.QSTRFTP4,   NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QSTRRR",   (char *)&MP.QSTRRR,     F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QSTRMAGE", (char *)&MP.QSTRMAGE,   NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "QSTREXT",  (char *)&MP.QSTREXT,    NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	
	/*                    Family Allowance Tax Credit */
	pmaddent(pcp, "2.3.4.5.5.5.2",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "QFATCMIN", (char *)&MP.QFATCMIN,      NULL,     P_SCL,   C_NUM, 0,       0, NULL, 0);				  
	pmaddent(pcp, "QFATCMNK", (char *)&MP.QFATCMNK[0][0],F_LKTURI, P_LKPXY, C_NUM, 0, QFATCMNKMAX, &MP.QFATCMNKrows, 0);
	pmaddent(pcp, "QFATCMRR", (char *)&MP.QFATCMRR[0][0],F_LKTURI, P_LKPXY, C_NUM, 0, QFATCMRRMAX, &MP.QFATCMRRrows, 0);
	pmaddent(pcp, "QFATCMXK", (char *)&MP.QFATCMXK[0][0],F_LKTURI, P_LKPXY, C_NUM, 0, QFATCMXKMAX, &MP.QFATCMXKrows, 0);
	pmaddent(pcp, "QFATCOPT", (char *)&MP.QFATCOPT,      NULL,     P_SCL,   C_INT, E_OPT,   3, NULL, 0);
	pmaddent(pcp, "QFATCSRR", (char *)&MP.QFATCSRR[0][0],F_LKTURI, P_LKPXY, C_NUM, 0, QFATCSRRMAX, &MP.QFATCSRRrows, 0);
	pmaddent(pcp, "QFATCSUP", (char *)&MP.QFATCSUP,      NULL,     P_SCL,   C_NUM, 0,       0, NULL, 0);				  
	pmaddent(pcp, "QFATD4K",  (char *)&MP.QFATD4K,       NULL,     P_SCL,   C_NUM, 0,       0, NULL, 0);				  
	pmaddent(pcp, "QFATD4KI", (char *)&MP.QFATD4KI,      NULL,     P_SCL,   C_NUM, 0,       0, NULL, 0);				  
	pmaddent(pcp, "QFATCTK",  (char *)&MP.QFATCTK[0][0], F_LKTURI, P_LKPXY, C_NUM, E_FRCT, QFATCTKMAX, &MP.QFATCTKrows, 0);
	pmaddent(pcp, "QFATCK6",  (char *)&MP.QFATCK6,       "8.2",    P_TBL,   C_NUM, 0, QFATCK6RMAX, &MP.QFATCK6rows, QFATCK6CMAX);
	pmaddent(pcp, "QFATCHIRR",  (char *)&MP.QFATCHIRR,   F_FRACT,  P_SCL,   C_NUM, 0,       0, NULL, 0);				  
	pmaddent(pcp, "QFATCHITD",  (char *)&MP.QFATCHITD,   NULL,     P_SCL,   C_NUM, 0,       0, NULL, 0);				  
	pmaddent(pcp, "QFATCK6PYR",  (char *)&MP.QFATCK6PYR,   F_FRACT,  P_SCL,   C_NUM, 0,       0, NULL, 0);				  
	pmaddent(pcp, "QFATCK6YR",(char *)&MP.QFATCK6YR,NULL,    P_SCL, C_INT,    0,      0, NULL, 0);
	pmaddent(pcp, "QFAMNETI",  (char *)&MP.QFAMNETI,      NULL,   P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	
	/*                    Housing Parent Tax Credit */
	pmaddent(pcp, "2.3.4.5.5.5.3",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "QHPTC",    (char *)&MP.QHPTC,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);				  
	pmaddent(pcp, "QHPTCFLG", (char *)&MP.QHPTCFLG,   NULL,    P_SCL, C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "QHPTCOPT", (char *)&MP.QHPTCOPT,   NULL,    P_SCL, C_INT, E_OPT,   2, NULL, 0);
	
	/*                    Income Definition */
	pmaddent(pcp, "2.3.4.5.5.5.4",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "QEIA1",    (char *)&MP.QEIA1,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QEIA2",    (char *)&MP.QEIA2,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QEIA3",    (char *)&MP.QEIA3,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QEIA4",    (char *)&MP.QEIA4,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QEIA5",    (char *)&MP.QEIA5,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QEIAA",    (char *)&MP.QEIAA,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	
	/*                    Property Tax Credit */
	pmaddent(pcp, "2.3.4.5.5.5.5",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "QPTRGISB", (char *)&MP.QPTRGISB,   NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QPTRMTP",  (char *)&MP.QPTRMTP,    NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QPTRMTR",  (char *)&MP.QPTRMTR,    NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QPTRTF",   (char *)&MP.QPTRTF,     F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QPTRRR",   (char *)&MP.QPTRRR,     F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QRTRFLAG", (char *)&MP.QRTRFLAG,   NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);

	/*                    Medical Expenses Refundable Tax Credit */
	pmaddent(pcp, "2.3.4.5.5.5.6",  NULL,                      NULL,   P_DUMMY, C_STR, 0,     0, NULL, 0);
	pmaddent(pcp, "QMEDRMIN", (char *)&MP.QMEDRMIN,   NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QMEDRATE", (char *)&MP.QMEDRATE,   F_FRACT, P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QMEDRMAX", (char *)&MP.QMEDRMAX,   NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QMEDRTD",  (char *)&MP.QMEDRTD,    NULL,    P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QMEDRRR",  (char *)&MP.QMEDRRR,    F_FRACT, P_SCL,     C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "QMRTCFLG", (char *)&MP.QMRTCFLG,   NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "QMEDINC",  (char *)&MP.QMEDINC,    NULL,    P_SCL, C_INT, E_OPT,   2, NULL, 0);

	/*                    Child Assistance Refundable Tax Credit */
 	pmaddent(pcp, "2.3.4.5.5.5.7",  NULL,                      NULL,   P_DUMMY, C_STR, 0,     0, NULL, 0);		
	pmaddent(pcp, "QCAFLAG",  (char *)&MP.QCAFLAG,    NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "QCAMIN",   (char *)&MP.QCAMIN[0],  "8.2",   P_VCT, C_NUM, E_FIXL,  QCAMINMAX, &MP.QCAMINrows, 0, "childf");
	pmaddent(pcp, "QCAMAX",   (char *)&MP.QCAMAX[0],  "8.2",   P_VCT, C_NUM, E_FIXL,  QCAMAXMAX, &MP.QCAMAXrows, 0, "childf");
	pmaddent(pcp, "QCATDC",   (char *)&MP.QCATDC,     NULL,    P_SCL, C_NUM, 0,  0, NULL, 0);
	pmaddent(pcp, "QCATDS",   (char *)&MP.QCATDS,     NULL,    P_SCL, C_NUM, 0,  0, NULL, 0);
	pmaddent(pcp, "QCASPMAX", (char *)&MP.QCASPMAX,   NULL,    P_SCL, C_NUM, 0,  0, NULL, 0);
	pmaddent(pcp, "QCASPMIN", (char *)&MP.QCASPMIN,   NULL,    P_SCL, C_NUM, 0,  0, NULL, 0);
	pmaddent(pcp, "QCARR",    (char *)&MP.QCARR,      F_FRACT, P_SCL, C_NUM,    0,  0, NULL, 0);


	/*                    Work Premium Refundable Tax Credit */
 	pmaddent(pcp, "2.3.4.5.5.5.8",  NULL,                      NULL,   P_DUMMY, C_STR, 0,     0, NULL, 0);		
	pmaddent(pcp, "QWPFLAG",  (char *)&MP.QWPFLAG,    NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "QWPCR",    (char *)&MP.QWPCR[0],   NULL,    P_VCT, C_NUM, E_FIXL,  QWPCRMAX, &MP.QWPCRrows, 0, "qwftype");
	pmaddent(pcp, "QWPEIPI",  (char *)&MP.QWPEIPI[0], "8.2",   P_VCT, C_NUM, E_FIXL,  QWPEIPIMAX, &MP.QWPEIPIrows, 0, "qwftype");
	pmaddent(pcp, "QWPMAX",   (char *)&MP.QWPMAX[0],  "8.2",   P_VCT, C_NUM, E_FIXL,  QWPMAXMAX, &MP.QWPMAXrows, 0, "qwftype");
	pmaddent(pcp, "QWPTD",    (char *)&MP.QWPTD[0],   "8.2",   P_VCT, C_NUM, E_FIXL,  QWPTDMAX, &MP.QWPTDrows, 0, "qwftype");
	pmaddent(pcp, "QWPRR",    (char *)&MP.QWPRR,      F_FRACT, P_SCL, C_NUM,    0,  0, NULL, 0);

	/*                    Natural Caregivers Tax Credit */
	pmaddent(pcp, "2.3.4.5.5.5.9",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "QRNCGTC",  (char *)&MP.QRNCGTC,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);				  
	pmaddent(pcp, "QRNCGFLG", (char *)&MP.QRNCGFLG,   NULL,    P_SCL, C_INT, E_FLAG, 0, NULL, 0);
	 
	DEBUG_OFF("mpd3");
}

