/***
*mpd4.cpp - Tax/transfer model parameter definitions (cont.)
*
*$Id: mpd4.cpp 6.146 2007/09/18 17:22:09 hickcha Exp $
*
*   SPSD/M Copyright (c) 1987-1995, Minister of Industry.
*   All rights reserved.  Use, reproduction, or disclosure of this work,
*   as well as publication of results derived from this work, are subject
*   to the conditions specified in the SPSD/M License Agreement.
*
*Purpose:
*   This file contains the definition of the .c function.
*		   
*Revisions:
* +-----+----------+---------------------------------------------------------+
* | Who |   Date   | Description                                             |
* +-----+----------+---------------------------------------------------------+
* | CH  | 07/07/30 | Added MAMTFTCFLG and CAMTFTCFLG                         |
* | CH  | 07/07/26 | Labeled dimensions of AFETCAPC, AFETCAPCP               |
* | CH  | 07/07/23 | Added CTPNEW and CTFNEW                                 |
* | CH  | 07/06/25 | Added CTFGSTHOUSE                                       |
* | LP  | 07/04/13 | Changed MCMINAGE and MSCHAGE from C_NUM to C_INT        |
* | CH  | 07/03/19 | Deleted labels of AFETCAPC and AFETCAPCP                |
* | CH  | 07/02/22 | Added AHCIPINCFLG and CMSPINCFLAG                       |
* | CH  | 07/02/19 | Added CTCAPTOBFLG, CTTOBMAX, removed CTDFLAG            |
* | LP  | 07/02/15 | Added OHPFLAG, ACHIPFLG, CMSPFLAG, prov health prem flgs|
* | LP  | 07/01/25 | Changed dollar type vectors from NULL to 8.2            |
* | LP  | 07/01/22 | Removed provincial UCCB in income test flags - _UCCBITF |
* | LP  | 06/12/27 | Removed MTCINCFL - unnecessary given net income changes |
* | LP  | 06/07/07 | Added CSUPCR - BC supplementary tax credit for 2000 and |
* |     |          | added CPTCREF - BC political tax credit refundable flag |
* | LP  | 06/07/04 | Added CSTCKID - BC sales tax credit amount for kids     |
* | LP  | 06/06/12 | Added Phase in rates for Alta Family Employment Tx Cred |
* | LP  | 06/06/09 | Removed provincial AXPI series - age tax credit phase-in|
* | LP  | 06/06/08 | Added Sask Sales Tax Credit parms for calendar year calc|
* | LP  | 06/06/07 | Add flags to remove UCCB from income test BC,ON,SA,MB,AL|
* | LP  | 06/06/02 | Added Alberta Family Tax Credit parms for previous year |
* | LP  | 06/05/15 | Added provincial large corp dividend tax credit rates   |
* | LP  | 06/04/20 | Added MCMINAGE - Man. cost of living credit min. age    |
* | LP  | 05/12/28 | Removed ORDOPT & OMTY - pre 1991 parms for Ont tax red  |
* | LP  | 05/12/01 | Removed CTFOEN & CTFMFG - pre 91 parameters not needed  |
* | LP  | 05/11/03 | Added ARESREB - Alberta Resource Rebate Amount          |
* | LP  | 05/05/26 | Added OSTCNIBC - income turndown for senior couples     |
* | LP  | 05/05/16 | Added AHCIPSPI - Health premium seniors exempt phase-in |
* | LP  | 05/05/09 | Added BC low inc. tax reduction CLITR, CLITRTD, CLITRRR |
* | LP  | 05/04/18 | Added AFETCAPC - Removed AFETCBPC                       |
* | BBM | 04/10/25 | Added row/col classifications to series of parms        |
* | SFG | 04/10/19 | Added row and col classifications to CTPRST             |
* | LP  | 04/07/20 | Added Alta Health Care Insurance Plan (ACHIP series)    |
* | LP  | 04/07/15 | Added B.C. Medical Service Plan (MSP) Premium (CMSP + ) |
* | LP  | 04/06/04 | Added Ont. Health Premium - OHPBASE and OHPPI (phase in)|
* | LP  | 04/06/02 | Added OFTCOPT - foreign tax credit application option   |
* | LP  | 04/06/02 | Added OSPSMAX - Ont. prop/sales tax credit senior max   |
* | LP  | 04/01/06 | Removed provincial CGTC take ups and income turn downs  |
* | LP  | 03/12/22 | Added prov. non-ref medical tax credit _MEDALL & _MEDANF|
* | LP  | 03/12/09 | Added AODISTC, CODISTC, MODISTC, SODISTC, OODISTC       |
* | LP  | 03/11/17 | Added ACGTCOPT, CCGTCOPT, MCGTCOPT, SCGTCOPT, OCGTCOPT  |
* | LP  | 03/11/12 | Added AEDXPMPT, CEDXPMPT, MEDXPMPT, SEDXPMPT, OEDXPMPT  |
* | LP  | 02/09/04 | Revised number sequence                                 |
* | BBM | 01/06/20 | Drop OHT and OHIRF for 9.0 - No GB data                 |
* | LP  | 01/06/12 | Added OPTCFLAG- political cont tx cred. refundable flag |
* | LP  | 01/05/09 | Added new provincial alternative minimum tax parameters |
* | BBM | 01/04/19 | Dropped OHCMAX,CVCMAX (9.0 database change)             |
* | LP  | 01/04/10 | Added SPTC, SPTCBEN Sask political contrib. tax credit  |
* | LP  | 01/03/12 | Removed pre-1988 program parameters                     |
* | LP  | 00/05/16 | Added MTRNIOS Man. tax reduction net income offset      |
* | CH  | 00/05/15 | Added MHMASOPT                                          |
* | CH  | 00/05/12 | Added taxpayer dividend                                 |
* | LP  | 00/05/09 | Added OCGIRFLG, OCAPGIR Ont Capital Gains Inclusion rate|
* | CH  | 00/04/14 | Added precision to provincial tax tables                |
* | CH  | 00/04/10 | Added Sask refundable sales tax credit                  |
* | CH  | 00/04/07 | Added Sask child and senior tax credits                 |
* | CH  | 00/03/01 | Added provincial tax on taxable income                  |
* | CH  | 99/05/25 | Added Alberta flat tax                                  |
* | CH  | 99/03/22 | Added Labour-sponsored Funds parameters                 |
* | CH  | 99/03/09 | Added Man school tax assistance parameters              |
* | TCB | 98/05/28 | Renamed *.cpp, ANSI function headers                    |
* | CCH | 98/04/03 | Add MANLTMAX                                            |
* | BBM | 97/10/08 | Add MTCINCFL parameter                                  |
* | CCH | 97/09/10 | Add MANLTCF                                             |
* | ER  | 96/09/10 | Add SDSRA - Sask. Debt Surtax Reduction Amount          |
* | RSE | 94/02/07 | add refundable sales tax in 93 budget                   |
* | RSE | 94/02/04 | add the renter reduction flag                           |
* | GJC | 94/01/17 | remove MP.CTPUPST and MP.CTPUGAS change dim of CTPGAS   |
* | GJC | 93/04/16 | add sask defict surtax parameter                        |
* | GJC | 93/02/25 | add second tier bc surtax parameters                    |
* | BBM | 92/09/02 | Del Sask family tc parms SFTCFLAG SFTCPC SFTCTD SFTCRR  |
* | BBM | 92/07/22 | Add Ontario Tax credit parameters                       |
* | BBM | 92/07/15 | Add BC Tax credit parameters                            |
* | BBM | 92/07/07 | Prov. political tax credit parameters                   |
* | BBM | 92/06/30 | Add Manitoba political tax credit parameters            |
* | BBM | 92/06/22 | Add Manitoba reform surtax and tax reduction parameters |
* | SFG | 92/02/07 | ctupst -> ctpupst; ctugas -> ctpugas; also CTUPST,CTUGAS|
* | SFG | 92/02/06 | Delete CTPICT; add CTUPST, CTUGAS                       |
* | BBM | 91/07/10 | Added SFTCFLAG SFTCPC SFTCTD SFTCRR-Sask fam tax credit |
* | BBM | 91/07/05 | Added CSDC - BC surtax dependant tax credit 1991->      |
* | BBM | 91/06/27 | added OTRBPA OTRDCA OTRDDA OTRFP - Ont tax reduction    |
* | SFG | 90/07/31 | Changed order of commodity tax parameters               |
* | SFG | 90/03/02 | Created                                                 |
* |     |          |                                                         |
* +-----+----------+---------------------------------------------------------+
*
*Definitions:
*   mpd4     [global]  Tax/transfer model parameter definitions (cont.)
*
*****************************************************************************/


/* ==================== C-RUNTIME LIBRARY INCLUDE FILES =================== */

#include <stdio.h>  /* definitions/declarations for standard I/O routines   */


/* ==================== SPSD/M INCLUDE FILES ============================== */

#include "spsm.h"   /* SPSM common manifest constants and macros            */
#include "sub.h"    /* Subroutine library declarations                      */
#include "pm.h"     /* Parameter manipulation package declarations          */
#include "mpu.h"    /* Tax/transfer parameter declarations (user's)         */
#include "mp.h"     /* Tax/transfer parameter declarations                  */


/* ==================== STATIC VARIABLE DEFINITIONS ======================= */

static char NEAR F_FRACT[]  = "8.5";
static char NEAR F_LKTUR[]  = "8.0 8.3 10.4";


/* ==================== COMPILER PRAGMAS ================================== */

// eliminate spurious 'near/far mismatch' from MS-DOS compiler
#if defined(_MSDOS)
#pragma warning(disable : 4762)
#endif

#ifdef MSCOVL
#pragma alloc_text(INIT_TEXT,mpd4)
#endif


/* ==================== FUNCTION DEFINITIONS ============================== */


/*****************************************************************************
*mpd4 - Tax/transfer model parameter definitions (cont.)
*
*Synopsis:
*    void mpd4(           
*    P_pc pcp             
*    )                    
*
*Description:
*
*Return Value:
*   None.
*
*Calls:
*   pmaddent Define and add a parameter
*
*Structure Members:
*   MP.AAMTOPT      (i)  Alta alternative minimum tax option
*   MP.AAMTPCTF     (i)  Alta amt rate as pct of additional fed tax due to minimum tax
*   MP.AAMTPCTM     (i)  Alta amt rate as pct of federal minimum tax amount
*   MP.AAMTTX       (i)  Alta amt rate as tax on adjusted income
*   MP.AAXM         (i)  Alta Age Amount
*   MP.AAXRR        (i)  Alta Age Amount credit reduction rate
*   MP.AAXTD        (i)  Alta Age Amount net income turndown
*   MP.ABXM         (i)  Alta Basic Personal Exemption/amount
*   MP.ACGTC        (i)  Alta Caregiver Tax Credit
*   MP.ACGTCFLG     (i)  Alta Caregiver Tax Credit activation flag
*   MP.ACGTCOPT     (i)  Alta Caregiver Tax Credit Option (1=max, 2=greenbook)
*   MP.ACHATL1      (i)  Alta Charitable Donations amount level 1
*   MP.ACHATR1      (i)  Alta Charitable Donations tax credit rate 1
*   MP.ACHATR2      (i)  Alta Charitable Donations tax credit rate 2
*   MP.ADTCR        (i)  Alta dividend tax credit rate
*   MP.ADTCRLC      (i)  Alta dividend tax credit rate from large (eligible) corporations
*   MP.AEDXPM       (i)  Alta Education Amount per month of full-time studies
*   MP.AEDXPMPT     (i)  Alta Education Amount per month of part-time studies
*   MP.AEMXM        (i)  Alta equivalent to married amount
*   MP.AEMXMT       (i)  Alta equivalent to married turndown level
*   MP.AFETCAPC     (i)  Alberta Family Employment Tax Credit Amount Per Child [number of children]
*   MP.AFETCAPCP    (i)  Alberta Family Employment Tax Credit Amount Per Child for 1st half of year
*   MP.AFETCAPCrows (i)  number of rows in AFETCAPC
*   MP.AFETCBR      (i)  Alberta Family Employment Tax Credit Benefit Rate
*   MP.AFETCBRP     (i)  Alberta Family Employment Tax Credit Benefit Rate for 1st half of year
*   MP.AFETCCI      (i)  Alberta Family Employment Tax Credit Benefit Cut-in Level
*   MP.AFETCCIP     (i)  Alberta Family Employment Tax Credit Benefit Cut-in Level for 1st half of year
*   MP.AFETCFLAG    (i)  Alberta Family Employment Tax Credit Activation Flag
*   MP.AFETCNC      (i)  Alberta Family Employment Tax Credit Maximum Number of Children
*   MP.AFETCNCP     (i)  Alberta Family Employment Tax Credit Maximum Number of Children for 1st half of year
*   MP.AFETCPI      (i)  Alberta Family Employment Tax Credit phase in
*   MP.AFETCPIP     (i)  Alberta Family Employment Tax Credit phase in for 2nd half of year
*   MP.AFETCRR      (i)  Alberta Family Employment Tax Credit Reduction Rate
*   MP.AFETCRRP     (i)  Alberta Family Employment Tax Credit Reduction Rate for 1st half of year
*   MP.AFETCTD      (i)  Alberta Family Employment Tax Credit Turndown Level
*   MP.AFETCTDP     (i)  Alberta Family Employment Tax Credit Turndown Level for 1st half of year
*   MP.AFTAX        (i)  Alberta flat surtax rate on taxable income
*   MP.AHCIPF       (i)  Alberta Health Care Insurance Plan Family Premium
*   MP.AHCIPFLG     (i)  Alberta Health Care Insurance Plan activation flag
*   MP.AHCIPFSB     (i)  Alberta Health Care Insurance Plan Family Subsidy Table
*   MP.AHCIPFSBrows (i)  number of rows in AHCIPFSB
*   MP.AHCIPINCFLG  (i)  Alberta Health Care Insurance Plan flag to give to highest earner
*   MP.AHCIPIT      (i)  Alberta Health Care Insurance Plan Income Threshold [family type]
*   MP.AHCIPITrows  (i)  number of rows in AHCIPIT
*   MP.AHCIPS       (i)  Alberta Health Care Insurance Plan Single Premium
*   MP.AHCIPSOPT    (i)  Alberta Health Care Insurance Plan Subsidy option (1=table, 2=flat rate)
*   MP.AHCIPSPI     (i)  Alberta Health Care Insurance Plan Senior Exemption Phase In
*   MP.AHCIPSR      (i)  Alberta Health Care Insurance Plan Subsidy Rate
*   MP.AHCIPSSB     (i)  Alberta Health Care Insurance Plan Single Subsidy Table
*   MP.AHCIPSSBrows (i)  number of rows in AHCIPSSB
*   MP.AMAXDX       (i)  Alta Maximum Disability deduction/amount
*   MP.AMAXET       (i)  Alta maximum on transfer of education and tuition amount
*   MP.AMEDALL      (i)  Alta Medical allowance maximum lower limit
*   MP.AMEDANF      (i)  Alta Medical allowance lower limit net income fraction
*   MP.AMXM         (i)  Alta married amount
*   MP.AMXMT        (i)  Alta married amount turndown level
*   MP.AODISTC      (i)  Alta Maximum infirm dependent 18 or older tax credit
*   MP.APNTCR       (i)  Alta provincial non-refundable tax credit rate
*   MP.APTC         (i)  Alberta political contribution table [total donations,donation allowed]
*   MP.APTCBEN      (i)  Maximum Alberta political tax credit allowed
*   MP.APTCrows     (i)  number of rows in APTC
*   MP.APTF         (i)  Alberta provincial tax fraction
*   MP.APTX         (i)  Alta tax table [taxable income,basic provincial tax]
*   MP.APTXrows     (i)  number of rows in APTX
*   MP.ARESREB      (i)  Alberta Resource Rebate Amount
*   MP.ASCI         (i)  Alberta surtax cut-in
*   MP.ASF          (i)  Alberta surtax fraction
*   MP.ATRBC        (i)  Alberta tax reduction basic claim
*   MP.ATRF         (i)  Alberta tax reduction fraction
*   MP.ATXFLG       (i)  Alta tax on taxable income activation flag
*   MP.AYPNDL       (i)  Alta Pension Income Deduction Amount
*   MP.CAMTFTCFLG   (i)  B.C. amt flag for provincial foreign tax credit
*   MP.CAMTOPT      (i)  B.C. alternative minimum tax option
*   MP.CAMTPCTF     (i)  B.C. amt rate as pct of additional fed tax due to minimum tax
*   MP.CAMTPCTM     (i)  B.C. amt rate as pct of federal minimum tax amount
*   MP.CAMTTX       (i)  B.C. amt rate as tax on adjusted income
*   MP.CAXM         (i)  B.C. Age Amount
*   MP.CAXRR        (i)  B.C. Age Amount credit reduction rate
*   MP.CAXTD        (i)  B.C. Age Amount net income turndown
*   MP.CBXM         (i)  B.C. Basic Personal Exemption/amount
*   MP.CCGTC        (i)  B.C. Caregiver Tax Credit
*   MP.CCGTCFLG     (i)  B.C. Caregiver Tax Credit activation flag
*   MP.CCGTCOPT     (i)  B.C. Caregiver Tax Credit Option (1=max, 2=greenbook)
*   MP.CCHATL1      (i)  B.C. Charitable Donations amount level 1
*   MP.CCHATR1      (i)  B.C. Charitable Donations tax credit rate 1
*   MP.CCHATR2      (i)  B.C. Charitable Donations tax credit rate 2
*   MP.CDTCR        (i)  B.C. dividend tax credit rate
*   MP.CDTCRLC      (i)  B.C. dividend tax credit rate from large (eligible) corporations
*   MP.CEDXPM       (i)  B.C. Education Amount per month of full-time studies
*   MP.CEDXPMPT     (i)  B.C. Education Amount per month of part-time studies
*   MP.CEMXM        (i)  B.C. equivalent to married amount
*   MP.CEMXMT       (i)  B.C. equivalent to married turndown level
*   MP.CLITR        (i)  B.C. Low Income Tax Reduction Credit
*   MP.CLITRRR      (i)  B.C. Low Income Tax Reduction Credit reduction rate
*   MP.CLITRTD      (i)  B.C. Low Income Tax Reduction Credit net income turndown
*   MP.CLVCMAX      (i)  Maximum B.C. labour-sponsored funds tax credit allowed
*   MP.CLVCRT       (i)  Percent of B.C. labour-sponsored funds cost allowed as credit
*   MP.CMAXDX       (i)  B.C. Maximum Disability deduction/amount
*   MP.CMAXET       (i)  B.C. maximum on transfer of education and tuition amount
*   MP.CMEDALL      (i)  B.C. Medical allowance maximum lower limit
*   MP.CMEDANF      (i)  B.C. Medical allowance lower limit net income fraction
*   MP.CMSP         (i)  B.C. Medical Services Plan Premium [family size, amount]
*   MP.CMSPADED     (i)  B.C. Medical Services Plan Age 65+ Deduction
*   MP.CMSPCDED     (i)  B.C. Medical Services Plan Child Deduction
*   MP.CMSPDDED     (i)  B.C. Medical Services Plan Disability Deduction
*   MP.CMSPFLAG     (i)  B.C. Medical Services Plan activation flag
*   MP.CMSPINCFLAG  (i)  B.C. Medical Services Plan flag to give to highest earner
*   MP.CMSPRATE     (i)  B.C. Medical Services Plan Subsidy Rate [income, rate]
*   MP.CMSPRATErows (i)  number of rows in CMSPRATE
*   MP.CMSPSDED     (i)  B.C. Medical Services Plan Spouse Deduction
*   MP.CMSProws     (i)  number of rows in CMSP
*   MP.CMXM         (i)  B.C. married amount
*   MP.CMXMT        (i)  B.C. married amount turndown level
*   MP.CODISTC      (i)  B.C. Maximum infirm dependent 18 or older tax credit
*   MP.CPNTCR       (i)  B.C. provincial non-refundable tax credit rate
*   MP.CPTCBEN      (i)  Maximum B.C. political tax credit allowed
*   MP.CPTCREF      (i)  British Columbia political tax credit refundable flag
*   MP.CPTCT        (i)  B.C. political contribution table [total donations,donation allowed]
*   MP.CPTCTrows    (i)  number of rows in CPTCT
*   MP.CPTF         (i)  British Columbia provincial tax fraction
*   MP.CPTX         (i)  B.C. tax table [taxable income,basic provincial tax]
*   MP.CPTXrows     (i)  number of rows in CPTX
*   MP.CRFLAG       (i)  British Columbia rental reduction flag
*   MP.CRTRB        (i)  British Columbia renter tax reduction basic credit
*   MP.CRTRD        (i)  British Columbia renter tax reduction credit for other dependants
*   MP.CRTRP        (i)  British Columbia renter tax reduction proportion of rent allowed
*   MP.CRTRPN       (i)  British Columbia renter tax reduction proportion of net income
*   MP.CRTRS        (i)  British Columbia renter tax reduction credit for spouse
*   MP.CRTRT        (i)  B.C. renter tax reduction base amount turndown [dependants, amount]
*   MP.CRTRTrows    (i)  number of rows in CTCTUR
*   MP.CSCI         (i)  British Columbia surtax first cut-in level
*   MP.CSCI2        (i)  British Columbia surtax second cut-in level
*   MP.CSDC         (i)  British Columbia provincial surtax dependant credit
*   MP.CSF          (i)  British Columbia surtax first level rate
*   MP.CSF2         (i)  British Columbia surtax second level rate
*   MP.CSTC         (i)  British Columbia stc amount
*   MP.CSTCFLAG     (i)  British Columbia sales tax credit flag
*   MP.CSTCKID      (i)  British Columbia stc amount for children
*   MP.CSTCR        (i)  British Columbia stc reduction rate
*   MP.CSTHINC      (i)  British Columbia family head income threshold (stc)
*   MP.CSTKINC      (i)  British Columbia kid income threshold top-up (stc)
*   MP.CSTSINC      (i)  British Columbia spousal income threshold top-up (stc)
*   MP.CSUPCR       (i)  British Columbia supplemental tax credit
*   MP.CTCAPTOBFLG  (i)  Flag to cap tobacco expenditures
*   MP.CTFCID       (i)  Federal custom import duties [com]
*   MP.CTFEXD       (i)  Federal excise duties [com]
*   MP.CTFEXT       (i)  Federal excise taxes [com]
*   MP.CTFGST       (i)  Federal GST [com]
*   MP.CTFGSTHOUSE  (i)  Gst on housing to be allocated [prov][tenure]
*   MP.CTFLAG       (i)  Commodity tax activation flag
*   MP.CTFNEW       (i)  New federal commodity tax [com]
*   MP.CTLPROP      (i)  Local property taxes
*   MP.CTNES        (i)  Expenditures NES
*   MP.CTNUMCOM     (i)  number of rows for commodity dimension parms
*   MP.CTNUMREG     (i)  number of rows in region dimension parms
*   MP.CTOPT        (i)  Commodity tax calculation method [1=SHS,2=SPSM]
*   MP.CTPAMU       (i)  Provincial amusement tax [prov]
*   MP.CTPGAS       (i)  Provincial gasoline tax [com x prov]
*   MP.CTPLGL       (i)  Provincial liquor gallonage tax [prov]
*   MP.CTPNEW       (i)  New provincial commodity tax [com x prov]
*   MP.CTPPLQ       (i)  Provincial profits on liquor commissions [prov]
*   MP.CTPRST       (i)  Provincial retail sales tax [com x prov]
*   MP.CTPTOB       (i)  Provincial tobacco tax [prov]
*   MP.CTSAVE       (i)  All positive savings
*   MP.CTTOBMAX     (i)  Maximum value of tobacco expenditures
*   MP.CTXFLG       (i)  B.C. tax on taxable income activation flag
*   MP.CYPNDL       (i)  B.C. Pension Income Deduction Amount
*   MP.MAMTFTCFLG   (i)  Man. amt flag for provincial foreign tax credit
*   MP.MAMTOPT      (i)  Man. alternative minimum tax option
*   MP.MAMTPCTF     (i)  Man. amt rate as pct of additional fed tax due to minimum tax
*   MP.MAMTPCTM     (i)  Man. amt rate as pct of federal minimum tax amount
*   MP.MAMTTX       (i)  Man. amt rate as tax on adjusted income
*   MP.MANLTCF      (i)  Manitoba learning tax credit factor
*   MP.MANLTMAX     (i)  Manitoba learning tax credit maximum amount per student
*   MP.MAXM         (i)  Man. Age Amount
*   MP.MAXRR        (i)  Man. Age Amount credit reduction rate
*   MP.MAXTD        (i)  Man. Age Amount net income turndown
*   MP.MBXM         (i)  Man. Basic Personal Exemption/amount
*   MP.MCAXM        (i)  Manitoba cost-of-living age credit
*   MP.MCBXM        (i)  Manitoba cost-of-living basic credit
*   MP.MCDISEX      (i)  Manitoba cost-of-living disability credit
*   MP.MCEMXM       (i)  Manitoba cost-of-living married equivalent credit
*   MP.MCFINCRR     (i)  Manitoba cost-of-living family income reduction rate
*   MP.MCGTC        (i)  Man. Caregiver Tax Credit
*   MP.MCGTCFLG     (i)  Man. Caregiver Tax Credit activation flag
*   MP.MCGTCOPT     (i)  Man. Caregiver Tax Credit Option (1=max, 2=greenbook)
*   MP.MCHATL1      (i)  Man. Charitable Donations amount level 1
*   MP.MCHATR1      (i)  Man. Charitable Donations tax credit rate 1
*   MP.MCHATR2      (i)  Man. Charitable Donations tax credit rate 2
*   MP.MCMINAGE     (i)  Manitoba cost-of-living tax credit minimum age
*   MP.MCMXM        (i)  Manitoba cost-of-living married credit
*   MP.MCODISEX     (i)  Manitoba cost-of-living old disabled dependant credit
*   MP.MCSAXM       (i)  Manitoba cost-of-living spouse age credit
*   MP.MCSDISEX     (i)  Manitoba cost-of-living spouse disabled credit
*   MP.MCYCXM       (i)  Manitoba cost-of-living young dependants credit
*   MP.MDTCR        (i)  Man. dividend tax credit rate
*   MP.MDTCRLC      (i)  Man. dividend tax credit rate from large (eligible) corporations
*   MP.MEDXPM       (i)  Man. Education Amount per month of full-time studies
*   MP.MEDXPMPT     (i)  Man. Education Amount per month of part-time studies
*   MP.MEMXM        (i)  Man. equivalent to married amount
*   MP.MEMXMT       (i)  Man. equivalent to married turndown level
*   MP.MHMASOPT     (i)  Manitoba homeowner assistance option (1=Model 2=database)
*   MP.MLVCMAX      (i)  Maximum Man. labour-sponsored funds tax credit allowed
*   MP.MLVCRT       (i)  Percent of Man. labour-sponsored funds cost allowed as credit
*   MP.MMAXDX       (i)  Man. Maximum Disability deduction/amount
*   MP.MMAXET       (i)  Man. maximum on transfer of education and tuition amount
*   MP.MMEDALL      (i)  Man. Medical allowance maximum lower limit
*   MP.MMEDANF      (i)  Man. Medical allowance lower limit net income fraction
*   MP.MMXM         (i)  Man. married amount
*   MP.MMXMT        (i)  Man. married amount turndown level
*   MP.MNITR        (i)  Manitoba net income tax rate
*   MP.MODISTC      (i)  Man. Maximum infirm dependent 18 or older tax credit
*   MP.MPAXM        (i)  Manitoba property tax credit senior citizen credit
*   MP.MPBXM        (i)  Manitoba property tax credit basic credit
*   MP.MPFINCRR     (i)  Manitoba property tax credit family income reduction rate
*   MP.MPMINC       (i)  Manitoba property tax credit minimum credit
*   MP.MPMNTH       (i)  Manitoba property tax minimum threshold
*   MP.MPNTCR       (i)  Man. provincial non-refundable tax credit rate
*   MP.MPRIR        (i)  Manitoba property tax credit rental inclusion rate
*   MP.MPTC         (i)  Manitoba political contribution table [total donations,donation allowed]
*   MP.MPTCBEN      (i)  Maximum Manitoba political tax credit allowed
*   MP.MPTCrows     (i)  number of rows in MPTC
*   MP.MPTF         (i)  Manitoba provincial tax fraction
*   MP.MPTX         (i)  Man. tax table [taxable income,basic provincial tax]
*   MP.MPTXrows     (i)  number of rows in MPTX
*   MP.MRAXM        (i)  Manitoba tax reduction age credit
*   MP.MRBXM        (i)  Manitoba tax reduction basic credit
*   MP.MRDISEX      (i)  Manitoba tax reduction disability credit
*   MP.MREMXM       (i)  Manitoba tax reduction married equivalent credit
*   MP.MRMXM        (i)  Manitoba tax reduction married credit
*   MP.MRODISEX     (i)  Manitoba tax reduction old disabled dependant credit
*   MP.MRSAXM       (i)  Manitoba tax reduction spouse age credit
*   MP.MRYCXM       (i)  Manitoba tax reduction young dependants credit
*   MP.MSAXM        (i)  Manitoba surtax age credit
*   MP.MSBXM        (i)  Manitoba surtax basic credit
*   MP.MSCHAGE      (i)  Manitoba school tax minimum age
*   MP.MSCHBXM      (i)  Manitoba school tax basic amount
*   MP.MSCHFLAG     (i)  Manitoba school tax assistance activation flag
*   MP.MSCHMNTH     (i)  Manitoba school tax minimum threshold
*   MP.MSCHRND      (i)  Manitoba school tax assistance rounding unit
*   MP.MSCHRR       (i)  Manitoba school tax reduction rate
*   MP.MSCHTD       (i)  Manitoba school tax turndown
*   MP.MSDISEX      (i)  Manitoba surtax disability credit
*   MP.MSEMXM       (i)  Manitoba surtax married equivalent credit
*   MP.MSMXM        (i)  Manitoba surtax married credit
*   MP.MSODISEX     (i)  Manitoba surtax old disabled dependant credit
*   MP.MSSAXM       (i)  Manitoba surtax spouse age credit
*   MP.MSYCXM       (i)  Manitoba surtax young dependants credit
*   MP.MTRNIOS      (i)  Manitoba tax reduction net income offset
*   MP.MTXFLG       (i)  Man. tax on taxable income activation flag
*   MP.MYPNDL       (i)  Man. Pension Income Deduction Amount
*   MP.OAMTOPT      (i)  Ont. alternative minimum tax option
*   MP.OAMTPCTF     (i)  Ont. amt rate as pct of additional fed tax due to minimum tax
*   MP.OAMTPCTM     (i)  Ont. amt rate as pct of federal minimum tax amount
*   MP.OAMTTX       (i)  Ont. amt rate as tax on adjusted income
*   MP.OAXM         (i)  Ont. Age Amount
*   MP.OAXRR        (i)  Ont. Age Amount credit reduction rate
*   MP.OAXTD        (i)  Ont. Age Amount net income turndown
*   MP.OBXM         (i)  Ont. Basic Personal Exemption/amount
*   MP.OCAPGIR      (i)  Ont. Capital Gains Inclusion Rate
*   MP.OCGIRFLG     (i)  Ont. Capital Gains Inclusion Rate Activation Flag
*   MP.OCGTC        (i)  Ont. Caregiver Tax Credit
*   MP.OCGTCFLG     (i)  Ont. Caregiver Tax Credit activation flag
*   MP.OCGTCOPT     (i)  Ont. Caregiver Tax Credit Option (1=max, 2=greenbook)
*   MP.OCHATL1      (i)  Ont. Charitable Donations amount level 1
*   MP.OCHATR1      (i)  Ont. Charitable Donations tax credit rate 1
*   MP.OCHATR2      (i)  Ont. Charitable Donations tax credit rate 2
*   MP.ODTCR        (i)  Ont. dividend tax credit rate
*   MP.ODTCRLC      (i)  Ont. dividend tax credit rate from large (eligible) corporations
*   MP.OEDXPM       (i)  Ont. Education Amount per month of full-time studies
*   MP.OEDXPMPT     (i)  Ont. Education Amount per month of part-time studies
*   MP.OEHTDRR      (i)  OEHT - Income Tax Deduction Rate
*   MP.OEHTEX       (i)  OEHT - Exemption
*   MP.OEHTFLAG     (i)  OEHT - Ontario Employer Health Tax Flag
*   MP.OEHTRR1      (i)  OEHT - Rate 1
*   MP.OEHTRR2      (i)  OEHT - Rate 2
*   MP.OEHTRR3      (i)  OEHT - Rate 3
*   MP.OEHTTD1      (i)  OEHT - Turndown 1
*   MP.OEHTTD2      (i)  OEHT - Turndown 2
*   MP.OEMXM        (i)  Ont. equivalent to married amount
*   MP.OEMXMT       (i)  Ont. equivalent to married turndown level
*   MP.OFTCOPT      (i)  Ontario foreign tax credit application option
*   MP.OHPBASE      (i)  Ontario Health Premium table [taxable income,premium]
*   MP.OHPBASErows  (i)  number of rows in OHPBASE
*   MP.OHPFLAG      (i)  Ontario Health Premium activation flag
*   MP.OHPPI        (i)  Ontario Health Premium program phase in
*   MP.OLVCMAX      (i)  Maximum Ont. labour-sponsored funds tax credit allowed
*   MP.OLVCRT       (i)  Percent of Ont. labour-sponsored funds cost allowed as credit
*   MP.OMAXDX       (i)  Ont. Maximum Disability deduction/amount
*   MP.OMAXET       (i)  Ont. maximum on transfer of education and tuition amount
*   MP.OMEDALL      (i)  Ont. Medical allowance maximum lower limit
*   MP.OMEDANF      (i)  Ont. Medical allowance lower limit net income fraction
*   MP.OMXM         (i)  Ont. married amount
*   MP.OMXMT        (i)  Ont. married amount turndown level
*   MP.OODISTC      (i)  Ont. Maximum infirm dependent 18 or older tax credit
*   MP.OPCRA        (i)  Ontario property tax college residence amount
*   MP.OPNTCR       (i)  Ont. provincial non-refundable tax credit rate
*   MP.OPOCAR       (i)  Ontario property tax percent of occupancy cost
*   MP.OPOCM        (i)  Ontario property tax maximum occupancy cost
*   MP.OPRIR        (i)  Ontario property tax credit rental inclusion rate
*   MP.OPSMAX       (i)  Ontario property/sales tax credit maximum
*   MP.OPTC         (i)  Ontario political contribution table [total donations,donation allowed]
*   MP.OPTCBEN      (i)  Maximum Ontario political tax credit allowed
*   MP.OPTCFLAG     (i)  Ontario political contribution refundable tax credit flag
*   MP.OPTCrows     (i)  number of rows in OPTC
*   MP.OPTF         (i)  Ontario provincial tax fraction
*   MP.OPTX         (i)  Ont. tax table [taxable income,basic provincial tax]
*   MP.OPTXrows     (i)  number of rows in OPTX
*   MP.OPYTAX       (i)  Estimate of previous year's Ontario taxes
*   MP.OSPOCM       (i)  Ontario seniors property tax maximum occupancy cost
*   MP.OSPSMAX      (i)  Ontario seniors property/sales tax credit maximum
*   MP.OSSML        (i)  Ontario surtax first cut-in level
*   MP.OSSML2       (i)  Ontario surtax second cut-in level
*   MP.OSSMR        (i)  Ontario surtax first level rate
*   MP.OSSMR2       (i)  Ontario surtax second level rate
*   MP.OSSTCP       (i)  Ontario seniors sales tax credit percent of income
*   MP.OSTCB        (i)  Ontario sales tax credit basic credit
*   MP.OSTCD        (i)  Ontario sales tax credit dependant credit
*   MP.OSTCFLAG     (i)  Ontario seniors tax credit claimed flag
*   MP.OSTCNIBA     (i)  Ontario seniors tax credit net income base amount
*   MP.OSTCNIBC     (i)  Ontario seniors tax credit net income base amount for couples
*   MP.OSTCP        (i)  Ontario sales tax credit percent of income
*   MP.OSTCS        (i)  Ontario sales tax credit spouse credit
*   MP.OTCNIBA      (i)  Ontario tax credit net income base amount
*   MP.OTRBPA       (i)  Ontario tax reduction basic personal amount
*   MP.OTRDCA       (i)  Ontario tax reduction dependant child amount
*   MP.OTRDDA       (i)  Ontario tax reduction disabled dependant amount
*   MP.OTRF         (i)  Ontario tax reduction Ontario tax multiplier
*   MP.OTRFP        (i)  Ontario tax reduction personal amount multiplier
*   MP.OTXDVMAX     (i)  Maximum taxpayer dividend
*   MP.OTXDVMIN     (i)  Minimum taxpayer dividend for people with non-zero taxes
*   MP.OTXFLG       (i)  Ont. tax on taxable income activation flag
*   MP.OYPNDL       (i)  Ont. Pension Income Deduction Amount
*   MP.SAMTOPT      (i)  Sask. alternative minimum tax option
*   MP.SAMTPCTF     (i)  Sask. amt rate as pct of additional fed tax due to minimum tax
*   MP.SAMTPCTM     (i)  Sask. amt rate as pct of federal minimum tax amount
*   MP.SAMTTX       (i)  Sask. amt rate as tax on adjusted income
*   MP.SAXM         (i)  Sask. Age Amount
*   MP.SAXRR        (i)  Sask. Age Amount credit reduction rate
*   MP.SAXTD        (i)  Sask. Age Amount net income turndown
*   MP.SBXM         (i)  Sask. Basic Personal Exemption/amount
*   MP.SCGTC        (i)  Sask. Caregiver Tax Credit
*   MP.SCGTCFLG     (i)  Sask. Caregiver Tax Credit activation flag
*   MP.SCGTCOPT     (i)  Sask. Caregiver Tax Credit Option (1=max, 2=greenbook)
*   MP.SCHATL1      (i)  Sask. Charitable Donations amount level 1
*   MP.SCHATR1      (i)  Sask. Charitable Donations tax credit rate 1
*   MP.SCHATR2      (i)  Sask. Charitable Donations tax credit rate 2
*   MP.SCNTC        (i)  Sask. non-refundable child tax credit amt per child
*   MP.SDSF         (i)  Saskatchewan provincial deficit surtax fraction
*   MP.SDSRA        (i)  Saskatchewan deficit surtax reduction rate
*   MP.SDTCR        (i)  Sask. dividend tax credit rate
*   MP.SDTCRLC      (i)  Sask. dividend tax credit rate from large (eligible) corporations
*   MP.SEDXPM       (i)  Sask. Education Amount per month of full-time studies
*   MP.SEDXPMPT     (i)  Sask. Education Amount per month of part-time studies
*   MP.SEMXM        (i)  Sask. equivalent to married amount
*   MP.SEMXMT       (i)  Sask. equivalent to married turndown level
*   MP.SFTAX        (i)  Saskatchewan provincial flat surtax rate on net income
*   MP.SLVCMAX      (i)  Maximum Sask. labour-sponsored funds tax credit allowed
*   MP.SLVCRT       (i)  Percent of Sask. labour-sponsored funds cost allowed as credit
*   MP.SMAXDX       (i)  Sask. Maximum Disability deduction/amount
*   MP.SMAXET       (i)  Sask. maximum on transfer of education and tuition amount
*   MP.SMEDALL      (i)  Sask. Medical allowance maximum lower limit
*   MP.SMEDANF      (i)  Sask. Medical allowance lower limit net income fraction
*   MP.SMXM         (i)  Sask. married amount
*   MP.SMXMT        (i)  Sask. married amount turndown level
*   MP.SODISTC      (i)  Sask. Maximum infirm dependent 18 or older tax credit
*   MP.SPNTCR       (i)  Sask. provincial non-refundable tax credit rate
*   MP.SPTC         (i)  Saskatchewan political contribution table [total donations,donation allowed]
*   MP.SPTCBEN      (i)  Maximum Saskatchewan political tax credit allowed
*   MP.SPTCrows     (i)  number of rows in SPTC
*   MP.SPTF         (i)  Saskatchewan provincial tax fraction
*   MP.SPTX         (i)  Sask. tax table [taxable income,basic provincial tax]
*   MP.SPTXrows     (i)  number of rows in SPTX
*   MP.SSCI         (i)  Saskatchewan surtax cut-in
*   MP.SSF          (i)  Saskatchewan provincial high income surtax fraction
*   MP.SSSTC        (i)  Sask. senior supplement tax credit
*   MP.SSTC1KIDTD   (i)  Sask. sales tax credit child amount turndown if only 1 child
*   MP.SSTC1KIDTDP  (i)  Sask. sales tax credit child amount turndown if only 1 child for 1st half of year
*   MP.SSTC2KIDTD   (i)  Sask. sales tax credit child amount turndown if more than 1 child
*   MP.SSTC2KIDTDP  (i)  Sask. sales tax credit child amount turndown if more than 1 child for 1st half of year
*   MP.SSTCBAS      (i)  Sask. sales tax credit base amount
*   MP.SSTCBASP     (i)  Sask. sales tax credit base amount for 1st half of year
*   MP.SSTCBASPIR   (i)  Sask. sales tax credit base amount phase in rate
*   MP.SSTCBASPIRP  (i)  Sask. sales tax credit base amount phase in rate for 1st half of year
*   MP.SSTCBASTD    (i)  Sask. sales tax credit base amount turndown
*   MP.SSTCBASTDP   (i)  Sask. sales tax credit base amount turndown for 1st half of year
*   MP.SSTCFLAG     (i)  Sask. sales tax credit activation flag
*   MP.SSTCKID      (i)  Sask. sales tax credit child amount
*   MP.SSTCKIDP     (i)  Sask. sales tax credit child amount for 1st half of year
*   MP.SSTCPI       (i)  Sask. sales tax credit phase in
*   MP.SSTCPI1P     (i)  Sask. sales tax credit phase in for 1st half of year
*   MP.SSTCPI2P     (i)  Sask. sales tax credit phase in for 2nd half of year
*   MP.SSTCRR       (i)  Sask. sales tax credit reduction rate
*   MP.SSTCRRP      (i)  Sask. sales tax credit reduction rate for 1st half of year
*   MP.SSTCSP       (i)  Sask. sales tax credit spousal amount
*   MP.SSTCSPP      (i)  Sask. sales tax credit spousal amount for 1st half of year
*   MP.SSTCSPTD     (i)  Sask. sales tax credit spousal amount turndown
*   MP.SSTCSPTDP    (i)  Sask. sales tax credit spousal amount turndown for 1st half of year
*   MP.SSTR         (i)  Saskatchewan spousal & married equivalent tax reduction
*   MP.STRBA        (i)  Saskatchewan tax reduction base amount
*   MP.STRBR        (i)  Saskatchewan basic provincial tax reduction
*   MP.STRCL        (i)  Saskatchewan child tax reduction limit
*   MP.STRPC        (i)  Saskatchewan tax reduction per child
*   MP.STRRR        (i)  Saskatchewan tax reduction reduction rate
*   MP.STRSC        (i)  Saskatchewan tax reduction for senior citizens
*   MP.STXFLG       (i)  Sask. tax on taxable income activation flag
*   MP.SYPNDL       (i)  Sask. Pension Income Deduction Amount
*
*Called by:
*   mpd      Tax/transfer model parameter definitions
*
*****************************************************************************/
void mpd4(
	P_pc pcp
)
{
	DEBUG_ON("mpd4");

	/*                    Ontario */
	pmaddent(pcp, "2.3.4.5.6",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "OPTF",    (char *)&MP.OPTF,       F_FRACT,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "OFTCOPT", (char *)&MP.OFTCOPT,    NULL,    P_SCL, C_INT, E_OPT,   2, NULL, 0);
	pmaddent(pcp, "OSSML",   (char *)&MP.OSSML,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "OSSML2",  (char *)&MP.OSSML2,    NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "OSSMR",   (char *)&MP.OSSMR,      F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "OSSMR2",  (char *)&MP.OSSMR2,    F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "OPTCFLAG",(char *)&MP.OPTCFLAG,   NULL,    P_SCL, C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "OPTC",    (char *)&MP.OPTC[0][0], NULL,    P_LKPSL, C_NUM, 0,    OPTCMAX, &MP.OPTCrows, 0); 
	pmaddent(pcp, "OPTCBEN", (char *)&MP.OPTCBEN,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);				  
	pmaddent(pcp, "OLVCRT",  (char *)&MP.OLVCRT,     F_FRACT, P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OLVCMAX", (char *)&MP.OLVCMAX,    NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OTXDVMIN",(char *)&MP.OTXDVMIN,   NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OTXDVMAX",(char *)&MP.OTXDVMAX,   NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OPYTAX",  (char *)&MP.OPYTAX,     F_FRACT, P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OHPFLAG", (char *)&MP.OHPFLAG,    NULL,    P_SCL, C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "OHPBASE", (char *)&MP.OHPBASE[0][0], NULL,    P_LKPSL, C_NUM, 0,    OHPBASEMAX, &MP.OHPBASErows, 0); 
	pmaddent(pcp, "OHPPI",   (char *)&MP.OHPPI,      F_FRACT, P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "2.3.4.5.6.1",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "OTRBPA",  (char *)&MP.OTRBPA,     NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "OTRDCA",  (char *)&MP.OTRDCA,     NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "OTRDDA",  (char *)&MP.OTRDDA,     NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "OTRFP",   (char *)&MP.OTRFP,      F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "OTRF",    (char *)&MP.OTRF,       F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "2.3.4.5.6.2",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "OTCNIBA", (char *)&MP.OTCNIBA,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OSTCNIBA",(char *)&MP.OSTCNIBA,   NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OSTCNIBC",(char *)&MP.OSTCNIBC,   NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OSTCFLAG",(char *)&MP.OSTCFLAG,   NULL,    P_SCL, C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "OPRIR",   (char *)&MP.OPRIR,      F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "OPCRA",   (char *)&MP.OPCRA,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OPOCM",   (char *)&MP.OPOCM,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OSPOCM",  (char *)&MP.OSPOCM,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OPOCAR",  (char *)&MP.OPOCAR,     F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "OSTCB",   (char *)&MP.OSTCB,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OSTCS",   (char *)&MP.OSTCS,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OSTCD",   (char *)&MP.OSTCD,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OSTCP",   (char *)&MP.OSTCP,      F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "OSPSMAX", (char *)&MP.OSPSMAX,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OSSTCP",  (char *)&MP.OSSTCP,     F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "OPSMAX",  (char *)&MP.OPSMAX,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "2.3.4.5.6.3",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "OEHTFLAG",(char *)&MP.OEHTFLAG,   NULL,    P_SCL, C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "OEHTEX",  (char *)&MP.OEHTEX,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OEHTTD1", (char *)&MP.OEHTTD1,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OEHTTD2", (char *)&MP.OEHTTD2,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OEHTRR1", (char *)&MP.OEHTRR1,    F_FRACT, P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OEHTRR2", (char *)&MP.OEHTRR2,    F_FRACT, P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OEHTRR3", (char *)&MP.OEHTRR3,    F_FRACT, P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OEHTDRR", (char *)&MP.OEHTDRR,    F_FRACT, P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "2.3.4.5.6.4",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "OTXFLG",  (char *)&MP.OTXFLG,     NULL,    P_SCL, C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "OMXM",    (char *)&MP.OMXM,       NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OMXMT",   (char *)&MP.OMXMT,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OEMXM",   (char *)&MP.OEMXM,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OEMXMT",  (char *)&MP.OEMXMT,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OPNTCR",  (char *)&MP.OPNTCR,     F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "OBXM",    (char *)&MP.OBXM,       NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OAXM",    (char *)&MP.OAXM,       NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OAXTD",   (char *)&MP.OAXTD,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OAXRR",   (char *)&MP.OAXRR,      F_FRACT, P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OYPNDL",  (char *)&MP.OYPNDL,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
    pmaddent(pcp, "OMEDANF", (char *)&MP.OMEDANF,    F_FRACT,   P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "OMEDALL", (char *)&MP.OMEDALL,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
   	pmaddent(pcp, "OCHATL1", (char *)&MP.OCHATL1,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
    pmaddent(pcp, "OCHATR1", (char *)&MP.OCHATR1,    F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "OCHATR2", (char *)&MP.OCHATR2,    F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "OMAXDX",  (char *)&MP.OMAXDX,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OODISTC", (char *)&MP.OODISTC,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OEDXPM",  (char *)&MP.OEDXPM,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OEDXPMPT",(char *)&MP.OEDXPMPT,   NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OMAXET",  (char *)&MP.OMAXET,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OPTX",    (char *)&MP.OPTX[0][0], "8.0 10.4 10.6", P_LKPSL, C_NUM, 0, OPTXMAX, &MP.OPTXrows, 0);
	pmaddent(pcp, "OCGTC",   (char *)&MP.OCGTC,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);				  
	pmaddent(pcp, "OCGTCFLG",(char *)&MP.OCGTCFLG,   NULL,    P_SCL, C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "OCGTCOPT",(char *)&MP.OCGTCOPT,   NULL,    P_SCL, C_INT, E_OPT, 2, NULL, 0);
	pmaddent(pcp, "ODTCR",   (char *)&MP.ODTCR,      F_FRACT,  P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "ODTCRLC", (char *)&MP.ODTCRLC,    F_FRACT,  P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "OAMTOPT", (char *)&MP.OAMTOPT,    NULL,    P_SCL, C_INT, E_OPT,   4, NULL, 0);
	pmaddent(pcp, "OAMTTX",  (char *)&MP.OAMTTX,     F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "OAMTPCTF",(char *)&MP.OAMTPCTF,   F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "OAMTPCTM",(char *)&MP.OAMTPCTM,   F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "OCGIRFLG",(char *)&MP.OCGIRFLG,     NULL,    P_SCL, C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "OCAPGIR", (char *)&MP.OCAPGIR,     F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	/*                    Manitoba */
	pmaddent(pcp, "2.3.4.5.7",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "MPTF",     (char *)&MP.MPTF,       F_FRACT,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MNITR",    (char *)&MP.MNITR,      F_FRACT,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MPTC",     (char *)&MP.MPTC[0][0], NULL,    P_LKPSL, C_NUM, 0,    MPTCMAX, &MP.MPTCrows, 0); 
	pmaddent(pcp, "MPTCBEN",  (char *)&MP.MPTCBEN,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);				  
	pmaddent(pcp, "MANLTCF",  (char *)&MP.MANLTCF,    F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "MANLTMAX", (char *)&MP.MANLTMAX,   NULL, P_SCL, C_NUM, 0, 0, NULL, 0);
	pmaddent(pcp, "MLVCRT",  (char *)&MP.MLVCRT,     F_FRACT, P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "MLVCMAX", (char *)&MP.MLVCMAX,    NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "2.3.4.5.7.1",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "MRBXM",    (char *)&MP.MRBXM,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MRMXM",    (char *)&MP.MRMXM,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MREMXM",   (char *)&MP.MREMXM,     NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MRAXM",    (char *)&MP.MRAXM,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MRSAXM",   (char *)&MP.MRSAXM,     NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MRDISEX",  (char *)&MP.MRDISEX,    NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MRODISEX", (char *)&MP.MRODISEX,   NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MRYCXM",   (char *)&MP.MRYCXM,     NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MTRNIOS",  (char *)&MP.MTRNIOS,    F_FRACT,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "2.3.4.5.7.2",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "MSBXM",    (char *)&MP.MSBXM,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MSMXM",    (char *)&MP.MSMXM,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MSEMXM",   (char *)&MP.MSEMXM,     NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MSAXM",    (char *)&MP.MSAXM,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MSSAXM",   (char *)&MP.MSSAXM,     NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MSDISEX",  (char *)&MP.MSDISEX,    NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MSODISEX", (char *)&MP.MSODISEX,   NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MSYCXM",   (char *)&MP.MSYCXM,     NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "2.3.4.5.7.3",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "MCBXM",    (char *)&MP.MCBXM,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MCMXM",    (char *)&MP.MCMXM,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MCEMXM",   (char *)&MP.MCEMXM,     NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MCAXM",    (char *)&MP.MCAXM,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MCSAXM",   (char *)&MP.MCSAXM,     NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MCDISEX",  (char *)&MP.MCDISEX,    NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MCSDISEX", (char *)&MP.MCSDISEX,   NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MCODISEX", (char *)&MP.MCODISEX,   NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MCYCXM",   (char *)&MP.MCYCXM,     NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MCFINCRR", (char *)&MP.MCFINCRR,   F_FRACT,    P_SCL, C_NUM, E_FRCT,  0, NULL, 0);
	pmaddent(pcp, "MCMINAGE", (char *)&MP.MCMINAGE,   NULL,    P_SCL, C_INT, 0,       0, NULL, 0);
	pmaddent(pcp, "2.3.4.5.7.4",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "MPRIR",    (char *)&MP.MPRIR,      F_FRACT,    P_SCL, C_NUM, E_FRCT,  0, NULL, 0);
	pmaddent(pcp, "MPBXM",    (char *)&MP.MPBXM,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MPAXM",    (char *)&MP.MPAXM,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MPFINCRR", (char *)&MP.MPFINCRR,   F_FRACT,    P_SCL, C_NUM, E_FRCT,  0, NULL, 0);
	pmaddent(pcp, "MPMINC",   (char *)&MP.MPMINC,     NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MPMNTH",   (char *)&MP.MPMNTH,     NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MHMASOPT", (char *)&MP.MHMASOPT,   NULL,    P_SCL, C_INT, E_OPT,   2, NULL, 0);
	pmaddent(pcp, "MSCHFLAG", (char *)&MP.MSCHFLAG,   NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "MSCHAGE",  (char *)&MP.MSCHAGE,    NULL,    P_SCL, C_INT, 0,       0, NULL, 0);
	pmaddent(pcp, "MSCHMNTH", (char *)&MP.MSCHMNTH,   NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MSCHTD",   (char *)&MP.MSCHTD,     NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MSCHRND",  (char *)&MP.MSCHRND,    NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MSCHBXM",  (char *)&MP.MSCHBXM,    NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "MSCHRR",   (char *)&MP.MSCHRR,     F_FRACT, P_SCL, C_NUM, E_FRCT,  0, NULL, 0);
	pmaddent(pcp, "2.3.4.5.7.5",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "MTXFLG",  (char *)&MP.MTXFLG,     NULL,    P_SCL, C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "MMXM",    (char *)&MP.MMXM,       NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "MMXMT",   (char *)&MP.MMXMT,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "MEMXM",   (char *)&MP.MEMXM,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "MEMXMT",  (char *)&MP.MEMXMT,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "MPNTCR",  (char *)&MP.MPNTCR,     F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "MBXM",    (char *)&MP.MBXM,       NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "MAXM",    (char *)&MP.MAXM,       NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "MAXTD",   (char *)&MP.MAXTD,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "MAXRR",   (char *)&MP.MAXRR,      F_FRACT, P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "MYPNDL",  (char *)&MP.MYPNDL,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
    pmaddent(pcp, "MMEDANF", (char *)&MP.MMEDANF,    F_FRACT,   P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "MMEDALL", (char *)&MP.MMEDALL,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
   	pmaddent(pcp, "MCHATL1", (char *)&MP.MCHATL1,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
    pmaddent(pcp, "MCHATR1", (char *)&MP.MCHATR1,    F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "MCHATR2", (char *)&MP.MCHATR2,    F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "MMAXDX",  (char *)&MP.MMAXDX,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "MODISTC", (char *)&MP.MODISTC,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "MEDXPM",  (char *)&MP.MEDXPM,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "MEDXPMPT",(char *)&MP.MEDXPMPT,   NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "MMAXET",  (char *)&MP.MMAXET,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "MPTX",    (char *)&MP.MPTX[0][0], "8.0 10.4 10.6", P_LKPSL, C_NUM, 0, MPTXMAX, &MP.MPTXrows, 0);
	pmaddent(pcp, "MCGTC",   (char *)&MP.MCGTC,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);				  
	pmaddent(pcp, "MCGTCFLG",(char *)&MP.MCGTCFLG,   NULL,    P_SCL, C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "MCGTCOPT",(char *)&MP.MCGTCOPT,   NULL,    P_SCL, C_INT, E_OPT, 2, NULL, 0);
	pmaddent(pcp, "MDTCR",   (char *)&MP.MDTCR,      F_FRACT,  P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "MDTCRLC", (char *)&MP.MDTCRLC,    F_FRACT,  P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "MAMTOPT", (char *)&MP.MAMTOPT,    NULL,    P_SCL, C_INT, E_OPT,   4, NULL, 0);
	pmaddent(pcp, "MAMTTX",  (char *)&MP.MAMTTX,     F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "MAMTPCTF",(char *)&MP.MAMTPCTF,   F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "MAMTPCTM",(char *)&MP.MAMTPCTM,   F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "MAMTFTCFLG",(char *)&MP.MAMTFTCFLG,   NULL,    P_SCL, C_INT, E_FLAG, 0, NULL, 0);

   /*                    Saskatchewan */
	pmaddent(pcp, "2.3.4.5.8",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "SDSRA",    (char *)&MP.SDSRA,     NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "SPTF",     (char *)&MP.SPTF,      F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "SFTAX",    (char *)&MP.SFTAX,     F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "SDSF",     (char *)&MP.SDSF,      F_FRACT,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "SSF",      (char *)&MP.SSF,       F_FRACT,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "SSCI",     (char *)&MP.SSCI,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "STRBR",    (char *)&MP.STRBR,     NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "SSTR",     (char *)&MP.SSTR,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "STRCL",    (char *)&MP.STRCL,     NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "STRPC",    (char *)&MP.STRPC,     NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "STRSC",    (char *)&MP.STRSC,     NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "STRRR",    (char *)&MP.STRRR,     F_FRACT,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "STRBA",    (char *)&MP.STRBA,     NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "SPTC",     (char *)&MP.SPTC[0][0], NULL,    P_LKPSL, C_NUM, 0,    SPTCMAX, &MP.SPTCrows, 0); 
	pmaddent(pcp, "SPTCBEN",  (char *)&MP.SPTCBEN,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);				  
	pmaddent(pcp, "SLVCRT",   (char *)&MP.SLVCRT,     F_FRACT, P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "SLVCMAX",  (char *)&MP.SLVCMAX,    NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "SSTCFLAG", (char *)&MP.SSTCFLAG,   NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "SSTCBAS",  (char *)&MP.SSTCBAS,    NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "SSTCBASTD",(char *)&MP.SSTCBASTD,  NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "SSTCSP",   (char *)&MP.SSTCSP,     NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "SSTCSPTD", (char *)&MP.SSTCSPTD,   NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "SSTCKID",  (char *)&MP.SSTCKID,    NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "SSTC1KIDTD",(char *)&MP.SSTC1KIDTD, NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "SSTC2KIDTD",(char *)&MP.SSTC2KIDTD,   NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "SSTCRR",   (char *)&MP.SSTCRR,     F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "SSTCBASPIR",(char *)&MP.SSTCBASPIR,  F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "SSTCPI",   (char *)&MP.SSTCPI,     F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "SSTCBASP", (char *)&MP.SSTCBASP,   NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "SSTCBASTDP",(char *)&MP.SSTCBASTDP, NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "SSTCSPP",  (char *)&MP.SSTCSPP,    NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "SSTCSPTDP",(char *)&MP.SSTCSPTDP,  NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "SSTCKIDP", (char *)&MP.SSTCKIDP,   NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "SSTC1KIDTDP",(char *)&MP.SSTC1KIDTDP, NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "SSTC2KIDTDP",(char *)&MP.SSTC2KIDTDP,  NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "SSTCRRP",  (char *)&MP.SSTCRRP,     F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "SSTCBASPIRP",(char *)&MP.SSTCBASPIRP,  F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "SSTCPI1P",  (char *)&MP.SSTCPI1P,    F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "SSTCPI2P",  (char *)&MP.SSTCPI2P,    F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "2.3.4.5.8.1",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "STXFLG",  (char *)&MP.STXFLG,     NULL,    P_SCL, C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "SMXM",    (char *)&MP.SMXM,       NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "SMXMT",   (char *)&MP.SMXMT,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "SEMXM",   (char *)&MP.SEMXM,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "SEMXMT",  (char *)&MP.SEMXMT,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "SPNTCR",  (char *)&MP.SPNTCR,     F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "SBXM",    (char *)&MP.SBXM,       NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "SAXM",    (char *)&MP.SAXM,       NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "SAXTD",   (char *)&MP.SAXTD,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "SAXRR",   (char *)&MP.SAXRR,      F_FRACT, P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "SYPNDL",  (char *)&MP.SYPNDL,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
    pmaddent(pcp, "SMEDANF", (char *)&MP.SMEDANF,    F_FRACT,   P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "SMEDALL", (char *)&MP.SMEDALL,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
   	pmaddent(pcp, "SCHATL1", (char *)&MP.SCHATL1,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
    pmaddent(pcp, "SCHATR1", (char *)&MP.SCHATR1,    F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "SCHATR2", (char *)&MP.SCHATR2,    F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "SMAXDX",  (char *)&MP.SMAXDX,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "SODISTC", (char *)&MP.SODISTC,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "SEDXPM",  (char *)&MP.SEDXPM,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "SEDXPMPT",(char *)&MP.SEDXPMPT,   NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "SMAXET",  (char *)&MP.SMAXET,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "SPTX",    (char *)&MP.SPTX[0][0], "8.0 10.4 10.6", P_LKPSL, C_NUM, 0, SPTXMAX, &MP.SPTXrows, 0);
	pmaddent(pcp, "SCGTC",   (char *)&MP.SCGTC,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);				  
	pmaddent(pcp, "SCGTCFLG",(char *)&MP.SCGTCFLG,   NULL,    P_SCL, C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "SCGTCOPT",(char *)&MP.SCGTCOPT,   NULL,    P_SCL, C_INT, E_OPT, 2, NULL, 0);
	pmaddent(pcp, "SDTCR",   (char *)&MP.SDTCR,      F_FRACT,  P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "SDTCRLC", (char *)&MP.SDTCRLC,    F_FRACT,  P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "SAMTOPT", (char *)&MP.SAMTOPT,    NULL,    P_SCL, C_INT, E_OPT,   4, NULL, 0);
	pmaddent(pcp, "SAMTTX",  (char *)&MP.SAMTTX,     F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "SAMTPCTF",(char *)&MP.SAMTPCTF,   F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "SAMTPCTM",(char *)&MP.SAMTPCTM,   F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "SCNTC",   (char *)&MP.SCNTC,     NULL,    P_SCL, C_NUM, 0,     0, NULL, 0);				  
	pmaddent(pcp, "SSSTC",   (char *)&MP.SSSTC,     NULL,    P_SCL, C_NUM, 0,     0, NULL, 0);				  
	/*                    Alberta */
	pmaddent(pcp, "2.3.4.5.9",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "APTF",    (char *)&MP.APTF,       F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "ASCI",    (char *)&MP.ASCI,       NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "ASF",     (char *)&MP.ASF,        F_FRACT,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "AFTAX",   (char *)&MP.AFTAX,       F_FRACT,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "ATRBC",   (char *)&MP.ATRBC,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "ATRF",    (char *)&MP.ATRF,       F_FRACT,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "APTC",    (char *)&MP.APTC[0][0], NULL,    P_LKPSL, C_NUM, 0,    APTCMAX, &MP.APTCrows, 0); 
	pmaddent(pcp, "APTCBEN", (char *)&MP.APTCBEN,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);				  
	pmaddent(pcp, "AFETCFLAG",(char *)&MP.AFETCFLAG,   NULL,    P_SCL, C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "AFETCAPC", (char *)&MP.AFETCAPC[0],   "8.2",   P_VCT, C_NUM, E_FIXL,  AFETCAPCMAX, &MP.AFETCAPCrows, 0, "childf");
	pmaddent(pcp, "AFETCNC",  (char *)&MP.AFETCNC,       NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "AFETCCI",  (char *)&MP.AFETCCI,       NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "AFETCBR",  (char *)&MP.AFETCBR,        F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "AFETCTD",  (char *)&MP.AFETCTD,       NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "AFETCRR",  (char *)&MP.AFETCRR,       F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "AFETCPI",  (char *)&MP.AFETCPI,       F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "AFETCAPCP",(char *)&MP.AFETCAPCP[0],  "8.2",   P_VCT, C_NUM, E_FIXL,  AFETCAPCMAX, &MP.AFETCAPCrows, 0, "childf");
	pmaddent(pcp, "AFETCNCP", (char *)&MP.AFETCNCP,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "AFETCCIP", (char *)&MP.AFETCCIP,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "AFETCBRP", (char *)&MP.AFETCBRP,      F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "AFETCTDP", (char *)&MP.AFETCTDP,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "AFETCRRP", (char *)&MP.AFETCRRP,      F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "AFETCPIP", (char *)&MP.AFETCPIP,      F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "ARESREB",  (char *)&MP.ARESREB,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);				  
	pmaddent(pcp, "2.3.4.5.9.1",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "AHCIPFLG", (char *)&MP.AHCIPFLG,     NULL,    P_SCL, C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "AHCIPS",   (char *)&MP.AHCIPS,       NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "AHCIPF",   (char *)&MP.AHCIPF,       NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "AHCIPINCFLG", (char *)&MP.AHCIPINCFLG,     NULL,    P_SCL, C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "AHCIPSR",  (char *)&MP.AHCIPSR,       F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "AHCIPIT",  (char *)&MP.AHCIPIT[0],   "8.2",   P_VCT, C_NUM, E_FIXL,  AHCIPITMAX, &MP.AHCIPITrows, 0, "aftype");
	pmaddent(pcp, "AHCIPSOPT",(char *)&MP.AHCIPSOPT,    NULL,    P_SCL, C_INT, E_OPT,   2, NULL, 0);
	pmaddent(pcp, "AHCIPSSB", (char *)&MP.AHCIPSSB[0][0],F_LKTUR, P_LKPXY, C_NUM, E_NONE, AHCIPSSBMAX, &MP.AHCIPSSBrows, 0);
	pmaddent(pcp, "AHCIPFSB", (char *)&MP.AHCIPFSB[0][0],F_LKTUR, P_LKPXY, C_NUM, E_NONE, AHCIPFSBMAX, &MP.AHCIPFSBrows, 0);
	pmaddent(pcp, "AHCIPSPI", (char *)&MP.AHCIPSPI,      F_FRACT, P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "2.3.4.5.9.2",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "ATXFLG",  (char *)&MP.ATXFLG,     NULL,    P_SCL, C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "AMXM",    (char *)&MP.AMXM,       NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "AMXMT",   (char *)&MP.AMXMT,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "AEMXM",   (char *)&MP.AEMXM,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "AEMXMT",  (char *)&MP.AEMXMT,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "APNTCR",  (char *)&MP.APNTCR,     F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "ABXM",    (char *)&MP.ABXM,       NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "AAXM",    (char *)&MP.AAXM,       NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "AAXTD",   (char *)&MP.AAXTD,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "AAXRR",   (char *)&MP.AAXRR,      F_FRACT, P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "AYPNDL",  (char *)&MP.AYPNDL,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
    pmaddent(pcp, "AMEDANF", (char *)&MP.AMEDANF,    F_FRACT,   P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "AMEDALL", (char *)&MP.AMEDALL,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
   	pmaddent(pcp, "ACHATL1", (char *)&MP.ACHATL1,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
    pmaddent(pcp, "ACHATR1", (char *)&MP.ACHATR1,    F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "ACHATR2", (char *)&MP.ACHATR2,    F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "AMAXDX",  (char *)&MP.AMAXDX,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "AODISTC", (char *)&MP.AODISTC,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "AEDXPM",  (char *)&MP.AEDXPM,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "AEDXPMPT",(char *)&MP.AEDXPMPT,   NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "AMAXET",  (char *)&MP.AMAXET,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "APTX",    (char *)&MP.APTX[0][0], "8.0 10.4 10.6", P_LKPSL, C_NUM, 0, APTXMAX, &MP.APTXrows, 0);
	pmaddent(pcp, "ACGTC",   (char *)&MP.ACGTC,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);				  
	pmaddent(pcp, "ACGTCFLG",(char *)&MP.ACGTCFLG,   NULL,    P_SCL, C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "ACGTCOPT",(char *)&MP.ACGTCOPT,   NULL,    P_SCL, C_INT, E_OPT, 2, NULL, 0);
	pmaddent(pcp, "ADTCR",   (char *)&MP.ADTCR,      F_FRACT,  P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "ADTCRLC", (char *)&MP.ADTCRLC,    F_FRACT,  P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "AAMTOPT", (char *)&MP.AAMTOPT,    NULL,    P_SCL, C_INT, E_OPT,   4, NULL, 0);
	pmaddent(pcp, "AAMTTX",  (char *)&MP.AAMTTX,     F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "AAMTPCTF",(char *)&MP.AAMTPCTF,   F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "AAMTPCTM",(char *)&MP.AAMTPCTM,   F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	/*                    British Columbia */
	pmaddent(pcp, "2.3.4.5.10",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "CPTF",    (char *)&MP.CPTF,       F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "CSCI",    (char *)&MP.CSCI,       NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "CSCI2",   (char *)&MP.CSCI2,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "CSF",     (char *)&MP.CSF,        F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "CSF2",    (char *)&MP.CSF2,       F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "CSDC",    (char *)&MP.CSDC,       NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "CPTCT",   (char *)&MP.CPTCT[0][0],NULL,    P_LKPSL, C_NUM, 0,    CPTCTMAX, &MP.CPTCTrows, 0); 
	pmaddent(pcp, "CPTCBEN", (char *)&MP.CPTCBEN,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "CPTCREF", (char *)&MP.CPTCREF,    NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "CRTRP",   (char *)&MP.CRTRP,      F_FRACT, P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "CRTRB",   (char *)&MP.CRTRB,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "CRTRS",   (char *)&MP.CRTRS,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "CRTRD",   (char *)&MP.CRTRD,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "CRTRPN",  (char *)&MP.CRTRPN,     F_FRACT,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "CRTRT",   (char *)&MP.CRTRT[0][0], F_LKTUR, P_LKPXY,C_NUM, 0, CRTRTMAX, &MP.CRTRTrows, 0);
	pmaddent(pcp, "CRFLAG",  (char *)&MP.CRFLAG,     NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "CSUPCR",  (char *)&MP.CSUPCR,     NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "CSTCFLAG",(char *)&MP.CSTCFLAG,   NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "CSTHINC", (char *)&MP.CSTHINC,    NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "CSTSINC", (char *)&MP.CSTSINC,    NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "CSTKINC", (char *)&MP.CSTKINC,    NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "CSTCR",   (char *)&MP.CSTCR,      NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "CSTC",    (char *)&MP.CSTC,       NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "CSTCKID", (char *)&MP.CSTCKID,    NULL,    P_SCL, C_NUM, 0,       0, NULL, 0);
	pmaddent(pcp, "CLITR",   (char *)&MP.CLITR,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "CLITRTD", (char *)&MP.CLITRTD,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "CLITRRR", (char *)&MP.CLITRRR,    F_FRACT, P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "CLVCRT",  (char *)&MP.CLVCRT,     F_FRACT, P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "CLVCMAX", (char *)&MP.CLVCMAX,    NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "2.3.4.5.10.1",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "CMSPFLAG",(char *)&MP.CMSPFLAG,   NULL,    P_SCL, C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "CMSP",    (char *)&MP.CMSP[0][0], F_LKTUR, P_LKPXY, C_NUM, 0, CMSPMAX, &MP.CMSProws, 0);
	pmaddent(pcp, "CMSPINCFLAG",(char *)&MP.CMSPINCFLAG,   NULL,    P_SCL, C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "CMSPSDED",(char *)&MP.CMSPSDED,   NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "CMSPADED",(char *)&MP.CMSPADED,   NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "CMSPCDED",(char *)&MP.CMSPCDED,   NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "CMSPDDED",(char *)&MP.CMSPDDED,   NULL,     P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "CMSPRATE",(char *)&MP.CMSPRATE[0][0],F_LKTUR, P_LKPXY, C_NUM, E_NONE, CMSPRATEMAX, &MP.CMSPRATErows, 0);
	pmaddent(pcp, "2.3.4.5.10.2",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "CTXFLG",  (char *)&MP.CTXFLG,     NULL,    P_SCL, C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "CMXM",    (char *)&MP.CMXM,       NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "CMXMT",   (char *)&MP.CMXMT,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "CEMXM",   (char *)&MP.CEMXM,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "CEMXMT",  (char *)&MP.CEMXMT,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "CPNTCR",  (char *)&MP.CPNTCR,     F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "CBXM",    (char *)&MP.CBXM,       NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "CAXM",    (char *)&MP.CAXM,       NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "CAXTD",   (char *)&MP.CAXTD,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "CAXRR",   (char *)&MP.CAXRR,      F_FRACT, P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "CYPNDL",  (char *)&MP.CYPNDL,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
    pmaddent(pcp, "CMEDANF", (char *)&MP.CMEDANF,    F_FRACT,   P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "CMEDALL", (char *)&MP.CMEDALL,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
   	pmaddent(pcp, "CCHATL1", (char *)&MP.CCHATL1,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
    pmaddent(pcp, "CCHATR1", (char *)&MP.CCHATR1,    F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "CCHATR2", (char *)&MP.CCHATR2,    F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "CMAXDX",  (char *)&MP.CMAXDX,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "CODISTC", (char *)&MP.CODISTC,    NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "CEDXPM",  (char *)&MP.CEDXPM,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "CEDXPMPT",(char *)&MP.CEDXPMPT,   NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "CMAXET",  (char *)&MP.CMAXET,     NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "CPTX",    (char *)&MP.CPTX[0][0], "8.0 10.4 10.6", P_LKPSL, C_NUM, 0, CPTXMAX, &MP.CPTXrows, 0);
	pmaddent(pcp, "CCGTC",   (char *)&MP.CCGTC,      NULL,    P_SCL, C_NUM, 0,      0, NULL, 0);				  
	pmaddent(pcp, "CCGTCFLG",(char *)&MP.CCGTCFLG,   NULL,    P_SCL, C_INT, E_FLAG, 0, NULL, 0);
	pmaddent(pcp, "CCGTCOPT",(char *)&MP.CCGTCOPT,   NULL,    P_SCL, C_INT, E_OPT,  2, NULL, 0);
	pmaddent(pcp, "CDTCR",   (char *)&MP.CDTCR,      F_FRACT,  P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "CDTCRLC", (char *)&MP.CDTCRLC,    F_FRACT,  P_SCL, C_NUM, 0,      0, NULL, 0);
	pmaddent(pcp, "CAMTOPT", (char *)&MP.CAMTOPT,    NULL,    P_SCL, C_INT, E_OPT,   4, NULL, 0);
	pmaddent(pcp, "CAMTTX",  (char *)&MP.CAMTTX,     F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "CAMTPCTF",(char *)&MP.CAMTPCTF,   F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "CAMTPCTM",(char *)&MP.CAMTPCTM,   F_FRACT, P_SCL, C_NUM, E_FRCT, 0, NULL, 0);
	pmaddent(pcp, "CAMTFTCFLG",(char *)&MP.CAMTFTCFLG,   NULL,    P_SCL, C_INT, E_FLAG, 0, NULL, 0);
	/*               Commodity Taxes */
	pmaddent(pcp, "2.3.5",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);
	pmaddent(pcp, "CTFLAG",  (char *)&MP.CTFLAG,     NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "CTOPT",   (char *)&MP.CTOPT,      NULL,    P_SCL, C_INT, E_OPT,   2, NULL, 0);
	pmaddent(pcp, "CTFCID",  (char *)MP.CTFCID,      NULL,    P_VCT, C_NUM, E_FIXL, NUMCOM, &MP.CTNUMCOM, 0, "com");
	pmaddent(pcp, "CTFEXD",  (char *)MP.CTFEXD,      NULL,    P_VCT, C_NUM, E_FIXL, NUMCOM, &MP.CTNUMCOM, 0, "com");
	pmaddent(pcp, "CTFEXT",  (char *)MP.CTFEXT,      NULL,    P_VCT, C_NUM, E_FIXL, NUMCOM, &MP.CTNUMCOM, 0, "com");
	pmaddent(pcp, "CTFGST",  (char *)MP.CTFGST,      NULL,    P_VCT, C_NUM, E_FIXL, NUMCOM, &MP.CTNUMCOM, 0, "com");
	pmaddent(pcp, "CTFGSTHOUSE",(char *)MP.CTFGSTHOUSE, NULL,    P_TBL, C_NUM, E_FIXL, NUMREG, &MP.CTNUMREG, 2, "prov", "tenur");
	pmaddent(pcp, "CTFNEW",  (char *)MP.CTFNEW,      NULL,    P_VCT, C_NUM, E_FIXL, NUMCOM, &MP.CTNUMCOM, 0, "com");
	pmaddent(pcp, "CTPPLQ",  (char *)MP.CTPPLQ,      NULL,    P_VCT, C_NUM, E_FIXL, NUMREG, &MP.CTNUMREG, 0, "prov");
	pmaddent(pcp, "CTPLGL",  (char *)MP.CTPLGL,      NULL,    P_VCT, C_NUM, E_FIXL, NUMREG, &MP.CTNUMREG, 0, "prov");
	pmaddent(pcp, "CTPGAS",  (char *)MP.CTPGAS,      NULL,    P_TBL, C_NUM, E_FIXL, NUMCOM, &MP.CTNUMCOM, NUMREG, "com", "prov");
	pmaddent(pcp, "CTPAMU",  (char *)MP.CTPAMU,      NULL,    P_VCT, C_NUM, E_FIXL, NUMREG, &MP.CTNUMREG, 0, "prov");
	pmaddent(pcp, "CTPTOB",  (char *)MP.CTPTOB,      NULL,    P_VCT, C_NUM, E_FIXL, NUMREG, &MP.CTNUMREG, 0, "prov");
	pmaddent(pcp, "CTPRST",  (char *)MP.CTPRST,      NULL,    P_TBL, C_NUM, E_FIXL, NUMCOM, &MP.CTNUMCOM, NUMREG, "com", "prov");
	pmaddent(pcp, "CTPNEW",  (char *)MP.CTPNEW,      NULL,    P_TBL, C_NUM, E_FIXL, NUMCOM, &MP.CTNUMCOM, NUMREG, "com", "prov");
	pmaddent(pcp, "CTLPROP", (char *)&MP.CTLPROP,    NULL,    P_SCL, C_NUM,      0,      0,         NULL, 0);
	pmaddent(pcp, "CTNES",   (char *)&MP.CTNES,      NULL,    P_SCL, C_NUM,      0,      0,         NULL, 0);
	pmaddent(pcp, "CTSAVE",  (char *)&MP.CTSAVE,     NULL,    P_SCL, C_NUM,      0,      0,         NULL, 0);
	pmaddent(pcp, "CTCAPTOBFLG", (char *)&MP.CTCAPTOBFLG,     NULL,    P_SCL, C_INT, E_FLAG,  0, NULL, 0);
	pmaddent(pcp, "CTTOBMAX",(char *)&MP.CTTOBMAX,   NULL,    P_SCL, C_NUM,      0,      0,         NULL, 0);

	pmaddent(pcp, "2.3.6",   NULL,                     NULL,    P_DUMMY, C_STR, 0,    0, NULL, 0);

	DEBUG_OFF("mpd4");
}



