/***
*vsdm.cpp - Define standard algorithm SPSM variables
*
*$Id: vsdm.cpp 6.196 2007/09/18 17:22:12 hickcha Exp $
*
*   SPSD/M Copyright (c) 1987-1995, Minister of Industry.
*   All rights reserved.  Use, reproduction, or disclosure of this work,
*   as well as publication of results derived from this work, are subject
*   to the conditions specified in the SPSD/M License Agreement.
*
*Purpose:
*   This file contains the definition of the .c function.
*
*Revisions:
* +-----+----------+---------------------------------------------------------+
* | Who |   Date   | Description                                             |
* +-----+----------+---------------------------------------------------------+
* | CH  | 07/07/30 | Added imqbtax and imqtuitt                              |
* | CH  | 07/07/23 | Added ctpnew and ctfnew                                 |
* | CH  | 07/07/17 | Added imqctpc imqtctc imqtpcn                           |
* | LP  | 07/07/08 | Added Manitoba Child Benefit - immcb                    |
* | CH  | 07/06/25 | Added ctfgsths                                          |
* | LP  | 07/06/04 | Added Ontario Child Benefit - imocb and imocbyng        |
* | LP  | 07/04/24 | Added non-ref child Tax credit - imchdtxc               |
* | LP  | 07/04/04 | Added Working Income Tax Benefit - imwitb, imwitbs      |
* | CH  | 07/02/22 | Make pension income split variables fractional          |
* | CH  | 07/02/19 | Added commodity tax array variables                     |
* | CH  | 07/02/06 | Added pension income splitting                          |
* | LP  | 07/01/23 | Removed imninc - no income flag - no longer used        |
* | LP  | 07/01/15 | Removed impucctc, changed to impyctxc-yng child tx cred |
* | LP  | 06/06/14 | Added imbcss - B.C. Senior Supplement (part of SA)      |
* | LP  | 06/06/01 | Added N.S. Universal Child Care Benefit credit,impucctc |
* | LP  | 06/05/25 | Added Universal Child Care Benefit amount - imuccb      |
* | LP  | 06/05/15 | Added small/lrg corp dividend(taxable) imisdivt,imildivt|
* | LP  | 06/05/05 | Added Canada Employment Credit - imemptxc               |
* | LP  | 06/05/05 | Added federal text book non-ref tax credit - imtxttxc   |
* | CH  | 06/01/04 | Added federal QPIP self-employed credit and deduction   |
* | LP  | 05/12/16 | Added QPIP premium and benefit variables                |
* | LP  | 05/12/01 | Removed ctfoen & ctfmfg - pre 91 variables deleted      |
* | LP  | 05/11/09 | Added imictot, imicnet - tax form total and net income  |
* | LP  | 05/11/04 | Added imresreb - Alberta Resource Rebate amount         |
* | LP  | 05/10/21 | Added imfecb - Federal Energy Cost Benefit amount       |
* | LP  | 05/08/10 | Added imsaclaw - CTB/SA calculated clawback amount      |
* | LP  | 05/07/12 | Added back imashelt - reinstitute CTB/SA clawbacks      |
* | LP  | 05/05/30 | Added imqncgtc, Que. Refund. Natural Caregivers tax cred|
* | LP  | 05/05/11 | Added imqempdd - earned income deduction for workers    |
* | CH  | 04/08/10 | Deleted imqodtc - no longer used                        |
* | CH  | 04/08/09 | Added income of designated dependant child              |
* | LP  | 04/06/18 | Added imqca and imqodtc - Que. Child Assistance cred    |
* | LP  | 04/06/09 | Added imqwrkpr - Que. Work Premium refundable tax cred  |
* | LP  | 04/06/04 | Added imphp - Provincial Health Premium                 |
* | LP  | 04/06/02 | Added imopstc - Ont. prop/sales tax credit calc. amount |
* | LP  | 04/02/20 | Removed imashelt - dropped Alberta Shelter Increase     |
* | LP  | 04/02/20 | Removed imses - no longer modeling Sask. Emp. Supplement|
* | LP  | 04/01/06 | Removed imcgtcp and impcgtcp                            |
* | LP  | 03/12/22 | Added impmeda - prov. medical expense allowed (computed)|
* | LP  | 03/12/08 | Added impothpe - prov. infirm depend. 18+ tax credit    |
* | LP  | 03/11/17 | Added imqintsl (student loan int.) to total tax credits |
* | LP  | 03/11/17 | Added imintsl - fed. interest on student loans tax cred |
* | LP  | 03/11/14 | Added impintsl - prov. interest on student loans tax cr |
* | CH  | 03/05/16 | NS Taxpayer refund program implemented                  |
* | LP  | 02/06/21 | Added imoccext - Ont. one-time Child Care extra Supp.   |
* | LP  | 02/06/17 | Added imnmbns - NFLD Mother-Baby Nutrition Supplement   |
* | BBM | 02/06/12 | Add after tax LICO option: imatpinc var def             |
* | LP  | 02/06/05 | Added imashelt - Alta shelter increase (NCBS clawback)  |
* | LP  | 01/07/18 | Renamed imuiydeps to imuiydep and impmincar to impminco |
* | EGA | 01/07/10 | Add net consumption SNA adjusted                        |
* | BBM | 01/06/20 | Drop prov home ownership saving plan variable imphotc   |
* | CH  | 01/06/12 | Added ubp6 ubp6c                                        |
* | LP  | 01/05/09 | Added impmincar, imminamt, imamtprv new alt min tax var.|
* | LP  | 01/04/02 | Added impheatr - provincial home heating rebates        |
* | LP  | 01/03/12 | Removed pre-1988 variables (exemptions, etc)            |
* | LP  | 01/03/05 | Removed Seniors Benefit variables                       |
* | CH  | 00/12/19 | Added imuiydeps                                         |                                          
* | CH  | 00/10/24 | Added CPP deduction for the self-employed               |
* | CH  | 00/10/24 | Added relief for heating expenses                       |
* | CH  | 00/06/14 | Added imothpe                                           |
* | CH  | 00/05/17 | Added imqcchc                                           |
* | CH  | 00/05/15 | Added homeowners assistance                             |
* | CH  | 00/05/12 | Added taxpayer dividend                                 |
* | LP  | 00/05/10 | Added imiotax (taxable inc. using Ont. CapGain Rate     |
* | CH  | 00/04/14 | Added imiloss imstkded imqiloss imqstkdd imqcapgx       |
* | LP  | 00/04/11 | Added improved tax system self-employ workers imqcppse  |
* | CH  | 00/04/10 | Added Sask refundable sales tax credit                  |
* | CH  | 00/04/07 | Added Sask child and senior tax credits                 |
* | CH  | 00/03/30 | Renamed imqchartc to imqchatc to be under 8 characters  |
* | LP  | 00/03/21 | Added imqmedrc - Quebec Ref. tax credit for medical ex. |                       
* | LP  | 00/03/16 | Added imncb - Nfld. child benefit                       |
* | CH  | 00/03/10 | Deleted imamtc                                          |
* | CH  | 00/03/07 | Added imcgtcp                                           |
* | CH  | 00/03/01 | Added provincial tax on taxable income                  |
* | CH  | 99/05/26 | Add Alta married tax credit                             |
* | LP  | 99/05/25 | Add BC Earned Income Benefit imibceib                   |
* | CH  | 99/05/21 | Modified simplified tax system and added imqcalr        |
* | CH  | 99/04/20 | Add NS child benefit imnscb                             |
* | CH  | 99/04/15 | Added imbtcs                                            |
* | CH  | 99/03/22 | Added imlabtxc and implvctc                             |
* | CH  | 99/02/17 | added selected commodity breakdowns in order to grow    |
* | TCB | 98/05/28 | Renamed *.cpp, ANSI function headers                    |
* | CH  | 98/05/01 | add imscb imses (Sask child benefit and emp. supp.)     |
* | EGA | 98/04/21 | add imqchartc                                           |
* | EGA | 98/04/07 | add imqapf (Anti-Poverty Fund)                          |
* | CH  | 98/04/07 | add imfsurtr                                            |
* | EGA | 98/04/02 | add imqlitc                                             |
* | CH  | 98/04/01 | deleted imoccec                                         |
* | EGA | 98/03/24 | add imcgtc                                              |
* | EGA | 98/03/09 | add imqtuitc,imqamt,imqamtfg                            |
* | EGA | 98/02/18 | add imqfatc                                             | 
* | EGA | 98/02/13 | add imqduetc                                            |
* | CH  | 98/02/03 | added NS Direct Assistance iminsda                      |
* | CH  | 98/01/22 | immedref, Fed. Refundable medical expense supplement    |
* | EGA | 97/12/17 | imqhptc, Quebec Home Parent Tax Credit level            |
* | BBM | 97/10/15 | added Ont. Refundable child care tax credit VARS imoccea|
* | BBM | 97/10/07 | Implement B.C. Family Bonus variable imibcfb            |
* | CCH | 97/10/03 | Add ubcalfs ubclmfs: family supplement received         |
* | BBM | 97/09/29 | Add vars for NB child tax ben imnbcben,imnbwis,imnbcben |
* | BBM | 97/09/12 | Add Alberta Family Employment Tax Credit Var imiafetc   |
* | CCH | 97/09/10 | Added imedrcv,imedtrf,immanltc                          |
* | CCH | 97/08/21 | Added imigispa                                          |
* | CCH | 97/06/19 | Dropped imeiwbp5 (replaced by ubeiwpb)                  |
* | CCH | 97/04/04 | Add EI contribution refund and ubeiwbp (weeks of ei)    |
* | BBM | 96/05/12 | Add Seniors Benefit variables                           |
* | BBM | 95/05/23 | Add Nova Scotia Pharmacare variables                    |
* | BBM | 94/10/05 | Add Quebec refundable child care expense credit vars    |
* | BBM | 94/09/29 | add imqittr income tested tax reduction variable        |
* | BBM | 94/09/29 | add Quebec net income/tax credit vars imquictc imqcpptc |
* | BBM | 94/09/29 | add imqhsfc - Quebec health services fund contributions |
* | GJC | 94/04/06 | add imuidpfg for assigning ui dependents to a claimant  |
* | RSE | 94/04/05 | add imiasb for Alberta seniors benefit                  |
* | GJC | 94/01/17 | remove ctpupst and ctpugas                              |
* | GJC | 93/02/16 | add imfortxc foreign tax credit variable                |
* | GJC | 93/02/08 | add ui training pointers ubp5(c)                        |
* | BBM | 92/09/02 | Delete imccetxc and impctc                              |
* | BBM | 92/07/27 | replace imqmetc with imqmeda                            |
* | BBM | 92/07/22 | Add prov non-refundable tax credit variable imnptc      |
* | BBM | 92/07/09 | Add prov net income tax variable impnit                 |
* | BBM | 92/07/08 | Add prov home ownership saving plan variable imphotc    |
* | BBM | 92/07/07 | imfcben, imfcbenb, imfcbene: child benefit vars added   |
* | BBM | 92/07/06 | impptxtc added: Provincial Property tax credit          |
* | BBM | 92/06/23 | impptc added: Provincial Political Contrib. Tax Credit  |
* | BBM | 92/06/23 | imfptc added: Federal Political Contribution Tax Credit |
* | SFG | 92/02/07 | ctupst -> ctpupst; ctugas -> ctpugas; also CTUPST,CTUGAS|
* | SFG | 92/02/06 | add ctnes, ctsave, ctothmon to complete expend. identity|
* | SFG | 92/02/06 | remove cttotexp; add ctnexp instead                     |
* | SFG | 92/02/06 | ctpct -> cttxpc_; ctfct -> cttxfc_; ctexp -> ctnexp     |
* | SFG | 92/02/06 | Delete ctpict; add ctupst, ctugas                       |
* | SFG | 89/12/05 | Add imoftca variable                                    |
* | --- | 89/10/13 | Release 4.0                                             |
* |     |          |                                                         |
* +-----+----------+---------------------------------------------------------+
*
*Definitions:
*   vsdm     [global]  Define SPSD/M variables
*
*****************************************************************************/


/* ==================== C-RUNTIME LIBRARY INCLUDE FILES =================== */

#include <stdio.h>  /* definitions/declarations for standard I/O routines   */


/* ==================== SPSD/M INCLUDE FILES ============================== */

#include "spsm.h"   /* SPSM common manifest constants and macros            */
#include "sub.h"    /* Subroutine library declarations                      */
#include "vsu.h"    /* Household variable sub-structure (user's)            */
#include "vs.h"     /* Household variable structure and sub-structures      */
#include "vm.h"     /* Variable manipulation package declarations           */


/* ==================== COMPILER PRAGMAS ================================== */

// eliminate spurious 'near/far mismatch' from MS-DOS compiler
#if defined(_MSDOS)
#pragma warning(disable : 4762)
#endif

#ifdef MSCOVL
#pragma alloc_text(INIT_TEXT,vsdm)
#endif


/* ==================== FUNCTION DEFINITIONS ============================== */


/*****************************************************************************
*vsdm - Define SPSD/M variables
*
*Synopsis:
*    void vsdm()          
*
*Description:
*
*Return Value:
*   None.
*
*Calls:
*   vardef   Define structure member as an SPSM variable
*   vmfind   Find variable entry corresponding to name
*
*Structure Members:
*   im.imalexp      (i)  Allowable employment expenses
*   im.imamtdf      (i)  Difference due to minimum tax
*   im.imamtfg      (i)  Minimum tax flag
*   im.imamtinc     (i)  Net adjusted income used for minimum tax
*   im.imamtprv     (i)  Federal minimum tax concept used for provincial minimum tax
*   im.imashelt     (i)  Alberta shelter increase under NCBS clawback
*   im.imatpinc     (i)  After tax Income for low income measurement
*   im.imatxc       (i)  Age tax credit
*   im.imatxcrt     (i)  Total tax credits applied
*   im.imbcss       (i)  British Columbia Seniors Supplement
*   im.imbft        (i)  Basic federal tax
*   im.imbpt        (i)  Basic provincial tax
*   im.imbtc        (i)  Basic personal tax credit
*   im.imbtcs       (i)  Basic personal tax credit supplement
*   im.imcapgex     (i)  Modelled capital gains deduction (254)
*   im.imccea       (i)  Child care expenses allowed
*   im.imccec       (i)  Child care expenses claimed on behalf of child
*   im.imcceni      (i)  Consumable income with CCE not zeroed
*   im.imccez       (i)  Is CCE zeroed?
*   im.imccezi      (i)  Consumable income with CCE zeroed
*   im.imcchc       (i)  Child's non-refundable credit
*   im.imcemc       (i)  Child's equivalent to married credit
*   im.imcgtc       (i)  Caregiver Tax Credit Level
*   im.imchara      (i)  Allowable charitable donations and gifts (calculated)
*   im.imchartc     (i)  Charitable donations tax credit
*   im.imchclm      (i)  Number of dependent children claimed
*   im.imchdtxc     (i)  Non-refundable Child Tax Credit
*   im.imcppctc     (i)  CPP contributions tax credit
*   im.imcppse      (i)  CPP contributions deduction for self-emp
*   im.imcqppc      (i)  CPP/QPP contributions
*   im.imctc        (i)  Child tax credit
*   im.imctcben     (i)  Federal child tax credit and child benefits
*   im.imctxcrt     (i)  Tax credits transferred from children
*   im.imctxcs      (i)  Dependent children tax credits
*   im.imdedfn      (i)  All deductions from net income
*   im.imdedft      (i)  Deductions from total income
*   im.imdepni      (i)  Dependant's net income
*   im.imdisatc     (i)  Disability tax credit
*   im.imedrcv      (i)  Education and tuition transferred from others
*   im.imedtrf      (i)  Education and tuition transferred to others
*   im.imedtxc      (i)  Education allowance tax credit
*   im.imemptxc     (i)  Canada Employment Credit
*   im.imfar        (i)  Family allowance recovery
*   im.imfcben      (i)  Total Federal Child Benefits
*   im.imfcbenb     (i)  Total Federal Child Benefits Base
*   im.imfcbene     (i)  Total Federal Child Benefit Supplement
*   im.imfdtxc      (i)  Federal dividend tax credit
*   im.imfecb       (i)  Federal Energy Cost Benefit
*   im.imfedbal     (i)  Federal taxes less transfers
*   im.imfedtax     (i)  Federal tax before tax credits
*   im.imffa        (i)  Federal portion of family allowances
*   im.imfiler      (i)  Taxable filer status
*   im.imfnewpg     (i)  Federal new programs
*   im.imfortc      (i)  Federal other refundable tax credits
*   im.imfortxc     (i)  Federal foreign tax credit (509)
*   im.imfoth       (i)  Federal other government income
*   im.imfothtr     (i)  Federal other trans income and ref. credits
*   im.imfptc       (i)  Federal Political Contribution Tax Credit
*   im.imfsa        (i)  Federal social assistance
*   im.imfstc       (i)  Federal sales tax credit
*   im.imfsur       (i)  Federal surtax
*   im.imfsurtr     (i)  Federal surtax reduction
*   im.imftax       (i)  Federal taxes
*   im.imftran      (i)  Federal transfer income
*   im.imgisinc     (i)  Individual's income for GIS/SPA reduction
*   im.imgismax     (i)  Maximum amount of GIS
*   im.imgistyp     (i)  Type of GIS entitlement
*   im.imheatrl     (i)  Federal relief for heating expenses
*   im.imiafetc     (i)  Alberta Family Employment Tax Credit Benefits
*   im.imiasb       (i)  Alberta seniors benefit
*   im.imibceib     (i)  B.C. Earned Income Benefit
*   im.imibcfb      (i)  B.C. Family Bonus
*   im.imicapgt     (i)  Capital gains (taxable)
*   im.imicnet      (i)  Net Income (line 236)
*   im.imicqp       (i)  CPP/QPP payable
*   im.imictot      (i)  Total Income (line 150)
*   im.imidivt      (i)  Dividend income (taxable)
*   im.imiemp       (i)  Wages and salaries
*   im.imigis       (i)  GIS benefits
*   im.imigispa     (i)  GIS and spouse's allowance
*   im.imigist      (i)  GIS provincial top-up
*   im.imildivt     (i)  Dividend income from large (eligible) corporations (taxable)
*   im.imiloss      (i)  Modelled Business investment losses (217)
*   im.iminet       (i)  Net income
*   im.iminsda      (i)  NS Direct Assistance Program
*   im.imintsl      (i)  Federal interest on student loans tax credit
*   im.imioas       (i)  OAS benefits
*   im.imiosa       (i)  Other SA or guarantees
*   im.imiotax      (i)  Ontario taxable income
*   im.imiotg       (i)  Other taxable demogrants
*   im.imipnst      (i)  Taxable pension income (after splitting)
*   im.imisa        (i)  Social assistance (or replacement program)
*   im.imisdivt     (i)  Dividend income from small corporations (taxable)
*   im.imiself      (i)  Total self-employment income
*   im.imishri      (i)  Shared income concept (SHS & SPSD)
*   im.imispa       (i)  Spouse's allowance
*   im.imitax       (i)  Taxable income
*   im.imitot       (i)  Total income
*   im.imiuib       (i)  Unemployment Insurance/Employment Insurance benefits
*   im.imlabtxc     (i)  Federal labour-sponsored funds tax credit
*   im.immanltc     (i)  Manitoba learning tax credit
*   im.immaramt     (i)  Adjustment to income source
*   im.immartax     (i)  Change in consumable income after adjustment
*   im.immartxc     (i)  Married tax credit claimed
*   im.immcb        (i)  Manitoba Child Benefit
*   im.immdisp      (i)  Disposable income
*   im.immeda       (i)  Medical expenses allowed (computed)
*   im.immedatc     (i)  Medical expenses allowed tax credit
*   im.immedref     (i)  Refundable medical expense supplement (452)
*   im.immemp       (i)  All employment income
*   im.immhmas      (i)  Manitoba Homeowners Assistance
*   im.immicons     (i)  Consumable income
*   im.imminamt     (i)  Minimum Amount due to Federal Minimum Tax
*   im.imminv       (i)  Investment income
*   im.immmkt       (i)  Market income
*   im.immoth       (i)  Other income
*   im.immtax       (i)  All taxes
*   im.immtot       (i)  Total income
*   im.immtran      (i)  All transfer income
*   im.imnbcbb      (i)  NB child tax Benefits base amount
*   im.imnbcben     (i)  Total NB child tax Benefits
*   im.imnbwis      (i)  NB child tax Benefits WIS
*   im.imncb        (i)  Newfoundland Child Benefit
*   im.imnettr      (i)  Net transfers to person
*   im.imnfach      (i)  Number of family allowance children claimed
*   im.imnmbns      (i)  Newfoundland Mother-Baby Nutrition Supplement
*   im.imnptc       (i)  Non-refundable provincial tax credits
*   im.imnscb       (i)  Nova Scotia Child Benefit
*   im.imnstxrf     (i)  Nova Scotia Taxpayer Refund
*   im.imoaspar     (i)  Partial OAS residency flag
*   im.imoasr       (i)  OAS recovery
*   im.imoasres     (i)  Partial OAS fraction
*   im.imocb        (i)  Ontario Child Benefit
*   im.imocbyng     (i)  Ontario Child Benefit amount for Child Care Supplement dependents
*   im.imoccea      (i)  Ont. Child Care Exp. credit allowed (Family)
*   im.imoccext     (i)  Ont. Child Care Supplement one-time extra benefit
*   im.imoftca      (i)  Other federal tax credits applied (416)
*   im.imoldtyp     (i)  Type of GIS/SPA nuclear family
*   im.imonteht     (i)  Ontario Employers Heath Tax (Self-employed)
*   im.imopstc      (i)  Ont. Property and Sales Tax Credit
*   im.imothpe      (i)  Other dependant tax credit (306)
*   im.imothrep     (i)  Other federal repayments
*   im.imotxdv      (i)  Ontario Taxpayer Dividend
*   im.impalltc     (i)  All refundable provincial tax credits
*   im.impatxc      (i)  Prov Age amount tax credit
*   im.impatxcr     (i)  Prov total tax credits applied
*   im.impbtc       (i)  Prov Basic amount
*   im.impcgtc      (i)  Prov Caregiver Tax Credit Level
*   im.impchrtc     (i)  Prov Charitable Donations tax credit
*   im.impcpptc     (i)  Prov CPP/QPP contributions tax credit
*   im.impctxct     (i)  Prov tax credits transferred from children
*   im.impdistc     (i)  Prov Disability tax credit
*   im.impdtxc      (i)  Provincial dividend tax credit
*   im.impedtxc     (i)  Prov Education tax credit
*   im.impeht       (i)  Provincial elderly health tax
*   im.impehtc      (i)  Provincial elderly health tax credit
*   im.impentxc     (i)  Pension income tax credit
*   im.impfa        (i)  Provincial family allowance
*   im.impfp        (i)  Provincial family programs
*   im.impheatr     (i)  Provincial Home Heating Fuel/Energy Rebate
*   im.imphp        (i)  Provincial Health Premium
*   im.impintsl     (i)  Provincial interest on student loans tax credit
*   im.implvctc     (i)  Provincial labour-sponsored funds tax credit
*   im.impmartc     (i)  Prov Married and Equivalent to Married tax credit
*   im.impmeda      (i)  Prov Medical expenses allowed (computed)
*   im.impmedtc     (i)  Prov Medical Expenses tax credit
*   im.impminco     (i)  Prov Minimum tax carryover
*   im.impnit       (i)  Provincial net income tax
*   im.impnsph      (i)  Pension income split for head
*   im.impnsps      (i)  Pension income split for spouse
*   im.importc      (i)  Other refundable provincial tax credits
*   im.impoth       (i)  Provincial other government income
*   im.impothpe     (i)  Provincial infirm dependents 18 or older tax credit
*   im.impovinc     (i)  Before Tax Income for low income measurement
*   im.imppentc     (i)  Prov Pension Income tax credit
*   im.impptc       (i)  Provincial Political Contrib Tax Credit
*   im.impptg       (i)  Provincial property tax grant for seniors
*   im.impptxtc     (i)  Provincial Property tax tax credit
*   im.improptx     (i)  Imputed property tax paid
*   im.imprvbal     (i)  Provincial taxes less transfers
*   im.imprvtax     (i)  Prov gross provincial tax
*   im.impsa        (i)  Provincial social assistance
*   im.impstg       (i)  Provincial sales tax grant for seniors
*   im.impstxct     (i)  Prov tax credits transferred from spouse
*   im.impsur       (i)  Provincial surtax
*   im.imptax       (i)  Provincial taxes
*   im.imptaxcr     (i)  Prov total tax credits
*   im.imptc        (i)  Refundable provincial tax credits
*   im.imptr        (i)  Provincial tax reduction
*   im.imptran      (i)  Provincial transfer income
*   im.impttxct     (i)  Prov total tax credits transferred
*   im.imptutxc     (i)  Prov Tuition tax credit
*   im.impuictc     (i)  Prov UI/EI contributions tax credit
*   im.impyctxc     (i)  Prov Young Child tax credit
*   im.imqaafa      (i)  Quebec Availability Allowance FA Supplement
*   im.imqalexp     (i)  Quebec allowable employment expenses
*   im.imqamt       (i)  Quebec Minimum Tax Amount
*   im.imqamtfg     (i)  Quebec Minimum Tax flag
*   im.imqapf       (i)  Quebec Anti-Poverty Fund
*   im.imqatc       (i)  Quebec age tax credit
*   im.imqbtax      (i)  Quebec tax before credits
*   im.imqbtc       (i)  Quebec basic tax credit
*   im.imqca        (i)  Quebec Child Assistance refundable tax credit
*   im.imqcalr      (i)  Quebec combined age, living alone, retirement credit
*   im.imqcapgt     (i)  Quebec taxable capital gains
*   im.imqcapgx     (i)  Quebec modelled capital gains deduction (254)
*   im.imqccea      (i)  Quebec child care expenses allowed (dedn)
*   im.imqcceni     (i)  Quebec net income for refundable cce credit calculation
*   im.imqccetc     (i)  Quebec refundable child care expenses Tax Credit
*   im.imqcchc      (i)  Quebec child's non-refundable credit
*   im.imqchara     (i)  Quebec allowable charitable donations(calc)
*   im.imqchatc     (i)  Quebec allowable charitable donations tax credit
*   im.imqcppse     (i)  Quebec self-employ. QPP/CPP Cont. deduction
*   im.imqcpptc     (i)  Quebec CPP/QPP contributions tax credit
*   im.imqctpc      (i)  Quebec child's transfer of recognized parental contribution
*   im.imqdctc      (i)  Quebec dependent child tax credits
*   im.imqdedea     (i)  Quebec employment allowance
*   im.imqdedfn     (i)  Quebec all deductions from net income
*   im.imqdedft     (i)  Quebec deductions from total income
*   im.imqdepni     (i)  Quebec dependant's net income
*   im.imqdistc     (i)  Quebec disability tax credit
*   im.imqdtxc      (i)  Quebec dividend tax credit
*   im.imqduetc     (i)  Quebec Dues Tax Credit
*   im.imqei        (i)  Quebec eligible income for tax reduction
*   im.imqempdd     (i)  Quebec earned income deduction for workers
*   im.imqfatc      (i)  Quebec Family Allowance Tax Credit
*   im.imqfs        (i)  Quebec family situation (1-5)
*   im.imqftr       (i)  Quebec family tax reduction
*   im.imqhptc      (i)  Quebec Home Parent Tax Credit level
*   im.imqhsfc      (i)  Quebec Health Services Fund Contributions
*   im.imqhsftc     (i)  Quebec Health Services Fund Cont.tax credit
*   im.imqidc       (i)  Quebec income of designated dependent child
*   im.imqidivt     (i)  Quebec taxable dividends
*   im.imqiloss     (i)  Quebec Modelled Business investment losses (234)
*   im.imqinet      (i)  Quebec net income
*   im.imqintsl     (i)  Quebec student loan interest tax credit
*   im.imqipnst     (i)  Quebec taxable pension income (after splitting)
*   im.imqitax      (i)  Quebec taxable income
*   im.imqitot      (i)  Quebec total income
*   im.imqittr      (i)  Quebec income tested tax reduction
*   im.imqlatc      (i)  Quebec living alone tax credit
*   im.imqldivt     (i)  Quebec taxable dividends from large (eligible) corporations
*   im.imqmeda      (i)  Quebec medical expenses allowed
*   im.imqmedrc     (i)  Quebec refundable tax credit for medical expenses
*   im.imqmtc       (i)  Quebec married tax credit
*   im.imqnbfa      (i)  Quebec newborn Allowance
*   im.imqncgtc     (i)  Quebec Refundable Natural Caregivers Tax Credit
*   im.imqndc       (i)  Quebec number of dependent children
*   im.imqpcmtb     (i)  Quebec parental insurance plan calendar year maternity benefits
*   im.imqpcmtw     (i)  Quebec parental insurance plan calendar year maternity weeks
*   im.imqpcprb     (i)  Quebec parental insurance plan calendar year parental benefits
*   im.imqpcprw     (i)  Quebec parental insurance plan calendar year parental weeks
*   im.imqpcptb     (i)  Quebec parental insurance plan calendar year paternity benefits
*   im.imqpcptw     (i)  Quebec parental insurance plan calendar year paternity weeks
*   im.imqpipcbn    (i)  Quebec parental insurance plan calendar year benefits
*   im.imqpipcwk    (i)  Quebec parental insurance plan calendar year weeks
*   im.imqpipp      (i)  Quebec parental insurance plan premiums for paid workers
*   im.imqpippse    (i)  Quebec parental insurance plan premiums for self-employed
*   im.imqpipt      (i)  Quebec parental insurance plan type (basic/special)
*   im.imqpiptbn    (i)  Quebec parental insurance plan total benefits
*   im.imqpiptc     (i)  Quebec parental insurance plan premium tax credit for paid workers (federal)
*   im.imqpiptwk    (i)  Quebec parental insurance plan total weeks
*   im.imqpnsph     (i)  Quebec pension income split for head
*   im.imqpnsps     (i)  Quebec pension income split for spouse
*   im.imqpsedd     (i)  Quebec parental insurance plan premium deduction for self-employed (federal)
*   im.imqpsetc     (i)  Quebec parental insurance plan premium tax credit for self-employed (federal)
*   im.imqptmtb     (i)  Quebec parental insurance plan total maternity benefits
*   im.imqptmtw     (i)  Quebec parental insurance plan total maternity weeks
*   im.imqptprb     (i)  Quebec parental insurance plan total parental benefits
*   im.imqptprw     (i)  Quebec parental insurance plan total parental weeks
*   im.imqptptb     (i)  Quebec parental insurance plan total paternity benefits
*   im.imqptptw     (i)  Quebec parental insurance plan total paternity weeks
*   im.imqptr       (i)  Quebec property tax refund
*   im.imqqpiptc    (i)  Quebec parental insurance plan premium tax credit for paid workers (Quebec)
*   im.imqqpsedd    (i)  Quebec parental insurance plan premium deduction for self-employed (Quebec)
*   im.imqqpsetc    (i)  Quebec parental insurance plan premium tax credit for self-employed (Quebec)
*   im.imqritc      (i)  Quebec retirement income tax credit
*   im.imqsdivt     (i)  Quebec taxable dividends from small corporations
*   im.imqsfflg     (i)  Quebec simplified tax form flag 0=general 1=simplified
*   im.imqstkdd     (i)  Quebec modelled Stock option deduction (249)
*   im.imqstr       (i)  Quebec sales tax refund
*   im.imqta        (i)  Quebec tax abatement (total)
*   im.imqtaa       (i)  Quebec tax abatement (applied)
*   im.imqtar       (i)  Quebec tax abatement (refundable)
*   im.imqtca       (i)  Quebec tax credits applied
*   im.imqtct       (i)  Quebec tax credits transferable
*   im.imqtctc      (i)  Quebec tax credits transferred from child
*   im.imqtcts      (i)  Quebec tax credits transferred from spouse
*   im.imqtfa       (i)  Quebec taxable family allowances
*   im.imqtottc     (i)  Quebec total tax credits
*   im.imqtpcn      (i)  Quebec number of children who transferred parental contribution
*   im.imqtuitc     (i)  Quebec Tuition Tax Credit
*   im.imqtuitt     (i)  Quebec amount of tuition transferred to parents
*   im.imquictc     (i)  Quebec UI contributions tax credit
*   im.imqwrkpr     (i)  Quebec Work Premium refundable tax credit
*   im.imrentpd     (i)  Imputed rent paid
*   im.imrepay      (i)  Social Benefits Repayments
*   im.imresreb     (i)  Alberta Resource Rebate Amount
*   im.imsaclaw     (i)  Social Assistance NCB Clawback Amount
*   im.imscb        (i)  Saskatchewan Child Benefit
*   im.imsctxc      (i)  Saskatchewan Non-refundable child tax credit
*   im.imspamax     (i)  Maximum amount of SPA
*   im.imspatyp     (i)  Type of SPA entitlement
*   im.imssstxc     (i)  Saskatchewan senior supplement tax credit
*   im.imsstc       (i)  Saskatchewan refundable sales tax credit
*   im.imstkded     (i)  Modelled Stock option deduction (249)
*   im.imstxcrt     (i)  Tax credits transferred from spouse
*   im.imtaxcr      (i)  Total tax credits
*   im.imtfa        (i)  Taxable family allowances
*   im.imttxcrt     (i)  Total tax credits transferred
*   im.imtutxc      (i)  Tuition tax credit
*   im.imtxf        (i)  Federal income tax payable
*   im.imtxfc       (i)  Federal commodity taxes
*   im.imtxp        (i)  Provincial income tax payable
*   im.imtxpc       (i)  Provincial commodity taxes
*   im.imtxttxc     (i)  Federal textbook tax credit
*   im.imuccb       (i)  Universal Child Care Benefit amount
*   im.imuibr       (i)  UI benefit recovery
*   im.imuic        (i)  UIC contributions
*   im.imuicrf      (i)  UI EI contribution refund
*   im.imuictc      (i)  UIC contributions tax credit
*   im.imuidpfg     (i)  UI claimants has dependents flag
*   im.imuiydep     (i)  Number of dependents under 7 for family supplement (EI only)
*   im.imwitb       (i)  Working Income Tax Benefit
*   im.imwitbs      (i)  Working Income Tax Benefit Supplement for Disabilities
*   ub.ubcalfs      (i)  Family supplement paid in calendar year
*   ub.ubcalpd      (i)  Benefits paid in calendar year
*   ub.ubcalwk      (i)  Weeks on claim in calendar year
*   ub.ubclmfs      (i)  Family supplement paid on claim
*   ub.ubclmpd      (i)  Benefits paid on claim
*   ub.ubclmwk      (i)  Weeks on claim
*   ub.ubeiwbp      (i)  Weeks of past EI benefits
*   ub.ubern        (i)  Modelled insurable weekly earnings
*   ub.ubp1         (i)  Week # of first payment
*   ub.ubp1c        (i)  Week # of first payment (windowed)
*   ub.ubp2         (i)  Week # of start of second phase
*   ub.ubp2c        (i)  Week # of start of second phase (windowed)
*   ub.ubp3         (i)  Week # of start of third phase
*   ub.ubp3c        (i)  Week # of start of third phase (windowed)
*   ub.ubp4         (i)  Week # of last payment
*   ub.ubp4c        (i)  Week # of last payment (windowed)
*   ub.ubp5         (i)  Week # of last other type of ui/ei payment
*   ub.ubp5c        (i)  Week # of last other type of ui/ei payment (windowed)
*   ub.ubp6         (i)  Week # of last training payment
*   ub.ubp6c        (i)  Week # of last training payment (windowed)
*   ve.veprec       (o)  output precision
*
*Called by:
*   phase1   Perform initialisation tasks
*
*****************************************************************************/
void vsdm()
{
	DEBUG_ON("vsdm");

	/* Note: vardef is a macro defined in vm.h.  It expands into a call */
	/*       to the vmadd function.                                     */

	vardef("_ctseqhv",   CT, ctseqhv,  C_INT,V_ANAL);
	vardef("ctprov",     CT, ctprov,   C_INT,V_CLAS);
	vardef("_ctfcid",    CT, ctfcid,   C_NUM,V_ANAL);
	vardef("_ctfexd",    CT, ctfexd,   C_NUM,V_ANAL);
	vardef("_ctfext",    CT, ctfext,   C_NUM,V_ANAL);
	vardef("_ctfgst",    CT, ctfgst,   C_NUM,V_ANAL);
	vardef("_ctfnew",    CT, ctfnew,   C_NUM,V_ANAL);
	vardef("_ctfgsths",  CT, ctfgsths, C_NUM,V_ANAL);
	vardef("_cttxfc",    CT, cttxfc,   C_NUM,V_ANAL);
	vardef("_cttxfc0",    CT, cttxfc_[0],  C_NUM,V_ANAL);
	vardef("_cttxfc1",    CT, cttxfc_[1],  C_NUM,V_ANAL);
	vardef("_cttxfc2",    CT, cttxfc_[2],  C_NUM,V_ANAL);
	vardef("_cttxfc3",    CT, cttxfc_[3],  C_NUM,V_ANAL);
	vardef("_cttxfc4",    CT, cttxfc_[4],  C_NUM,V_ANAL);
	vardef("_cttxfc5",    CT, cttxfc_[5],  C_NUM,V_ANAL);
	vardef("_cttxfc6",    CT, cttxfc_[6],  C_NUM,V_ANAL);
	vardef("_cttxfc7",    CT, cttxfc_[7],  C_NUM,V_ANAL);
	vardef("_cttxfc8",    CT, cttxfc_[8],  C_NUM,V_ANAL);
	vardef("_cttxfc9",    CT, cttxfc_[9],  C_NUM,V_ANAL);
	vardef("_cttxfc10",   CT, cttxfc_[10], C_NUM,V_ANAL);
	vardef("_cttxfc11",   CT, cttxfc_[11], C_NUM,V_ANAL);
	vardef("_cttxfc12",   CT, cttxfc_[12], C_NUM,V_ANAL);
	vardef("_cttxfc13",   CT, cttxfc_[13], C_NUM,V_ANAL);
	vardef("_cttxfc14",   CT, cttxfc_[14], C_NUM,V_ANAL);
	vardef("_cttxfc15",   CT, cttxfc_[15], C_NUM,V_ANAL);
	vardef("_cttxfc16",   CT, cttxfc_[16], C_NUM,V_ANAL);
	vardef("_cttxfc17",   CT, cttxfc_[17], C_NUM,V_ANAL);
	vardef("_cttxfc18",   CT, cttxfc_[18], C_NUM,V_ANAL);
	vardef("_cttxfc19",   CT, cttxfc_[19], C_NUM,V_ANAL);
	vardef("_cttxfc20",   CT, cttxfc_[20], C_NUM,V_ANAL);
	vardef("_cttxfc21",   CT, cttxfc_[21], C_NUM,V_ANAL);
	vardef("_cttxfc22",   CT, cttxfc_[22], C_NUM,V_ANAL);
	vardef("_cttxfc23",   CT, cttxfc_[23], C_NUM,V_ANAL);
	vardef("_cttxfc24",   CT, cttxfc_[24], C_NUM,V_ANAL);
	vardef("_cttxfc25",   CT, cttxfc_[25], C_NUM,V_ANAL);
	vardef("_cttxfc26",   CT, cttxfc_[26], C_NUM,V_ANAL);
	vardef("_cttxfc27",   CT, cttxfc_[27], C_NUM,V_ANAL);
	vardef("_cttxfc28",   CT, cttxfc_[28], C_NUM,V_ANAL);
	vardef("_cttxfc29",   CT, cttxfc_[29], C_NUM,V_ANAL);
	vardef("_cttxfc30",   CT, cttxfc_[30], C_NUM,V_ANAL);
	vardef("_cttxfc31",   CT, cttxfc_[31], C_NUM,V_ANAL);
	vardef("_cttxfc32",   CT, cttxfc_[32], C_NUM,V_ANAL);
	vardef("_cttxfc33",   CT, cttxfc_[33], C_NUM,V_ANAL);
	vardef("_cttxfc34",   CT, cttxfc_[34], C_NUM,V_ANAL);
	vardef("_cttxfc35",   CT, cttxfc_[35], C_NUM,V_ANAL);
	vardef("_cttxfc36",   CT, cttxfc_[36], C_NUM,V_ANAL);
	vardef("_cttxfc37",   CT, cttxfc_[37], C_NUM,V_ANAL);
	vardef("_cttxfc38",   CT, cttxfc_[38], C_NUM,V_ANAL);
	vardef("_cttxfc39",   CT, cttxfc_[39], C_NUM,V_ANAL);
	vardef("_cttxfc40",   CT, cttxfc_[40], C_NUM,V_ANAL);
	vardef("_cttxfc41",   CT, cttxfc_[41], C_NUM,V_ANAL);
	vardef("_cttxfc42",   CT, cttxfc_[42], C_NUM,V_ANAL);
	vardef("_cttxfc43",   CT, cttxfc_[43], C_NUM,V_ANAL);
	vardef("_cttxfc44",   CT, cttxfc_[44], C_NUM,V_ANAL);
	vardef("_cttxfc45",   CT, cttxfc_[45], C_NUM,V_ANAL);
	vardef("_cttxfc46",   CT, cttxfc_[46], C_NUM,V_ANAL);
	vardef("_cttxfc47",   CT, cttxfc_[47], C_NUM,V_ANAL);
	vardef("_ctfcid0",    CT, ctfcid_[0],  C_NUM,V_ANAL);
	vardef("_ctfcid1",    CT, ctfcid_[1],  C_NUM,V_ANAL);
	vardef("_ctfcid2",    CT, ctfcid_[2],  C_NUM,V_ANAL);
	vardef("_ctfcid3",    CT, ctfcid_[3],  C_NUM,V_ANAL);
	vardef("_ctfcid4",    CT, ctfcid_[4],  C_NUM,V_ANAL);
	vardef("_ctfcid5",    CT, ctfcid_[5],  C_NUM,V_ANAL);
	vardef("_ctfcid6",    CT, ctfcid_[6],  C_NUM,V_ANAL);
	vardef("_ctfcid7",    CT, ctfcid_[7],  C_NUM,V_ANAL);
	vardef("_ctfcid8",    CT, ctfcid_[8],  C_NUM,V_ANAL);
	vardef("_ctfcid9",    CT, ctfcid_[9],  C_NUM,V_ANAL);
	vardef("_ctfcid10",   CT, ctfcid_[10], C_NUM,V_ANAL);
	vardef("_ctfcid11",   CT, ctfcid_[11], C_NUM,V_ANAL);
	vardef("_ctfcid12",   CT, ctfcid_[12], C_NUM,V_ANAL);
	vardef("_ctfcid13",   CT, ctfcid_[13], C_NUM,V_ANAL);
	vardef("_ctfcid14",   CT, ctfcid_[14], C_NUM,V_ANAL);
	vardef("_ctfcid15",   CT, ctfcid_[15], C_NUM,V_ANAL);
	vardef("_ctfcid16",   CT, ctfcid_[16], C_NUM,V_ANAL);
	vardef("_ctfcid17",   CT, ctfcid_[17], C_NUM,V_ANAL);
	vardef("_ctfcid18",   CT, ctfcid_[18], C_NUM,V_ANAL);
	vardef("_ctfcid19",   CT, ctfcid_[19], C_NUM,V_ANAL);
	vardef("_ctfcid20",   CT, ctfcid_[20], C_NUM,V_ANAL);
	vardef("_ctfcid21",   CT, ctfcid_[21], C_NUM,V_ANAL);
	vardef("_ctfcid22",   CT, ctfcid_[22], C_NUM,V_ANAL);
	vardef("_ctfcid23",   CT, ctfcid_[23], C_NUM,V_ANAL);
	vardef("_ctfcid24",   CT, ctfcid_[24], C_NUM,V_ANAL);
	vardef("_ctfcid25",   CT, ctfcid_[25], C_NUM,V_ANAL);
	vardef("_ctfcid26",   CT, ctfcid_[26], C_NUM,V_ANAL);
	vardef("_ctfcid27",   CT, ctfcid_[27], C_NUM,V_ANAL);
	vardef("_ctfcid28",   CT, ctfcid_[28], C_NUM,V_ANAL);
	vardef("_ctfcid29",   CT, ctfcid_[29], C_NUM,V_ANAL);
	vardef("_ctfcid30",   CT, ctfcid_[30], C_NUM,V_ANAL);
	vardef("_ctfcid31",   CT, ctfcid_[31], C_NUM,V_ANAL);
	vardef("_ctfcid32",   CT, ctfcid_[32], C_NUM,V_ANAL);
	vardef("_ctfcid33",   CT, ctfcid_[33], C_NUM,V_ANAL);
	vardef("_ctfcid34",   CT, ctfcid_[34], C_NUM,V_ANAL);
	vardef("_ctfcid35",   CT, ctfcid_[35], C_NUM,V_ANAL);
	vardef("_ctfcid36",   CT, ctfcid_[36], C_NUM,V_ANAL);
	vardef("_ctfcid37",   CT, ctfcid_[37], C_NUM,V_ANAL);
	vardef("_ctfcid38",   CT, ctfcid_[38], C_NUM,V_ANAL);
	vardef("_ctfcid39",   CT, ctfcid_[39], C_NUM,V_ANAL);
	vardef("_ctfcid40",   CT, ctfcid_[40], C_NUM,V_ANAL);
	vardef("_ctfcid41",   CT, ctfcid_[41], C_NUM,V_ANAL);
	vardef("_ctfcid42",   CT, ctfcid_[42], C_NUM,V_ANAL);
	vardef("_ctfcid43",   CT, ctfcid_[43], C_NUM,V_ANAL);
	vardef("_ctfcid44",   CT, ctfcid_[44], C_NUM,V_ANAL);
	vardef("_ctfcid45",   CT, ctfcid_[45], C_NUM,V_ANAL);
	vardef("_ctfcid46",   CT, ctfcid_[46], C_NUM,V_ANAL);
	vardef("_ctfcid47",   CT, ctfcid_[47], C_NUM,V_ANAL);
	vardef("_ctfexd0",    CT, ctfexd_[0],  C_NUM,V_ANAL);
	vardef("_ctfexd1",    CT, ctfexd_[1],  C_NUM,V_ANAL);
	vardef("_ctfexd2",    CT, ctfexd_[2],  C_NUM,V_ANAL);
	vardef("_ctfexd3",    CT, ctfexd_[3],  C_NUM,V_ANAL);
	vardef("_ctfexd4",    CT, ctfexd_[4],  C_NUM,V_ANAL);
	vardef("_ctfexd5",    CT, ctfexd_[5],  C_NUM,V_ANAL);
	vardef("_ctfexd6",    CT, ctfexd_[6],  C_NUM,V_ANAL);
	vardef("_ctfexd7",    CT, ctfexd_[7],  C_NUM,V_ANAL);
	vardef("_ctfexd8",    CT, ctfexd_[8],  C_NUM,V_ANAL);
	vardef("_ctfexd9",    CT, ctfexd_[9],  C_NUM,V_ANAL);
	vardef("_ctfexd10",   CT, ctfexd_[10], C_NUM,V_ANAL);
	vardef("_ctfexd11",   CT, ctfexd_[11], C_NUM,V_ANAL);
	vardef("_ctfexd12",   CT, ctfexd_[12], C_NUM,V_ANAL);
	vardef("_ctfexd13",   CT, ctfexd_[13], C_NUM,V_ANAL);
	vardef("_ctfexd14",   CT, ctfexd_[14], C_NUM,V_ANAL);
	vardef("_ctfexd15",   CT, ctfexd_[15], C_NUM,V_ANAL);
	vardef("_ctfexd16",   CT, ctfexd_[16], C_NUM,V_ANAL);
	vardef("_ctfexd17",   CT, ctfexd_[17], C_NUM,V_ANAL);
	vardef("_ctfexd18",   CT, ctfexd_[18], C_NUM,V_ANAL);
	vardef("_ctfexd19",   CT, ctfexd_[19], C_NUM,V_ANAL);
	vardef("_ctfexd20",   CT, ctfexd_[20], C_NUM,V_ANAL);
	vardef("_ctfexd21",   CT, ctfexd_[21], C_NUM,V_ANAL);
	vardef("_ctfexd22",   CT, ctfexd_[22], C_NUM,V_ANAL);
	vardef("_ctfexd23",   CT, ctfexd_[23], C_NUM,V_ANAL);
	vardef("_ctfexd24",   CT, ctfexd_[24], C_NUM,V_ANAL);
	vardef("_ctfexd25",   CT, ctfexd_[25], C_NUM,V_ANAL);
	vardef("_ctfexd26",   CT, ctfexd_[26], C_NUM,V_ANAL);
	vardef("_ctfexd27",   CT, ctfexd_[27], C_NUM,V_ANAL);
	vardef("_ctfexd28",   CT, ctfexd_[28], C_NUM,V_ANAL);
	vardef("_ctfexd29",   CT, ctfexd_[29], C_NUM,V_ANAL);
	vardef("_ctfexd30",   CT, ctfexd_[30], C_NUM,V_ANAL);
	vardef("_ctfexd31",   CT, ctfexd_[31], C_NUM,V_ANAL);
	vardef("_ctfexd32",   CT, ctfexd_[32], C_NUM,V_ANAL);
	vardef("_ctfexd33",   CT, ctfexd_[33], C_NUM,V_ANAL);
	vardef("_ctfexd34",   CT, ctfexd_[34], C_NUM,V_ANAL);
	vardef("_ctfexd35",   CT, ctfexd_[35], C_NUM,V_ANAL);
	vardef("_ctfexd36",   CT, ctfexd_[36], C_NUM,V_ANAL);
	vardef("_ctfexd37",   CT, ctfexd_[37], C_NUM,V_ANAL);
	vardef("_ctfexd38",   CT, ctfexd_[38], C_NUM,V_ANAL);
	vardef("_ctfexd39",   CT, ctfexd_[39], C_NUM,V_ANAL);
	vardef("_ctfexd40",   CT, ctfexd_[40], C_NUM,V_ANAL);
	vardef("_ctfexd41",   CT, ctfexd_[41], C_NUM,V_ANAL);
	vardef("_ctfexd42",   CT, ctfexd_[42], C_NUM,V_ANAL);
	vardef("_ctfexd43",   CT, ctfexd_[43], C_NUM,V_ANAL);
	vardef("_ctfexd44",   CT, ctfexd_[44], C_NUM,V_ANAL);
	vardef("_ctfexd45",   CT, ctfexd_[45], C_NUM,V_ANAL);
	vardef("_ctfexd46",   CT, ctfexd_[46], C_NUM,V_ANAL);
	vardef("_ctfexd47",   CT, ctfexd_[47], C_NUM,V_ANAL);
	vardef("_ctfext0",    CT, ctfext_[0],  C_NUM,V_ANAL);
	vardef("_ctfext1",    CT, ctfext_[1],  C_NUM,V_ANAL);
	vardef("_ctfext2",    CT, ctfext_[2],  C_NUM,V_ANAL);
	vardef("_ctfext3",    CT, ctfext_[3],  C_NUM,V_ANAL);
	vardef("_ctfext4",    CT, ctfext_[4],  C_NUM,V_ANAL);
	vardef("_ctfext5",    CT, ctfext_[5],  C_NUM,V_ANAL);
	vardef("_ctfext6",    CT, ctfext_[6],  C_NUM,V_ANAL);
	vardef("_ctfext7",    CT, ctfext_[7],  C_NUM,V_ANAL);
	vardef("_ctfext8",    CT, ctfext_[8],  C_NUM,V_ANAL);
	vardef("_ctfext9",    CT, ctfext_[9],  C_NUM,V_ANAL);
	vardef("_ctfext10",   CT, ctfext_[10], C_NUM,V_ANAL);
	vardef("_ctfext11",   CT, ctfext_[11], C_NUM,V_ANAL);
	vardef("_ctfext12",   CT, ctfext_[12], C_NUM,V_ANAL);
	vardef("_ctfext13",   CT, ctfext_[13], C_NUM,V_ANAL);
	vardef("_ctfext14",   CT, ctfext_[14], C_NUM,V_ANAL);
	vardef("_ctfext15",   CT, ctfext_[15], C_NUM,V_ANAL);
	vardef("_ctfext16",   CT, ctfext_[16], C_NUM,V_ANAL);
	vardef("_ctfext17",   CT, ctfext_[17], C_NUM,V_ANAL);
	vardef("_ctfext18",   CT, ctfext_[18], C_NUM,V_ANAL);
	vardef("_ctfext19",   CT, ctfext_[19], C_NUM,V_ANAL);
	vardef("_ctfext20",   CT, ctfext_[20], C_NUM,V_ANAL);
	vardef("_ctfext21",   CT, ctfext_[21], C_NUM,V_ANAL);
	vardef("_ctfext22",   CT, ctfext_[22], C_NUM,V_ANAL);
	vardef("_ctfext23",   CT, ctfext_[23], C_NUM,V_ANAL);
	vardef("_ctfext24",   CT, ctfext_[24], C_NUM,V_ANAL);
	vardef("_ctfext25",   CT, ctfext_[25], C_NUM,V_ANAL);
	vardef("_ctfext26",   CT, ctfext_[26], C_NUM,V_ANAL);
	vardef("_ctfext27",   CT, ctfext_[27], C_NUM,V_ANAL);
	vardef("_ctfext28",   CT, ctfext_[28], C_NUM,V_ANAL);
	vardef("_ctfext29",   CT, ctfext_[29], C_NUM,V_ANAL);
	vardef("_ctfext30",   CT, ctfext_[30], C_NUM,V_ANAL);
	vardef("_ctfext31",   CT, ctfext_[31], C_NUM,V_ANAL);
	vardef("_ctfext32",   CT, ctfext_[32], C_NUM,V_ANAL);
	vardef("_ctfext33",   CT, ctfext_[33], C_NUM,V_ANAL);
	vardef("_ctfext34",   CT, ctfext_[34], C_NUM,V_ANAL);
	vardef("_ctfext35",   CT, ctfext_[35], C_NUM,V_ANAL);
	vardef("_ctfext36",   CT, ctfext_[36], C_NUM,V_ANAL);
	vardef("_ctfext37",   CT, ctfext_[37], C_NUM,V_ANAL);
	vardef("_ctfext38",   CT, ctfext_[38], C_NUM,V_ANAL);
	vardef("_ctfext39",   CT, ctfext_[39], C_NUM,V_ANAL);
	vardef("_ctfext40",   CT, ctfext_[40], C_NUM,V_ANAL);
	vardef("_ctfext41",   CT, ctfext_[41], C_NUM,V_ANAL);
	vardef("_ctfext42",   CT, ctfext_[42], C_NUM,V_ANAL);
	vardef("_ctfext43",   CT, ctfext_[43], C_NUM,V_ANAL);
	vardef("_ctfext44",   CT, ctfext_[44], C_NUM,V_ANAL);
	vardef("_ctfext45",   CT, ctfext_[45], C_NUM,V_ANAL);
	vardef("_ctfext46",   CT, ctfext_[46], C_NUM,V_ANAL);
	vardef("_ctfext47",   CT, ctfext_[47], C_NUM,V_ANAL);
	vardef("_ctfgst0",    CT, ctfgst_[0],  C_NUM,V_ANAL);
	vardef("_ctfgst1",    CT, ctfgst_[1],  C_NUM,V_ANAL);
	vardef("_ctfgst2",    CT, ctfgst_[2],  C_NUM,V_ANAL);
	vardef("_ctfgst3",    CT, ctfgst_[3],  C_NUM,V_ANAL);
	vardef("_ctfgst4",    CT, ctfgst_[4],  C_NUM,V_ANAL);
	vardef("_ctfgst5",    CT, ctfgst_[5],  C_NUM,V_ANAL);
	vardef("_ctfgst6",    CT, ctfgst_[6],  C_NUM,V_ANAL);
	vardef("_ctfgst7",    CT, ctfgst_[7],  C_NUM,V_ANAL);
	vardef("_ctfgst8",    CT, ctfgst_[8],  C_NUM,V_ANAL);
	vardef("_ctfgst9",    CT, ctfgst_[9],  C_NUM,V_ANAL);
	vardef("_ctfgst10",   CT, ctfgst_[10], C_NUM,V_ANAL);
	vardef("_ctfgst11",   CT, ctfgst_[11], C_NUM,V_ANAL);
	vardef("_ctfgst12",   CT, ctfgst_[12], C_NUM,V_ANAL);
	vardef("_ctfgst13",   CT, ctfgst_[13], C_NUM,V_ANAL);
	vardef("_ctfgst14",   CT, ctfgst_[14], C_NUM,V_ANAL);
	vardef("_ctfgst15",   CT, ctfgst_[15], C_NUM,V_ANAL);
	vardef("_ctfgst16",   CT, ctfgst_[16], C_NUM,V_ANAL);
	vardef("_ctfgst17",   CT, ctfgst_[17], C_NUM,V_ANAL);
	vardef("_ctfgst18",   CT, ctfgst_[18], C_NUM,V_ANAL);
	vardef("_ctfgst19",   CT, ctfgst_[19], C_NUM,V_ANAL);
	vardef("_ctfgst20",   CT, ctfgst_[20], C_NUM,V_ANAL);
	vardef("_ctfgst21",   CT, ctfgst_[21], C_NUM,V_ANAL);
	vardef("_ctfgst22",   CT, ctfgst_[22], C_NUM,V_ANAL);
	vardef("_ctfgst23",   CT, ctfgst_[23], C_NUM,V_ANAL);
	vardef("_ctfgst24",   CT, ctfgst_[24], C_NUM,V_ANAL);
	vardef("_ctfgst25",   CT, ctfgst_[25], C_NUM,V_ANAL);
	vardef("_ctfgst26",   CT, ctfgst_[26], C_NUM,V_ANAL);
	vardef("_ctfgst27",   CT, ctfgst_[27], C_NUM,V_ANAL);
	vardef("_ctfgst28",   CT, ctfgst_[28], C_NUM,V_ANAL);
	vardef("_ctfgst29",   CT, ctfgst_[29], C_NUM,V_ANAL);
	vardef("_ctfgst30",   CT, ctfgst_[30], C_NUM,V_ANAL);
	vardef("_ctfgst31",   CT, ctfgst_[31], C_NUM,V_ANAL);
	vardef("_ctfgst32",   CT, ctfgst_[32], C_NUM,V_ANAL);
	vardef("_ctfgst33",   CT, ctfgst_[33], C_NUM,V_ANAL);
	vardef("_ctfgst34",   CT, ctfgst_[34], C_NUM,V_ANAL);
	vardef("_ctfgst35",   CT, ctfgst_[35], C_NUM,V_ANAL);
	vardef("_ctfgst36",   CT, ctfgst_[36], C_NUM,V_ANAL);
	vardef("_ctfgst37",   CT, ctfgst_[37], C_NUM,V_ANAL);
	vardef("_ctfgst38",   CT, ctfgst_[38], C_NUM,V_ANAL);
	vardef("_ctfgst39",   CT, ctfgst_[39], C_NUM,V_ANAL);
	vardef("_ctfgst40",   CT, ctfgst_[40], C_NUM,V_ANAL);
	vardef("_ctfgst41",   CT, ctfgst_[41], C_NUM,V_ANAL);
	vardef("_ctfgst42",   CT, ctfgst_[42], C_NUM,V_ANAL);
	vardef("_ctfgst43",   CT, ctfgst_[43], C_NUM,V_ANAL);
	vardef("_ctfgst44",   CT, ctfgst_[44], C_NUM,V_ANAL);
	vardef("_ctfgst45",   CT, ctfgst_[45], C_NUM,V_ANAL);
	vardef("_ctfgst46",   CT, ctfgst_[46], C_NUM,V_ANAL);
	vardef("_ctfgst47",   CT, ctfgst_[47], C_NUM,V_ANAL);
	vardef("_ctfnew0",    CT, ctfnew_[0],  C_NUM,V_ANAL);
	vardef("_ctfnew1",    CT, ctfnew_[1],  C_NUM,V_ANAL);
	vardef("_ctfnew2",    CT, ctfnew_[2],  C_NUM,V_ANAL);
	vardef("_ctfnew3",    CT, ctfnew_[3],  C_NUM,V_ANAL);
	vardef("_ctfnew4",    CT, ctfnew_[4],  C_NUM,V_ANAL);
	vardef("_ctfnew5",    CT, ctfnew_[5],  C_NUM,V_ANAL);
	vardef("_ctfnew6",    CT, ctfnew_[6],  C_NUM,V_ANAL);
	vardef("_ctfnew7",    CT, ctfnew_[7],  C_NUM,V_ANAL);
	vardef("_ctfnew8",    CT, ctfnew_[8],  C_NUM,V_ANAL);
	vardef("_ctfnew9",    CT, ctfnew_[9],  C_NUM,V_ANAL);
	vardef("_ctfnew10",   CT, ctfnew_[10], C_NUM,V_ANAL);
	vardef("_ctfnew11",   CT, ctfnew_[11], C_NUM,V_ANAL);
	vardef("_ctfnew12",   CT, ctfnew_[12], C_NUM,V_ANAL);
	vardef("_ctfnew13",   CT, ctfnew_[13], C_NUM,V_ANAL);
	vardef("_ctfnew14",   CT, ctfnew_[14], C_NUM,V_ANAL);
	vardef("_ctfnew15",   CT, ctfnew_[15], C_NUM,V_ANAL);
	vardef("_ctfnew16",   CT, ctfnew_[16], C_NUM,V_ANAL);
	vardef("_ctfnew17",   CT, ctfnew_[17], C_NUM,V_ANAL);
	vardef("_ctfnew18",   CT, ctfnew_[18], C_NUM,V_ANAL);
	vardef("_ctfnew19",   CT, ctfnew_[19], C_NUM,V_ANAL);
	vardef("_ctfnew20",   CT, ctfnew_[20], C_NUM,V_ANAL);
	vardef("_ctfnew21",   CT, ctfnew_[21], C_NUM,V_ANAL);
	vardef("_ctfnew22",   CT, ctfnew_[22], C_NUM,V_ANAL);
	vardef("_ctfnew23",   CT, ctfnew_[23], C_NUM,V_ANAL);
	vardef("_ctfnew24",   CT, ctfnew_[24], C_NUM,V_ANAL);
	vardef("_ctfnew25",   CT, ctfnew_[25], C_NUM,V_ANAL);
	vardef("_ctfnew26",   CT, ctfnew_[26], C_NUM,V_ANAL);
	vardef("_ctfnew27",   CT, ctfnew_[27], C_NUM,V_ANAL);
	vardef("_ctfnew28",   CT, ctfnew_[28], C_NUM,V_ANAL);
	vardef("_ctfnew29",   CT, ctfnew_[29], C_NUM,V_ANAL);
	vardef("_ctfnew30",   CT, ctfnew_[30], C_NUM,V_ANAL);
	vardef("_ctfnew31",   CT, ctfnew_[31], C_NUM,V_ANAL);
	vardef("_ctfnew32",   CT, ctfnew_[32], C_NUM,V_ANAL);
	vardef("_ctfnew33",   CT, ctfnew_[33], C_NUM,V_ANAL);
	vardef("_ctfnew34",   CT, ctfnew_[34], C_NUM,V_ANAL);
	vardef("_ctfnew35",   CT, ctfnew_[35], C_NUM,V_ANAL);
	vardef("_ctfnew36",   CT, ctfnew_[36], C_NUM,V_ANAL);
	vardef("_ctfnew37",   CT, ctfnew_[37], C_NUM,V_ANAL);
	vardef("_ctfnew38",   CT, ctfnew_[38], C_NUM,V_ANAL);
	vardef("_ctfnew39",   CT, ctfnew_[39], C_NUM,V_ANAL);
	vardef("_ctfnew40",   CT, ctfnew_[40], C_NUM,V_ANAL);
	vardef("_ctfnew41",   CT, ctfnew_[41], C_NUM,V_ANAL);
	vardef("_ctfnew42",   CT, ctfnew_[42], C_NUM,V_ANAL);
	vardef("_ctfnew43",   CT, ctfnew_[43], C_NUM,V_ANAL);
	vardef("_ctfnew44",   CT, ctfnew_[44], C_NUM,V_ANAL);
	vardef("_ctfnew45",   CT, ctfnew_[45], C_NUM,V_ANAL);
	vardef("_ctfnew46",   CT, ctfnew_[46], C_NUM,V_ANAL);
	vardef("_ctfnew47",   CT, ctfnew_[47], C_NUM,V_ANAL);
	vardef("_ctplgl",    CT, ctplgl,   C_NUM,V_ANAL);
	vardef("_ctpplq",    CT, ctpplq,   C_NUM,V_ANAL);
	vardef("_ctpgas",    CT, ctpgas,   C_NUM,V_ANAL);
	vardef("_ctpamu",    CT, ctpamu,   C_NUM,V_ANAL);
	vardef("_ctptob",    CT, ctptob,   C_NUM,V_ANAL);
	vardef("_ctprst",    CT, ctprst,   C_NUM,V_ANAL);
	vardef("_ctpnew",    CT, ctpnew,   C_NUM,V_ANAL);
	vardef("_cttxpc",    CT, cttxpc,   C_NUM,V_ANAL);
	vardef("_cttxpc0",    CT, cttxpc_[0],  C_NUM,V_ANAL);
	vardef("_cttxpc1",    CT, cttxpc_[1],  C_NUM,V_ANAL);
	vardef("_cttxpc2",    CT, cttxpc_[2],  C_NUM,V_ANAL);
	vardef("_cttxpc3",    CT, cttxpc_[3],  C_NUM,V_ANAL);
	vardef("_cttxpc4",    CT, cttxpc_[4],  C_NUM,V_ANAL);
	vardef("_cttxpc5",    CT, cttxpc_[5],  C_NUM,V_ANAL);
	vardef("_cttxpc6",    CT, cttxpc_[6],  C_NUM,V_ANAL);
	vardef("_cttxpc7",    CT, cttxpc_[7],  C_NUM,V_ANAL);
	vardef("_cttxpc8",    CT, cttxpc_[8],  C_NUM,V_ANAL);
	vardef("_cttxpc9",    CT, cttxpc_[9],  C_NUM,V_ANAL);
	vardef("_cttxpc10",   CT, cttxpc_[10], C_NUM,V_ANAL);
	vardef("_cttxpc11",   CT, cttxpc_[11], C_NUM,V_ANAL);
	vardef("_cttxpc12",   CT, cttxpc_[12], C_NUM,V_ANAL);
	vardef("_cttxpc13",   CT, cttxpc_[13], C_NUM,V_ANAL);
	vardef("_cttxpc14",   CT, cttxpc_[14], C_NUM,V_ANAL);
	vardef("_cttxpc15",   CT, cttxpc_[15], C_NUM,V_ANAL);
	vardef("_cttxpc16",   CT, cttxpc_[16], C_NUM,V_ANAL);
	vardef("_cttxpc17",   CT, cttxpc_[17], C_NUM,V_ANAL);
	vardef("_cttxpc18",   CT, cttxpc_[18], C_NUM,V_ANAL);
	vardef("_cttxpc19",   CT, cttxpc_[19], C_NUM,V_ANAL);
	vardef("_cttxpc20",   CT, cttxpc_[20], C_NUM,V_ANAL);
	vardef("_cttxpc21",   CT, cttxpc_[21], C_NUM,V_ANAL);
	vardef("_cttxpc22",   CT, cttxpc_[22], C_NUM,V_ANAL);
	vardef("_cttxpc23",   CT, cttxpc_[23], C_NUM,V_ANAL);
	vardef("_cttxpc24",   CT, cttxpc_[24], C_NUM,V_ANAL);
	vardef("_cttxpc25",   CT, cttxpc_[25], C_NUM,V_ANAL);
	vardef("_cttxpc26",   CT, cttxpc_[26], C_NUM,V_ANAL);
	vardef("_cttxpc27",   CT, cttxpc_[27], C_NUM,V_ANAL);
	vardef("_cttxpc28",   CT, cttxpc_[28], C_NUM,V_ANAL);
	vardef("_cttxpc29",   CT, cttxpc_[29], C_NUM,V_ANAL);
	vardef("_cttxpc30",   CT, cttxpc_[30], C_NUM,V_ANAL);
	vardef("_cttxpc31",   CT, cttxpc_[31], C_NUM,V_ANAL);
	vardef("_cttxpc32",   CT, cttxpc_[32], C_NUM,V_ANAL);
	vardef("_cttxpc33",   CT, cttxpc_[33], C_NUM,V_ANAL);
	vardef("_cttxpc34",   CT, cttxpc_[34], C_NUM,V_ANAL);
	vardef("_cttxpc35",   CT, cttxpc_[35], C_NUM,V_ANAL);
	vardef("_cttxpc36",   CT, cttxpc_[36], C_NUM,V_ANAL);
	vardef("_cttxpc37",   CT, cttxpc_[37], C_NUM,V_ANAL);
	vardef("_cttxpc38",   CT, cttxpc_[38], C_NUM,V_ANAL);
	vardef("_cttxpc39",   CT, cttxpc_[39], C_NUM,V_ANAL);
	vardef("_cttxpc40",   CT, cttxpc_[40], C_NUM,V_ANAL);
	vardef("_cttxpc41",   CT, cttxpc_[41], C_NUM,V_ANAL);
	vardef("_cttxpc42",   CT, cttxpc_[42], C_NUM,V_ANAL);
	vardef("_cttxpc43",   CT, cttxpc_[43], C_NUM,V_ANAL);
	vardef("_cttxpc44",   CT, cttxpc_[44], C_NUM,V_ANAL);
	vardef("_cttxpc45",   CT, cttxpc_[45], C_NUM,V_ANAL);
	vardef("_cttxpc46",   CT, cttxpc_[46], C_NUM,V_ANAL);
	vardef("_cttxpc47",   CT, cttxpc_[47], C_NUM,V_ANAL);
	vardef("_ctpgas0",    CT, ctpgas_[0],  C_NUM,V_ANAL);
	vardef("_ctpgas1",    CT, ctpgas_[1],  C_NUM,V_ANAL);
	vardef("_ctpgas2",    CT, ctpgas_[2],  C_NUM,V_ANAL);
	vardef("_ctpgas3",    CT, ctpgas_[3],  C_NUM,V_ANAL);
	vardef("_ctpgas4",    CT, ctpgas_[4],  C_NUM,V_ANAL);
	vardef("_ctpgas5",    CT, ctpgas_[5],  C_NUM,V_ANAL);
	vardef("_ctpgas6",    CT, ctpgas_[6],  C_NUM,V_ANAL);
	vardef("_ctpgas7",    CT, ctpgas_[7],  C_NUM,V_ANAL);
	vardef("_ctpgas8",    CT, ctpgas_[8],  C_NUM,V_ANAL);
	vardef("_ctpgas9",    CT, ctpgas_[9],  C_NUM,V_ANAL);
	vardef("_ctpgas10",   CT, ctpgas_[10], C_NUM,V_ANAL);
	vardef("_ctpgas11",   CT, ctpgas_[11], C_NUM,V_ANAL);
	vardef("_ctpgas12",   CT, ctpgas_[12], C_NUM,V_ANAL);
	vardef("_ctpgas13",   CT, ctpgas_[13], C_NUM,V_ANAL);
	vardef("_ctpgas14",   CT, ctpgas_[14], C_NUM,V_ANAL);
	vardef("_ctpgas15",   CT, ctpgas_[15], C_NUM,V_ANAL);
	vardef("_ctpgas16",   CT, ctpgas_[16], C_NUM,V_ANAL);
	vardef("_ctpgas17",   CT, ctpgas_[17], C_NUM,V_ANAL);
	vardef("_ctpgas18",   CT, ctpgas_[18], C_NUM,V_ANAL);
	vardef("_ctpgas19",   CT, ctpgas_[19], C_NUM,V_ANAL);
	vardef("_ctpgas20",   CT, ctpgas_[20], C_NUM,V_ANAL);
	vardef("_ctpgas21",   CT, ctpgas_[21], C_NUM,V_ANAL);
	vardef("_ctpgas22",   CT, ctpgas_[22], C_NUM,V_ANAL);
	vardef("_ctpgas23",   CT, ctpgas_[23], C_NUM,V_ANAL);
	vardef("_ctpgas24",   CT, ctpgas_[24], C_NUM,V_ANAL);
	vardef("_ctpgas25",   CT, ctpgas_[25], C_NUM,V_ANAL);
	vardef("_ctpgas26",   CT, ctpgas_[26], C_NUM,V_ANAL);
	vardef("_ctpgas27",   CT, ctpgas_[27], C_NUM,V_ANAL);
	vardef("_ctpgas28",   CT, ctpgas_[28], C_NUM,V_ANAL);
	vardef("_ctpgas29",   CT, ctpgas_[29], C_NUM,V_ANAL);
	vardef("_ctpgas30",   CT, ctpgas_[30], C_NUM,V_ANAL);
	vardef("_ctpgas31",   CT, ctpgas_[31], C_NUM,V_ANAL);
	vardef("_ctpgas32",   CT, ctpgas_[32], C_NUM,V_ANAL);
	vardef("_ctpgas33",   CT, ctpgas_[33], C_NUM,V_ANAL);
	vardef("_ctpgas34",   CT, ctpgas_[34], C_NUM,V_ANAL);
	vardef("_ctpgas35",   CT, ctpgas_[35], C_NUM,V_ANAL);
	vardef("_ctpgas36",   CT, ctpgas_[36], C_NUM,V_ANAL);
	vardef("_ctpgas37",   CT, ctpgas_[37], C_NUM,V_ANAL);
	vardef("_ctpgas38",   CT, ctpgas_[38], C_NUM,V_ANAL);
	vardef("_ctpgas39",   CT, ctpgas_[39], C_NUM,V_ANAL);
	vardef("_ctpgas40",   CT, ctpgas_[40], C_NUM,V_ANAL);
	vardef("_ctpgas41",   CT, ctpgas_[41], C_NUM,V_ANAL);
	vardef("_ctpgas42",   CT, ctpgas_[42], C_NUM,V_ANAL);
	vardef("_ctpgas43",   CT, ctpgas_[43], C_NUM,V_ANAL);
	vardef("_ctpgas44",   CT, ctpgas_[44], C_NUM,V_ANAL);
	vardef("_ctpgas45",   CT, ctpgas_[45], C_NUM,V_ANAL);
	vardef("_ctpgas46",   CT, ctpgas_[46], C_NUM,V_ANAL);
	vardef("_ctpgas47",   CT, ctpgas_[47], C_NUM,V_ANAL);
	vardef("_ctprst0",    CT, ctprst_[0],  C_NUM,V_ANAL);
	vardef("_ctprst1",    CT, ctprst_[1],  C_NUM,V_ANAL);
	vardef("_ctprst2",    CT, ctprst_[2],  C_NUM,V_ANAL);
	vardef("_ctprst3",    CT, ctprst_[3],  C_NUM,V_ANAL);
	vardef("_ctprst4",    CT, ctprst_[4],  C_NUM,V_ANAL);
	vardef("_ctprst5",    CT, ctprst_[5],  C_NUM,V_ANAL);
	vardef("_ctprst6",    CT, ctprst_[6],  C_NUM,V_ANAL);
	vardef("_ctprst7",    CT, ctprst_[7],  C_NUM,V_ANAL);
	vardef("_ctprst8",    CT, ctprst_[8],  C_NUM,V_ANAL);
	vardef("_ctprst9",    CT, ctprst_[9],  C_NUM,V_ANAL);
	vardef("_ctprst10",   CT, ctprst_[10], C_NUM,V_ANAL);
	vardef("_ctprst11",   CT, ctprst_[11], C_NUM,V_ANAL);
	vardef("_ctprst12",   CT, ctprst_[12], C_NUM,V_ANAL);
	vardef("_ctprst13",   CT, ctprst_[13], C_NUM,V_ANAL);
	vardef("_ctprst14",   CT, ctprst_[14], C_NUM,V_ANAL);
	vardef("_ctprst15",   CT, ctprst_[15], C_NUM,V_ANAL);
	vardef("_ctprst16",   CT, ctprst_[16], C_NUM,V_ANAL);
	vardef("_ctprst17",   CT, ctprst_[17], C_NUM,V_ANAL);
	vardef("_ctprst18",   CT, ctprst_[18], C_NUM,V_ANAL);
	vardef("_ctprst19",   CT, ctprst_[19], C_NUM,V_ANAL);
	vardef("_ctprst20",   CT, ctprst_[20], C_NUM,V_ANAL);
	vardef("_ctprst21",   CT, ctprst_[21], C_NUM,V_ANAL);
	vardef("_ctprst22",   CT, ctprst_[22], C_NUM,V_ANAL);
	vardef("_ctprst23",   CT, ctprst_[23], C_NUM,V_ANAL);
	vardef("_ctprst24",   CT, ctprst_[24], C_NUM,V_ANAL);
	vardef("_ctprst25",   CT, ctprst_[25], C_NUM,V_ANAL);
	vardef("_ctprst26",   CT, ctprst_[26], C_NUM,V_ANAL);
	vardef("_ctprst27",   CT, ctprst_[27], C_NUM,V_ANAL);
	vardef("_ctprst28",   CT, ctprst_[28], C_NUM,V_ANAL);
	vardef("_ctprst29",   CT, ctprst_[29], C_NUM,V_ANAL);
	vardef("_ctprst30",   CT, ctprst_[30], C_NUM,V_ANAL);
	vardef("_ctprst31",   CT, ctprst_[31], C_NUM,V_ANAL);
	vardef("_ctprst32",   CT, ctprst_[32], C_NUM,V_ANAL);
	vardef("_ctprst33",   CT, ctprst_[33], C_NUM,V_ANAL);
	vardef("_ctprst34",   CT, ctprst_[34], C_NUM,V_ANAL);
	vardef("_ctprst35",   CT, ctprst_[35], C_NUM,V_ANAL);
	vardef("_ctprst36",   CT, ctprst_[36], C_NUM,V_ANAL);
	vardef("_ctprst37",   CT, ctprst_[37], C_NUM,V_ANAL);
	vardef("_ctprst38",   CT, ctprst_[38], C_NUM,V_ANAL);
	vardef("_ctprst39",   CT, ctprst_[39], C_NUM,V_ANAL);
	vardef("_ctprst40",   CT, ctprst_[40], C_NUM,V_ANAL);
	vardef("_ctprst41",   CT, ctprst_[41], C_NUM,V_ANAL);
	vardef("_ctprst42",   CT, ctprst_[42], C_NUM,V_ANAL);
	vardef("_ctprst43",   CT, ctprst_[43], C_NUM,V_ANAL);
	vardef("_ctprst44",   CT, ctprst_[44], C_NUM,V_ANAL);
	vardef("_ctprst45",   CT, ctprst_[45], C_NUM,V_ANAL);
	vardef("_ctprst46",   CT, ctprst_[46], C_NUM,V_ANAL);
	vardef("_ctprst47",   CT, ctprst_[47], C_NUM,V_ANAL);
	vardef("_ctpnew0",    CT, ctpnew_[0],  C_NUM,V_ANAL);
	vardef("_ctpnew1",    CT, ctpnew_[1],  C_NUM,V_ANAL);
	vardef("_ctpnew2",    CT, ctpnew_[2],  C_NUM,V_ANAL);
	vardef("_ctpnew3",    CT, ctpnew_[3],  C_NUM,V_ANAL);
	vardef("_ctpnew4",    CT, ctpnew_[4],  C_NUM,V_ANAL);
	vardef("_ctpnew5",    CT, ctpnew_[5],  C_NUM,V_ANAL);
	vardef("_ctpnew6",    CT, ctpnew_[6],  C_NUM,V_ANAL);
	vardef("_ctpnew7",    CT, ctpnew_[7],  C_NUM,V_ANAL);
	vardef("_ctpnew8",    CT, ctpnew_[8],  C_NUM,V_ANAL);
	vardef("_ctpnew9",    CT, ctpnew_[9],  C_NUM,V_ANAL);
	vardef("_ctpnew10",   CT, ctpnew_[10], C_NUM,V_ANAL);
	vardef("_ctpnew11",   CT, ctpnew_[11], C_NUM,V_ANAL);
	vardef("_ctpnew12",   CT, ctpnew_[12], C_NUM,V_ANAL);
	vardef("_ctpnew13",   CT, ctpnew_[13], C_NUM,V_ANAL);
	vardef("_ctpnew14",   CT, ctpnew_[14], C_NUM,V_ANAL);
	vardef("_ctpnew15",   CT, ctpnew_[15], C_NUM,V_ANAL);
	vardef("_ctpnew16",   CT, ctpnew_[16], C_NUM,V_ANAL);
	vardef("_ctpnew17",   CT, ctpnew_[17], C_NUM,V_ANAL);
	vardef("_ctpnew18",   CT, ctpnew_[18], C_NUM,V_ANAL);
	vardef("_ctpnew19",   CT, ctpnew_[19], C_NUM,V_ANAL);
	vardef("_ctpnew20",   CT, ctpnew_[20], C_NUM,V_ANAL);
	vardef("_ctpnew21",   CT, ctpnew_[21], C_NUM,V_ANAL);
	vardef("_ctpnew22",   CT, ctpnew_[22], C_NUM,V_ANAL);
	vardef("_ctpnew23",   CT, ctpnew_[23], C_NUM,V_ANAL);
	vardef("_ctpnew24",   CT, ctpnew_[24], C_NUM,V_ANAL);
	vardef("_ctpnew25",   CT, ctpnew_[25], C_NUM,V_ANAL);
	vardef("_ctpnew26",   CT, ctpnew_[26], C_NUM,V_ANAL);
	vardef("_ctpnew27",   CT, ctpnew_[27], C_NUM,V_ANAL);
	vardef("_ctpnew28",   CT, ctpnew_[28], C_NUM,V_ANAL);
	vardef("_ctpnew29",   CT, ctpnew_[29], C_NUM,V_ANAL);
	vardef("_ctpnew30",   CT, ctpnew_[30], C_NUM,V_ANAL);
	vardef("_ctpnew31",   CT, ctpnew_[31], C_NUM,V_ANAL);
	vardef("_ctpnew32",   CT, ctpnew_[32], C_NUM,V_ANAL);
	vardef("_ctpnew33",   CT, ctpnew_[33], C_NUM,V_ANAL);
	vardef("_ctpnew34",   CT, ctpnew_[34], C_NUM,V_ANAL);
	vardef("_ctpnew35",   CT, ctpnew_[35], C_NUM,V_ANAL);
	vardef("_ctpnew36",   CT, ctpnew_[36], C_NUM,V_ANAL);
	vardef("_ctpnew37",   CT, ctpnew_[37], C_NUM,V_ANAL);
	vardef("_ctpnew38",   CT, ctpnew_[38], C_NUM,V_ANAL);
	vardef("_ctpnew39",   CT, ctpnew_[39], C_NUM,V_ANAL);
	vardef("_ctpnew40",   CT, ctpnew_[40], C_NUM,V_ANAL);
	vardef("_ctpnew41",   CT, ctpnew_[41], C_NUM,V_ANAL);
	vardef("_ctpnew42",   CT, ctpnew_[42], C_NUM,V_ANAL);
	vardef("_ctpnew43",   CT, ctpnew_[43], C_NUM,V_ANAL);
	vardef("_ctpnew44",   CT, ctpnew_[44], C_NUM,V_ANAL);
	vardef("_ctpnew45",   CT, ctpnew_[45], C_NUM,V_ANAL);
	vardef("_ctpnew46",   CT, ctpnew_[46], C_NUM,V_ANAL);
	vardef("_ctpnew47",   CT, ctpnew_[47], C_NUM,V_ANAL);
	vardef("_ctnexp",    CT, ctnexp,    C_NUM,V_ANAL);
	vardef("_ctnexp0",   CT, ctnexp_[0],  C_NUM,V_ANAL);
	vardef("_ctnexp1",   CT, ctnexp_[1],  C_NUM,V_ANAL);
	vardef("_ctnexp2",   CT, ctnexp_[2],  C_NUM,V_ANAL);
	vardef("_ctnexp3",   CT, ctnexp_[3],  C_NUM,V_ANAL);
	vardef("_ctnexp4",   CT, ctnexp_[4],  C_NUM,V_ANAL);
	vardef("_ctnexp5",   CT, ctnexp_[5],  C_NUM,V_ANAL);
	vardef("_ctnexp6",   CT, ctnexp_[6],  C_NUM,V_ANAL);
	vardef("_ctnexp7",   CT, ctnexp_[7],  C_NUM,V_ANAL);
	vardef("_ctnexp8",   CT, ctnexp_[8],  C_NUM,V_ANAL);
	vardef("_ctnexp9",   CT, ctnexp_[9],  C_NUM,V_ANAL);
	vardef("_ctnexp10",  CT, ctnexp_[10], C_NUM,V_ANAL);
	vardef("_ctnexp11",  CT, ctnexp_[11], C_NUM,V_ANAL);
	vardef("_ctnexp12",  CT, ctnexp_[12], C_NUM,V_ANAL);
	vardef("_ctnexp13",  CT, ctnexp_[13], C_NUM,V_ANAL);
	vardef("_ctnexp14",  CT, ctnexp_[14], C_NUM,V_ANAL);
	vardef("_ctnexp15",  CT, ctnexp_[15], C_NUM,V_ANAL);
	vardef("_ctnexp16",  CT, ctnexp_[16], C_NUM,V_ANAL);
	vardef("_ctnexp17",  CT, ctnexp_[17], C_NUM,V_ANAL);
	vardef("_ctnexp18",  CT, ctnexp_[18], C_NUM,V_ANAL);
	vardef("_ctnexp19",  CT, ctnexp_[19], C_NUM,V_ANAL);
	vardef("_ctnexp20",  CT, ctnexp_[20], C_NUM,V_ANAL);
	vardef("_ctnexp21",  CT, ctnexp_[21], C_NUM,V_ANAL);
	vardef("_ctnexp22",  CT, ctnexp_[22], C_NUM,V_ANAL);
	vardef("_ctnexp23",  CT, ctnexp_[23], C_NUM,V_ANAL);
	vardef("_ctnexp24",  CT, ctnexp_[24], C_NUM,V_ANAL);
	vardef("_ctnexp25",  CT, ctnexp_[25], C_NUM,V_ANAL);
	vardef("_ctnexp26",  CT, ctnexp_[26], C_NUM,V_ANAL);
	vardef("_ctnexp27",  CT, ctnexp_[27], C_NUM,V_ANAL);
	vardef("_ctnexp28",  CT, ctnexp_[28], C_NUM,V_ANAL);
	vardef("_ctnexp29",  CT, ctnexp_[29], C_NUM,V_ANAL);
	vardef("_ctnexp30",  CT, ctnexp_[30], C_NUM,V_ANAL);
	vardef("_ctnexp31",  CT, ctnexp_[31], C_NUM,V_ANAL);
	vardef("_ctnexp32",  CT, ctnexp_[32], C_NUM,V_ANAL);
	vardef("_ctnexp33",  CT, ctnexp_[33], C_NUM,V_ANAL);
	vardef("_ctnexp34",  CT, ctnexp_[34], C_NUM,V_ANAL);
	vardef("_ctnexp35",  CT, ctnexp_[35], C_NUM,V_ANAL);
	vardef("_ctnexp36",  CT, ctnexp_[36], C_NUM,V_ANAL);
	vardef("_ctnexp37",  CT, ctnexp_[37], C_NUM,V_ANAL);
	vardef("_ctnexp38",  CT, ctnexp_[38], C_NUM,V_ANAL);
	vardef("_ctnexp39",  CT, ctnexp_[39], C_NUM,V_ANAL);
	vardef("_ctnexp40",  CT, ctnexp_[40], C_NUM,V_ANAL);
	vardef("_ctnexp41",  CT, ctnexp_[41], C_NUM,V_ANAL);
	vardef("_ctnexp42",  CT, ctnexp_[42], C_NUM,V_ANAL);
	vardef("_ctnexp43",  CT, ctnexp_[43], C_NUM,V_ANAL);
	vardef("_ctnexp44",  CT, ctnexp_[44], C_NUM,V_ANAL);
	vardef("_ctnexp45",  CT, ctnexp_[45], C_NUM,V_ANAL);
	vardef("_ctnexp46",  CT, ctnexp_[46], C_NUM,V_ANAL);
	vardef("_ctnexp47",  CT, ctnexp_[47], C_NUM,V_ANAL);
	vardef("_ctnsna",    CT, ctnsna,    C_NUM,V_ANAL);
	vardef("_ctnsna0",   CT, ctnsna_[0],  C_NUM,V_ANAL);
	vardef("_ctnsna1",   CT, ctnsna_[1],  C_NUM,V_ANAL);
	vardef("_ctnsna2",   CT, ctnsna_[2],  C_NUM,V_ANAL);
	vardef("_ctnsna3",   CT, ctnsna_[3],  C_NUM,V_ANAL);
	vardef("_ctnsna4",   CT, ctnsna_[4],  C_NUM,V_ANAL);
	vardef("_ctnsna5",   CT, ctnsna_[5],  C_NUM,V_ANAL);
	vardef("_ctnsna6",   CT, ctnsna_[6],  C_NUM,V_ANAL);
	vardef("_ctnsna7",   CT, ctnsna_[7],  C_NUM,V_ANAL);
	vardef("_ctnsna8",   CT, ctnsna_[8],  C_NUM,V_ANAL);
	vardef("_ctnsna9",   CT, ctnsna_[9],  C_NUM,V_ANAL);
	vardef("_ctnsna10",  CT, ctnsna_[10], C_NUM,V_ANAL);
	vardef("_ctnsna11",  CT, ctnsna_[11], C_NUM,V_ANAL);
	vardef("_ctnsna12",  CT, ctnsna_[12], C_NUM,V_ANAL);
	vardef("_ctnsna13",  CT, ctnsna_[13], C_NUM,V_ANAL);
	vardef("_ctnsna14",  CT, ctnsna_[14], C_NUM,V_ANAL);
	vardef("_ctnsna15",  CT, ctnsna_[15], C_NUM,V_ANAL);
	vardef("_ctnsna16",  CT, ctnsna_[16], C_NUM,V_ANAL);
	vardef("_ctnsna17",  CT, ctnsna_[17], C_NUM,V_ANAL);
	vardef("_ctnsna18",  CT, ctnsna_[18], C_NUM,V_ANAL);
	vardef("_ctnsna19",  CT, ctnsna_[19], C_NUM,V_ANAL);
	vardef("_ctnsna20",  CT, ctnsna_[20], C_NUM,V_ANAL);
	vardef("_ctnsna21",  CT, ctnsna_[21], C_NUM,V_ANAL);
	vardef("_ctnsna22",  CT, ctnsna_[22], C_NUM,V_ANAL);
	vardef("_ctnsna23",  CT, ctnsna_[23], C_NUM,V_ANAL);
	vardef("_ctnsna24",  CT, ctnsna_[24], C_NUM,V_ANAL);
	vardef("_ctnsna25",  CT, ctnsna_[25], C_NUM,V_ANAL);
	vardef("_ctnsna26",  CT, ctnsna_[26], C_NUM,V_ANAL);
	vardef("_ctnsna27",  CT, ctnsna_[27], C_NUM,V_ANAL);
	vardef("_ctnsna28",  CT, ctnsna_[28], C_NUM,V_ANAL);
	vardef("_ctnsna29",  CT, ctnsna_[29], C_NUM,V_ANAL);
	vardef("_ctnsna30",  CT, ctnsna_[30], C_NUM,V_ANAL);
	vardef("_ctnsna31",  CT, ctnsna_[31], C_NUM,V_ANAL);
	vardef("_ctnsna32",  CT, ctnsna_[32], C_NUM,V_ANAL);
	vardef("_ctnsna33",  CT, ctnsna_[33], C_NUM,V_ANAL);
	vardef("_ctnsna34",  CT, ctnsna_[34], C_NUM,V_ANAL);
	vardef("_ctnsna35",  CT, ctnsna_[35], C_NUM,V_ANAL);
	vardef("_ctnsna36",  CT, ctnsna_[36], C_NUM,V_ANAL);
	vardef("_ctnsna37",  CT, ctnsna_[37], C_NUM,V_ANAL);
	vardef("_ctnsna38",  CT, ctnsna_[38], C_NUM,V_ANAL);
	vardef("_ctnsna39",  CT, ctnsna_[39], C_NUM,V_ANAL);
	vardef("_ctnsna40",  CT, ctnsna_[40], C_NUM,V_ANAL);
	vardef("_ctnsna41",  CT, ctnsna_[41], C_NUM,V_ANAL);
	vardef("_ctnsna42",  CT, ctnsna_[42], C_NUM,V_ANAL);
	vardef("_ctnsna43",  CT, ctnsna_[43], C_NUM,V_ANAL);
	vardef("_ctnsna44",  CT, ctnsna_[44], C_NUM,V_ANAL);
	vardef("_ctnsna45",  CT, ctnsna_[45], C_NUM,V_ANAL);
	vardef("_ctnsna46",  CT, ctnsna_[46], C_NUM,V_ANAL);
	vardef("_ctnsna47",  CT, ctnsna_[47], C_NUM,V_ANAL);
	vardef("_ctnes",     CT, ctnes,    C_NUM,V_ANAL);
	vardef("_ctlprop",   CT, ctlprop,  C_NUM,V_ANAL);
	vardef("_ctsave",    CT, ctsave,   C_NUM,V_ANAL);
	vardef("_ctothmon",  CT, ctothmon, C_NUM,V_ANAL);
	vardef("_ctishrh",   CT, ctishrh,  C_NUM,V_ANAL);
	vardef("_ctdfexp",   CT, ctdfexp,  C_NUM,V_ANAL);

	vardef("_ub1clmwk", IN, im.ub1.ubclmwk, C_INT, V_ANAL);
	vardef("_ub1calwk", IN, im.ub1.ubcalwk, C_INT, V_ANAL);
	vardef("_ub1eiwbp", IN, im.ub1.ubeiwbp, C_INT, V_ANAL);
	vardef("_ub1p1",    IN, im.ub1.ubp1,    C_INT, V_ANAL);
	vardef("_ub1p2",    IN, im.ub1.ubp2,    C_INT, V_ANAL);
	vardef("_ub1p3",    IN, im.ub1.ubp3,    C_INT, V_ANAL);
	vardef("_ub1p4",    IN, im.ub1.ubp4,    C_INT, V_ANAL);
	vardef("_ub1p5",    IN, im.ub1.ubp5,    C_INT, V_ANAL);
	vardef("_ub1p6",    IN, im.ub1.ubp6,    C_INT, V_ANAL);
	vardef("_ub1p1c",   IN, im.ub1.ubp1c,   C_INT, V_ANAL);
	vardef("_ub1p2c",   IN, im.ub1.ubp2c,   C_INT, V_ANAL);
	vardef("_ub1p3c",   IN, im.ub1.ubp3c,   C_INT, V_ANAL);
	vardef("_ub1p4c",   IN, im.ub1.ubp4c,   C_INT, V_ANAL);
	vardef("_ub1p5c",   IN, im.ub1.ubp5c,   C_INT, V_ANAL);
	vardef("_ub1p6c",   IN, im.ub1.ubp6c,   C_INT, V_ANAL);
	vardef("_ub1clmpd", IN, im.ub1.ubclmpd, C_NUM, V_ANAL);
	vardef("_ub1calpd", IN, im.ub1.ubcalpd, C_NUM, V_ANAL);
	vardef("_ub1clmfs", IN, im.ub1.ubclmfs, C_NUM, V_ANAL);
	vardef("_ub1calfs", IN, im.ub1.ubcalfs, C_NUM, V_ANAL);
	vardef("_ub1ern",   IN, im.ub1.ubern,   C_NUM, V_ANAL);

	vardef("_ub2clmwk", IN, im.ub2.ubclmwk, C_INT, V_ANAL);
	vardef("_ub2calwk", IN, im.ub2.ubcalwk, C_INT, V_ANAL);
	vardef("_ub2eiwbp", IN, im.ub2.ubeiwbp, C_INT, V_ANAL);
	vardef("_ub2p1",    IN, im.ub2.ubp1,    C_INT, V_ANAL);
	vardef("_ub2p2",    IN, im.ub2.ubp2,    C_INT, V_ANAL);
	vardef("_ub2p3",    IN, im.ub2.ubp3,    C_INT, V_ANAL);
	vardef("_ub2p4",    IN, im.ub2.ubp4,    C_INT, V_ANAL);
	vardef("_ub2p5",    IN, im.ub2.ubp5,    C_INT, V_ANAL);
	vardef("_ub2p6",    IN, im.ub2.ubp6,    C_INT, V_ANAL);
	vardef("_ub2p1c",   IN, im.ub2.ubp1c,   C_INT, V_ANAL);
	vardef("_ub2p2c",   IN, im.ub2.ubp2c,   C_INT, V_ANAL);
	vardef("_ub2p3c",   IN, im.ub2.ubp3c,   C_INT, V_ANAL);
	vardef("_ub2p4c",   IN, im.ub2.ubp4c,   C_INT, V_ANAL);
	vardef("_ub2p5c",   IN, im.ub2.ubp5c,   C_INT, V_ANAL);
	vardef("_ub2p6c",   IN, im.ub2.ubp6c,   C_INT, V_ANAL);
	vardef("_ub2clmpd", IN, im.ub2.ubclmpd, C_NUM, V_ANAL);
	vardef("_ub2calpd", IN, im.ub2.ubcalpd, C_NUM, V_ANAL);
	vardef("_ub2clmfs", IN, im.ub2.ubclmfs, C_NUM, V_ANAL);
	vardef("_ub2calfs", IN, im.ub2.ubcalfs, C_NUM, V_ANAL);
	vardef("_ub2ern",   IN, im.ub2.ubern,   C_NUM, V_ANAL);

	vardef("_imalexp",  IN, im.imalexp, C_NUM, V_ANAL);
	vardef("_imamtinc", IN, im.imamtinc,C_NUM, V_ANAL);
	vardef("_imamtdf",  IN, im.imamtdf, C_NUM, V_ANAL);
	vardef("_imamtprv", IN, im.imamtprv, C_NUM, V_ANAL);
	vardef("_imashelt", IN, im.imashelt, C_NUM, V_ANAL);
    vardef("_imatpinc", IN, im.imatpinc,C_NUM, V_ANAL);
	vardef("_imatxc",   IN, im.imatxc,  C_NUM, V_ANAL);
	vardef("_imatxcrt", IN, im.imatxcrt,C_NUM, V_ANAL);
	vardef("_imbft",    IN, im.imbft,   C_NUM, V_ANAL);
	vardef("_imbpt",    IN, im.imbpt,   C_NUM, V_ANAL);
	vardef("_imbtc",    IN, im.imbtc,   C_NUM, V_ANAL);
	vardef("_imbtcs",   IN, im.imbtcs,  C_NUM, V_ANAL);
	vardef("_imccea",   IN, im.imccea,  C_NUM, V_ANAL);
	vardef("_imccec",   IN, im.imccec,  C_NUM, V_ANAL);
	vardef("_imcceni",  IN, im.imcceni, C_NUM, V_ANAL);
	vardef("_imccezi",  IN, im.imccezi, C_NUM, V_ANAL);
	vardef("_imcchc",   IN, im.imcchc,  C_NUM, V_ANAL);
	vardef("_imcemc",   IN, im.imcemc,  C_NUM, V_ANAL);
	vardef("_imchara",  IN, im.imchara ,C_NUM, V_ANAL);
	vardef("_imchartc", IN, im.imchartc,C_NUM, V_ANAL);
	vardef("_imchclm",  IN, im.imchclm, C_NUM, V_ANAL);
	vardef("_imcppctc", IN, im.imcppctc,C_NUM, V_ANAL);
	vardef("_imcppse",  IN, im.imcppse, C_NUM, V_ANAL);
	vardef("_imcqppc",  IN, im.imcqppc, C_NUM, V_ANAL);
	vardef("_imctcben" ,IN, im.imctcben,C_NUM, V_ANAL);
	vardef("_imctc",    IN, im.imctc,   C_NUM, V_ANAL);
	vardef("_imctxcrt", IN, im.imctxcrt,C_NUM, V_ANAL);
	vardef("_imctxcs",  IN, im.imctxcs, C_NUM, V_ANAL);
	vardef("_imcapgex", IN, im.imcapgex, C_NUM, V_ANAL);
	vardef("_imdedfn",  IN, im.imdedfn, C_NUM, V_ANAL);
	vardef("_imdedft",  IN, im.imdedft, C_NUM, V_ANAL);
	vardef("_imdepni",  IN, im.imdepni, C_NUM, V_ANAL);
	vardef("_imdisatc", IN, im.imdisatc,C_NUM, V_ANAL);
	vardef("_imedrcv",  IN, im.imedrcv, C_NUM, V_ANAL);
	vardef("_imedtrf",  IN, im.imedtrf, C_NUM, V_ANAL);
	vardef("_imedtxc",  IN, im.imedtxc, C_NUM, V_ANAL);
	vardef("_imemptxc", IN, im.imemptxc,C_NUM, V_ANAL);
	vardef("_imtxttxc", IN, im.imtxttxc,C_NUM, V_ANAL);
	vardef("_imfar",    IN, im.imfar,   C_NUM, V_ANAL);
	vardef("_imfcben",  IN, im.imfcben, C_NUM, V_ANAL);
	vardef("_imfcbenb", IN, im.imfcbenb,C_NUM, V_ANAL);
	vardef("_imfcbene", IN, im.imfcbene,C_NUM, V_ANAL);
	vardef("_imfdtxc",  IN, im.imfdtxc, C_NUM, V_ANAL);
	vardef("_imfedbal", IN, im.imfedbal,C_NUM, V_ANAL);
	vardef("_imfedtax", IN, im.imfedtax,C_NUM, V_ANAL);
	vardef("_imffa",    IN, im.imffa,   C_NUM, V_ANAL);
	vardef("_imfothtr", IN, im.imfothtr,C_NUM, V_ANAL);
	vardef("_imfoth",   IN, im.imfoth,  C_NUM, V_ANAL);
	vardef("_imfptc",   IN, im.imfptc,  C_NUM, V_ANAL);
	vardef("_imfsa",    IN, im.imfsa,   C_NUM, V_ANAL);
	vardef("_imfstc",   IN, im.imfstc,  C_NUM, V_ANAL);
	vardef("_imfsur",   IN, im.imfsur,  C_NUM, V_ANAL);
	vardef("_imfsurtr", IN, im.imfsurtr,  C_NUM, V_ANAL);
	vardef("_imftax",   IN, im.imftax,  C_NUM, V_ANAL);
	vardef("_imfortc",  IN, im.imfortc, C_NUM, V_ANAL);
	vardef("_imftran",  IN, im.imftran, C_NUM, V_ANAL);
	vardef("_imgisinc", IN, im.imgisinc,C_NUM, V_ANAL);
	vardef("_imgismax", IN, im.imgismax,C_NUM, V_ANAL);
	vardef("_imheatrl", IN, im.imheatrl,C_NUM, V_ANAL);
	vardef("_imfecb",   IN, im.imfecb,  C_NUM, V_ANAL);
	vardef("_imiafetc", IN, im.imiafetc,C_NUM, V_ANAL);
	vardef("_imibcfb",  IN, im.imibcfb, C_NUM, V_ANAL);
	vardef("_imibceib", IN, im.imibceib,C_NUM, V_ANAL);
	vardef("_imicapgt", IN, im.imicapgt,C_NUM, V_ANAL);
	vardef("_imicqp",   IN, im.imicqp,  C_NUM, V_ANAL);
	vardef("_imicnet",  IN, im.imicnet, C_NUM, V_ANAL);
	vardef("_imictot",  IN, im.imictot, C_NUM, V_ANAL);
	vardef("_imidivt",  IN, im.imidivt, C_NUM, V_ANAL);
	vardef("_imisdivt", IN, im.imisdivt,C_NUM, V_ANAL);
	vardef("_imildivt", IN, im.imildivt,C_NUM, V_ANAL);
	vardef("_imiemp",   IN, im.imiemp,  C_NUM, V_ANAL);
	vardef("_imiloss",  IN, im.imiloss, C_NUM, V_ANAL);
	vardef("_imintsl",  IN, im.imintsl, C_NUM, V_ANAL);
	vardef("_imiself",  IN, im.imiself, C_NUM, V_ANAL);
	vardef("_imigis",   IN, im.imigis,  C_NUM, V_ANAL);
	vardef("_imigist",  IN, im.imigist, C_NUM, V_ANAL);
	vardef("_imigispa", IN, im.imigispa,C_NUM, V_ANAL);
	vardef("_imiasb",   IN, im.imiasb,  C_NUM, V_ANAL);
	vardef("_iminet",   IN, im.iminet,  C_NUM, V_ANAL);
	vardef("_imioas",   IN, im.imioas,  C_NUM, V_ANAL);
	vardef("_imiosa",   IN, im.imiosa,  C_NUM, V_ANAL);
	vardef("_imfnewpg", IN, im.imfnewpg,C_NUM, V_ANAL);
	vardef("_imiotg",   IN, im.imiotg,  C_NUM, V_ANAL);
	vardef("_imipnst",  IN, im.imipnst, C_NUM, V_ANAL);
	vardef("_iminsda",  IN, im.iminsda, C_NUM, V_ANAL);
	vardef("_imishri",  IN, im.imishri, C_NUM, V_ANAL);
	vardef("_imisa",    IN, im.imisa,   C_NUM, V_ANAL);
	vardef("_imispa",   IN, im.imispa,  C_NUM, V_ANAL);
	vardef("_imitax",   IN, im.imitax,  C_NUM, V_ANAL);
	vardef("_imiotax",  IN, im.imiotax, C_NUM, V_ANAL);
	vardef("_imitot",   IN, im.imitot,  C_NUM, V_ANAL);
	vardef("_imiuib",   IN, im.imiuib,  C_NUM, V_ANAL);
	vardef("_imlabtxc", IN, im.imlabtxc,C_NUM,V_ANAL);
	vardef("_immanltc", IN, im.immanltc,C_NUM,V_ANAL);
	vardef("_immaramt", IN, im.immaramt,C_NUM,V_ANAL);
	vardef("_immartax", IN, im.immartax,C_NUM,V_ANAL);

	/* immartax requires accuracy, so modify precision appropriately */
	vmfind("_immartax")->veprec = 2;
	vmfind("immartax")->veprec = 2;

	vardef("_immartxc", IN, im.immartxc,C_NUM, V_ANAL);
	vardef("_immdisp",  IN, im.immdisp, C_NUM, V_ANAL);
	vardef("_immeda",   IN, im.immeda,  C_NUM, V_ANAL);
	vardef("_immedatc", IN, im.immedatc,C_NUM, V_ANAL);
	vardef("_immedref", IN, im.immedref,C_NUM, V_ANAL);
	vardef("_immemp",   IN, im.immemp,  C_NUM, V_ANAL);
	vardef("_immhmas",  IN, im.immhmas, C_NUM, V_ANAL);
	vardef("_immicons", IN, im.immicons,C_NUM, V_ANAL);
	vardef("_imminamt", IN, im.imminamt,C_NUM, V_ANAL);
	vardef("_imminv",   IN, im.imminv,  C_NUM, V_ANAL);
	vardef("_immmkt",   IN, im.immmkt,  C_NUM, V_ANAL);
	vardef("_immoth",   IN, im.immoth,  C_NUM, V_ANAL);
	vardef("_immtax",   IN, im.immtax,  C_NUM, V_ANAL);
	vardef("_immtot",   IN, im.immtot,  C_NUM, V_ANAL);
	vardef("_immtran",  IN, im.immtran, C_NUM, V_ANAL);
	vardef("_imnfach",  IN, im.imnfach, C_NUM, V_ANAL);
	vardef("_imnettr",  IN, im.imnettr, C_NUM, V_ANAL);
	vardef("_imnmbns",  IN, im.imnmbns, C_NUM, V_ANAL);
	vardef("_imnptc",   IN, im.imnptc,  C_NUM, V_ANAL);
 	vardef("_imnbcbb",  IN, im.imnbcbb, C_NUM, V_ANAL);
	vardef("_imnbwis",  IN, im.imnbwis, C_NUM, V_ANAL);
	vardef("_imnbcben", IN, im.imnbcben,C_NUM, V_ANAL);
	vardef("_imncb",    IN, im.imncb,   C_NUM, V_ANAL);
	vardef("_imnscb",   IN, im.imnscb,  C_NUM, V_ANAL);
	vardef("_imnstxrf", IN, im.imnstxrf,C_NUM, V_ANAL);
	vardef("_imoasr",   IN, im.imoasr,  C_NUM, V_ANAL);
	vardef("_imoasres", IN, im.imoasres,C_NUM, V_ANAL);

	/* imoasres is a fraction, so modify precision appropriately */
	vmfind("_imoasres")->veprec = 4;
	vmfind("imoasres")->veprec = 4;

	vardef("_imoccea",  IN, im.imoccea, C_NUM, V_ANAL);
	vardef("_imoccext", IN, im.imoccext,C_NUM, V_ANAL);
	vardef("_imopstc",  IN, im.imopstc, C_NUM, V_ANAL);
	vardef("_imonteht", IN, im.imonteht,C_NUM, V_ANAL);
	vardef("_imothpe",  IN, im.imothpe, C_NUM, V_ANAL);
	vardef("_imotxdv",  IN, im.imotxdv, C_NUM, V_ANAL);
	vardef("_imfortxc", IN, im.imfortxc,C_NUM, V_ANAL);
	vardef("_imoftca",  IN, im.imoftca, C_NUM, V_ANAL);
 	vardef("_imothrep", IN, im.imothrep,C_NUM, V_ANAL);
    vardef("_impalltc", IN, im.impalltc,C_NUM, V_ANAL);
    vardef("_impatxc",  IN, im.impatxc, C_NUM, V_ANAL);
    vardef("_impatxcr", IN, im.impatxcr,C_NUM, V_ANAL);
    vardef("_impbtc",   IN, im.impbtc,  C_NUM, V_ANAL);
	vardef("_impcgtc",  IN, im.impcgtc, C_NUM, V_ANAL);
    vardef("_impchrtc", IN, im.impchrtc,C_NUM, V_ANAL);
    vardef("_impcpptc", IN, im.impcpptc,C_NUM, V_ANAL);
    vardef("_impctxct", IN, im.impctxct,C_NUM, V_ANAL);
    vardef("_impdistc", IN, im.impdistc,C_NUM, V_ANAL);
	vardef("_impdtxc",  IN, im.impdtxc, C_NUM, V_ANAL);
    vardef("_impedtxc", IN, im.impedtxc,C_NUM, V_ANAL);
    vardef("_impintsl", IN, im.impintsl,C_NUM, V_ANAL);
    vardef("_impeht",   IN, im.impeht,  C_NUM, V_ANAL);
    vardef("_impehtc",  IN, im.impehtc, C_NUM, V_ANAL);
	vardef("_impnsph",  IN, im.impnsph, C_NUM, V_ANAL);
	vardef("_impnsps",  IN, im.impnsps, C_NUM, V_ANAL);
    vardef("_impentxc", IN, im.impentxc,C_NUM, V_ANAL);
    vardef("_impfa",    IN, im.impfa,   C_NUM, V_ANAL);
    vardef("_impfp",    IN, im.impfp,   C_NUM, V_ANAL);
    vardef("_impheatr", IN, im.impheatr,C_NUM, V_ANAL);
    vardef("_imphp",    IN, im.imphp   ,C_NUM, V_ANAL);
    vardef("_implvctc", IN, im.implvctc,C_NUM, V_ANAL);
    vardef("_impmartc", IN, im.impmartc,C_NUM, V_ANAL);
	vardef("_impmeda",  IN, im.impmeda, C_NUM, V_ANAL);
    vardef("_impmedtc", IN, im.impmedtc,C_NUM, V_ANAL);
    vardef("_impminco", IN, im.impminco,C_NUM, V_ANAL);
    vardef("_impnit",   IN, im.impnit,  C_NUM, V_ANAL);
    vardef("_importc",  IN, im.importc, C_NUM, V_ANAL);
    vardef("_impoth",   IN, im.impoth,  C_NUM, V_ANAL);
    vardef("_impothpe", IN, im.impothpe,C_NUM, V_ANAL);
    vardef("_impovinc", IN, im.impovinc,C_NUM, V_ANAL);
    vardef("_imppentc", IN, im.imppentc,C_NUM, V_ANAL);
    vardef("_impptc",   IN, im.impptc,  C_NUM, V_ANAL);
    vardef("_impptg",   IN, im.impptg,  C_NUM, V_ANAL);
    vardef("_impptxtc", IN, im.impptxtc,C_NUM, V_ANAL);
    vardef("_improptx", IN, im.improptx,C_NUM, V_ANAL);
    vardef("_imprvbal", IN, im.imprvbal,C_NUM, V_ANAL);
    vardef("_imprvtax", IN, im.imprvtax,C_NUM, V_ANAL);
    vardef("_impsa",    IN, im.impsa,   C_NUM, V_ANAL);
    vardef("_impstg",   IN, im.impstg,  C_NUM, V_ANAL);
    vardef("_impstxct", IN, im.impstxct,C_NUM, V_ANAL);
    vardef("_impsur",   IN, im.impsur,  C_NUM, V_ANAL);
    vardef("_imptax",   IN, im.imptax,  C_NUM, V_ANAL);
    vardef("_imptaxcr", IN, im.imptaxcr,C_NUM, V_ANAL);
    vardef("_imptc",    IN, im.imptc,   C_NUM, V_ANAL);
    vardef("_imptr",    IN, im.imptr,   C_NUM, V_ANAL);
    vardef("_imptran",  IN, im.imptran, C_NUM, V_ANAL);
    vardef("_impttxct", IN, im.impttxct,C_NUM, V_ANAL);
    vardef("_imptutxc", IN, im.imptutxc,C_NUM, V_ANAL);
    vardef("_impuictc", IN, im.impuictc,C_NUM, V_ANAL);
    vardef("_impyctxc", IN, im.impyctxc,C_NUM, V_ANAL);
	vardef("_imqaafa",  IN, im.imqaafa, C_NUM, V_ANAL);
	vardef("_imqnbfa",  IN, im.imqnbfa, C_NUM, V_ANAL);
	vardef("_imqalexp", IN, im.imqalexp,C_NUM, V_ANAL);
	vardef("_imqatc",   IN, im.imqatc,  C_NUM, V_ANAL);
	vardef("_imqbtc",   IN, im.imqbtc,  C_NUM, V_ANAL);
	vardef("_imqbtax",  IN, im.imqbtax,  C_NUM, V_ANAL);
	vardef("_imqcapgt", IN, im.imqcapgt,C_NUM, V_ANAL);
	vardef("_imqcalr",  IN, im.imqcalr, C_NUM, V_ANAL);
	vardef("_imqcapgx", IN, im.imqcapgx, C_NUM, V_ANAL);
	vardef("_imqccea",  IN, im.imqccea, C_NUM, V_ANAL);
	vardef("_imqcceni", IN, im.imqcceni,C_NUM, V_ANAL);
	vardef("_imqccetc", IN, im.imqccetc,C_NUM, V_ANAL);
	vardef("_imqcchc",  IN, im.imqcchc, C_NUM, V_ANAL);
	vardef("_imqchara", IN, im.imqchara,C_NUM, V_ANAL);
	vardef("_imqchatc",IN, im.imqchatc,C_NUM, V_ANAL);
	vardef("_imqcpptc", IN, im.imqcpptc,C_NUM, V_ANAL);
	vardef("_imqctpc",  IN, im.imqctpc, C_NUM, V_ANAL);
	vardef("_imqdctc",  IN, im.imqdctc, C_NUM, V_ANAL);
	vardef("_imqdedea", IN, im.imqdedea,C_NUM, V_ANAL);
	vardef("_imqdedfn", IN, im.imqdedfn,C_NUM, V_ANAL);
	vardef("_imqdedft", IN, im.imqdedft,C_NUM, V_ANAL);
	vardef("_imqdepni", IN, im.imqdepni,C_NUM, V_ANAL);
	vardef("_imqdistc", IN, im.imqdistc,C_NUM, V_ANAL);
	vardef("_imqdtxc",  IN, im.imqdtxc, C_NUM, V_ANAL);
	vardef("_imqei",    IN, im.imqei,   C_NUM, V_ANAL);
	vardef("_imqempdd", IN, im.imqempdd,C_NUM, V_ANAL);
	vardef("_imqftr",   IN, im.imqftr,  C_NUM, V_ANAL);
	vardef("_imqhsfc",  IN, im.imqhsfc, C_NUM, V_ANAL);
	vardef("_imqhsftc", IN, im.imqhsftc,C_NUM, V_ANAL);
	vardef("_imqidc",   IN, im.imqidc,  C_NUM, V_ANAL);
	vardef("_imqidivt", IN, im.imqidivt,C_NUM, V_ANAL);
	vardef("_imqldivt", IN, im.imqldivt,C_NUM, V_ANAL);
	vardef("_imqsdivt", IN, im.imqsdivt,C_NUM, V_ANAL);
	vardef("_imqiloss", IN, im.imqiloss,C_NUM, V_ANAL);
	vardef("_imqinet",  IN, im.imqinet, C_NUM, V_ANAL);
	vardef("_imqipnst", IN, im.imqipnst,C_NUM, V_ANAL);
	vardef("_imqitax",  IN, im.imqitax, C_NUM, V_ANAL);
	vardef("_imqitot",  IN, im.imqitot, C_NUM, V_ANAL);
	vardef("_imqittr",  IN, im.imqittr, C_NUM, V_ANAL);
	vardef("_imqmeda",  IN, im.imqmeda, C_NUM, V_ANAL);
	vardef("_imqmtc",   IN, im.imqmtc,  C_NUM, V_ANAL);
	vardef("_imqpnsph", IN, im.imqpnsph,C_NUM, V_ANAL);
	vardef("_imqpnsps", IN, im.imqpnsps,C_NUM, V_ANAL);
	vardef("_imqptr",   IN, im.imqptr,  C_NUM, V_ANAL);
	vardef("_imqintsl", IN, im.imqintsl,C_NUM, V_ANAL);
	vardef("_imqstkdd", IN, im.imqstkdd,C_NUM, V_ANAL);
	vardef("_imqstr",   IN, im.imqstr,  C_NUM, V_ANAL);
	vardef("_imqritc",  IN, im.imqritc, C_NUM, V_ANAL);
	vardef("_imqta",    IN, im.imqta,   C_NUM, V_ANAL);
	vardef("_imqtaa",   IN, im.imqtaa,  C_NUM, V_ANAL);
	vardef("_imqtar",   IN, im.imqtar,  C_NUM, V_ANAL);
	vardef("_imqtca",   IN, im.imqtca,  C_NUM, V_ANAL);
	vardef("_imqtct",   IN, im.imqtct,  C_NUM, V_ANAL);
	vardef("_imqtctc",  IN, im.imqtctc, C_NUM, V_ANAL);
	vardef("_imqtcts",  IN, im.imqtcts, C_NUM, V_ANAL);
	vardef("_imqtfa",   IN, im.imqtfa,  C_NUM, V_ANAL);
	vardef("_imqtottc", IN, im.imqtottc,C_NUM, V_ANAL);
	vardef("_imqtpcn",  IN, im.imqtpcn, C_INT, V_ANAL);
	vardef("_imquictc", IN, im.imquictc,C_NUM, V_ANAL);
	vardef("_imqlatc",  IN, im.imqlatc, C_NUM, V_ANAL);
	vardef("_imrentpd", IN, im.imrentpd,C_NUM, V_ANAL);
	vardef("_imrepay",  IN, im.imrepay, C_NUM, V_ANAL);
	vardef("_imresreb", IN, im.imresreb,C_NUM, V_ANAL);
	vardef("_imscb",    IN, im.imscb,   C_NUM, V_ANAL);
	vardef("_imspamax", IN, im.imspamax,C_NUM, V_ANAL);
	vardef("_imssstxc", IN, im.imssstxc,C_NUM, V_ANAL);
	vardef("_imsstc",   IN, im.imsstc,  C_NUM, V_ANAL);
	vardef("_imsctxc",  IN, im.imsctxc, C_NUM, V_ANAL);
	vardef("_imstkded", IN, im.imstkded,C_NUM, V_ANAL);
	vardef("_imstxcrt", IN, im.imstxcrt,C_NUM, V_ANAL);
	vardef("_imtaxcr",  IN, im.imtaxcr, C_NUM, V_ANAL);
	vardef("_imtfa",    IN, im.imtfa,   C_NUM, V_ANAL);
	vardef("_imtutxc",  IN, im.imtutxc, C_NUM, V_ANAL);
	vardef("_imttxcrt", IN, im.imttxcrt,C_NUM, V_ANAL);
	vardef("_imtxf",    IN, im.imtxf,   C_NUM, V_ANAL);
	vardef("_imtxfc",   IN, im.imtxfc,  C_NUM, V_ANAL);
	vardef("_imtxp",    IN, im.imtxp,   C_NUM, V_ANAL);
	vardef("_imtxpc",   IN, im.imtxpc,  C_NUM, V_ANAL);
	vardef("_imuibr",   IN, im.imuibr,  C_NUM, V_ANAL);
	vardef("_imuic",    IN, im.imuic,   C_NUM, V_ANAL);
	vardef("_imuicrf",  IN, im.imuicrf ,C_NUM, V_ANAL);
	vardef("_imuictc",  IN, im.imuictc, C_NUM, V_ANAL);
	vardef("_imqhptc",  IN, im.imqhptc, C_NUM, V_ANAL);
	vardef("_imcgtc",   IN, im.imcgtc,  C_NUM, V_ANAL);
	vardef("_imqduetc", IN, im.imqduetc,C_NUM, V_ANAL);
	vardef("_imqfatc",  IN, im.imqfatc, C_NUM, V_ANAL);
	vardef("_imqamt",   IN, im.imqamt , C_NUM, V_ANAL);
	vardef("_imqtuitc", IN, im.imqtuitc,C_NUM, V_ANAL);
	vardef("_imqtuitt", IN, im.imqtuitt,C_NUM, V_ANAL);
	vardef("_imqapf",   IN, im.imqapf,  C_NUM, V_ANAL);
	vardef("_imqmedrc", IN, im.imqmedrc,C_NUM, V_ANAL);
	vardef("_imqcppse", IN, im.imqcppse,C_NUM, V_ANAL);
	vardef("_imamtfg",  IN, im.imamtfg, C_INT, V_CLAS);
	vardef("_imccez",   IN, im.imccez,  C_INT, V_CLAS);
	vardef("_imfiler",  IN, im.imfiler, C_INT, V_CLAS);
	vardef("_imgistyp", IN, im.imgistyp,C_INT, V_CLAS);
	vardef("_imoaspar", IN, im.imoaspar,C_INT, V_CLAS);
	vardef("_imoldtyp", IN, im.imoldtyp,C_INT, V_CLAS);
	vardef("_imqfs",    IN, im.imqfs,   C_INT, V_CLAS);
	vardef("_imqndc",   IN, im.imqndc,  C_INT, V_CLAS);
	vardef("_imqsfflg", IN, im.imqsfflg,C_INT, V_CLAS);
	vardef("_imspatyp", IN, im.imspatyp,C_INT, V_CLAS);
	vardef("_imuidpfg", IN, im.imuidpfg,C_INT, V_CLAS);
	vardef("_imuiydep", IN, im.imuiydep,C_INT, V_CLAS);
	vardef("_imqamtfg", IN, im.imqamtfg,C_INT, V_CLAS);
	vardef("_imqwrkpr", IN, im.imqwrkpr,C_NUM, V_ANAL);
	vardef("_imqca",    IN, im.imqca,   C_NUM, V_ANAL);
	vardef("_imqncgtc", IN, im.imqncgtc,C_NUM, V_ANAL);
	vardef("_imsaclaw", IN, im.imsaclaw,C_NUM, V_ANAL);
	vardef("_imqpipt",  IN, im.imqpipt, C_INT, V_CLAS);
	vardef("_imqpipcbn",IN, im.imqpipcbn, C_NUM, V_ANAL);
	vardef("_imqpiptbn",IN, im.imqpiptbn, C_NUM, V_ANAL);
	vardef("_imqpipcwk",IN, im.imqpipcwk, C_NUM, V_ANAL);
	vardef("_imqpiptwk",IN, im.imqpiptwk, C_NUM, V_ANAL);
	vardef("_imqpcmtb", IN, im.imqpcmtb,  C_NUM, V_ANAL);
	vardef("_imqpcptb", IN, im.imqpcptb,  C_NUM, V_ANAL);
	vardef("_imqpcprb", IN, im.imqpcprb,  C_NUM, V_ANAL);
	vardef("_imqptmtb", IN, im.imqptmtb,  C_NUM, V_ANAL);
	vardef("_imqptptb", IN, im.imqptptb,  C_NUM, V_ANAL);
	vardef("_imqptprb", IN, im.imqptprb,  C_NUM, V_ANAL);
	vardef("_imqpcmtw", IN, im.imqpcmtw,  C_NUM, V_ANAL);
	vardef("_imqpcptw", IN, im.imqpcptw,  C_NUM, V_ANAL);
	vardef("_imqpcprw", IN, im.imqpcprw,  C_NUM, V_ANAL);
	vardef("_imqptmtw", IN, im.imqptmtw,  C_NUM, V_ANAL);
	vardef("_imqptptw", IN, im.imqptptw,  C_NUM, V_ANAL);
	vardef("_imqptprw", IN, im.imqptprw,  C_NUM, V_ANAL);
	vardef("_imqpipp",  IN, im.imqpipp,   C_NUM, V_ANAL);
	vardef("_imqpippse",IN, im.imqpippse, C_NUM, V_ANAL);
	vardef("_imqpiptc" ,IN, im.imqpiptc,  C_NUM, V_ANAL);
	vardef("_imqpsetc" ,IN, im.imqpsetc,  C_NUM, V_ANAL);
	vardef("_imqpsedd" ,IN, im.imqpsedd,  C_NUM, V_ANAL);
	vardef("_imqqpiptc",IN, im.imqqpiptc, C_NUM, V_ANAL);
	vardef("_imqqpsetc",IN, im.imqqpsetc, C_NUM, V_ANAL);
	vardef("_imqqpsedd",IN, im.imqqpsedd, C_NUM, V_ANAL);
	vardef("_imuccb",   IN, im.imuccb,    C_NUM, V_ANAL);
	vardef("_imbcss",   IN, im.imbcss,    C_NUM, V_ANAL);
	vardef("_imwitb",   IN, im.imwitb,    C_NUM, V_ANAL);
	vardef("_imwitbs",  IN, im.imwitbs,   C_NUM, V_ANAL);
	vardef("_imchdtxc", IN, im.imchdtxc,  C_NUM, V_ANAL);
	vardef("_imocb",    IN, im.imocb,     C_NUM, V_ANAL);
	vardef("_imocbyng", IN, im.imocbyng,  C_NUM, V_ANAL);
	vardef("_immcb",    IN, im.immcb,     C_NUM, V_ANAL);
	DEBUG_OFF("vsdm");
}


